@@ -24,12 +24,13 @@ class UniverseObject;
 class FO_COMMON_API EmpireManager {
 public:
     /// Iterator over Empires
-    typedef std::map<int, Empire*>::iterator iterator; 
+    typedef std::map<int, Empire*>::iterator iterator;
 
     /// Const Iterator over Empires
     typedef std::map<int, Empire*>::const_iterator const_iterator;
 
     /** \name Structors */ //@{
+    EmpireManager();
     virtual ~EmpireManager();
 
     const EmpireManager& operator=(EmpireManager& rhs); ///< assignment operator (move semantics)
@@ -46,6 +47,7 @@ public:
     const_iterator      end() const;
 
     int                 NumEmpires() const;
+    int                 NumEliminatedEmpires() const;
 
     DiplomaticStatus            GetDiplomaticStatus(int empire1, int empire2) const;
     std::set<int>               GetEmpireIDsWithDiplomaticStatusWithEmpire(int empire_id,
@@ -77,7 +79,7 @@ public:
       * caller's responsibility to make sure that universe updates planet
       * ownership. */
     Empire*     CreateEmpire(int empire_id, const std::string& name, const std::string& player_name,
-                             const GG::Clr& color);
+                             const GG::Clr& color, bool authenticated);
 
     /** Removes and deletes all empires from the manager. */
     void        Clear();
@@ -89,8 +91,6 @@ public:
     mutable DiploSignalType DiplomaticMessageChangedSignal;
 
 private:
-    EmpireManager();
-
     std::string DumpDiplomacy() const;
 
     /** Adds the given empire to the manager. */
@@ -106,7 +106,7 @@ private:
     friend class ServerApp;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
