@@ -1,19 +1,24 @@
 #include "ProductionQueue.h"
 
 #include "Empire.h"
-#include "../universe/Building.h"
+#include "../universe/BuildingType.h"
+#include "../universe/Condition.h"
+#include "../universe/ShipHull.h"
+#include "../universe/ShipPart.h"
 #include "../universe/ShipDesign.h"
 #include "../universe/ValueRef.h"
 #include "../util/AppInterface.h"
 #include "../util/GameRules.h"
 #include "../util/ScopedTimer.h"
+#include "../util/i18n.h"
 
 #include <boost/range/numeric.hpp>
 #include <boost/range/adaptor/map.hpp>
+#include <boost/uuid/uuid_io.hpp>
 
 
 namespace {
-    const float EPSILON = 0.01f;
+    const float EPSILON = 0.001f;
 
     void AddRules(GameRules& rules) {
         // limits amount of PP per turn that can be imported into the stockpile
@@ -82,8 +87,8 @@ namespace {
         float additional_pp_to_complete_item = item_cost - element_accumulated_PP;  // additional PP, beyond already-accumulated PP, to produce the current item of this element
         float basic_element_per_turn_limit = item_cost / build_turns;
         // the extra constraints on frontload and topping up amounts ensure that won't let complete in less than build_turns (so long as costs do not decrease)
-        float frontload = (1.0 + frontload_limit_factor/std::max(build_turns-1,1)) *
-            basic_element_per_turn_limit  - 2 * EPSILON;
+        float frontload = (1.0f + frontload_limit_factor/std::max(build_turns-1,1)) *
+            basic_element_per_turn_limit - 2.0f * EPSILON;
         float topping_up_limit = basic_element_per_turn_limit +
             std::min(topping_up_limit_factor * item_cost, basic_element_per_turn_limit - 2 * EPSILON);
         float topping_up = (additional_pp_to_complete_item < topping_up_limit) ?
@@ -197,8 +202,8 @@ namespace {
             // get resource sharing group and amount of resource available to build this item
             const auto& group = queue_element_resource_sharing_object_groups[i];
             auto available_pp_it = available_pp.find(group);
-            float& group_pp_available = (available_pp_it != available_pp.end()) ? 
-                        available_pp_it->second : dummy_pp_source;
+            float& group_pp_available = (available_pp_it != available_pp.end()) ?
+                                        available_pp_it->second : dummy_pp_source;
 
             if ((group_pp_available <= 0) &&
                 (available_stockpile <= 0 || !queue_element.allowed_imperial_stockpile_use))
@@ -313,8 +318,7 @@ namespace {
 }
 
 
-ProductionQueue::ProductionItem::ProductionItem() :
-    build_type(INVALID_BUILD_TYPE)
+ProductionQueue::ProductionItem::ProductionItem()
 {}
 
 ProductionQueue::ProductionItem::ProductionItem(BuildType build_type_) :
@@ -364,12 +368,11 @@ bool ProductionQueue::ProductionItem::EnqueueConditionPassedAt(int location_id)
     switch (build_type) {
     case BT_BUILDING: {
         if (const BuildingType* bt = GetBuildingType(name)) {
-            auto location_obj = GetUniverseObject(location_id);
-            const Condition::ConditionBase* c = bt->EnqueueLocation();
+            auto location_obj = Objects().get(location_id);
+            auto c = bt->EnqueueLocation();
             if (!c)
                 return true;
-            ScriptingContext context(location_obj);
-            return c->Eval(context, location_obj);
+            return c->Eval(ScriptingContext(location_obj), location_obj);
         }
         return true;
         break;
@@ -401,7 +404,7 @@ ProductionQueue::ProductionItem::CompletionSpecialConsumption(int location_id) c
     switch (build_type) {
     case BT_BUILDING: {
         if (const BuildingType* bt = GetBuildingType(name)) {
-            auto location_obj = GetUniverseObject(location_id);
+            auto location_obj = Objects().get(location_id);
             ScriptingContext context(location_obj);
 
             for (const auto& psc : bt->ProductionSpecialConsumption()) {
@@ -427,11 +430,11 @@ ProductionQueue::ProductionItem::CompletionSpecialConsumption(int location_id) c
     }
     case BT_SHIP: {
         if (const ShipDesign* sd = GetShipDesign(design_id)) {
-            auto location_obj = GetUniverseObject(location_id);
+            auto location_obj = Objects().get(location_id);
             ScriptingContext context(location_obj);
 
-            if (const HullType* ht = GetHullType(sd->Hull())) {
-                for (const auto& psc : ht->ProductionSpecialConsumption()) {
+            if (const ShipHull* ship_hull = GetShipHull(sd->Hull())) {
+                for (const auto& psc : ship_hull->ProductionSpecialConsumption()) {
                     if (!psc.second.first)
                         continue;
                     retval[psc.first][location_id] += psc.second.first->Eval(context);
@@ -439,10 +442,10 @@ ProductionQueue::ProductionItem::CompletionSpecialConsumption(int location_id) c
             }
 
             for (const std::string& part_name : sd->Parts()) {
-                const PartType* pt = GetPartType(part_name);
-                if (!pt)
+                const ShipPart* part = GetShipPart(part_name);
+                if (!part)
                     continue;
-                for (const auto& psc : pt->ProductionSpecialConsumption()) {
+                for (const auto& psc : part->ProductionSpecialConsumption()) {
                     if (!psc.second.first)
                         continue;
                     retval[psc.first][location_id] += psc.second.first->Eval(context);
@@ -461,14 +464,13 @@ ProductionQueue::ProductionItem::CompletionSpecialConsumption(int location_id) c
 }
 
 std::map<MeterType, std::map<int, float>>
-ProductionQueue::ProductionItem::CompletionMeterConsumption(int location_id) const
-{
+ProductionQueue::ProductionItem::CompletionMeterConsumption(int location_id) const {
     std::map<MeterType, std::map<int, float>> retval;
 
     switch (build_type) {
     case BT_BUILDING: {
         if (const BuildingType* bt = GetBuildingType(name)) {
-            auto obj = GetUniverseObject(location_id);
+            auto obj = Objects().get(location_id);
             ScriptingContext context(obj);
 
             for (const auto& pmc : bt->ProductionMeterConsumption()) {
@@ -481,11 +483,11 @@ ProductionQueue::ProductionItem::CompletionMeterConsumption(int location_id) con
     }
     case BT_SHIP: {
         if (const ShipDesign* sd = GetShipDesign(design_id)) {
-            auto obj = GetUniverseObject(location_id);
+            auto obj = Objects().get(location_id);
             ScriptingContext context(obj);
 
-            if (const HullType* ht = GetHullType(sd->Hull())) {
-                for (const auto& pmc : ht->ProductionMeterConsumption()) {
+            if (const ShipHull* ship_hull = GetShipHull(sd->Hull())) {
+                for (const auto& pmc : ship_hull->ProductionMeterConsumption()) {
                     if (!pmc.second.first)
                         continue;
                     retval[pmc.first][location_id] += pmc.second.first->Eval(context);
@@ -493,7 +495,7 @@ ProductionQueue::ProductionItem::CompletionMeterConsumption(int location_id) con
             }
 
             for (const std::string& part_name : sd->Parts()) {
-                const PartType* pt = GetPartType(part_name);
+                const ShipPart* pt = GetShipPart(part_name);
                 if (!pt)
                     continue;
                 for (const auto& pmc : pt->ProductionMeterConsumption()) {
@@ -515,11 +517,11 @@ ProductionQueue::ProductionItem::CompletionMeterConsumption(int location_id) con
 }
 
 std::string ProductionQueue::ProductionItem::Dump() const {
-    std::string retval = "ProductionItem: " + boost::lexical_cast<std::string>(build_type) + " ";
+    std::string retval = "ProductionItem: " + boost::lexical_cast<std::string>(build_type);
     if (!name.empty())
-        retval += "name: " + name;
+        retval += " name: " + name;
     if (design_id != INVALID_DESIGN_ID)
-        retval += "id: " + std::to_string(design_id);
+        retval += " id: " + std::to_string(design_id);
     return retval;
 }
 
@@ -527,10 +529,12 @@ std::string ProductionQueue::ProductionItem::Dump() const {
 //////////////////////////////
 // ProductionQueue::Element //
 //////////////////////////////
-ProductionQueue::Element::Element()
+ProductionQueue::Element::Element() :
+     uuid(boost::uuids::nil_generator()())
 {}
 
-ProductionQueue::Element::Element(ProductionItem item_, int empire_id_, int ordered_,
+ProductionQueue::Element::Element(ProductionItem item_, int empire_id_,
+                                  boost::uuids::uuid uuid_, int ordered_,
                                   int remaining_, int blocksize_, int location_, bool paused_,
                                   bool allowed_imperial_stockpile_use_) :
     item(item_),
@@ -541,10 +545,12 @@ ProductionQueue::Element::Element(ProductionItem item_, int empire_id_, int orde
     location(location_),
     blocksize_memory(blocksize_),
     paused(paused_),
-    allowed_imperial_stockpile_use(allowed_imperial_stockpile_use_)
+    allowed_imperial_stockpile_use(allowed_imperial_stockpile_use_),
+    uuid(uuid_)
 {}
 
-ProductionQueue::Element::Element(BuildType build_type, std::string name, int empire_id_, int ordered_,
+ProductionQueue::Element::Element(BuildType build_type, std::string name, int empire_id_,
+                                  boost::uuids::uuid uuid_, int ordered_,
                                   int remaining_, int blocksize_, int location_, bool paused_,
                                   bool allowed_imperial_stockpile_use_) :
     item(build_type, name),
@@ -555,10 +561,12 @@ ProductionQueue::Element::Element(BuildType build_type, std::string name, int em
     location(location_),
     blocksize_memory(blocksize_),
     paused(paused_),
-    allowed_imperial_stockpile_use(allowed_imperial_stockpile_use_)
+    allowed_imperial_stockpile_use(allowed_imperial_stockpile_use_),
+    uuid(uuid_)
 {}
 
-ProductionQueue::Element::Element(BuildType build_type, int design_id, int empire_id_, int ordered_,
+ProductionQueue::Element::Element(BuildType build_type, int design_id, int empire_id_,
+                                  boost::uuids::uuid uuid_, int ordered_,
                                   int remaining_, int blocksize_, int location_, bool paused_,
                                   bool allowed_imperial_stockpile_use_) :
     item(build_type, design_id),
@@ -569,13 +577,14 @@ ProductionQueue::Element::Element(BuildType build_type, int design_id, int empir
     location(location_),
     blocksize_memory(blocksize_),
     paused(paused_),
-    allowed_imperial_stockpile_use(allowed_imperial_stockpile_use_)
+    allowed_imperial_stockpile_use(allowed_imperial_stockpile_use_),
+    uuid(uuid_)
 {}
 
 std::string ProductionQueue::Element::Dump() const {
     std::string retval = "ProductionQueue::Element (" + item.Dump() + ") (" +
         std::to_string(blocksize) + ") x" + std::to_string(ordered) + " ";
-    retval += " (remaining: " + std::to_string(remaining) + ") ";
+    retval += " (remaining: " + std::to_string(remaining) + ")  uuid: " + boost::uuids::to_string(uuid);
     return retval;
 }
 
@@ -584,9 +593,6 @@ std::string ProductionQueue::Element::Dump() const {
 // ProductionQueue //
 /////////////////////
 ProductionQueue::ProductionQueue(int empire_id) :
-    m_projects_in_progress(0),
-    m_expected_new_stockpile_amount(0),
-    m_expected_project_transfer_to_stockpile(0),
     m_empire_id(empire_id)
 {}
 
@@ -686,10 +692,27 @@ ProductionQueue::const_iterator ProductionQueue::find(int i) const
 { return (0 <= i && i < static_cast<int>(size())) ? (begin() + i) : end(); }
 
 const ProductionQueue::Element& ProductionQueue::operator[](int i) const {
-    assert(0 <= i && i < static_cast<int>(m_queue.size()));
+    if (i < 0 || i >= static_cast<int>(m_queue.size()))
+        throw std::out_of_range("Tried to access ProductionQueue element out of bounds");
     return m_queue[i];
 }
 
+ProductionQueue::const_iterator ProductionQueue::find(boost::uuids::uuid uuid) const {
+    if (uuid == boost::uuids::nil_generator()())
+        return m_queue.end();
+    for (auto it = m_queue.begin(); it != m_queue.end(); ++it)
+        if (it->uuid == uuid)
+            return it;
+    return m_queue.end();
+}
+
+int ProductionQueue::IndexOfUUID(boost::uuids::uuid uuid) const {
+    auto it = find(uuid);
+    if (it == end())
+        return -1;
+    return std::distance(begin(), it);
+}
+
 void ProductionQueue::Update() {
     const Empire* empire = GetEmpire(m_empire_id);
     if (!empire) {
@@ -877,23 +900,35 @@ void ProductionQueue::Update() {
     }
     DebugLogger() << "ProductionQueue::Update: Projections took "
                   << ((sim_time_end - sim_time_start).total_microseconds()) << " microseconds with "
-                  << empire->ProductionPoints() << " total Production Points";
+                  << empire->ResourceOutput(RE_INDUSTRY) << " industry output";
     ProductionQueueChangedSignal();
 }
 
-void ProductionQueue::push_back(const Element& element)
-{ m_queue.push_back(element); }
+void ProductionQueue::push_back(const Element& element) {
+    if (find(element.uuid) != end()) {
+        ErrorLogger() << "Trying to push back repeated UUID " << element.uuid;
+        throw std::invalid_argument("Repeated use of UUID");
+    }
+    m_queue.push_back(element);
+}
 
-void ProductionQueue::insert(iterator it, const Element& element)
-{ m_queue.insert(it, element); }
+void ProductionQueue::insert(iterator it, const Element& element) {
+    if (find(element.uuid) != end()) {
+        ErrorLogger() << "Trying to insert repeated UUID " << element.uuid;
+        throw std::invalid_argument("Repeated use of UUID");
+    }
+    m_queue.insert(it, element);
+}
 
 void ProductionQueue::erase(int i) {
-    assert(i <= static_cast<int>(size()));
+    if (i < 0 || i >= static_cast<int>(m_queue.size()))
+        throw std::out_of_range("Tried to erase ProductionQueue item out of bounds.");
     m_queue.erase(begin() + i);
 }
 
 ProductionQueue::iterator ProductionQueue::erase(iterator it) {
-    assert(it != end());
+    if (it == end())
+        throw std::out_of_range("Tried to erase ProductionQueue item out of bounds.");
     return m_queue.erase(it);
 }
 
@@ -907,7 +942,8 @@ ProductionQueue::iterator ProductionQueue::find(int i)
 { return (0 <= i && i < static_cast<int>(size())) ? (begin() + i) : end(); }
 
 ProductionQueue::Element& ProductionQueue::operator[](int i) {
-    assert(0 <= i && i < static_cast<int>(m_queue.size()));
+    if (i < 0 || i >= static_cast<int>(m_queue.size()))
+        throw std::out_of_range("Tried to access ProductionQueue element out of bounds");
     return m_queue[i];
 }
 
