@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -36,16 +36,6 @@ namespace GG {
     /** Calls the appropriate version of glColor*() with \a clr. */
     GG_API void glColor(Clr clr);
 
-    /** Returns the lightened version of color clr.  LightColor leaves the
-        alpha channel unchanged, and multiplies the other channels by some
-        factor.  (The factor is defined within LightColor().) */
-    GG_API Clr LightColor(Clr clr);
-
-    /** Returns the darkened version of color clr.  DarkColor leaves the alpha
-        channel unchanged, and divides the other channels by some factor.
-        (The factor is defined within DarkColor().) */
-    GG_API Clr DarkColor(Clr clr);
-
     /** Returns the "disabled" (grayed) version of color clr.  DisabledColor
         leaves the alpha channel unchanged, and adjusts the other channels in
         the direction of gray (GG_CLR_GRAY) by a factor between 0.0 and 1.0.
@@ -66,6 +56,10 @@ namespace GG {
         There must be an outstanding call to BeginScissorClipping(). */
     GG_API void EndScissorClipping();
 
+    /** Returns the most recently begun and not yet ended scissor clipping
+        region. */
+    GG_API Rect ActiveScissorClippingRegion();
+
     /** Sets up a GL stencil, so that anything inside of the screen region
         defined by points \a inner_ul and \a inner_lr, or outside of the
         screen region defined by points \a outer_ul and \a outer_lr, is
