@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -36,8 +36,9 @@
 #  else
 #   define GG_API __declspec(dllimport)
 #  endif
-# else
-#  define GG_API
+# endif
+# ifdef __GNUC__
+#  define GG_API __attribute__((__visibility__("default")))
 # endif
 #endif
 
