@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2007 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -31,13 +31,11 @@
 
 #include <GG/Exception.h>
 
-#include <boost/utility/enable_if.hpp>
-#include <boost/mpl/assert.hpp>
-
 #include <cassert>
 #include <iosfwd>
 #include <map>
 #include <set>
+#include <type_traits>
 
 
 namespace GG {
@@ -59,8 +57,8 @@ namespace detail {
 
 /** \brief Metafunction predicate that evaluates as true iff \a T is a GG flag
     type, declared by using GG_FLAG_TYPE. */
-template <class T>
-struct is_flag_type : boost::mpl::false_ {};
+template <typename T>
+struct is_flag_type : std::false_type {};
 
 
 /** \brief Defines a new type \a name that is usable as a bit-flag type that
@@ -74,9 +72,9 @@ struct is_flag_type : boost::mpl::false_ {};
     class name;                                                         \
                                                                         \
     template <>                                                         \
-    struct is_flag_type<name> : boost::mpl::true_ {};                   \
+    struct is_flag_type<name> : std::true_type {};                      \
                                                                         \
-    class name                                                          \
+    class GG_API name                                                   \
     {                                                                   \
     public:                                                             \
         name() : m_value(0) {}                                          \
@@ -144,7 +142,7 @@ struct is_flag_type : boost::mpl::false_ {};
     unloaded.  \note All user-instantiated FlagSpecs must provide their own
     implementations of the instance() static function (all the GG-provided
     FlagSpec instantiations provide such implementations already). */
-template <class FlagType>
+template <typename FlagType>
 class GG_API FlagSpec
 {
 public:
@@ -152,7 +150,7 @@ public:
     // it means you probably have tried to use this class with a FlagsType
     // that is not a type generated by GG_FLAG_TYPE.  Use that to generate new
     // flag types.
-    BOOST_MPL_ASSERT((is_flag_type<FlagType>));
+    static_assert(is_flag_type<FlagType>::value, "Using FlagsType without GG_FLAG_TYPE macro");
 
     /** Iterator over all known flags. */
     typedef typename std::set<FlagType>::iterator iterator;
@@ -176,11 +174,11 @@ public:
     /** \name Accessors */ ///@{
     /** Returns true iff FlagSpec contains \a flag. */
     bool contains(FlagType flag) const
-    { return m_flags.count(flag); }
+    { return m_flags.count(flag) != 0; }
     /** Returns true iff \a flag is a "permanent" flag -- a flag used
         internally by the GG library, as opposed to a user-added flag. */
     bool permanent(FlagType flag) const
-    { return m_permanent.count(flag); }
+    { return m_permanent.count(flag) != 0; }
     /** Returns an iterator to \a flag, if flag is in the FlagSpec, or end()
         otherwise. */
     const_iterator find(FlagType flag) const
@@ -259,17 +257,17 @@ private:
 };
 
 
-template <class FlagType>
+template <typename FlagType>
 class Flags;
 
-template <class FlagType>
+template <typename FlagType>
 std::ostream& operator<<(std::ostream& os, Flags<FlagType> flags);
 
 /** \brief A set of flags of the same type.
 
     Individual flags and sets of flags can be passed as parameters and/or be
     stored as member variables in Flags objects. */
-template <class FlagType>
+template <typename FlagType>
 class Flags
 {
 private:
@@ -280,7 +278,7 @@ public:
     // it means you probably have tried to use this class with a FlagsType
     // that is not a type generated by GG_FLAG_TYPE.  Use that to generate new
     // flag types.
-    BOOST_MPL_ASSERT((is_flag_type<FlagType>));
+    static_assert(is_flag_type<FlagType>::value, "Using Flags without GG_FLAG_TYPE macro");
 
     /** \name Exceptions */ ///@{
     /** The base class for Flags exceptions. */
@@ -353,7 +351,7 @@ private:
 };
 
 /** Writes \a flags to \a os in the format "flag1 | flag2 | ... flagn". */
-template <class FlagType>
+template <typename FlagType>
 std::ostream& operator<<(std::ostream& os, Flags<FlagType> flags)
 {
     unsigned int flags_data = flags.m_flags;
@@ -372,7 +370,7 @@ std::ostream& operator<<(std::ostream& os, Flags<FlagType> flags)
 
 /** Returns a Flags object that consists of the bitwise-or of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator|(Flags<FlagType> lhs, Flags<FlagType> rhs)
 {
     Flags<FlagType> retval(lhs);
@@ -382,21 +380,21 @@ Flags<FlagType> operator|(Flags<FlagType> lhs, Flags<FlagType> rhs)
 
 /** Returns a Flags object that consists of the bitwise-or of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator|(Flags<FlagType> lhs, FlagType rhs)
 { return lhs | Flags<FlagType>(rhs); }
 
 /** Returns a Flags object that consists of the bitwise-or of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator|(FlagType lhs, Flags<FlagType> rhs)
 { return Flags<FlagType>(lhs) | rhs; }
 
 /** Returns a Flags object that consists of the bitwise-or of \a lhs and \a
     rhs. */
-template <class FlagType>
-typename boost::enable_if<
-    is_flag_type<FlagType>,
+template <typename FlagType>
+typename std::enable_if<
+    is_flag_type<FlagType>::value,
     Flags<FlagType>
 >::type
 operator|(FlagType lhs, FlagType rhs)
@@ -404,7 +402,7 @@ operator|(FlagType lhs, FlagType rhs)
 
 /** Returns a Flags object that consists of the bitwise-and of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator&(Flags<FlagType> lhs, Flags<FlagType> rhs)
 {
     Flags<FlagType> retval(lhs);
@@ -414,21 +412,21 @@ Flags<FlagType> operator&(Flags<FlagType> lhs, Flags<FlagType> rhs)
 
 /** Returns a Flags object that consists of the bitwise-and of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator&(Flags<FlagType> lhs, FlagType rhs)
 { return lhs & Flags<FlagType>(rhs); }
 
 /** Returns a Flags object that consists of the bitwise-and of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator&(FlagType lhs, Flags<FlagType> rhs)
 { return Flags<FlagType>(lhs) & rhs; }
 
 /** Returns a Flags object that consists of the bitwise-and of \a lhs and \a
     rhs. */
-template <class FlagType>
-typename boost::enable_if<
-    is_flag_type<FlagType>,
+template <typename FlagType>
+typename std::enable_if<
+    is_flag_type<FlagType>::value,
     Flags<FlagType>
 >::type
 operator&(FlagType lhs, FlagType rhs)
@@ -436,7 +434,7 @@ operator&(FlagType lhs, FlagType rhs)
 
 /** Returns a Flags object that consists of the bitwise-xor of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator^(Flags<FlagType> lhs, Flags<FlagType> rhs)
 {
     Flags<FlagType> retval(lhs);
@@ -446,21 +444,21 @@ Flags<FlagType> operator^(Flags<FlagType> lhs, Flags<FlagType> rhs)
 
 /** Returns a Flags object that consists of the bitwise-xor of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator^(Flags<FlagType> lhs, FlagType rhs)
 { return lhs ^ Flags<FlagType>(rhs); }
 
 /** Returns a Flags object that consists of the bitwise-xor of \a lhs and \a
     rhs. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator^(FlagType lhs, Flags<FlagType> rhs)
 { return Flags<FlagType>(lhs) ^ rhs; }
 
 /** Returns a Flags object that consists of the bitwise-xor of \a lhs and \a
     rhs. */
-template <class FlagType>
-typename boost::enable_if<
-    is_flag_type<FlagType>,
+template <typename FlagType>
+typename std::enable_if<
+    is_flag_type<FlagType>::value,
     Flags<FlagType>
 >::type
 operator^(FlagType lhs, FlagType rhs)
@@ -468,7 +466,7 @@ operator^(FlagType lhs, FlagType rhs)
 
 /** Returns a Flags object that consists of all the flags known to
     FlagSpec<FlagType>::instance() except those in \a flags. */
-template <class FlagType>
+template <typename FlagType>
 Flags<FlagType> operator~(Flags<FlagType> flags)
 {
     Flags<FlagType> retval;
@@ -481,9 +479,9 @@ Flags<FlagType> operator~(Flags<FlagType> flags)
 
 /** Returns a Flags object that consists of all the flags known to
     FlagSpec<FlagType>::instance() except \a flag. */
-template <class FlagType>
-typename boost::enable_if<
-    is_flag_type<FlagType>,
+template <typename FlagType>
+typename std::enable_if<
+    is_flag_type<FlagType>::value,
     Flags<FlagType>
 >::type
 operator~(FlagType flag)
