@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -134,7 +134,7 @@ public:
 
         /** \name Structors */ ///@{
         Row();
-        Row(X w, Y h, const std::string& drag_drop_data_type, Alignment align = ALIGN_VCENTER, unsigned int margin = 2);
+        Row(X w, Y h);
         virtual ~Row();
         //@}
 
@@ -159,7 +159,7 @@ public:
         //@}
 
         /** \name Mutators */ ///@{
-        void Render() override;
+        void         Render() override;
 
         void         push_back(std::shared_ptr<Control> c); ///< adds a given Control to the end of the Row; this Control becomes property of the Row
         void         clear(); ///< removes and deletes all cells in this Row
@@ -187,15 +187,14 @@ public:
         void GrowWidthsStretchesAlignmentsTo(std::size_t nn);
         void RClick(const Pt& pt, GG::Flags<GG::ModKey> mod) override;
 
-        std::vector<std::shared_ptr<Control>>  m_cells;          ///< the Controls in this Row (each may be null)
-        Alignment              m_row_alignment;  ///< row alignment; one of ALIGN_TOP, ALIGN_VCENTER, or ALIGN_BOTTOM
-        std::vector<Alignment> m_col_alignments; ///< column alignments; each is one of ALIGN_TOP, ALIGN_VCENTER, or ALIGN_BOTTOM
-        std::vector<X>         m_col_widths;     ///< column widths
-        std::vector<double>    m_col_stretches;  ///< the stretch factor of each column
-        unsigned int           m_margin;         ///< the amount of space left between the contents of adjacent cells, in pixels
-
-        bool                   m_ignore_adjust_layout;
-        bool                   m_is_normalized;
+        std::vector<std::shared_ptr<Control>>   m_cells;                    ///< the Controls in this Row (each may be null)
+        Alignment                               m_row_alignment;            ///< row alignment; one of ALIGN_TOP, ALIGN_VCENTER, or ALIGN_BOTTOM
+        std::vector<Alignment>                  m_col_alignments;           ///< column alignments; each is one of ALIGN_TOP, ALIGN_VCENTER, or ALIGN_BOTTOM
+        std::vector<X>                          m_col_widths;               ///< column widths
+        std::vector<double>                     m_col_stretches;            ///< the stretch factor of each column
+        unsigned int                            m_margin = DEFAULT_MARGIN;  ///< the amount of space left between the contents of adjacent cells, in pixels
+        bool                                    m_ignore_adjust_layout = false;
+        bool                                    m_is_normalized = false;
     };
 
     typedef std::list<std::shared_ptr<Row>>::iterator iterator;
@@ -214,7 +213,8 @@ public:
         bool operator()(const iterator& lhs, const iterator& rhs) const;
     };
 
-    struct IteratorHash : std::unary_function<iterator, std::size_t> {
+    struct IteratorHash
+    {
         std::size_t operator()(const iterator& it) const
         { return boost::hash<const std::shared_ptr<Row>>()(*it); }
     };
@@ -239,9 +239,6 @@ public:
     typedef RowSignalType      AfterInsertRowSignalType;    ///< emitted after a row is inserted into the list box
     typedef RowSignalType      DroppedRowSignalType;        ///< emitted when a row is inserted into the list box via drag-and-drop
     typedef ConstRowSignalType DropRowAcceptableSignalType; ///< emitted when a row may be inserted into the list box via drag-and-drop
-    typedef RowClickSignalType LeftClickedRowSignalType;    ///< emitted when a row in the listbox is left-clicked; provides the row left-clicked and the clicked point
-    typedef RowClickSignalType RightClickedRowSignalType;   ///< emitted when a row in the listbox is right-clicked; provides the row right-clicked and the clicked point
-    typedef RowClickSignalType DoubleClickedRowSignalType;  ///< emitted when a row in the listbox is left-double-clicked
     typedef RowSignalType      BeforeEraseRowSignalType;    ///< emitted when a row in the listbox is erased; provides the deleted Row, and is emitted before the row is removed
     typedef RowSignalType      AfterEraseRowSignalType;     ///< emitted when a row in the listbox is erased; provides the deleted Row, and is emitted after the row is removed
     typedef RowSignalType      BrowsedRowSignalType;        ///< emitted when a row in the listbox is "browsed" (rolled over) by the cursor; provides the browsed row
@@ -308,7 +305,7 @@ public:
 
     /** Returns true iff \p type is allowed to be dropped over this ListBox
         when drag-and-drop is enabled. */
-    bool AllowedDropType(const std::string& type) const;
+    bool            AllowedDropType(const std::string& type) const;
 
     /** Whether the list should autoscroll when the user is attempting to drop
         an item into a location that is not currently visible. */
@@ -323,19 +320,19 @@ public:
     unsigned int    AutoScrollInterval() const;
 
     /** Return true if drops are allowed.*/
-    bool AllowingDrops();
+    bool            AllowingDrops();
 
 
-    mutable ClearedRowsSignalType        ClearedRowsSignal;        /// the cleared signal object for this ListBox
+    mutable ClearedRowsSignalType        ClearedRowsSignal;        ///< the cleared signal object for this ListBox
     mutable BeforeInsertRowSignalType    BeforeInsertRowSignal;    ///< the before insert signal object for this ListBox
     mutable AfterInsertRowSignalType     AfterInsertRowSignal;     ///< the after insert signal object for this ListBox
     mutable SelRowsChangedSignalType     SelRowsChangedSignal;     ///< the selection change signal object for this ListBox
     mutable DroppedRowSignalType         DroppedRowSignal;         ///< the dropped signal object for this ListBox
     mutable DropRowAcceptableSignalType  DropRowAcceptableSignal;  ///< the drop-acceptability signal object for this ListBox
     mutable MovedRowSignalType           MovedRowSignal;           ///< the moved signal object for this ListBox
-    mutable LeftClickedRowSignalType     LeftClickedRowSignal;     ///< the left click signal object for this ListBox
-    mutable RightClickedRowSignalType    RightClickedRowSignal;    ///< the right click signal object for this ListBox
-    mutable DoubleClickedRowSignalType   DoubleClickedRowSignal;   ///< the double click signal object for this ListBox
+    mutable RowClickSignalType           LeftClickedRowSignal;     ///< the left click signal object for this ListBox
+    mutable RowClickSignalType           RightClickedRowSignal;    ///< the right click signal object for this ListBox
+    mutable RowClickSignalType           DoubleClickedRowSignal;   ///< the double click signal object for this ListBox
     mutable BeforeEraseRowSignalType     BeforeEraseRowSignal;     ///< the before erase signal object for this ListBox
     mutable AfterEraseRowSignalType      AfterEraseRowSignal;      ///< the after erase signal object for this ListBox
     mutable BrowsedRowSignalType         BrowsedRowSignal;         ///< the browsed signal object for this ListBox
@@ -378,112 +375,112 @@ public:
         of this ListBox. */
     void Insert(const std::vector<std::shared_ptr<Row>>& rows);
 
-    std::shared_ptr<Row> Erase(iterator it, bool signal = false);        ///< removes and returns the row that \a it points to from the ListBox, or 0 if no such row exists
-    void            Clear();                                        ///< empties the ListBox
-    void            SelectRow(iterator it, bool signal = false);    ///< selects row \a it
-    void            DeselectRow(iterator it, bool signal = false);  ///< deselects row \a it
-    void            SelectAll(bool signal = false);                 ///< selects all rows
-    void            DeselectAll(bool signal = false);               ///< deselects all rows
-    void            SetSelections(const SelectionSet& s,
-                                  bool signal = false);     ///< sets the set of selected rows to \a s
+    std::shared_ptr<Row>Erase(iterator it, bool signal = false);        ///< removes and returns the row that \a it points to from the ListBox, or 0 if no such row exists
 
-    iterator        begin();                                ///< returns an iterator to the first list row
-    iterator        end();                                  ///< returns an iterator to the imaginary row one past the last one
+    void Clear();                                        ///< empties the ListBox
+    void SelectRow(iterator it, bool signal = false);    ///< selects row \a it
+    void DeselectRow(iterator it, bool signal = false);  ///< deselects row \a it
+    void SelectAll(bool signal = false);                 ///< selects all rows
+    void DeselectAll(bool signal = false);               ///< deselects all rows
+    void SetSelections(const SelectionSet& s, bool signal = false);  ///< sets the set of selected rows to \a s
 
-    Row&            GetRow(std::size_t n);                  ///< returns a reference to the Row at row index \a n; not range-checked.  \note This function is O(n).
+    iterator    begin();                                ///< returns an iterator to the first list row
+    iterator    end();                                  ///< returns an iterator to the imaginary row one past the last one
 
-    void            SetCaret(iterator it);                  ///< sets the position of the caret to \a it
-    void            BringRowIntoView(iterator it);          ///< moves the scrollbars so that row \a it is visible
-    void            SetFirstRowShown(iterator it);          ///< moves the scrollbars so that row \a it is the first visible
+    Row& GetRow(std::size_t n);                         ///< returns a reference to the Row at row index \a n; not range-checked.  \note This function is O(n).
+
+    void SetCaret(iterator it);                         ///< sets the position of the caret to \a it
+    void BringRowIntoView(iterator it);                 ///< moves the scrollbars so that row \a it is visible
+    void SetFirstRowShown(iterator it);                 ///< moves the scrollbars so that row \a it is the first visible
 
     /** Sets how much to scroll when scrolled using the mousewheel. */
-    void            SetVScrollWheelIncrement(unsigned int increment);
-    void            SetHScrollWheelIncrement(unsigned int increment);
+    void SetVScrollWheelIncrement(unsigned int increment);
+    void SetHScrollWheelIncrement(unsigned int increment);
 
-    void            SetInteriorColor(Clr c);                ///< sets the color painted into the client area of the control
-    void            SetHiliteColor(Clr c);                  ///< sets the color behind selected line items
+    void SetInteriorColor(Clr c);                       ///< sets the color painted into the client area of the control
+    void SetHiliteColor(Clr c);                         ///< sets the color behind selected line items
 
     /** sets the style flags for the ListBox to \a s. \see GG::ListBoxStyle */
-    void            SetStyle(Flags<ListBoxStyle> s);
+    void SetStyle(Flags<ListBoxStyle> s);
 
-    void            SetColHeaders(const std::shared_ptr<Row>& r);                  ///< sets the row used as headings for the columns; this Row becomes property of the ListBox.
-    void            RemoveColHeaders();                     ///< removes any columns headings set
+    void SetColHeaders(const std::shared_ptr<Row>& r);  ///< sets the row used as headings for the columns; this Row becomes property of the ListBox.
+    void RemoveColHeaders();                            ///< removes any columns headings set
 
-    void            SetColWidth(std::size_t n, X w);        ///< sets the width of column \n to \a w; not range-checked
-    void            SetNumCols(std::size_t n);              ///< sets the number of columns in the ListBox to \a n; if no column widths exist before this call, proportional widths are calulated and set, otherwise no column widths are set
-    void            SetSortCol(std::size_t n);              ///< sets the index of the column used to sort rows when sorting is enabled; not range-checked
+    void SetColWidth(std::size_t n, X w);               ///< sets the width of column \n to \a w; not range-checked
+    void SetNumCols(std::size_t n);                     ///< sets the number of columns in the ListBox to \a n; if no column widths exist before this call, proportional widths are calulated and set, otherwise no column widths are set
+    void SetSortCol(std::size_t n);                     ///< sets the index of the column used to sort rows when sorting is enabled; not range-checked
 
     /** Sets the comparison function used to sort a given pair of Rows during
         row sorting.  Note that \a sort_cmp is assumed to produce an ascending
         order when used to sort; setting the LIST_SORTDESCENDING style can be
         used to produce a reverse sort. */
-    void            SetSortCmp(const boost::function<bool (const Row&, const Row&, std::size_t)>& sort_cmp);
+    void SetSortCmp(const std::function<bool (const Row&, const Row&, std::size_t)>& sort_cmp);
 
     /** Fixes the column widths; by default, an empty ListBox will take on the
         number of columns of its first added row. \note The number of columns
         and their widths may still be set via SetNumCols() and SetColWidth()
         after this function has been called. */
-    void            LockColWidths();
+    void LockColWidths();
 
     /** Allows the number of columns to be determined by the first row added to
         an empty ListBox */
-    void            UnLockColWidths();
+    void UnLockColWidths();
 
     /** Set ListBox to stop managing column widths and alignment.  The number of columns must be
         set with SetColWidth(), but widths of individual rows columns or the header will not be
         managed by ListBox. */
-    void            ManuallyManageColProps();
+    void ManuallyManageColProps();
 
     /** Sets the alignment of column \a n to \a align; not range-checked */
-    void            SetColAlignment(std::size_t n, Alignment align);
+    void SetColAlignment(std::size_t n, Alignment align);
 
     /** Sets the stretch of column \a n to \a stretch; not range-checked */
-    void            SetColStretch(std::size_t n, double stretch);
+    void SetColStretch(std::size_t n, double stretch);
 
     /** Sets the alignment of row \a it to \a align; not range-checked */
-    void            SetRowAlignment(iterator it, Alignment align);
+    void SetRowAlignment(iterator it, Alignment align);
 
     /** Sets whether to normalize rows when inserted (true) or leave them as
       * they are. */
-    void            NormalizeRowsOnInsert(bool enable = true);
+    void NormalizeRowsOnInsert(bool enable = true);
 
     /** Sets the column widths from an exemplar \p row.*/
-    void            DefineColWidths(const Row& row);
+    void DefineColWidths(const Row& row);
 
     /** Sets the column alignments from an exemplar \p row.*/
-    void            DefineColAlignments(const Row& row);
+    void DefineColAlignments(const Row& row);
 
     /** Sets the column alignments from an exemplar \p row.*/
-    void            DefineColStretches(const Row& row);
+    void DefineColStretches(const Row& row);
 
     /** Sets whether to add padding at the end of the scrolls when the ListBox is
      *  bigger than the client area, so that any row can be scrolled all the way to
      *  the top (true), or only use as much space as it needs. */
-    void            AddPaddingAtEnd(bool enable = true);
+    void AddPaddingAtEnd(bool enable = true);
 
     /** Allow drops if \p allow is true.*/
-    void            AllowDrops(bool allow);
+    void AllowDrops(bool allow);
 
     /** Allow all drop types if \p allow is true.*/
-    void            AllowAllDropTypes(bool allow);
+    void AllowAllDropTypes(bool allow);
 
     /** Allows Rows with data type \a str to be dropped over this ListBox when
         drag-and-drop is enabled. \note Passing "" enables all drop types. */
-    void            AllowDropType(const std::string& str);
+    void AllowDropType(const std::string& str);
 
     /** Set this to determine whether the list should autoscroll when the user
         is attempting to drop an item into a location that is not currently
         visible. */
-    void            AutoScrollDuringDragDrops(bool auto_scroll);
+    void AutoScrollDuringDragDrops(bool auto_scroll);
 
     /** Sets the thickness of the area around the border of the client area that
         will provoke an auto-scroll, if AutoScrollDuringDragDrops() returns
         true. */
-    void            SetAutoScrollMargin(unsigned int margin);
+    void SetAutoScrollMargin(unsigned int margin);
 
     /** Sets the number of milliseconds that elapse between row/column scrolls
         when auto-scrolling. */
-    void            SetAutoScrollInterval(unsigned int interval);
+    void SetAutoScrollInterval(unsigned int interval);
     //@}
 
     /** \brief Sorts two Rows of a ListBox using operator<() on the
@@ -491,7 +488,7 @@ public:
 
         If you want to use operator<() with a Row subclass DerivedRow that has
         a custom SortKeyType, use DefaultRowCmp<DerivedRow>. */
-    template <class RowType>
+    template <typename RowType>
     struct DefaultRowCmp
     {
         /** Returns true iff lhs.SortKey( \a column ) < rhs.SortKey( \a column ). */
@@ -541,33 +538,34 @@ protected:
     void Insert(const std::vector<std::shared_ptr<Row>>& rows, iterator it, bool dropped);
 
     std::shared_ptr<Row> Erase(iterator it, bool removing_duplicate, bool signal); ///< erases the row at index \a idx, handling it as a duplicate removal (such as for drag-and-drops within a single ListBox) if indicated
-    void            BringCaretIntoView();           ///< makes sure caret is visible when scrolling occurs due to keystrokes etc.
-    void            ResetAutoScrollVars();          ///< resets all variables related to auto-scroll to their initial values
-    void            Resort();                       ///< performs a full resort of all rows, using the current sort functor.
-    Row&            ColHeaders();                   ///< returns the row containing the headings for the columns, if any.  If undefined, the returned heading Row will have size() 0. non-const for derivers
+    void BringCaretIntoView();  ///< makes sure caret is visible when scrolling occurs due to keystrokes etc.
+    void ResetAutoScrollVars(); ///< resets all variables related to auto-scroll to their initial values
+    void Resort();              ///< performs a full resort of all rows, using the current sort functor.
+    Row& ColHeaders();          ///< returns the row containing the headings for the columns, if any.  If undefined, the returned heading Row will have size() 0. non-const for derivers
     //@}
 
     /** creates, destroys, or resizes scrolls to reflect size of data in listbox. \p force_scroll
         forces the scroll bar to be added.*/
-    void            AdjustScrolls(bool adjust_for_resize, const std::pair<bool, bool>& force_scrolls = {false, false});
+    void AdjustScrolls(bool adjust_for_resize,
+                       const std::pair<bool, bool>& force_scrolls = {false, false});
 
     void DropsAcceptable(DropsAcceptableIter first, DropsAcceptableIter last,
                          const Pt& pt, Flags<ModKey> mod_keys) const override;
-    void            HandleRowRightClicked(const Pt& pt, Flags<ModKey> mod);
+    void HandleRowRightClicked(const Pt& pt, Flags<ModKey> mod);
 
 private:
     /** Show only rows that are within the visible list box area and hide all others.  If
         \p do_prerender is true then prerender the visible rows.  Return true if prerender
         resulted in any visible row changing size. */
-    bool            ShowVisibleRows(bool do_prerender);
-    void            ConnectSignals();
-    void            ValidateStyle();                                        ///< reconciles inconsistencies in the style flags
-    void            VScrolled(int tab_low, int tab_high, int low, int high);///< signals from the vertical scroll bar are caught here
-    void            HScrolled(int tab_low, int tab_high, int low, int high);///< signals from the horizontal scroll bar are caught here
-    void            ClickAtRow(iterator it, Flags<ModKey> mod_keys);        ///< handles to a mouse-click or spacebar-click on \a it, modified by \a keys
-    void            NormalizeRow(Row* row);                                 ///< adjusts a Row so that it has the same number of cells as other rows, and that each cell has the correct width and alignment
-    iterator        FirstRowShownWhenBottomIs(iterator bottom_row); ///< Returns the first row shown when the last row shown is \a bottom_row
-    std::size_t     FirstColShownWhenRightIs(std::size_t right_col, X client_width); ///< Returns the index of the first column shown when the last column shown is \a right_col
+    bool        ShowVisibleRows(bool do_prerender);
+    void        ConnectSignals();
+    void        ValidateStyle();                                        ///< reconciles inconsistencies in the style flags
+    void        VScrolled(int tab_low, int tab_high, int low, int high);///< signals from the vertical scroll bar are caught here
+    void        HScrolled(int tab_low, int tab_high, int low, int high);///< signals from the horizontal scroll bar are caught here
+    void        ClickAtRow(iterator it, Flags<ModKey> mod_keys);        ///< handles to a mouse-click or spacebar-click on \a it, modified by \a keys
+    void        NormalizeRow(Row* row);                                 ///< adjusts a Row so that it has the same number of cells as other rows, and that each cell has the correct width and alignment
+    iterator    FirstRowShownWhenBottomIs(iterator bottom_row);         ///< Returns the first row shown when the last row shown is \a bottom_row
+    std::size_t FirstColShownWhenRightIs(std::size_t right_col, X client_width); ///< Returns the index of the first column shown when the last column shown is \a right_col
 
     struct SelectionCache;
     /** Cache the selected, clicked and last browsed rows.*/
@@ -602,62 +600,60 @@ private:
     /// m_rows is mutable to enable returning end() from const functions in constant time.
     mutable std::list<std::shared_ptr<Row>> m_rows;             ///< line item data
 
-    std::shared_ptr<Scroll>         m_vscroll;          ///< vertical scroll bar on right
-    std::shared_ptr<Scroll>         m_hscroll;          ///< horizontal scroll bar at bottom
-    unsigned int    m_vscroll_wheel_scroll_increment;
-    unsigned int    m_hscroll_wheel_scroll_increment;
+    std::shared_ptr<Scroll> m_vscroll;          ///< vertical scroll bar on right
+    std::shared_ptr<Scroll> m_hscroll;          ///< horizontal scroll bar at bottom
+    unsigned int            m_vscroll_wheel_scroll_increment = 0;
+    unsigned int            m_hscroll_wheel_scroll_increment = 0;
 
     iterator        m_caret;            ///< the item currently selected, or the last item selected by the user 
     SelectionSet    m_selections;       ///< vector of indexes of selected items
     iterator        m_old_sel_row;      ///< used to make sure clicks end on the same row where they started
-    bool            m_old_sel_row_selected; ///< set to true if m_old_sel_row was selected at the point at which it was designated
+    bool            m_old_sel_row_selected = false; ///< set to true if m_old_sel_row was selected at the point at which it was designated
     iterator        m_old_rdown_row;    ///< the row that most recently recieved a right button down message
     iterator        m_lclick_row;       ///< the row most recently left-clicked
     iterator        m_rclick_row;       ///< the row most recently right-clicked
     iterator        m_last_row_browsed; ///< the last row sent out as having been browsed (used to prevent duplicate browse signals)
 
-    GG::Pt          m_first_row_offset; ///< scrolled offset of the first row.
-    iterator        m_first_row_shown;  ///< index of row at top of visible area (always begin() for non-empty ListBox with LIST_NOSCROLL set)
-    std::size_t     m_first_col_shown;  ///< like above, but index of column at left
-    std::size_t     m_num_cols;         ///< the number of columns
+    GG::Pt          m_first_row_offset = {X(BORDER_THICK), Y(BORDER_THICK)};///< scrolled offset of the first row.
+    iterator        m_first_row_shown;      ///< index of row at top of visible area (always begin() for non-empty ListBox with LIST_NOSCROLL set)
+    std::size_t     m_first_col_shown = 0;  ///< like above, but index of column at left
+    std::size_t     m_num_cols = 1;         ///< the number of columns
     std::vector<X>  m_col_widths;       ///< the width of each of the columns goes here
-    std::vector<Alignment>
-                    m_col_alignments;   ///< the horizontal alignment of each of the columns goes here
-    std::vector<double>
-                    m_col_stretches;    ///< the stretch factor of each column
-    unsigned int    m_cell_margin;      ///< the amount of space left between each edge of the cell and its contents, in pixels
 
-    Clr             m_int_color;        ///< color painted into the client area of the control
-    Clr             m_hilite_color;     ///< color behind selected line items
-    Flags<ListBoxStyle>
-                    m_style;            ///< composed of ListBoxStyles enums (see GUIBase.h)
+    std::vector<Alignment>  m_col_alignments;   ///< the horizontal alignment of each of the columns goes here
+    std::vector<double>     m_col_stretches;    ///< the stretch factor of each column
+    unsigned int            m_cell_margin;      ///< the amount of space left between each edge of the cell and its contents, in pixels
 
-    std::shared_ptr<Row>            m_header_row;       ///< row of header text/graphics
-    bool            m_keep_col_widths;  ///< should we keep the column widths, once set?
-    bool            m_clip_cells;       ///< if true, the contents of each cell will be clipped to the visible area of that cell (TODO: currently unused)
-    std::size_t     m_sort_col;         ///< the index of the column data used to sort the list
-    boost::function<bool (const Row&, const Row&, std::size_t)>
-                    m_sort_cmp;         ///< the predicate used to sort the values in the m_sort_col column of two rows
+    Clr                     m_int_color;                ///< color painted into the client area of the control
+    Clr                     m_hilite_color = CLR_SHADOW;///< color behind selected line items
+    Flags<ListBoxStyle>     m_style = LIST_NONE;        ///< composed of ListBoxStyles enums (see GUIBase.h)
 
-    bool            m_allow_drops;      ///< are we accepting drops
+    std::shared_ptr<Row>    m_header_row;               ///< row of header text/graphics
+    bool                    m_keep_col_widths = false;  ///< should we keep the column widths, once set?
+    bool                    m_clip_cells = false;       ///< if true, the contents of each cell will be clipped to the visible area of that cell (TODO: currently unused)
+    std::size_t             m_sort_col = 0;             ///< the index of the column data used to sort the list
+
+    std::function<bool (const Row&, const Row&, std::size_t)>
+                            m_sort_cmp;                 ///< the predicate used to sort the values in the m_sort_col column of two rows
+
+    bool                    m_allow_drops = false;      ///< are we accepting drops
 
     /** Set to boost::none to allow all types.  Otherwise each string is an
         allowed type.*/
     boost::optional<std::unordered_set<std::string>>
-                    m_allowed_drop_types;
+                            m_allowed_drop_types = boost::none;
 
-    bool            m_auto_scroll_during_drag_drops;
-    unsigned int    m_auto_scroll_margin;
-    bool            m_auto_scrolling_up;
-    bool            m_auto_scrolling_down;
-    bool            m_auto_scrolling_left;
-    bool            m_auto_scrolling_right;
-    Timer           m_auto_scroll_timer;
+    bool            m_auto_scroll_during_drag_drops = true;
+    unsigned int    m_auto_scroll_margin = 8;
+    bool            m_auto_scrolling_up = false;
+    bool            m_auto_scrolling_down = false;
+    bool            m_auto_scrolling_left = false;
+    bool            m_auto_scrolling_right = false;
+    Timer           m_auto_scroll_timer{250};
 
-    bool            m_normalize_rows_on_insert;
-    bool            m_manage_column_props;
-
-    bool            m_add_padding_at_end;
+    bool            m_normalize_rows_on_insert = true;
+    bool            m_manage_column_props = true;
+    bool            m_add_padding_at_end = true;
 
     friend class DropDownList; ///< allow complete access to DropDownList, which relies on ListBox to do its rendering
 };
@@ -666,7 +662,7 @@ private:
 
 
 // template implementations
-template <class RowType>
+template <typename RowType>
 bool GG::ListBox::DefaultRowCmp<RowType>::operator()(const GG::ListBox::Row& lhs, const GG::ListBox::Row& rhs, std::size_t column) const
 {
     return static_cast<const RowType&>(lhs).SortKey(column) < static_cast<const RowType&>(rhs).SortKey(column);
