@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -31,7 +31,6 @@
 #define _GG_Spin_h_
 
 #include <GG/Button.h>
-#include <GG/DrawUtil.h>
 #include <GG/Edit.h>
 #include <GG/GUI.h>
 #include <GG/StyleFactory.h>
@@ -45,8 +44,8 @@ namespace GG {
 
 // forward declaration of helper functions and classes
 namespace spin_details {
-    template <class T> T mod(T, T);
-    template <class T> T div(T, T);
+    template <typename T> T mod(T, T);
+    template <typename T> T div(T, T);
 }
 
 
@@ -69,7 +68,7 @@ namespace spin_details {
     at arbitrary sizes, and note that Spin buttons are always H wide by H/2
     tall, where H is the height of the Spin, less the thickness of the Spin's
     border. */
-template <class T>
+template <typename T>
 class Spin : public Control
 {
 public:
@@ -89,20 +88,20 @@ public:
     //@}
 
     /** \name Accessors */ ///@{
-    Pt MinUsableSize() const override;
+    Pt      MinUsableSize() const override;
 
-    T      Value() const;              ///< returns the current value of the control's text
-    T      StepSize() const;           ///< returns the step size of the control
-    T      MinValue() const;           ///< returns the minimum value of the control
-    T      MaxValue() const;           ///< returns the maximum value of the control
-    bool   Editable() const;           ///< returns true if the spinbox can have its value typed in directly
+    T       Value() const;              ///< returns the current value of the control's text
+    T       StepSize() const;           ///< returns the step size of the control
+    T       MinValue() const;           ///< returns the minimum value of the control
+    T       MaxValue() const;           ///< returns the maximum value of the control
+    bool    Editable() const;           ///< returns true if the spinbox can have its value typed in directly
 
-    X      ButtonWidth() const;        ///< returns the width used for the up and down buttons
+    X       ButtonWidth() const;        ///< returns the width used for the up and down buttons
 
-    Clr    TextColor() const;          ///< returns the text color
-    Clr    InteriorColor() const;      ///< returns the the interior color of the control
-    Clr    HiliteColor() const;        ///< returns the color used to render hiliting around selected text
-    Clr    SelectedTextColor() const;  ///< returns the color used to render selected text
+    Clr     TextColor() const;          ///< returns the text color
+    Clr     InteriorColor() const;      ///< returns the the interior color of the control
+    Clr     HiliteColor() const;        ///< returns the color used to render hiliting around selected text
+    Clr     SelectedTextColor() const;  ///< returns the color used to render selected text
 
     mutable ValueChangedSignalType ValueChangedSignal; ///< the value changed signal object for this Spin
     //@}
@@ -126,7 +125,7 @@ public:
     void SetTextColor(Clr c);           ///< sets the text color
     void SetInteriorColor(Clr c);       ///< sets the interior color of the control
     void SetHiliteColor(Clr c);         ///< sets the color used to render hiliting around selected text
-    void SetSelectedTextColor(Clr c);   ///< sets the color used to render selected text   
+    void SetSelectedTextColor(Clr c);   ///< sets the color used to render selected text
     //@}
 
 protected:
@@ -135,9 +134,9 @@ protected:
     enum {BORDER_THICK = 2, PIXEL_MARGIN = 5};
 
     /** \name Accessors */ ///@{
-    Button*     UpButton() const;   ///< returns a pointer to the Button control used as this control's up button
-    Button*     DownButton() const; ///< returns a pointer to the Button control used as this control's down button
-    Edit*       GetEdit() const;    ///< returns a pointer to the Edit control used to render this control's text and accept keyboard input
+    Button* UpButton() const;   ///< returns a pointer to the Button control used as this control's up button
+    Button* DownButton() const; ///< returns a pointer to the Button control used as this control's down button
+    Edit*   GetEdit() const;    ///< returns a pointer to the Edit control used to render this control's text and accept keyboard input
     //@}
 
     /** \name Mutators */ ///@{
@@ -147,7 +146,7 @@ protected:
     virtual void SetEditTextFromValue();
     //@}
 
-    std::shared_ptr<Edit>      m_edit;
+    std::shared_ptr<Edit> m_edit;
 
 private:
     void ConnectSignals();
@@ -163,17 +162,17 @@ private:
 
     bool       m_editable;
 
-    std::shared_ptr<Button>    m_up_button;
-    std::shared_ptr<Button>    m_down_button;
+    std::shared_ptr<Button> m_up_button;
+    std::shared_ptr<Button> m_down_button;
 
-    X          m_button_width;
+    X          m_button_width = GG::X(15);
 
     static void ValueChangedEcho(const T& value);
 };
 
 
 // template implementations
-template<class T>
+template <typename T>
 Spin<T>::Spin(T value, T step, T min, T max, bool edits, const std::shared_ptr<Font>& font, Clr color,
               Clr text_color/* = CLR_BLACK*/) :
     Control(X0, Y0, X1, font->Height() + 2 * PIXEL_MARGIN, INTERACTIVE),
@@ -181,16 +180,12 @@ Spin<T>::Spin(T value, T step, T min, T max, bool edits, const std::shared_ptr<F
     m_step_size(step),
     m_min_value(min),
     m_max_value(max),
-    m_editable(edits),
-    m_edit(nullptr),
-    m_up_button(nullptr),
-    m_down_button(nullptr),
-    m_button_width(15)
+    m_editable(edits)
 {
     const auto& style = GetStyleFactory();
     Control::SetColor(color);
     m_edit = style->NewSpinEdit("", font, CLR_ZERO, text_color, CLR_ZERO);
-    std::shared_ptr<Font> small_font = GUI::GetGUI()->GetFont(font, static_cast<int>(font->PointSize() * 0.75));
+    auto small_font = GUI::GetGUI()->GetFont(font, static_cast<int>(font->PointSize() * 0.75));
     m_up_button = style->NewSpinIncrButton(small_font, color);
     m_down_button = style->NewSpinDecrButton(small_font, color);
 
@@ -198,7 +193,7 @@ Spin<T>::Spin(T value, T step, T min, T max, bool edits, const std::shared_ptr<F
         ValueChangedSignal.connect(&ValueChangedEcho);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::CompleteConstruction()
 {
     const auto& style = GetStyleFactory();
@@ -213,11 +208,11 @@ void Spin<T>::CompleteConstruction()
     Spin<T>::SetEditTextFromValue();
 }
 
-template<class T>
+template <typename T>
 Spin<T>::~Spin()
 {}
 
-template<class T>
+template <typename T>
 Pt Spin<T>::MinUsableSize() const
 {
     Pt edit_min = m_edit->MinUsableSize();
@@ -227,47 +222,47 @@ Pt Spin<T>::MinUsableSize() const
               std::max(up_min.y + down_min.y, edit_min.y) + 2 * BORDER_THICK);
 }
 
-template<class T>
+template <typename T>
 T Spin<T>::Value() const
 { return m_value; }
 
-template<class T>
+template <typename T>
 T Spin<T>::StepSize() const
 { return m_step_size; }
 
-template<class T>
+template <typename T>
 T Spin<T>::MinValue() const
 { return m_min_value; }
 
-template<class T>
+template <typename T>
 T Spin<T>::MaxValue() const
 { return m_max_value; }
 
-template<class T>
-bool Spin<T>::Editable() const 
+template <typename T>
+bool Spin<T>::Editable() const
 { return m_editable; }
 
-template<class T>
+template <typename T>
 X Spin<T>::ButtonWidth() const
 { return m_button_width; }
 
-template<class T>
+template <typename T>
 Clr Spin<T>::TextColor() const
 { return m_edit->TextColor(); }
 
-template<class T>
+template <typename T>
 Clr Spin<T>::InteriorColor() const
 { return m_edit->InteriorColor(); }
 
-template<class T>
+template <typename T>
 Clr Spin<T>::HiliteColor() const
 { return m_edit->HiliteColor(); }
 
-template<class T>
+template <typename T>
 Clr Spin<T>::SelectedTextColor() const
 { return m_edit->SelectedTextColor(); }
 
-template<class T>
+template <typename T>
 void Spin<T>::Render()
 {
     Clr color_to_use = Disabled() ? DisabledColor(Color()) : Color();
@@ -276,7 +271,7 @@ void Spin<T>::Render()
     BeveledRectangle(ul, lr, int_color_to_use, color_to_use, false, BORDER_THICK);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::SizeMove(const Pt& ul, const Pt& lr)
 {
     Wnd::SizeMove(ul, lr);
@@ -289,7 +284,7 @@ void Spin<T>::SizeMove(const Pt& ul, const Pt& lr)
                             Pt(BUTTON_X_POS + m_button_width, BORDER_THICK + BUTTONS_HEIGHT));
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::Disable(bool b/* = true*/)
 {
     Control::Disable(b);
@@ -298,7 +293,7 @@ void Spin<T>::Disable(bool b/* = true*/)
     m_down_button->Disable(b);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetColor(Clr c)
 {
     Control::SetColor(c);
@@ -306,26 +301,26 @@ void Spin<T>::SetColor(Clr c)
     m_down_button->SetColor(c);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::Incr()
 { SetValueImpl(m_value + m_step_size, false); }
 
-template<class T>
+template <typename T>
 void Spin<T>::Decr()
 { SetValueImpl(m_value - m_step_size, false); }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetValue(T value)
 { SetValueImpl(value, false); }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetStepSize(T step)
 {
     m_step_size = step;
     SetValue(m_value);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetMinValue(T value)
 {
     m_min_value = value;
@@ -333,7 +328,7 @@ void Spin<T>::SetMinValue(T value)
         SetValue(m_min_value);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetMaxValue(T value)
 {
     m_max_value = value;
@@ -341,11 +336,11 @@ void Spin<T>::SetMaxValue(T value)
         SetValue(m_max_value);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetTextColor(Clr c)
 { m_edit->SetTextColor(c); }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetButtonWidth(X width)
 {
     if (1 <= width) {
@@ -356,33 +351,38 @@ void Spin<T>::SetButtonWidth(X width)
     }
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetInteriorColor(Clr c)
 { m_edit->SetInteriorColor(c); }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetHiliteColor(Clr c)
 { m_edit->SetHiliteColor(c); }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetSelectedTextColor(Clr c)
 { m_edit->SetSelectedTextColor(c); }
 
-template<class T>
+template <typename T>
 Button* Spin<T>::UpButton() const
 { return m_up_button.get(); }
 
-template<class T>
+template <typename T>
 Button* Spin<T>::DownButton() const
 { return m_down_button.get(); }
 
-template<class T>
+template <typename T>
 Edit* Spin<T>::GetEdit() const
 { return m_edit.get(); }
 
-template<class T>
+template <typename T>
 void Spin<T>::KeyPress(Key key, std::uint32_t key_code_point, Flags<ModKey> mod_keys)
 {
+    if (Disabled()) {
+        Control::KeyPress(key, key_code_point, mod_keys);
+        return;
+    }
+
     switch (key) {
     case GGK_HOME:
         SetValueImpl(m_min_value, true);
@@ -392,13 +392,11 @@ void Spin<T>::KeyPress(Key key, std::uint32_t key_code_point, Flags<ModKey> mod_
         break;
     case GGK_PAGEUP:
     case GGK_UP:
-    case GGK_PLUS:
     case GGK_KP_PLUS:
         IncrImpl(true);
         break;
     case GGK_PAGEDOWN:
     case GGK_DOWN:
-    case GGK_MINUS:
     case GGK_KP_MINUS:
         DecrImpl(true);
         break;
@@ -407,18 +405,21 @@ void Spin<T>::KeyPress(Key key, std::uint32_t key_code_point, Flags<ModKey> mod_
     }
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::MouseWheel(const Pt& pt, int move, Flags<ModKey> mod_keys)
 {
-    for (int i = 0; i < move; ++i) {
+    if (Disabled()) {
+        Control::MouseWheel(pt, move, mod_keys);
+        return;
+    }
+
+    for (int i = 0; i < move; ++i)
         IncrImpl(true);
-    }
-    for (int i = 0; i < -move; ++i) {
+    for (int i = 0; i < -move; ++i)
         DecrImpl(true);
-    }
 }
 
-template<class T>
+template <typename T>
 bool Spin<T>::EventFilter(Wnd* w, const WndEvent& event)
 {
     if (w == m_edit.get()) {
@@ -432,25 +433,26 @@ bool Spin<T>::EventFilter(Wnd* w, const WndEvent& event)
     return false;
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetEditTextFromValue()
 {
     if (m_edit)
         m_edit->SetText(std::to_string(m_value));
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::ConnectSignals()
 {
-    m_edit->FocusUpdateSignal.connect(
-        boost::bind(&Spin::ValueUpdated, this, _1));
-    m_up_button->LeftClickedSignal.connect(
-        boost::bind(&Spin::IncrImpl, this, true));
-    m_down_button->LeftClickedSignal.connect(
-        boost::bind(&Spin::DecrImpl, this, true));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+#endif
+
+    m_edit->FocusUpdateSignal.connect(boost::bind(&Spin::ValueUpdated, this, _1));
+    m_up_button->LeftClickedSignal.connect(boost::bind(&Spin::IncrImpl, this, true));
+    m_down_button->LeftClickedSignal.connect(boost::bind(&Spin::DecrImpl, this, true));
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::ValueUpdated(const std::string& val_text)
 {
     T value;
@@ -463,15 +465,15 @@ void Spin<T>::ValueUpdated(const std::string& val_text)
     SetValueImpl(value, true);
 }
 
-template<class T>
+template <typename T>
 void Spin<T>::IncrImpl(bool signal)
 { SetValueImpl(static_cast<T>(m_value + m_step_size), signal); }
 
-template<class T>
+template <typename T>
 void Spin<T>::DecrImpl(bool signal)
 { SetValueImpl(static_cast<T>(m_value - m_step_size), signal); }
 
-template<class T>
+template <typename T>
 void Spin<T>::SetValueImpl(T value, bool signal)
 {
     //std::cout << "Spin<T>::SetValueImpl(" << value << ", " << signal << ")" << std::endl;
@@ -506,34 +508,34 @@ void Spin<T>::SetValueImpl(T value, bool signal)
         ValueChangedSignal(m_value);
 }
 
-template <class T>
+template <typename T>
 void Spin<T>::ValueChangedEcho(const T& value)
 { std::cerr << "GG SIGNAL : Spin<>::ValueChangedSignal(value=" << value << ")\n"; }
 
 
 namespace spin_details {
     // provides a typesafe mod function
-    template <class T> inline 
-    T mod (T dividend, T divisor) {return static_cast<T>(dividend % divisor);}
+    template <typename T>
+    inline T mod (T dividend, T divisor) {return static_cast<T>(dividend % divisor);}
 
     // template specializations
-    template <> inline 
+    template <> inline
     float mod<float> (float dividend, float divisor) {return std::fmod(dividend, divisor);}
-    template <> inline 
+    template <> inline
     double mod<double> (double dividend, double divisor) {return std::fmod(dividend, divisor);}
-    template <> inline 
+    template <> inline
     long double mod<long double> (long double dividend, long double divisor) {return std::fmod(dividend, divisor);}
 
     // provides a typesafe div function
-    template <class T> inline 
-    T div (T dividend, T divisor) {return static_cast<T>(dividend / divisor);}
+    template <typename T>
+    inline T div (T dividend, T divisor) {return static_cast<T>(dividend / divisor);}
 
     // template specializations
-    template <> inline 
+    template <> inline
     float div<float> (float dividend, float divisor) {return std::floor(dividend / divisor);}
-    template <> inline 
+    template <> inline
     double div<double> (double dividend, double divisor) {return std::floor(dividend / divisor);}
-    template <> inline 
+    template <> inline
     long double div<long double> (long double dividend, long double divisor) {return std::floor(dividend / divisor);}
 } // namespace spin_details
 
