@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -108,15 +108,6 @@ public:
     void Init(X width, Y height, const unsigned char* image, GLenum format, GLenum type,
               unsigned bytes_per_pixel, bool mipmap = false);
 
-    /** Frees any currently-held memory and creates a texture from subarea of
-        supplied array \a image.  \throw GG::Texture::Exception Throws
-        applicable subclass if the texture creation fails in one of the
-        specified ways. */
-    void Init(X x, Y y, X width, Y height, X image_width,
-              const unsigned char* image, GLenum format, GLenum type,
-              unsigned int bytes_per_pixel, bool mipmap = false);
-
-    void SetWrap(GLenum s, GLenum t);         ///< sets the opengl texture wrap modes associated with opengl texture m_opengl_id
     void SetFilters(GLenum min, GLenum mag);  ///< sets the opengl min/mag filter modes associated with opengl texture m_opengl_id
     void Clear();  ///< frees the opengl texture object associated with this object
     //@}
@@ -144,22 +135,24 @@ private:
 
     boost::filesystem::path m_path;     ///< file path from which this Texture was constructed
 
-    unsigned int m_bytes_pp;
-    X            m_width;
-    Y            m_height;
+    unsigned int m_bytes_pp = 0;
+    X            m_width = GG::X0;
+    Y            m_height = GG::Y0;
 
-    GLenum       m_wrap_s, m_wrap_t;
-    GLenum       m_min_filter, m_mag_filter;
+    GLenum       m_wrap_s = GL_REPEAT;
+    GLenum       m_wrap_t = GL_REPEAT;
+    GLenum       m_min_filter = GL_LINEAR_MIPMAP_LINEAR;
+    GLenum       m_mag_filter = GL_LINEAR;
 
-    bool         m_mipmaps;
-    GLuint       m_opengl_id;   ///< OpenGL texture ID
-    GLenum       m_format;
-    GLenum       m_type;
+    bool         m_mipmaps = false;
+    GLuint       m_opengl_id = 0;   ///< OpenGL texture ID
+    GLenum       m_format = GL_INVALID_ENUM;
+    GLenum       m_type = GL_INVALID_ENUM;
 
     /// each of these is used for a non-power-of-two-sized graphic loaded into a power-of-two-sized texture
-    GLfloat      m_tex_coords[4];  ///< the texture coords used to blit from this texture by default (reflecting original image width and height)
-    X            m_default_width;  ///< the original width and height of this texture to be used in blitting 
-    Y            m_default_height;
+    GLfloat      m_tex_coords[4] = {0.0f, 0.0f, 0.0f, 0.0f};    ///< the texture coords used to blit from this texture by default (reflecting original image width and height)
+    X            m_default_width = GG::X0;                      ///< the original width and height of this texture to be used in blitting 
+    Y            m_default_height = GG::Y0;
 };
 
 /** \brief This class is a convenient way to store the info needed to use a
@@ -204,6 +197,10 @@ public:
     void OrthoBlit(const Pt& pt) const;
     //@}
 
+    /** \name Mutators */ ///@{
+    void Clear();
+    //@}
+
     /** \name Exceptions */ ///@{
     /** The base class for SubTexture exceptions. */
     GG_ABSTRACT_EXCEPTION(Exception);
@@ -219,10 +216,10 @@ public:
 
 private:
     /** shared_ptr to texture object with entire image. */
-    std::shared_ptr<const Texture> m_texture;
-    X                                m_width;
-    Y                                m_height;
-    GLfloat                          m_tex_coords[4];  ///< position of element within containing texture 
+    std::shared_ptr<const Texture>  m_texture;
+    X                               m_width;
+    Y                               m_height;
+    GLfloat                         m_tex_coords[4];    ///< position of element within containing texture 
 };
 
 /** \brief A singleton that loads and stores textures for use by GG.
@@ -261,21 +258,18 @@ public:
     /** Removes the manager's shared_ptr to the texture created from image
         file \a path, if it exists.  \note Due to shared_ptr semantics, the
         texture may not be deleted until much later. */
-    void                       FreeTexture(const boost::filesystem::path& path);
+    void                     FreeTexture(const boost::filesystem::path& path);
 
     /** Removes the manager's shared_ptr to the texture stored with the name
         \a name, if it exists.  \note Due to shared_ptr semantics, the
         texture may not be deleted until much later. */
-    void                       FreeTexture(const std::string& name);
+    void                     FreeTexture(const std::string& name);
     //@}
 
 private:
     TextureManager();
     std::shared_ptr<Texture> LoadTexture(const boost::filesystem::path& path, bool mipmap);
 
-    static bool s_created;
-    static bool s_il_initialized;
-
     /** Indexed by string, not path, because some textures may be stored by a
         name and not loaded from a path. */
     std::map<std::string, std::shared_ptr<Texture>> m_textures;
