@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -150,7 +150,7 @@ extern GG_API const WndFlag NO_WND_FLAGS;
     local execution of the GUI's event pump.  Execution of the code that calls
     Run() is effectively halted until Run() returns.  Derived classes that
     wish to use modal execution should set m_done = true to escape from the
-    modal execution loop.  EventPump has more information about processing
+    modal execution loop.  GUI::RunModal has more information about processing
     during modal dialog execution.
 
     <br>Note that OnTop() and Modal() flags only apply to top-level
@@ -298,7 +298,7 @@ public:
     {
         /** The time the cursor must linger over the Wnd before this mode
             becomes active, in ms. */
-        unsigned int time;
+        unsigned int time = 0;
 
         /** The BrowseInfoWnd used to display the browse info for this
             mode. */
@@ -312,7 +312,7 @@ public:
     typedef std::map<const Wnd*, bool>::iterator DropsAcceptableIter;
 
     /** The modes of child clipping. */
-    enum ChildClippingMode {
+    enum ChildClippingMode : int {
         /** No child clipping is performed. */
         DontClip,
 
@@ -411,7 +411,7 @@ public:
 
     /** Returns the name of this Wnd.  This name is not used by GG in any way;
         it only exists for user convenience. */
-     const std::string& Name() const;
+    const std::string& Name() const;
 
     /** Returns the string key that defines the type of data that this Wnd
         represents in drag-and-drop drags.  Returns an empty string when this
@@ -496,6 +496,9 @@ public:
     /** Returns the window's parent (may be null). */
     std::shared_ptr<Wnd> Parent() const;
 
+    /** Returns true iff \a wnd is an ancestor (indirect parent) of this wnd. */
+    bool IsAncestorOf(const std::shared_ptr<Wnd>& wnd) const;
+
     /** Returns the earliest ancestor window (may be null). */
     std::shared_ptr<Wnd> RootParent() const;
 
@@ -512,7 +515,7 @@ public:
         corresponding Wnd is shown superimposed over this Wnd and its
         children.  Set the first time cutoff to 0 for immediate browse info
         display. */
-    const std::vector<BrowseInfoMode>&  BrowseModes() const;
+    const std::vector<BrowseInfoMode>& BrowseModes() const;
 
     /** Returns the text to display for browse info mode \a mode.  \throw
         std::out_of_range May throw std::out_of_range if \a mode is not a
@@ -792,7 +795,7 @@ protected:
     /** The states a Wnd may be in, with respect to drag-and-drop operations.
         Wnds may wish to consider the current state when rendering to provide
         visual feedback to the user. */
-    enum DragDropRenderingState {
+    enum DragDropRenderingState : int {
         /** No drag-and-drop is taking place at all with this Wnd. */
         NOT_DRAGGED,
 
