@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -59,14 +59,14 @@ public:
     /** RenderOrderIterable can be iterated in back to front render order. */
     struct RenderOrderIterable {
         RenderOrderIterable(const std::list<std::shared_ptr<Wnd>>& list) :
-            m_list(list.crbegin(), list.crend())
+            m_list(list.rbegin(), list.rend())
         {}
 
-        std::vector<std::shared_ptr<Wnd>>::const_iterator begin()
-        { return m_list.cbegin(); }
+        std::vector<std::shared_ptr<Wnd>>::const_iterator begin() const
+        { return m_list.begin(); }
 
-        std::vector<std::shared_ptr<Wnd>>::const_iterator end()
-        { return m_list.cend(); }
+        std::vector<std::shared_ptr<Wnd>>::const_iterator end() const
+        { return m_list.end(); }
 
         private:
         const std::vector<std::shared_ptr<Wnd>> m_list;
