@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -206,7 +206,7 @@ void Edit::DeselectAll()
 
 void Edit::SelectRange(CPSize from, CPSize to)
 {
-    //std::cout << "Selecting range from: " << from << "  to: " << to << std::endl << std::flush;
+    //std::cout << "Selecting range from: " << from << "  to: " << to << std::endl;
     if (from < to) {
         m_cursor_pos.first = std::max(CP0, from);
         m_cursor_pos.second = std::min(to, Length());
@@ -292,7 +292,16 @@ CPSize Edit::CharIndexOf(X x) const
 }
 
 X Edit::FirstCharOffset() const
-{ return (!GetLineData().empty() && m_first_char_shown ? GetLineData()[0].char_data[Value(m_first_char_shown - 1)].extent : X0); }
+{
+    const auto& line_data = GetLineData();
+    if (line_data.empty() || m_first_char_shown == CP0)
+        return X0;
+    const auto& char_data = line_data.at(0).char_data;
+    if (char_data.empty())
+        return X0;
+    auto char_idx = std::min(char_data.size() - 1, Value(m_first_char_shown) - 1);
+    return char_data.at(char_idx).extent;
+}
 
 X Edit::ScreenPosOfChar(CPSize idx) const
 {
@@ -365,7 +374,7 @@ void Edit::LDrag(const Pt& pt, const Pt& move, Flags<ModKey> mod_keys)
 
     X xpos = ScreenToClient(pt).x; // x coord for mouse position within text space
     CPSize idx = CharIndexOf(xpos);
-    //std::cout << "CharIndexOf mouse x-pos: " << xpos << std::endl << std::flush;
+    //std::cout << "CharIndexOf mouse x-pos: " << xpos << std::endl;
 
     if (m_in_double_click_mode) {
         auto word_indices = GetDoubleButtonDownDragWordIndices(idx);
@@ -396,7 +405,7 @@ void Edit::LDrag(const Pt& pt, const Pt& move, Flags<ModKey> mod_keys)
             AdjustView();
     }
 
-    //std::cout << "LDrag selected from: " << m_cursor_pos.first << "  to: " << m_cursor_pos.second << std::endl << std::flush;
+    //std::cout << "LDrag selected from: " << m_cursor_pos.first << "  to: " << m_cursor_pos.second << std::endl;
 }
 
 void Edit::LButtonUp(const Pt& pt, Flags<ModKey> mod_keys)
@@ -608,7 +617,7 @@ void Edit::AdjustView()
     X first_char_offset = FirstCharOffset();
     if (m_cursor_pos.second < m_first_char_shown) { // if the caret is at a place left of the current visible area
         if (m_first_char_shown - m_cursor_pos.second < 5) // if the caret is less than five characters before m_first_char_shown
-            m_first_char_shown = (0 <= m_first_char_shown - 5) ? m_first_char_shown - 5 : CP0; // try to move the caret by five characters
+            m_first_char_shown = (5 < m_first_char_shown) ? m_first_char_shown - 5 : CP0; // try to move the caret by five characters
         else // if the caret is more than five characters before m_first_char_shown, just move straight to that spot
             m_first_char_shown = m_cursor_pos.second;
     } else if (Length() && text_space <= (m_cursor_pos.second ? GetLineData()[0].char_data[Value(m_cursor_pos.second - 1)].extent : X0) - first_char_offset) { // if the caret is moving to a place right of the current visible area
@@ -644,12 +653,6 @@ void GG::GetTranslatedCodePoint(Key key, std::uint32_t key_code_point, Flags<Mod
         } catch (const utf8::invalid_code_point&) {
             translated_code_point.clear();
         }
-    } else {
-        KeypadKeyToPrintable(key, mod_keys);
-        if (GGK_DELETE <= key || !isprint(key))
-            translated_code_point.clear();
-        else
-            translated_code_point = key;
     }
 }
 
