@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -84,7 +84,7 @@ namespace {
     class RowSorter // used to sort rows by a certain column (which may contain some empty cells)
     {
     public:
-        RowSorter(const boost::function<bool (const ListBox::Row&, const ListBox::Row&, std::size_t)>& cmp,
+        RowSorter(const std::function<bool (const ListBox::Row&, const ListBox::Row&, std::size_t)>& cmp,
                   std::size_t col, bool invert) :
             m_cmp(cmp),
             m_sort_col(col),
@@ -97,7 +97,7 @@ namespace {
         { return m_invert ? m_cmp(*r, *l, m_sort_col) : m_cmp(*l, *r, m_sort_col); }
 
     private:
-        boost::function<bool (const ListBox::Row&, const ListBox::Row&, std::size_t)> m_cmp;
+        std::function<bool (const ListBox::Row&, const ListBox::Row&, std::size_t)> m_cmp;
         std::size_t m_sort_col;
         bool m_invert;
     };
@@ -201,29 +201,14 @@ namespace {
 // GG::ListBox::Row
 ////////////////////////////////////////////////
 ListBox::Row::Row() :
-    Control(X0, Y0, ListBox::DEFAULT_ROW_WIDTH, ListBox::DEFAULT_ROW_HEIGHT),
-    m_cells(),
-    m_row_alignment(ALIGN_VCENTER),
-    m_col_alignments(),
-    m_col_widths(),
-    m_col_stretches(),
-    m_margin(ListBox::DEFAULT_MARGIN),
-    m_ignore_adjust_layout(false),
-    m_is_normalized(false)
+    Row(ListBox::DEFAULT_ROW_WIDTH, ListBox::DEFAULT_ROW_HEIGHT)
 {}
 
-ListBox::Row::Row(X w, Y h, const std::string& drag_drop_data_type,
-                  Alignment align/* = ALIGN_VCENTER*/, unsigned int margin/* = 2*/) : 
+ListBox::Row::Row(X w, Y h) :
     Control(X0, Y0, w, h),
-    m_cells(),
-    m_row_alignment(align),
-    m_col_alignments(),
-    m_col_widths(),
-    m_col_stretches(),
-    m_margin(margin),
-    m_ignore_adjust_layout(false),
-    m_is_normalized(false)
-{ SetDragDropDataType(drag_drop_data_type); }
+    m_row_alignment(ALIGN_VCENTER),
+    m_margin(ListBox::DEFAULT_MARGIN)
+{}
 
 void ListBox::Row::CompleteConstruction()
 { SetLayout(Wnd::Create<DeferredLayout>(X0, Y0, Width(), Height(), 1, 1, m_margin, m_margin)); }
@@ -501,9 +486,12 @@ void ListBox::Row::SetMargin(unsigned int margin)
         return;
 
     m_margin = margin;
-    auto&& layout = GetLayout();
-    layout->SetBorderMargin(margin);
-    layout->SetCellMargin(margin);
+    auto layout = GetLayout();
+    if (layout)
+    {
+        layout->SetBorderMargin(margin);
+        layout->SetCellMargin(margin);
+    }
 }
 
 void ListBox::Row::SetNormalized(bool normalized)
@@ -523,50 +511,19 @@ bool ListBox::RowPtrIteratorLess::operator()(const ListBox::iterator& lhs, const
 ////////////////////////////////////////////////
 // GG::ListBox
 ////////////////////////////////////////////////
-
 ListBox::ListBox(Clr color, Clr interior/* = CLR_ZERO*/) :
     Control(X0, Y0, X1, Y1, INTERACTIVE),
-    m_rows(),
-    m_vscroll(),
-    m_hscroll(),
-    m_vscroll_wheel_scroll_increment(0),
-    m_hscroll_wheel_scroll_increment(0),
     m_caret(m_rows.end()),
-    m_selections(),
     m_old_sel_row(m_rows.end()),
-    m_old_sel_row_selected(false),
     m_old_rdown_row(m_rows.end()),
     m_lclick_row(m_rows.end()),
     m_rclick_row(m_rows.end()),
     m_last_row_browsed(m_rows.end()),
-    m_first_row_offset(Pt(X(BORDER_THICK), Y(BORDER_THICK))),
     m_first_row_shown(m_rows.end()),
-    m_first_col_shown(0),
-    m_num_cols(1),
-    m_col_widths(),
-    m_col_alignments(),
-    m_col_stretches(),
     m_cell_margin(DEFAULT_MARGIN),
     m_int_color(interior),
-    m_hilite_color(CLR_SHADOW),
-    m_style(LIST_NONE),
     m_header_row(Wnd::Create<Row>()),
-    m_keep_col_widths(false),
-    m_clip_cells(false),
-    m_sort_col(0),
-    m_sort_cmp(DefaultRowCmp<Row>()),
-    m_allow_drops(false),
-    m_allowed_drop_types(boost::none),
-    m_auto_scroll_during_drag_drops(true),
-    m_auto_scroll_margin(8),
-    m_auto_scrolling_up(false),
-    m_auto_scrolling_down(false),
-    m_auto_scrolling_left(false),
-    m_auto_scrolling_right(false),
-    m_auto_scroll_timer(250),
-    m_normalize_rows_on_insert(true),
-    m_manage_column_props(true),
-    m_add_padding_at_end(true)
+    m_sort_cmp(DefaultRowCmp<Row>())
 {
     Control::SetColor(color);
 }
@@ -1405,7 +1362,7 @@ void ListBox::SetSortCol(std::size_t n)
         Resort();
 }
 
-void ListBox::SetSortCmp(const boost::function<bool (const Row&, const Row&, std::size_t)>& sort_cmp)
+void ListBox::SetSortCmp(const std::function<bool (const Row&, const Row&, std::size_t)>& sort_cmp)
 {
     m_sort_cmp = sort_cmp;
     if (!(m_style & LIST_NOSORT))
@@ -1838,7 +1795,7 @@ bool ListBox::EventFilter(Wnd* w, const WndEvent& event)
     case WndEvent::DragDroppedOn:
         if (w == this)
             return false;
-        //std::cout << "ListBox::EventFilter of type: " << EventTypeName(event) << std::endl << std::flush;
+        //std::cout << "ListBox::EventFilter of type: " << EventTypeName(event) << std::endl;
         HandleEvent(event);
         break;
 
@@ -1945,10 +1902,13 @@ ListBox::iterator ListBox::Insert(std::shared_ptr<Row> row, iterator it, bool dr
         std::advance(original_dropped_position, original_dropped_offset);
     }
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
     row->Hide();
-
     row->Resize(Pt(std::max(ClientWidth(), X(1)), row->Height()));
-
     row->RightClickedSignal.connect(boost::bind(&ListBox::HandleRowRightClicked, this, _1, _2));
 
     AfterInsertRowSignal(it);
@@ -2097,6 +2057,13 @@ ListBox::Row& ListBox::ColHeaders()
 
 void ListBox::ConnectSignals()
 {
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+    using boost::placeholders::_4;
+#endif
+
     if (m_vscroll)
         m_vscroll->ScrolledSignal.connect(boost::bind(&ListBox::VScrolled, this, _1, _2, _3, _4));
     if (m_hscroll)
@@ -2220,6 +2187,13 @@ std::pair<bool, bool> ListBox::AddOrRemoveScrolls(
         m_vscroll->MoveTo(Pt(cl_sz.x - SCROLL_WIDTH, Y0));
         m_vscroll->Resize(Pt(X(SCROLL_WIDTH), cl_sz.y - (horizontal_needed ? SCROLL_WIDTH : 0)));
 
+#if BOOST_VERSION >= 106000
+        using boost::placeholders::_1;
+        using boost::placeholders::_2;
+        using boost::placeholders::_3;
+        using boost::placeholders::_4;
+#endif
+
         AttachChild(m_vscroll);
         m_vscroll->ScrolledSignal.connect(boost::bind(&ListBox::VScrolled, this, _1, _2, _3, _4));
     }
@@ -2268,6 +2242,13 @@ std::pair<bool, bool> ListBox::AddOrRemoveScrolls(
         m_hscroll->MoveTo(Pt(X0, cl_sz.y - SCROLL_WIDTH));
         m_hscroll->Resize(Pt(cl_sz.x - (vertical_needed ? SCROLL_WIDTH : 0), Y(SCROLL_WIDTH)));
 
+#if BOOST_VERSION >= 106000
+        using boost::placeholders::_1;
+        using boost::placeholders::_2;
+        using boost::placeholders::_3;
+        using boost::placeholders::_4;
+#endif
+
         AttachChild(m_hscroll);
         m_hscroll->ScrolledSignal.connect(boost::bind(&ListBox::HScrolled, this, _1, _2, _3, _4));
     }
@@ -2425,7 +2406,7 @@ void ListBox::ClickAtRow(iterator it, Flags<ModKey> mod_keys)
             if (m_caret == m_rows.end()) {
                 // No previous caret exists; mark the first row as the caret.
                 m_caret = m_rows.begin();
-            } 
+            }
             // select all rows between the caret and this row (inclusive), don't move the caret
             iterator low  = RowPtrIteratorLess()(m_caret, it) ? m_caret : it;
             iterator high = RowPtrIteratorLess()(m_caret, it) ? it : m_caret;
