@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -27,7 +27,6 @@
 #include <GG/GUI.h>
 #include <GG/BrowseInfoWnd.h>
 #include <GG/DrawUtil.h>
-#include <GG/EventPump.h>
 #include <GG/Layout.h>
 #include <GG/WndEvent.h>
 
@@ -42,9 +41,7 @@ namespace {
     namespace mi = boost::multi_index;
     struct GridLayoutWnd
     {
-        GridLayoutWnd() :
-            wnd(nullptr)
-        {}
+        GridLayoutWnd() {}
 
         GridLayoutWnd(std::shared_ptr<Wnd>& wnd_, const Pt& ul_, const Pt& lr_) : wnd(wnd_), ul(ul_), lr(lr_) {}
         std::shared_ptr<Wnd> wnd;
@@ -54,26 +51,26 @@ namespace {
     struct IsLeft
     {
         bool operator()(const Pt& lhs, const Pt& rhs) const {return lhs.x < rhs.x;}
-        bool operator()(X x, const Pt& pt) const       {return x < pt.x;}
-        bool operator()(const Pt& pt, X x) const       {return pt.x < x;}
+        bool operator()(X x, const Pt& pt) const            {return x < pt.x;}
+        bool operator()(const Pt& pt, X x) const            {return pt.x < x;}
     };
     struct IsTop
     {
         bool operator()(const Pt& lhs, const Pt& rhs) const {return lhs.y < rhs.y;}
-        bool operator()(Y y, const Pt& pt) const       {return y < pt.y;}
-        bool operator()(const Pt& pt, Y y) const       {return pt.y < y;}
+        bool operator()(Y y, const Pt& pt) const            {return y < pt.y;}
+        bool operator()(const Pt& pt, Y y) const            {return pt.y < y;}
     };
     struct IsRight
     {
         bool operator()(const Pt& lhs, const Pt& rhs) const {return rhs.x < lhs.x;}
-        bool operator()(X x, const Pt& pt) const       {return pt.x < x;}
-        bool operator()(const Pt& pt, X x) const       {return x < pt.x;}
+        bool operator()(X x, const Pt& pt) const            {return pt.x < x;}
+        bool operator()(const Pt& pt, X x) const            {return x < pt.x;}
     };
     struct IsBottom
     {
         bool operator()(const Pt& lhs, const Pt& rhs) const {return rhs.y < lhs.y;}
-        bool operator()(Y y, const Pt& pt) const       {return pt.y < y;}
-        bool operator()(const Pt& pt, Y y) const       {return y < pt.y;}
+        bool operator()(Y y, const Pt& pt) const            {return pt.y < y;}
+        bool operator()(const Pt& pt, Y y) const            {return y < pt.y;}
     };
     struct Pointer {};
     struct LayoutLeft {};
@@ -361,6 +358,20 @@ const std::list<std::shared_ptr<Wnd>>& Wnd::Children() const
 std::shared_ptr<Wnd> Wnd::Parent() const
 { return LockAndResetIfExpired(m_parent); }
 
+bool Wnd::IsAncestorOf(const std::shared_ptr<Wnd>& wnd) const
+{
+    // Is this Wnd one of wnd's (direct or indirect) parents?
+    if (!wnd)
+        return false;
+    auto&& parent_of_wnd = wnd->Parent();
+    while (parent_of_wnd) {
+        if (parent_of_wnd.get() == this)
+            return true;
+        parent_of_wnd = parent_of_wnd->Parent();
+    }
+    return false;
+}
+
 std::shared_ptr<Wnd> Wnd::RootParent() const
 {
     auto&& parent = Parent();
@@ -918,8 +929,7 @@ bool Wnd::Run()
         gui->RegisterModal(shared_from_this());
         ModalInit();
         m_done = false;
-        std::shared_ptr<ModalEventPump> pump = gui->CreateModalEventPump(m_done);
-        (*pump)();
+        gui->RunModal(shared_from_this(), m_done);
         gui->Remove(shared_from_this());
         retval = true;
     }
