@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -24,7 +24,6 @@
 
 #include <GG/dialogs/ColorDlg.h>
 
-#include <GG/DrawUtil.h>
 #include <GG/Font.h>
 #include <GG/GLClientAndServerBuffer.h>
 #include <GG/GUI.h>
@@ -495,21 +494,7 @@ ColorDlg::ColorDlg(X x, Y y, Clr original_color, const std::shared_ptr<Font>& fo
                    Clr dialog_color, Clr border_color, Clr text_color/* = CLR_BLACK*/) :
     Wnd(x, y, X(315), Y(300), INTERACTIVE | DRAGABLE | MODAL),
     m_original_color(original_color),
-    m_original_color_specified(true),
-    m_color_was_picked(false),
-    m_hue_saturation_picker(nullptr),
-    m_value_picker(nullptr),
-    m_pickers_layout(nullptr),
-    m_new_color_square(nullptr),
-    m_old_color_square(nullptr),
-    m_new_color_square_text(nullptr),
-    m_old_color_square_text(nullptr),
-    m_color_squares_layout(nullptr),
-    m_color_buttons_layout(nullptr),
     m_current_color_button(INVALID_COLOR_BUTTON),
-    m_ok(nullptr),
-    m_cancel(nullptr),
-    m_sliders_ok_cancel_layout(nullptr),
     m_color(dialog_color),
     m_border_color(border_color),
     m_text_color(text_color)
@@ -629,34 +614,28 @@ void ColorDlg::CompleteConstruction()
     master_layout->Add(m_sliders_ok_cancel_layout, 0, 1, 3, 1);
     SetLayout(master_layout);
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
     for (std::size_t i = 0; i < m_color_buttons.size(); ++i) {
         m_color_buttons[i]->LeftClickedSignal.connect(
             [this, i](){ this->ColorButtonClicked(i); });
     }
-    m_sliders[R]->SlidSignal.connect(
-        boost::bind(&ColorDlg::RedSliderChanged, this, _1, _2, _3));
-    m_sliders[G]->SlidSignal.connect(
-        boost::bind(&ColorDlg::GreenSliderChanged, this, _1, _2, _3));
-    m_sliders[B]->SlidSignal.connect(
-        boost::bind(&ColorDlg::BlueSliderChanged, this, _1, _2, _3));
-    m_sliders[A]->SlidSignal.connect(
-        boost::bind(&ColorDlg::AlphaSliderChanged, this, _1, _2, _3));
-    m_sliders[H]->SlidSignal.connect(
-        boost::bind(&ColorDlg::HueSliderChanged, this, _1, _2, _3));
-    m_sliders[S]->SlidSignal.connect(
-        boost::bind(&ColorDlg::SaturationSliderChanged, this, _1, _2, _3));
-    m_sliders[V]->SlidSignal.connect(
-        boost::bind(&ColorDlg::ValueSliderChanged, this, _1, _2, _3));
-    m_ok->LeftClickedSignal.connect(
-        boost::bind(&ColorDlg::OkClicked, this));
-    m_cancel->LeftClickedSignal.connect(
-        boost::bind(&ColorDlg::CancelClicked, this));
-    m_hue_saturation_picker->ChangedSignal.connect(
-        boost::bind(&ValuePicker::SetHueSaturation, m_value_picker, _1, _2));
-    m_hue_saturation_picker->ChangedSignal.connect(
-        boost::bind(&ColorDlg::HueSaturationPickerChanged, this, _1, _2));
-    m_value_picker->ChangedSignal.connect(
-        boost::bind(&ColorDlg::ValuePickerChanged, this, _1));
+    m_sliders[R]->SlidSignal.connect(boost::bind(&ColorDlg::RedSliderChanged, this, _1, _2, _3));
+    m_sliders[G]->SlidSignal.connect(boost::bind(&ColorDlg::GreenSliderChanged, this, _1, _2, _3));
+    m_sliders[B]->SlidSignal.connect(boost::bind(&ColorDlg::BlueSliderChanged, this, _1, _2, _3));
+    m_sliders[A]->SlidSignal.connect(boost::bind(&ColorDlg::AlphaSliderChanged, this, _1, _2, _3));
+    m_sliders[H]->SlidSignal.connect(boost::bind(&ColorDlg::HueSliderChanged, this, _1, _2, _3));
+    m_sliders[S]->SlidSignal.connect(boost::bind(&ColorDlg::SaturationSliderChanged, this, _1, _2, _3));
+    m_sliders[V]->SlidSignal.connect(boost::bind(&ColorDlg::ValueSliderChanged, this, _1, _2, _3));
+    m_ok->LeftClickedSignal.connect(boost::bind(&ColorDlg::OkClicked, this));
+    m_cancel->LeftClickedSignal.connect(boost::bind(&ColorDlg::CancelClicked, this));
+    m_hue_saturation_picker->ChangedSignal.connect(boost::bind(&ValuePicker::SetHueSaturation, m_value_picker, _1, _2));
+    m_hue_saturation_picker->ChangedSignal.connect(boost::bind(&ColorDlg::HueSaturationPickerChanged, this, _1, _2));
+    m_value_picker->ChangedSignal.connect(boost::bind(&ColorDlg::ValuePickerChanged, this, _1));
 }
 
 bool ColorDlg::ColorWasSelected() const
