@@ -3,10 +3,10 @@
 #include "CUIControls.h"
 #include "PlayerListWnd.h"
 #include "../client/human/HumanClientApp.h"
+#include "../client/ClientNetworking.h"
 #include "../Empire/Empire.h"
 #include "../Empire/EmpireManager.h"
 #include "../network/Message.h"
-#include "../network/ClientNetworking.h"
 #include "../universe/Universe.h"
 #include "../universe/Ship.h"
 #include "../universe/ShipDesign.h"
@@ -14,7 +14,7 @@
 #include "../universe/Special.h"
 #include "../universe/Species.h"
 #include "../universe/Tech.h"
-#include "../universe/Building.h"
+#include "../universe/BuildingType.h"
 #include "../util/Directories.h"
 #include "../util/i18n.h"
 #include "../util/Logger.h"
@@ -23,68 +23,52 @@
 #include <GG/GUI.h>
 
 #include <boost/algorithm/string/predicate.hpp>
+#include <boost/xpressive/xpressive.hpp>
 
-
-// boost::spirit::classic pulls in windows.h which in turn defines the macros
-// SendMessage. Undefining those should avoid name collisions with FreeOrion
-// function names
-#include <boost/spirit/include/classic.hpp>
-#ifdef FREEORION_WIN32
-#  undef SendMessage
-#endif
+#include <algorithm>
+#include <iterator>
 
 
 namespace {
-    const std::string OPEN_TAG = "[[";
-    const std::string CLOSE_TAG = "]]";
+    std::string UserStringSubstitute(const boost::xpressive::smatch& match) {
+        auto key = match.str(1);
 
-    /** Converts (first, last) to a string, looks it up as a key in the
-      * stringtable, then then appends this to the end of a string. */
-    struct UserStringSubstituteAndAppend {
-        UserStringSubstituteAndAppend(std::string& str) :
-            m_str(str)
-        {}
-
-        void operator()(const char* first, const char* last) const {
-            std::string token(first, last);
-            if (token.empty() || !UserStringExists(token))
-                return;
-            m_str += UserString(token);
+        if (match.nested_results().empty()) {
+            // not parameterized
+            if (UserStringExists(key))
+                return UserString(key);
+            return key;
         }
 
-        std::string&    m_str;
-    };
+        if (UserStringExists(key))
+            // replace key with user string if such exists
+            key = UserString(key);
 
-    // sticks a sequence of characters onto the end of a string
-    struct StringAppend {
-        StringAppend(std::string& str) :
-            m_str(str)
-        {}
+        auto formatter = FlexibleFormat(key);
 
-        void operator()(const char* first, const char* last) const
-        { m_str += std::string(first, last); }
-
-        std::string&    m_str;
-    };
+        size_t arg = 1;
+        for (auto submatch : match.nested_results())
+            formatter.bind_arg(arg++, submatch.str());
 
+        return formatter.str();
+    }
 
+    // finds instances of stringtable substitutions and/or string formatting
+    // within the text \a input and evaluates them. [[KEY]] will be looked up
+    // in the stringtable, and if found, replaced with the corresponding
+    // stringtable entry. If not found, KEY is used instead. [[KEY,var1,var2]]
+    // will look up KEY in the stringtable or use just KEY if there is no
+    // such stringtable entry, and then substitute var1 for all instances of %1%
+    // in the string, and var2 for all instances of %2% in the string. Any
+    // intance of %3% or higher numbers will be deleted from the string, unless
+    // a third or more parameters are specified.
     std::string StringtableTextSubstitute(const std::string& input) {
-        std::string retval;
+        using namespace boost::xpressive;
 
-        // set up parser
-        namespace classic = boost::spirit::classic;
-        classic::rule<> token = *(classic::anychar_p - classic::space_p - CLOSE_TAG.c_str());
-        classic::rule<> var = OPEN_TAG.c_str() >> token[UserStringSubstituteAndAppend(retval)] >> CLOSE_TAG.c_str();
-        classic::rule<> non_var = classic::anychar_p - OPEN_TAG.c_str();
+        sregex param = (s1 = +_w);
+        sregex regex = as_xpr("[[") >> (s1 = +_w) >> !*(',' >> param) >> "]]";
 
-        // parse and substitute variables
-        try {
-            classic::parse(input.c_str(), *(non_var[StringAppend(retval)] | var));
-        } catch (const std::exception&) {
-            ErrorLogger() << "StringtableTextSubstitute caught exception when parsing input: " << input;
-        }
-
-        return retval;
+        return regex_replace(input, regex, UserStringSubstitute);
     }
 }
 
@@ -96,6 +80,7 @@ public:
 
     //! \name Mutators //@{
     void KeyPress(GG::Key key, std::uint32_t key_code_point, GG::Flags<GG::ModKey> mod_keys) override;
+    bool AutoComplete() override;   //!< Autocomplete current word
     //@}
 
     /** emitted when user presses enter/return while entering text */
@@ -104,20 +89,19 @@ public:
     mutable boost::signals2::signal<void ()> DownPressedSignal;
 
 private:
-    void            FindGameWords();                    //!< Finds all game words for autocomplete
-    void            AutoComplete();                     //!< Autocomplete current word
+    void FindGameWords();                    //!< Finds all game words for autocomplete
 
     /** AutoComplete helper function */
-    bool            CompleteWord(const std::set<std::string>& names, const std::string& partial_word,
-                                 const std::pair<GG::CPSize, const GG::CPSize>& cursor_pos,
-                                 std::string& text);
+    bool CompleteWord(const std::set<std::string>& names, const std::string& partial_word,
+                      const std::pair<GG::CPSize, const GG::CPSize>& cursor_pos,
+                      std::string& text);
 
     // Set for autocomplete game words
     std::set<std::string>       m_game_words;
 
-    // Repeated tabs variables
+    // Repeated autocomplete variables
      std::vector<std::string>   m_auto_complete_choices;
-     unsigned int               m_repeated_tab_count;
+     unsigned int               m_repeated_tab_count = 0;
      std::string                m_last_line_read;
      std::string                m_last_game_word;
 };
@@ -126,11 +110,7 @@ private:
 // MessageWndEdit //
 ////////////////////
 MessageWndEdit::MessageWndEdit() :
-    CUIEdit(""),
-    m_auto_complete_choices(),
-    m_repeated_tab_count(0),
-    m_last_line_read(),
-    m_last_game_word()
+    CUIEdit("")
 {}
 
 void MessageWndEdit::KeyPress(GG::Key key, std::uint32_t key_code_point,
@@ -160,13 +140,13 @@ void MessageWndEdit::FindGameWords() {
         m_game_words.insert(entry.second->PlayerName());
     }
     // add system names
-    for (auto& system : GetUniverse().Objects().FindObjects<System>()) {
-        if (system->Name() != "")
+    for (auto& system : GetUniverse().Objects().all<System>()) {
+        if (!system->Name().empty())
             m_game_words.insert(system->Name());
     }
      // add ship names
-    for (auto& ship : GetUniverse().Objects().FindObjects<Ship>()) {
-        if (ship->Name() != "")
+    for (auto& ship : GetUniverse().Objects().all<Ship>()) {
+        if (!ship->Name().empty())
             m_game_words.insert(ship->Name());
     }
      // add ship design names
@@ -177,22 +157,22 @@ void MessageWndEdit::FindGameWords() {
     }
      // add specials names
     for (const std::string& special_name : SpecialNames()) {
-        if (special_name != "")
+        if (!special_name.empty())
             m_game_words.insert(UserString(special_name));
     }
      // add species names
     for (const auto& entry : GetSpeciesManager()) {
-        if (entry.second->Name() != "")
+        if (!entry.second->Name().empty())
             m_game_words.insert(UserString(entry.second->Name()));
     }
      // add techs names
     for (const std::string& tech_name : GetTechManager().TechNames()) {
-        if (tech_name != "")
+        if (!tech_name.empty())
             m_game_words.insert(UserString(tech_name));
     }
     // add building type names
     for (const auto& entry : GetBuildingTypeManager()) {
-        if (entry.second->Name() != "")
+        if (!entry.second->Name().empty())
             m_game_words.insert(UserString(entry.second->Name()));
     }
     // add ship hulls
@@ -203,24 +183,24 @@ void MessageWndEdit::FindGameWords() {
     // add ship parts
     for (const auto& design : GetPredefinedShipDesignManager().GetOrderedShipDesigns()) {
         for (const std::string& part_name : design->Parts()) {
-            if (part_name != "")
+            if (!part_name.empty())
                 m_game_words.insert(UserString(part_name));
         }
     }
  }
 
-void MessageWndEdit::AutoComplete() {
+bool MessageWndEdit::AutoComplete() {
     std::string full_line = this->Text();
 
     // Check for repeated tab
     // if current line is same as the last read line
-    if (m_last_line_read != "" && boost::equals(full_line, m_last_line_read)){
+    if (!m_last_line_read.empty() && boost::equals(full_line, m_last_line_read)) {
         if (m_repeated_tab_count >= m_auto_complete_choices.size())
             m_repeated_tab_count = 0;
 
-        std::string next_word = m_auto_complete_choices.at(m_repeated_tab_count);
+        const std::string& next_word = m_auto_complete_choices.at(m_repeated_tab_count);
 
-        if (next_word != "") {
+        if (!next_word.empty()) {
             // Remove the old choice from the line
             // and replace it with the next choice
             full_line = full_line.substr(0, full_line.size() - (m_last_game_word.size() + 1));
@@ -232,8 +212,10 @@ void MessageWndEdit::AutoComplete() {
             m_last_line_read = this->Text();
         }
         ++m_repeated_tab_count;
-    }
-    else {
+
+        return true;    // indicates to calling signal that a hotkey press was processed
+
+    } else {
         bool exact_match = false;
 
         auto cursor_pos = this->CursorPosn();
@@ -245,7 +227,7 @@ void MessageWndEdit::AutoComplete() {
                 ++word_start;
             std::string partial_word = full_line.substr(word_start, Value(cursor_pos.first - word_start));
             if (partial_word.empty())
-                return;
+                return true;    // indicates to calling signal that a hotkey press was processed
 
             // Find game words to try an autocomplete
             FindGameWords();
@@ -265,6 +247,8 @@ void MessageWndEdit::AutoComplete() {
                 CompleteWord(m_game_words, partial_word, cursor_pos, full_line);
         }
     }
+
+    return true;    // indicates to calling signal that a hotkey press was processed
 }
 
 bool MessageWndEdit::CompleteWord(const std::set<std::string>& names, const std::string& partial_word,
@@ -275,25 +259,19 @@ bool MessageWndEdit::CompleteWord(const std::set<std::string>& names, const std:
     m_auto_complete_choices.clear();
     m_repeated_tab_count = 0;
 
-    bool partial_word_match = false;
     std::string game_word;
 
     // Check if the partial_word is contained in any game words
     for (const std::string& temp_game_word : names) {
         if (temp_game_word.size() >= partial_word.size()) {
+            // Add all possible word choices for repeated tab
             std::string game_word_partial = temp_game_word.substr(0, partial_word.size());
-
-            if (boost::iequals(game_word_partial, partial_word)) {
-                if (game_word_partial != "") {
-                    // Add all possible word choices for repeated tab
-                    m_auto_complete_choices.push_back(temp_game_word);
-                    partial_word_match = true;
-                }
-            }
+            if (!game_word_partial.empty() && boost::iequals(game_word_partial, partial_word))
+                m_auto_complete_choices.push_back(temp_game_word);
         }
     }
 
-    if (!partial_word_match)
+    if (m_auto_complete_choices.empty())
         return false;
 
     // Grab first autocomplete choice
@@ -316,11 +294,7 @@ bool MessageWndEdit::CompleteWord(const std::set<std::string>& names, const std:
 ////////////////////
 MessageWnd::MessageWnd(GG::Flags<GG::WndFlag> flags, const std::string& config_name) :
     CUIWnd(UserString("MESSAGES_PANEL_TITLE"), flags, config_name),
-    m_display(nullptr),
-    m_edit(nullptr),
-    m_display_show_time(0),
-    m_history(),
-    m_history_position()
+    m_display_show_time(0)
 {}
 
 void MessageWnd::CompleteConstruction() {
@@ -334,19 +308,22 @@ void MessageWnd::CompleteConstruction() {
     m_edit = GG::Wnd::Create<MessageWndEdit>();
     AttachChild(m_edit);
 
-    m_edit->TextEnteredSignal.connect(
-        boost::bind(&MessageWnd::MessageEntered, this));
-    m_edit->UpPressedSignal.connect(
-        boost::bind(&MessageWnd::MessageHistoryUpRequested, this));
-    m_edit->DownPressedSignal.connect(
-        boost::bind(&MessageWnd::MessageHistoryDownRequested, this));
-    m_edit->GainingFocusSignal.connect(
-        TypingSignal);
-    m_edit->LosingFocusSignal.connect(
-        DoneTypingSignal);
+    m_edit->TextEnteredSignal.connect(boost::bind(&MessageWnd::MessageEntered, this));
+    m_edit->UpPressedSignal.connect(boost::bind(&MessageWnd::MessageHistoryUpRequested, this));
+    m_edit->DownPressedSignal.connect(boost::bind(&MessageWnd::MessageHistoryDownRequested, this));
+    m_edit->GainingFocusSignal.connect(TypingSignal);
+    m_edit->LosingFocusSignal.connect(DoneTypingSignal);
 
     m_history.push_front("");
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
+    Empires().DiplomaticStatusChangedSignal.connect(
+        boost::bind(&MessageWnd::HandleDiplomaticStatusChange, this, _1, _2));
+
     DoLayout();
     SaveDefaultedOptions();
 }
@@ -359,8 +336,23 @@ void MessageWnd::DoLayout() {
                      GG::Pt(ClientWidth() - GG::X(CUIWnd::INNER_BORDER_ANGLE_OFFSET), ClientHeight()));
 }
 
-void MessageWnd::CloseClicked()
-{ ClosingSignal(); }
+void MessageWnd::CloseClicked() {
+    StopFlash();
+    ClosingSignal();
+}
+
+void MessageWnd::LClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) {
+    CUIWnd::LClick(pt, mod_keys);
+    StopFlash();
+}
+
+void MessageWnd::LDrag(const GG::Pt& pt, const GG::Pt& move, GG::Flags<GG::ModKey> mod_keys) {
+    CUIWnd::LDrag(pt, move, mod_keys);
+    StopFlash();
+}
+
+std::string MessageWnd::GetText() const
+{ return *m_display; }
 
 void MessageWnd::SizeMove(const GG::Pt& ul, const GG::Pt& lr) {
     const GG::Pt old_size = Size();
@@ -378,14 +370,21 @@ void MessageWnd::HandlePlayerChatMessage(const std::string& text,
                                          const std::string& player_name,
                                          GG::Clr text_color,
                                          const boost::posix_time::ptime& timestamp,
-                                         int recipient_player_id)
+                                         int recipient_player_id,
+                                         bool pm)
 {
     std::string filtered_message = StringtableTextSubstitute(text);
     std::string wrapped_text = RgbaTag(text_color);
+    std::string pm_text = "";
+    if (pm)
+        pm_text = UserString("MESSAGES_WHISPER");
     const std::string&& formatted_timestamp = ClientUI::FormatTimestamp(timestamp);
     if (IsValidUTF8(formatted_timestamp))
         wrapped_text += formatted_timestamp;
-    wrapped_text += player_name + ": " + filtered_message + "</rgba>";
+    if (player_name.empty())
+        wrapped_text += filtered_message + "</rgba>";
+    else
+        wrapped_text += player_name + pm_text + ": " + filtered_message + "</rgba>";
     TraceLogger() << "HandlePlayerChatMessage sender: " << player_name
                   << "  sender colour rgba tag: " << RgbaTag(text_color)
                   << "  filtered message: " << filtered_message
@@ -394,12 +393,23 @@ void MessageWnd::HandlePlayerChatMessage(const std::string& text,
 
     *m_display += wrapped_text + "\n";
     m_display_show_time = GG::GUI::GetGUI()->Ticks();
+
+    // if client empire is target of message, show message window
+    const ClientApp* app = ClientApp::GetApp();
+    if (!app) {
+        ErrorLogger() << "MessageWnd::HandlePlayerChatMessage couldn't get client app!";
+        return;
+    }
+    // only show and flash message window if other player sent message
+    const std::map<int, PlayerInfo>& players = app->Players();
+    const auto it = players.find(app->PlayerID());
+    if (it == players.end() || it->second.name != player_name) {
+        Flash();
+        Show();
+    }
 }
 
-void MessageWnd::HandlePlayerStatusUpdate(Message::PlayerStatus player_status, int about_player_id)
-{}
-
-void MessageWnd::HandleTurnPhaseUpdate(Message::TurnProgressPhase phase_id) {
+void MessageWnd::HandleTurnPhaseUpdate(Message::TurnProgressPhase phase_id, bool prefixed /*= false*/) {
     std::string phase_str;
     switch (phase_id) {
     case Message::FLEET_MOVEMENT:
@@ -438,7 +448,10 @@ void MessageWnd::HandleTurnPhaseUpdate(Message::TurnProgressPhase phase_id) {
         break;
     }
 
-    *m_display += phase_str + "\n";
+    if (prefixed)
+        *m_display += boost::str(FlexibleFormat(UserString("PLAYING_GAME")) % phase_str) + "\n";
+    else
+        *m_display += phase_str + "\n";
     m_display_show_time = GG::GUI::GetGUI()->Ticks();
 }
 
@@ -452,6 +465,50 @@ void MessageWnd::HandleLogMessage(const std::string& text) {
     m_display_show_time = GG::GUI::GetGUI()->Ticks();
 }
 
+void MessageWnd::HandleDiplomaticStatusChange(int empire1_id, int empire2_id) {
+    const ClientApp* app = ClientApp::GetApp();
+    if (!app) {
+        ErrorLogger() << "MessageWnd::HandleDiplomaticStatusChange couldn't get client app!";
+        return;
+    }
+
+    int client_empire_id = app->EmpireID();
+    DiplomaticStatus status = Empires().GetDiplomaticStatus(empire1_id, empire2_id);
+    std::string text;
+
+    const Empire* empire1 = GetEmpire(empire1_id);
+    const Empire* empire2 = GetEmpire(empire2_id);
+
+    std::string empire1_str = GG::RgbaTag(empire1->Color()) + empire1->Name() + "</rgba>";
+    std::string empire2_str = GG::RgbaTag(empire2->Color()) + empire2->Name() + "</rgba>";
+
+    switch (status) {
+    case DIPLO_WAR:
+        text = boost::str(FlexibleFormat(UserString("MESSAGES_WAR_DECLARATION"))
+                   % empire1_str % empire2_str);
+        break;
+    case DIPLO_PEACE:
+        text = boost::str(FlexibleFormat(UserString("MESSAGES_PEACE_TREATY"))
+                   % empire1_str % empire2_str);
+        break;
+    case DIPLO_ALLIED:
+        text = boost::str(FlexibleFormat(UserString("MESSAGES_ALLIANCE"))
+                   % empire1_str % empire2_str);
+        break;
+    default:
+        ErrorLogger() << "MessageWnd::HandleDiplomaticStatusChange: no valid diplomatic status found.";
+    }
+
+    *m_display += text + "\n";
+    m_display_show_time = GG::GUI::GetGUI()->Ticks();
+
+    // if client empire is target of diplomatic status change, show message window
+    if (empire2_id == client_empire_id) {
+        Flash();
+        Show();
+    }
+}
+
 void MessageWnd::Clear()
 { m_display->Clear(); }
 
@@ -460,44 +517,93 @@ void MessageWnd::OpenForInput() {
     m_display_show_time = GG::GUI::GetGUI()->Ticks();
 }
 
-namespace {
-    void SendChatMessage(const std::string& text, std::set<int> recipients) {
-        ClientNetworking& net = HumanClientApp::GetApp()->Networking();
+void MessageWnd::SetChatText(const std::string& chat_text)
+{ m_display->SetText(chat_text); }
 
-        if (recipients.empty()) {
-            net.SendMessage(PlayerChatMessage(text));
-        } else {
-            recipients.insert(HumanClientApp::GetApp()->PlayerID());   // ensure recipient sees own sent message
-            for (int recipient_id : recipients)
-                net.SendMessage(PlayerChatMessage(text, recipient_id));
+namespace {
+    void SendChatMessage(const std::string& text, std::set<int> recipients, bool pm) {
+        const ClientApp* app = ClientApp::GetApp();
+        if (!app) {
+            ErrorLogger() << "ChatWnd.cpp SendChatMessage couldn't get client app!";
+            return;
         }
+        ClientNetworking& net = HumanClientApp::GetApp()->Networking();
+        net.SendMessage(PlayerChatMessage(text, recipients, pm));
     }
 
-    void HandleTextCommand(const std::string& text) {
-        if (text.size() < 2)
-            return;
-
-        // extract command and parameters substrings
-        std::string command, params;
+    int ExtractPlayerID(const std::string& text) {
+        const ClientApp* app = ClientApp::GetApp();
+        if (!app) {
+            ErrorLogger() << "ChatWnd.cpp ExtractPlayerID couldn't get client app!";
+            return Networking::INVALID_PLAYER_ID;
+        }
         std::string::size_type space_pos = text.find_first_of(' ');
-        command = boost::trim_copy(text.substr(1, space_pos));
-        if (command.empty())
-            return;
-        if (space_pos != std::string::npos)
-            params = boost::trim_copy(text.substr(space_pos, std::string::npos));
+        if (space_pos == std::string::npos)
+            return Networking::INVALID_PLAYER_ID;
+        std::string player_name = boost::trim_copy(text.substr(0, space_pos));
+        const std::map<int, PlayerInfo>& players = app->Players();
 
-        ClientUI* client_ui = ClientUI::GetClientUI();
-        if (!client_ui)
-            return;
+        for (auto& player : players) {
+            if (boost::iequals(player.second.name, player_name)) {
+                return player.first;
+            }
+        }
 
-        // execute command matching understood syntax
-        if (boost::iequals(command, "zoom") && !params.empty()) {
-            client_ui->ZoomToObject(params) || client_ui->ZoomToContent(params, true);   // params came from chat, so will be localized, so should be reverse looked up to find internal name from human-readable name for zooming to content
-        } else if (boost::iequals(command, "pedia")) {
-            if (params.empty())
-                client_ui->ZoomToEncyclopediaEntry(UserStringNop("ENC_INDEX"));
-            else
-                client_ui->ZoomToContent(params, true);
+        return Networking::INVALID_PLAYER_ID;
+    }
+
+    std::string ExtractMessage(const std::string& text) {
+        std::string::size_type space_pos = text.find_first_of(' ');
+        if (space_pos == std::string::npos)
+            return "";
+        std::string message = boost::trim_copy(text.substr(space_pos, std::string::npos));
+        return message;
+    }
+
+}
+
+void MessageWnd::HandleTextCommand(const std::string& text) {
+    if (text.size() < 2)
+        return;
+
+    // extract command and parameters substrings
+    std::string command, params;
+    std::string::size_type space_pos = text.find_first_of(' ');
+    command = boost::trim_copy(text.substr(1, space_pos));
+    if (command.empty())
+        return;
+    if (space_pos != std::string::npos)
+        params = boost::trim_copy(text.substr(space_pos, std::string::npos));
+
+    ClientUI* client_ui = ClientUI::GetClientUI();
+    if (!client_ui)
+        return;
+
+    // execute command matching understood syntax
+    if (boost::iequals(command, "zoom") && !params.empty()) {
+        client_ui->ZoomToObject(params) || client_ui->ZoomToContent(params, true);   // params came from chat, so will be localized, so should be reverse looked up to find internal name from human-readable name for zooming to content
+    }
+    else if (boost::iequals(command, "pedia")) {
+        if (params.empty())
+            client_ui->ZoomToEncyclopediaEntry(UserStringNop("ENC_INDEX"));
+        else
+            client_ui->ZoomToContent(params, true);
+    }
+    else if (boost::iequals(command, "help")) {
+        *m_display += UserString("MESSAGES_HELP_COMMAND") + "\n";
+        m_display_show_time = GG::GUI::GetGUI()->Ticks();
+    }
+    else if (boost::iequals(command, "pm")) {
+        int player_id = ExtractPlayerID(params);
+        std::string message = ExtractMessage(params);
+
+        if (player_id != Networking::INVALID_PLAYER_ID) {
+            std::set<int> recipient;
+            recipient.insert(player_id);
+            SendChatMessage(message, recipient, true);
+        }
+        else {
+            *m_display += UserString("MESSAGES_INVALID") + "\n";
         }
     }
 }
@@ -508,6 +614,7 @@ void MessageWnd::MessageEntered() {
         return;
 
     m_display_show_time = GG::GUI::GetGUI()->Ticks();
+    bool pm = false;
 
     // update history
     if (m_history.size() == 1 || m_history[1] != trimmed_text) {
@@ -526,12 +633,15 @@ void MessageWnd::MessageEntered() {
     } else {
         // otherwise, treat message as chat and send to recipients
         std::set<int> recipients;
-        if (PlayerListWnd* player_list_wnd = ClientUI::GetClientUI()->GetPlayerListWnd().get())
+        if (PlayerListWnd* player_list_wnd = ClientUI::GetClientUI()->GetPlayerListWnd().get()) {
             recipients = player_list_wnd->SelectedPlayerIDs();
-        SendChatMessage(trimmed_text, recipients);
+            pm = !(player_list_wnd->SelectedPlayerIDs().empty());
+        }
+        SendChatMessage(trimmed_text, recipients, pm);
     }
 
     m_edit->Clear();
+    StopFlash();
 }
 
 void MessageWnd::MessageHistoryUpRequested() {
