@@ -18,6 +18,10 @@ public:
     void CompleteConstruction() override;
     //@}
 
+    //! \name Acessors */ //@{
+    std::string GetText() const;
+    //@}
+
     //! \name Mutators //@{
     void SizeMove(const GG::Pt& ul, const GG::Pt& lr) override;
 
@@ -27,13 +31,15 @@ public:
                                             const std::string& player_name,
                                             GG::Clr text_color,
                                             const boost::posix_time::ptime& timestamp,
-                                            int recipient_player_id);
-    void            HandlePlayerStatusUpdate(Message::PlayerStatus player_status, int about_player_id);
-    void            HandleTurnPhaseUpdate(Message::TurnProgressPhase phase_id);
+                                            int recipient_player_id,
+                                            bool pm);
+    void            HandleTurnPhaseUpdate(Message::TurnProgressPhase phase_id, bool prefixed = false);
     void            HandleGameStatusUpdate(const std::string& text);
     void            HandleLogMessage(const std::string& text);
+    void            HandleDiplomaticStatusChange(int empire1_id, int empire2_id);
     void            Clear();
     void            OpenForInput();
+    void            SetChatText(const std::string& chat_text);
     //@}
 
     /** emitted when the edit gains focus.  Keyboard accelerators elsewhere
@@ -45,9 +51,12 @@ public:
     mutable boost::signals2::signal<void ()> ClosingSignal;
 
 private:
-    void CloseClicked() override;
+    void            CloseClicked() override;
+    void            LClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) override;
+    void            LDrag(const GG::Pt& pt, const GG::Pt& move, GG::Flags<GG::ModKey> mod_keys) override;
 
     void            DoLayout();
+    void            HandleTextCommand(const std::string& text);
     void            MessageEntered();
     void            MessageHistoryUpRequested();
     void            MessageHistoryDownRequested();
