@@ -19,34 +19,30 @@
 #include "../util/i18n.h"
 #include "../util/OptionsDB.h"
 #include "../universe/Building.h"
+#include "../universe/BuildingType.h"
 #include "../universe/Fleet.h"
 #include "../universe/Planet.h"
 #include "../universe/System.h"
 #include "../universe/Ship.h"
 #include "../universe/ShipDesign.h"
+#include "../universe/ShipPart.h"
+#include "../universe/ShipHull.h"
 #include "../universe/Tech.h"
 #include "../universe/Special.h"
 #include "../universe/Species.h"
-#include "../universe/Field.h"
+#include "../universe/FieldType.h"
 #include "../universe/Enums.h"
 #include "../combat/CombatLogManager.h"
 #include "../client/human/HumanClientApp.h"
 
 #include <GG/Clr.h>
 #include <GG/dialogs/ThreeButtonDlg.h>
-#include <GG/DrawUtil.h>
 #include <GG/GUI.h>
 #include <GG/RichText/ImageBlock.h>
 #include <GG/UnicodeCharsets.h>
 
-// boost::spirit::classic pulls in windows.h which in turn defines the macros
-// MessageBox and PlaySound. Undefining those should avoid name collisions with
-// FreeOrion function names
-#include <boost/spirit/include/classic.hpp>
-#ifdef FREEORION_WIN32
-#  undef MessageBox
-#  undef PlaySound
-#endif
+#include <boost/spirit/include/qi.hpp>
+#include <boost/spirit/include/phoenix_operator.hpp>
 
 #include <boost/algorithm/string/predicate.hpp>
 #include <boost/filesystem/fstream.hpp>
@@ -61,8 +57,6 @@
 #include <boost/locale/date_time.hpp>
 
 
-const Tech* GetTech(const std::string& name);
-
 bool TextureFileNameCompare(const std::shared_ptr<GG::Texture> t1, const std::shared_ptr<GG::Texture> t2)
 { return t1 && t2 && t1->Path() < t2->Path(); }
 
@@ -236,7 +230,7 @@ std::shared_ptr<GG::Texture> ClientUI::MeterIcon(MeterType meter_type) {
     case METER_SPEED:
         icon_filename = "speed.png";        break;
     default:
-        break;
+        return ClientUI::GetTexture(ClientUI::ArtDir() / "misc" / "missing.png", true); break;
     }
     return ClientUI::GetTexture(ClientUI::ArtDir() / "icons" / "meter" / icon_filename, true);
 }
@@ -301,7 +295,7 @@ std::shared_ptr<GG::Texture> ClientUI::FieldTexture(const std::string& field_typ
 }
 
 std::shared_ptr<GG::Texture> ClientUI::PartIcon(const std::string& part_name) {
-    const PartType* part = GetPartType(part_name);
+    const ShipPart* part = GetShipPart(part_name);
     std::string texture_name;
     if (part)
         texture_name = part->Icon();
@@ -311,7 +305,7 @@ std::shared_ptr<GG::Texture> ClientUI::PartIcon(const std::string& part_name) {
 }
 
 std::shared_ptr<GG::Texture> ClientUI::HullTexture(const std::string& hull_name) {
-    const HullType* hull = GetHullType(hull_name);
+    const ShipHull* hull = GetShipHull(hull_name);
     std::string texture_name;
     if (hull) {
         texture_name = hull->Graphic();
@@ -324,7 +318,7 @@ std::shared_ptr<GG::Texture> ClientUI::HullTexture(const std::string& hull_name)
 }
 
 std::shared_ptr<GG::Texture> ClientUI::HullIcon(const std::string& hull_name) {
-    const HullType* hull = GetHullType(hull_name);
+    const ShipHull* hull = GetShipHull(hull_name);
     std::string texture_name;
     if (hull) {
         texture_name = hull->Icon();
@@ -483,7 +477,7 @@ namespace {
         db.Add("video.fps.max.enabled",                                 UserStringNop("OPTIONS_DB_LIMIT_FPS"),                      true);
         db.Add("video.fps.max",                                         UserStringNop("OPTIONS_DB_MAX_FPS"),                        60.0,                           RangedStepValidator<double>(1.0, 0.0, 240.0));
         db.Add("video.fps.unfocused.enabled",                           UserStringNop("OPTIONS_DB_LIMIT_FPS_NO_FOCUS"),             true);
-        db.Add("video.fps.unfocused",                                   UserStringNop("OPTIONS_DB_MAX_FPS_NO_FOCUS"),               15.0,                           RangedStepValidator<double>(1.0, 1.0, 30.0));
+        db.Add("video.fps.unfocused",                                   UserStringNop("OPTIONS_DB_MAX_FPS_NO_FOCUS"),               15.0,                           RangedStepValidator<double>(0.125, 0.125, 30.0));
 
         // sound and music
         db.Add<std::string>("audio.music.path",                         UserStringNop("OPTIONS_DB_BG_MUSIC"),                       (GetRootDataDir() / "default" / "data" / "sound" / "artificial_intelligence_v3.ogg").string());
@@ -570,7 +564,7 @@ namespace {
 
         // Other
         db.Add("resource.shipdesign.saved.enabled",                     UserStringNop("OPTIONS_DB_AUTO_ADD_SAVED_DESIGNS"),         true);
-        //db.Add("resource.shipdesign.default.enabled",                   UserStringNop("OPTIONS_DB_ADD_DEFAULT_DESIGNS"),            true);
+        db.Add("resource.shipdesign.default.enabled",                   UserStringNop("OPTIONS_DB_ADD_DEFAULT_DESIGNS"),            true);
 
     }
     bool temp_bool = RegisterOptions(&AddOptions);
@@ -582,7 +576,7 @@ namespace {
     const std::string MESSAGE_WND_NAME = "map.messages";
     const std::string PLAYER_LIST_WND_NAME = "map.empires";
 
-    template <class OptionType, class PredicateType>
+    template <typename OptionType, typename PredicateType>
     void ConditionalForward(const std::string& option_name,
                             const OptionsDB::OptionChangedSignalType::slot_type& slot,
                             OptionType ref_val,
@@ -592,7 +586,7 @@ namespace {
             slot();
     }
 
-    template <class OptionType, class PredicateType>
+    template <typename OptionType, typename PredicateType>
     void ConditionalConnectOption(const std::string& option_name,
                                   const OptionsDB::OptionChangedSignalType::slot_type& slot,
                                   OptionType ref_val,
@@ -609,12 +603,6 @@ namespace {
 // ClientUI
 ////////////////////////////////////////////////
 ClientUI::ClientUI() :
-    m_map_wnd(nullptr),
-    m_message_wnd(nullptr),
-    m_player_list_wnd(nullptr),
-    m_intro_screen(nullptr),
-    m_multiplayer_lobby_wnd(nullptr),
-    m_password_enter_wnd(nullptr),
     m_ship_designs(new ShipDesignManager())
 {
     s_the_UI = this;
@@ -624,15 +612,8 @@ ClientUI::ClientUI() :
     if (GetOptionsDB().Get<bool>("window-reset"))
         CUIWnd::InvalidateUnusedOptions();
 
-    m_message_wnd = GG::Wnd::Create<MessageWnd>(GG::INTERACTIVE | GG::DRAGABLE | GG::ONTOP | GG::RESIZABLE |
-                                                CLOSABLE | PINABLE, MESSAGE_WND_NAME);
-    m_player_list_wnd = GG::Wnd::Create<PlayerListWnd>(PLAYER_LIST_WND_NAME);
     InitializeWindows();
 
-    m_intro_screen = GG::Wnd::Create<IntroScreen>();
-    m_multiplayer_lobby_wnd = GG::Wnd::Create<MultiPlayerLobbyWnd>();
-    m_password_enter_wnd = GG::Wnd::Create<PasswordEnterWnd>();
-
     GetOptionsDB().OptionChangedSignal("video.fullscreen.width").connect(
         boost::bind(&ClientUI::HandleSizeChange, this, true));
     GetOptionsDB().OptionChangedSignal("video.fullscreen.height").connect(
@@ -676,14 +657,24 @@ MapWnd const* ClientUI::GetMapWndConst() const {
     return m_map_wnd.get();
 }
 
-std::shared_ptr<MessageWnd> ClientUI::GetMessageWnd()
-{ return m_message_wnd; }
+std::shared_ptr<MessageWnd> ClientUI::GetMessageWnd() {
+    if (!m_message_wnd)
+        m_message_wnd = GG::Wnd::Create<MessageWnd>(GG::INTERACTIVE | GG::DRAGABLE | GG::ONTOP | GG::RESIZABLE |
+                                                    CLOSABLE | PINABLE, MESSAGE_WND_NAME);
+    return m_message_wnd;
+}
 
-std::shared_ptr<PlayerListWnd> ClientUI::GetPlayerListWnd()
-{ return m_player_list_wnd; }
+std::shared_ptr<PlayerListWnd> ClientUI::GetPlayerListWnd() {
+    if (!m_player_list_wnd)
+        m_player_list_wnd = GG::Wnd::Create<PlayerListWnd>(PLAYER_LIST_WND_NAME);
+    return m_player_list_wnd;
+}
 
-std::shared_ptr<IntroScreen> ClientUI::GetIntroScreen()
-{ return m_intro_screen; }
+std::shared_ptr<IntroScreen> ClientUI::GetIntroScreen() {
+    if (!m_intro_screen)
+        m_intro_screen = GG::Wnd::Create<IntroScreen>();
+    return m_intro_screen;
+}
 
 void ClientUI::ShowIntroScreen() {
     if (m_map_wnd) {
@@ -693,9 +684,9 @@ void ClientUI::ShowIntroScreen() {
     }
 
     // Update intro screen Load & Continue buttons if all savegames are deleted.
-    m_intro_screen->RequirePreRender();
+    GetIntroScreen()->RequirePreRender();
 
-    HumanClientApp::GetApp()->Register(m_intro_screen);
+    HumanClientApp::GetApp()->Register(GetIntroScreen());
     HumanClientApp::GetApp()->Remove(m_message_wnd);
     HumanClientApp::GetApp()->Remove(m_player_list_wnd);
     HumanClientApp::GetApp()->Remove(m_multiplayer_lobby_wnd);
@@ -708,18 +699,23 @@ void ClientUI::ShowMultiPlayerLobbyWnd() {
         m_map_wnd->Hide();
     }
 
-    HumanClientApp::GetApp()->Register(m_multiplayer_lobby_wnd);
+    HumanClientApp::GetApp()->Register(GetMultiPlayerLobbyWnd());
     HumanClientApp::GetApp()->Remove(m_message_wnd);
     HumanClientApp::GetApp()->Remove(m_player_list_wnd);
     HumanClientApp::GetApp()->Remove(m_intro_screen);
 }
 
-std::shared_ptr<MultiPlayerLobbyWnd> ClientUI::GetMultiPlayerLobbyWnd()
-{ return m_multiplayer_lobby_wnd; }
-
-std::shared_ptr<PasswordEnterWnd> ClientUI::GetPasswordEnterWnd()
-{ return m_password_enter_wnd; }
+std::shared_ptr<MultiPlayerLobbyWnd> ClientUI::GetMultiPlayerLobbyWnd() {
+    if (!m_multiplayer_lobby_wnd)
+        m_multiplayer_lobby_wnd = GG::Wnd::Create<MultiPlayerLobbyWnd>();
+    return m_multiplayer_lobby_wnd;
+}
 
+std::shared_ptr<PasswordEnterWnd> ClientUI::GetPasswordEnterWnd() {
+    if (!m_password_enter_wnd)
+        m_password_enter_wnd = GG::Wnd::Create<PasswordEnterWnd>();
+    return m_password_enter_wnd;
+}
 
 std::shared_ptr<SaveFileDialog> ClientUI::GetSaveFileDialog()
 { return m_savefile_dialog; }
@@ -769,19 +765,27 @@ std::string ClientUI::FormatTimestamp(boost::posix_time::ptime timestamp) {
 }
 
 bool ClientUI::ZoomToObject(const std::string& name) {
-    for (auto& obj : GetUniverse().Objects().FindObjects<UniverseObject>())
+    // try first by finding the object by name
+    for (auto& obj : GetUniverse().Objects().all<UniverseObject>())
         if (boost::iequals(obj->Name(), name))
             return ZoomToObject(obj->ID());
+
+    // try again by converting string to an ID
+    try {
+        return ZoomToObject(std::stoi(name));
+    } catch (...) {
+    }
+
     return false;
 }
 
 bool ClientUI::ZoomToObject(int id) {
     return ZoomToSystem(id)     || ZoomToPlanet(id) || ZoomToBuilding(id)   ||
-           ZoomToFleet(id)      || ZoomToShip(id);
+           ZoomToFleet(id)      || ZoomToShip(id)   || ZoomToField(id);
 }
 
 bool ClientUI::ZoomToPlanet(int id) {
-    if (auto planet = GetPlanet(id)) {
+    if (auto planet = Objects().get<Planet>(id)) {
         GetMapWnd()->CenterOnObject(planet->SystemID());
         GetMapWnd()->SelectSystem(planet->SystemID());
         GetMapWnd()->SelectPlanet(id);
@@ -791,13 +795,13 @@ bool ClientUI::ZoomToPlanet(int id) {
 }
 
 bool ClientUI::ZoomToPlanetPedia(int id) {
-    if (GetPlanet(id))
+    if (Objects().get<Planet>(id))
         GetMapWnd()->ShowPlanet(id);
     return false;
 }
 
 bool ClientUI::ZoomToSystem(int id) {
-    if (auto system = GetSystem(id)) {
+    if (auto system = Objects().get<System>(id)) {
         ZoomToSystem(system);
         return true;
     }
@@ -805,7 +809,7 @@ bool ClientUI::ZoomToSystem(int id) {
 }
 
 bool ClientUI::ZoomToFleet(int id) {
-    if (auto fleet = GetFleet(id)) {
+    if (auto fleet = Objects().get<Fleet>(id)) {
         ZoomToFleet(fleet);
         return true;
     }
@@ -813,13 +817,13 @@ bool ClientUI::ZoomToFleet(int id) {
 }
 
 bool ClientUI::ZoomToShip(int id) {
-    if (auto ship = GetShip(id))
+    if (auto ship = Objects().get<Ship>(id))
         return ZoomToFleet(ship->FleetID());
     return false;
 }
 
 bool ClientUI::ZoomToBuilding(int id) {
-    if (auto building = GetBuilding(id)) {
+    if (auto building = Objects().get<Building>(id)) {
         ZoomToBuildingType(building->BuildingTypeName());
         return ZoomToPlanet(building->PlanetID());
     }
@@ -827,7 +831,7 @@ bool ClientUI::ZoomToBuilding(int id) {
 }
 
 bool ClientUI::ZoomToField(int id) {
-    //if (auto field = GetField(id)) {
+    //if (auto field = Objects().get<Field>(id)) {
     //  // TODO: implement this
     //}
     return false;
@@ -874,11 +878,11 @@ bool ClientUI::ZoomToContent(const std::string& name, bool reverse_lookup/* = fa
             if (boost::iequals(name, UserString(special_name)))
                 return ZoomToSpecial(special_name);
 
-        for (const auto& entry : GetHullTypeManager())
+        for (const auto& entry : GetShipHullManager())
             if (boost::iequals(name, UserString(entry.first)))
                 return ZoomToShipHull(entry.first);
 
-        for (const auto& entry : GetPartTypeManager())
+        for (const auto& entry : GetShipPartManager())
             if (boost::iequals(name, UserString(entry.first)))
                 return ZoomToShipPart(entry.first);
 
@@ -921,16 +925,16 @@ bool ClientUI::ZoomToSpecial(const std::string& special_name) {
 }
 
 bool ClientUI::ZoomToShipHull(const std::string& hull_name) {
-    if (!GetHullType(hull_name))
+    if (!GetShipHull(hull_name))
         return false;
-    GetMapWnd()->ShowHullType(hull_name);
+    GetMapWnd()->ShowShipHull(hull_name);
     return true;
 }
 
 bool ClientUI::ZoomToShipPart(const std::string& part_name) {
-    if (!GetPartType(part_name))
+    if (!GetShipPart(part_name))
         return false;
-    GetMapWnd()->ShowPartType(part_name);
+    GetMapWnd()->ShowShipPart(part_name);
     return true;
 }
 
@@ -973,7 +977,7 @@ bool ClientUI::ZoomToEncyclopediaEntry(const std::string& str) {
 }
 
 void ClientUI::DumpObject(int object_id) {
-    auto obj = GetUniverseObject(object_id);
+    auto obj = Objects().get(object_id);
     if (!obj)
         return;
     m_message_wnd->HandleLogMessage(obj->Dump() + "\n");
@@ -986,8 +990,8 @@ void ClientUI::InitializeWindows() {
     const GG::Pt player_list_ul(MESSAGE_PANEL_WIDTH, GG::GUI::GetGUI()->AppHeight() - PANEL_HEIGHT);
     const GG::Pt player_list_wh(PLAYER_LIST_PANEL_WIDTH, PANEL_HEIGHT);
 
-    m_message_wnd->    InitSizeMove(message_ul,     message_ul + message_wh);
-    m_player_list_wnd->InitSizeMove(player_list_ul, player_list_ul + player_list_wh);
+    GetMessageWnd()->InitSizeMove(message_ul,     message_ul + message_wh);
+    GetPlayerListWnd()->InitSizeMove(player_list_ul, player_list_ul + player_list_wh);
 }
 
 void ClientUI::HandleSizeChange(bool fullscreen) const {
@@ -1053,9 +1057,10 @@ ClientUI* ClientUI::GetClientUI()
 { return s_the_UI; }
 
 void ClientUI::MessageBox(const std::string& message, bool play_alert_sound/* = false*/) {
-    auto dlg = GG::Wnd::Create<GG::ThreeButtonDlg>(GG::X(320), GG::Y(200), message, GetFont(Pts()+2),
-                                                   WndColor(), WndOuterBorderColor(), CtrlColor(), TextColor(), 1,
-                                                   UserString("OK"));
+    auto dlg = GG::GUI::GetGUI()->GetStyleFactory()->NewThreeButtonDlg(
+        GG::X(320), GG::Y(200), message, GetFont(Pts()+2),
+        WndColor(), WndOuterBorderColor(), CtrlColor(), TextColor(),
+        1, UserString("OK"));
     if (play_alert_sound)
         Sound::GetSound().PlaySound(GetOptionsDB().Get<std::string>("ui.alert.sound.path"), true);
     dlg->Run();
@@ -1065,10 +1070,14 @@ std::shared_ptr<GG::Texture> ClientUI::GetTexture(const boost::filesystem::path&
     std::shared_ptr<GG::Texture> retval;
     try {
         retval = HumanClientApp::GetApp()->GetTexture(path, mipmap);
-    } catch(const std::exception& e) {
+    } catch (const std::exception& e) {
         ErrorLogger() << "Unable to load texture \"" + path.generic_string() + "\"\n"
             "reason: " << e.what();
         retval = HumanClientApp::GetApp()->GetTexture(ClientUI::ArtDir() / "misc" / "missing.png", mipmap);
+    } catch (...) {
+        ErrorLogger() << "Unable to load texture \"" + path.generic_string() + "\"\n"
+            "reason unknown...?";
+        retval = HumanClientApp::GetApp()->GetTexture(ClientUI::ArtDir() / "misc" / "missing.png", mipmap);
     }
 #ifdef FREEORION_MACOSX
     if (!mipmap)
@@ -1154,29 +1163,23 @@ int FontBasedUpscale(int x) {
 }
 
 namespace GG {
-    std::ostream& operator<<(std::ostream& os, const Clr& clr) {
-        os << "(" << +clr.r << "," << +clr.g << "," << +clr.b << "," << +clr.a << ")";
-        return os;
-    }
-
     std::istream& operator>>(std::istream& is, Clr& clr) {
-        namespace classic = boost::spirit::classic;
-        using classic::space_p;
-        using classic::int_p;
-        using classic::assign;
-        classic::rule<> color_p =
-            classic::ch_p('(') >> *space_p >>
-            int_p[assign(clr.r)] >> *space_p >> ',' >> *space_p >>
-            int_p[assign(clr.g)] >> *space_p >> ',' >> *space_p >>
-            int_p[assign(clr.b)] >> *space_p >> ',' >> *space_p >>
-            int_p[assign(clr.a)] >> *space_p >> ')';
+        namespace qi = boost::spirit::qi;
+        namespace phx = boost::phoenix;
         std::string str;
-        char c;
-        do {
-            is >> c;
-            str += c;
-        } while (is && c != ')');
-        if (!classic::parse(str.c_str(), color_p).full ||
+        std::getline(is, str, ')');
+        str.push_back(')');
+        bool parsed = qi::phrase_parse(
+            str.begin(), str.end(),
+            (
+                qi::lit('(') >>
+                qi::int_[phx::ref(clr.r) = qi::_1] >> ',' >>
+                qi::int_[phx::ref(clr.g) = qi::_1] >> ',' >>
+                qi::int_[phx::ref(clr.b) = qi::_1] >> ',' >>
+                qi::int_[phx::ref(clr.a) = qi::_1] >> ')'),
+            qi::blank
+        );
+        if (!parsed ||
             clr.r < 0 || 255 < clr.r ||
             clr.g < 0 || 255 < clr.g ||
             clr.b < 0 || 255 < clr.b ||
