@@ -2,22 +2,29 @@
 #define COMBATLOGWND_H
 
 #include "../CUIControls.h"
-#include <boost/scoped_ptr.hpp>
+
+#include <memory>
+
 
 /// Display a log of combat events with expandable log sections with more details of a combat event
 class CombatLogWnd : public GG::Wnd {
 public:
     CombatLogWnd(GG::X w, GG::Y h);
+
     virtual ~CombatLogWnd();
 
     /** \name Accessors */ ///@{
-    virtual GG::Pt ClientUpperLeft() const;
-    virtual GG::Pt ClientLowerRight() const;
-    virtual GG::Pt MinUsableSize() const;
+    GG::Pt ClientUpperLeft() const override;
+
+    GG::Pt ClientLowerRight() const override;
+
+    GG::Pt MinUsableSize() const override;
     //@}
 
     /** \name Mutators */ //@{
-    void SetFont(boost::shared_ptr<GG::Font> font);
+    void PreRender() override;
+
+    void SetFont(std::shared_ptr<GG::Font> font);
     /// Set which log to show
     void SetLog(int log_id);
     //@}
@@ -31,11 +38,11 @@ public:
     /* The window may have becomem visible.*/
     void HandleMadeVisible();
 
-    class CombatLogWndImpl;
+    class Impl;
+
 private:
-    //TODO C++11 unique_ptr
-    friend class CombatLogWndImpl;
-    const boost::scoped_ptr<CombatLogWndImpl> pimpl;
+    friend class Impl;
+    std::unique_ptr<Impl> const m_impl;
 
     /// The number of pixels to leave between the text and the frame.
     static const int MARGIN = 5;
