@@ -36,24 +36,24 @@ public:
         m_tabs->AddWnd(m_log_scroller, UserString("COMBAT_LOG"));
         m_wnd.AttachChild(m_tabs);
 
-        m_log->LinkClickedSignal.connect(
-            boost::bind(&Impl::HandleLinkClick, this, _1, _2));
-        m_log->LinkDoubleClickedSignal.connect(
-            boost::bind(&Impl::HandleLinkDoubleClick, this, _1, _2));
-        m_log->LinkRightClickedSignal.connect(
-            boost::bind(&Impl::HandleLinkDoubleClick, this, _1, _2));
-        m_log->WndChangedSignal.connect(
-            boost::bind(&Impl::HandleWindowChanged, this));
+#if BOOST_VERSION >= 106000
+        using boost::placeholders::_1;
+        using boost::placeholders::_2;
+        using boost::placeholders::_3;
+#endif
+
+        m_log->LinkClickedSignal.connect(boost::bind(&Impl::HandleLinkClick, this, _1, _2));
+        m_log->LinkDoubleClickedSignal.connect(boost::bind(&Impl::HandleLinkDoubleClick, this, _1, _2));
+        m_log->LinkRightClickedSignal.connect(boost::bind(&Impl::HandleLinkDoubleClick, this, _1, _2));
+        m_log->WndChangedSignal.connect(boost::bind(&Impl::HandleWindowChanged, this));
 
         // Catch the window-changed signal from the tab bar so that layout
         // updates can be performed for the newly-selected window.
-        m_tabs->TabChangedSignal.connect(
-            boost::bind(&Impl::HandleTabChanged, this, _1));
+        m_tabs->TabChangedSignal.connect(boost::bind(&Impl::HandleTabChanged, this, _1));
 
         // This can be called whether m_graphical is the selected window or
         // not, but it will still only use the min size of the selected window.
-        m_graphical->MinSizeChangedSignal.connect(
-            boost::bind(&Impl::UpdateMinSize, this));
+        m_graphical->MinSizeChangedSignal.connect(boost::bind(&Impl::UpdateMinSize, this));
     }
 
     void SetLog(int log_id) {
@@ -133,13 +133,13 @@ public:
 
         } catch (const boost::bad_lexical_cast&) {
             ErrorLogger() << "CombatReport::HandleLinkClick caught lexical cast exception for link type: " << link_type << " and data: " << data;
+        } catch (const std::exception& e) {
+            ErrorLogger() << "CombatReport::HandleLinkClick caught exception: " << e.what();
         }
-
     }
 
-    void HandleLinkDoubleClick(const std::string& link_type, const std::string& data) {
-        HandleLinkClick(link_type, data);
-    }
+    void HandleLinkDoubleClick(const std::string& link_type, const std::string& data)
+    { HandleLinkClick(link_type, data); }
 
     GG::Pt GetMinSize() const
     { return m_min_size; }
@@ -207,8 +207,7 @@ private:
 CombatReportWnd::CombatReportWnd(const std::string& config_name) :
     CUIWnd(UserString("COMBAT_REPORT_TITLE"),
            GG::INTERACTIVE | GG::RESIZABLE | GG::DRAGABLE | GG::ONTOP | CLOSABLE,
-           config_name, false),
-    m_impl(nullptr)
+           config_name, false)
 {}
 
 void CombatReportWnd::CompleteConstruction() {
