@@ -7,23 +7,12 @@
 class EncyclopediaDetailPanel;
 struct SaveGameUIData;
 
-struct Availability {
-    // Declaring an enum inside a struct makes the syntax when using the enum with tuples simpler,
-    // without polluting the global namespace with 3 generic names.
-
-    enum Enum {Obsolete,  // A design/part is researched/known by the player has marked it obsolete
-               Available, // A design/part is researched/known and currently available
-               Future     // A design/part is unresearched and hence not available
-    };
-};
-
 /** ShipDesignManager tracks information known to the client about ShipDesigns.
   * This includes the order of designs to be shown DesignWnd and the
   * BuildDesignator. */
 class ShipDesignManager {
 public:
     /** Designs provides ordered lists of designs for display in the UI.
-
      Derived classes provide an implementation for the pure virtual
      OrderedIDs(), which provides ship design ids in display order. They may
      also provide additional functionality used by the DesignWnd. */
@@ -60,17 +49,15 @@ public:
 
     /** \name Mutators */ //@{
     void SizeMove(const GG::Pt& ul, const GG::Pt& lr) override;
-
     void Render() override;
-
     void Reset();
     void Sanitize();
 
-    /** Shows \a part_type in design encyclopedia window */
-    void ShowPartTypeInEncyclopedia(const std::string& part_type);
+    //! Shows @a ship_part in design encyclopedia window
+    void ShowShipPartInEncyclopedia(const std::string& ship_part);
 
-    /** Shows \a hull_type in design encyclopedia window */
-    void ShowHullTypeInEncyclopedia(const std::string& hull_type);
+    //! Shows @p ship_hull in design encyclopedia window
+    void ShowShipHullInEncyclopedia(const std::string& ship_hull);
 
     /** Shows ship design with id \a design_id in design encyclopedia window */
     void ShowShipDesignInEncyclopedia(int design_id);
