@@ -11,18 +11,18 @@
 class EmpireColorSelector;
 class SpeciesSelector;
 struct GalaxySetupData;
-
+class CUIEdit;
 
 /** Displays game rules options */
 class GameRulesPanel : public GG::Control {
 public:
     /** \name Structors*/ //!@{
-    GameRulesPanel(GG::X w = GG::X(FontBasedUpscale(305)), GG::Y h = GG::Y(330));
+    GameRulesPanel(GG::X w = GG::X1, GG::Y h = GG::Y1);
     //!@}
     void CompleteConstruction() override;
 
     /** \name Accessors*/ //!@{
-    std::vector<std::pair<std::string, std::string>> GetRulesAsStrings() const;
+    std::map<std::string, std::string> GetRulesAsStrings() const;
     //!@}
 
     mutable boost::signals2::signal<void ()> SettingsChangedSignal;
@@ -80,7 +80,7 @@ public:
     GalaxySetupOption               GetSpecialsFrequency() const;   //!< Returns the rarity of planetary and system specials
     GalaxySetupOption               GetMonsterFrequency() const;    //!< Returns the frequency of space monsters
     GalaxySetupOption               GetNativeFrequency() const;     //!< Returns the frequency of natives
-    Aggression                      GetAIAggression() const;        //!< Returns the  maximum AI aggression level 
+    Aggression                      GetAIAggression() const;        //!< Returns the  maximum AI aggression level
 
     /** Returns the current preview image texture. */
     std::shared_ptr<GG::Texture> PreviewImage() const;
@@ -108,7 +108,7 @@ private:
     void ShapeChanged(GG::ListBox::iterator it);
 
     std::shared_ptr<GG::Label>          m_seed_label;
-    std::shared_ptr<GG::Edit>           m_seed_edit;            //!< The seed used in the generation of the galaxy;
+    std::shared_ptr<CUIEdit>            m_seed_edit;            //!< The seed used in the generation of the galaxy;
     std::string                         m_seed;
     std::shared_ptr<GG::Button>         m_random;               //!< Random seed button;
     std::shared_ptr<GG::Label>          m_stars_label;
@@ -152,7 +152,7 @@ public:
     GG::Clr                 EmpireColor() const;
     const std::string&      StartingSpeciesName() const;
     int                     NumberAIs() const;
-    std::vector<std::pair<std::string, std::string>>
+    std::map<std::string, std::string>
                             GetRulesAsStrings() const;
     //!@}
 
