@@ -26,6 +26,8 @@ public:
     GG::Pt MinUsableSize() const override;
 
     bool            LoadGameSelected() const;
+
+    std::string     GetChatText() const;
     //@}
 
     /** \name Mutators */ //@{
@@ -40,6 +42,7 @@ public:
                                 const std::string& player_name,
                                 GG::Clr text_color,
                                 const boost::posix_time::ptime& timestamp);
+    void            TurnPhaseUpdate(Message::TurnProgressPhase phase_id);
     void            LobbyUpdate(const MultiplayerLobbyData& lobby_data);
     void            Refresh();
     void            CleanupChat();
