@@ -2,10 +2,10 @@
 
 #include "CUIControls.h"
 #include "../client/human/HumanClientApp.h"
+#include "../client/ClientNetworking.h"
 #include "../Empire/Empire.h"
 #include "../Empire/EmpireManager.h"
 #include "../network/Message.h"
-#include "../network/ClientNetworking.h"
 #include "../util/i18n.h"
 #include "../util/Logger.h"
 #include "../util/OptionsDB.h"
@@ -14,17 +14,21 @@
 #include "../universe/System.h"
 #include "../universe/Enums.h"
 
-#include <GG/DrawUtil.h>
-
 #include <algorithm>
 
 namespace {
-    const int           DATA_PANEL_BORDER = 1;
+    const int DATA_PANEL_BORDER = 1;
 
     std::shared_ptr<GG::Texture> AIIcon() {
         static std::shared_ptr<GG::Texture> retval = ClientUI::GetTexture(ClientUI::ArtDir() / "icons" / "ai.png");
         return retval;
     }
+
+    std::shared_ptr<GG::Texture> MessageIcon() {
+        static std::shared_ptr<GG::Texture> retval = ClientUI::GetTexture(ClientUI::ArtDir() / "icons" / "buttons" / "messages.png");
+        return retval;
+    }
+
     std::shared_ptr<GG::Texture> HumanIcon() {
         static std::shared_ptr<GG::Texture> retval = ClientUI::GetTexture(ClientUI::ArtDir() / "icons" / "human.png");
         return retval;
@@ -49,10 +53,6 @@ namespace {
         static std::shared_ptr<GG::Texture> retval = ClientUI::GetTexture(ClientUI::ArtDir() / "icons" / "ready.png");
         return retval;
     }
-    std::shared_ptr<GG::Texture> CombatIcon() {
-        static std::shared_ptr<GG::Texture> retval = ClientUI::GetTexture(ClientUI::ArtDir() / "icons" / "combat.png");
-        return retval;
-    }
     std::shared_ptr<GG::Texture> WarIcon() {
         static std::shared_ptr<GG::Texture> retval = ClientUI::GetTexture(ClientUI::ArtDir() / "icons" / "war.png");
         return retval;
@@ -95,6 +95,128 @@ namespace {
     }
 
 
+    ////////////////////////////////////////////////
+    // DiplomaticStatusIndicator
+    ////////////////////////////////////////////////
+    /** Shows specified diplomatic status from specified empire to each other empire. */
+    class DiplomaticStatusIndicator : public GG::Control {
+    public:
+        DiplomaticStatusIndicator(GG::X w, GG::Y h, int empire_id, DiplomaticStatus diplo_status) :
+            Control(GG::X0, GG::Y0, w, h, GG::INTERACTIVE),
+            m_empire_id(empire_id),
+            m_diplo_status(diplo_status)
+        {}
+
+        void CompleteConstruction() override {
+            GG::Control::CompleteConstruction();
+
+            switch (m_diplo_status) {
+            case DIPLO_WAR:
+                m_icon = WarIcon();
+                break;
+            case DIPLO_PEACE:
+                m_icon = PeaceIcon();
+                break;
+            case DIPLO_ALLIED:
+                m_icon = AlliedIcon();
+                break;
+            default:
+                m_icon = UnknownIcon();
+                break;
+            }
+
+        }
+
+        void Update() {
+            const ClientApp* app = ClientApp::GetApp();
+            if (!app) {
+                ErrorLogger() << "DiplomaticStatusIndicator::Render couldn't get client app!";
+                return;
+            }
+
+            // add id for each empire with specified diplomatic status
+            m_empire_ids.clear();
+
+            for (const auto& empire : Empires()) {
+                int empire_id = empire.second->EmpireID();
+
+                if (empire.second->Eliminated()) continue;
+                if (m_empire_id == empire_id) continue;
+
+                if (Empires().GetDiplomaticStatus(empire_id, m_empire_id) == m_diplo_status) {
+                    m_empire_ids.emplace_back(empire_id);
+                }
+            }
+
+            // generate tooltip text
+            std::string tooltip_title = "";
+            std::string tooltip_text = "";
+
+            switch (m_diplo_status) {
+            case DIPLO_WAR:
+                tooltip_title = UserString("AT_WAR_WITH") + ":";
+                break;
+            case DIPLO_PEACE:
+                tooltip_title = UserString("AT_PEACE_WITH") + ":";
+                break;
+            case DIPLO_ALLIED:
+                tooltip_title = UserString("ALLIED_WITH") + ":";
+                break;
+            default:
+                break;
+            }
+
+            if (m_empire_ids.size() == 0)
+                tooltip_text += UserString("NONE");
+
+            for (int empire_id : m_empire_ids) {
+                const Empire* empire = GetEmpire(empire_id);
+                if (!empire) continue;
+
+                tooltip_text += GG::RgbaTag(empire->Color()) + empire->Name() + "\n";
+            }
+
+            // add tooltip
+            SetBrowseInfoWnd(GG::Wnd::Create<TextBrowseWnd>(tooltip_title, tooltip_text));
+            SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
+        }
+
+        void Render() override {
+            int ICON_SIZE = IconSize();
+            GG::Pt ul = UpperLeft();
+            const GG::Clr& border_clr = ClientUI::WndOuterBorderColor();
+
+            // diplomatic status icon
+            glColor(GG::CLR_WHITE);
+            m_icon->OrthoBlit(ul, ul + GG::Pt(GG::X(ICON_SIZE), GG::Y(ICON_SIZE)));
+
+            // empire color squares; move squares to the left if empire with lower id was eliminated
+            int square_position = 0;
+            for (const auto& empire : Empires()) {
+                if (empire.second->Eliminated()) continue;
+                square_position++;
+                if (std::find(m_empire_ids.begin(), m_empire_ids.end(), empire.first) != m_empire_ids.end()) {
+                    const GG::Clr& square_color = empire.second->Color();
+                    GG::Pt square_ul = ul + GG::Pt(GG::X(square_position * (ICON_SIZE + PAD)), GG::Y0);
+                    GG::FlatRectangle(square_ul, square_ul + GG::Pt(GG::X(ICON_SIZE), GG::Y(ICON_SIZE)), square_color, border_clr, DATA_PANEL_BORDER);
+                }
+            }
+        }
+
+        void RClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) override { ForwardEventToParent(); }
+        void RButtonDown(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) override { ForwardEventToParent(); }
+
+    private:
+        int                                        m_empire_id;
+        std::vector<int>                           m_empire_ids;
+        DiplomaticStatus                           m_diplo_status;
+        std::shared_ptr<GG::Texture>               m_icon;
+
+        int IconSize() const { return Value(Height()); }
+        int PAD = 3;
+    };
+
+
     ////////////////////////////////////////////////
     // PlayerDataPanel
     ////////////////////////////////////////////////
@@ -102,22 +224,12 @@ namespace {
       * each PlayerRow. */
     class PlayerDataPanel : public GG::Control {
     public:
-        PlayerDataPanel(GG::X w, GG::Y h, int player_id) :
+        PlayerDataPanel(GG::X w, GG::Y h, int player_id, int empire_id) :
             Control(GG::X0, GG::Y0, w, h, GG::NO_WND_FLAGS),
             m_player_id(player_id),
-            //m_player_name_text(nullptr),
-            m_empire_name_text(nullptr),
-            m_empire_ship_text(nullptr),
-            m_empire_planet_text(nullptr),
-            m_empire_production_text(nullptr),
-            m_empire_research_text(nullptr),
-            m_empire_detection_text(nullptr),
+            m_empire_id(empire_id),
             m_diplo_status(INVALID_DIPLOMATIC_STATUS),
-            m_player_status(Message::PLAYING_TURN),
-            m_player_type(Networking::INVALID_CLIENT_TYPE),
-            m_host(false),
-            m_win_status(NEITHER),
-            m_selected(false)
+            m_player_type(Networking::INVALID_CLIENT_TYPE)
         {}
 
         void CompleteConstruction() override {
@@ -133,6 +245,10 @@ namespace {
             m_empire_research_text = GG::Wnd::Create<CUILabel>("", GG::FORMAT_LEFT);
             m_empire_detection_text = GG::Wnd::Create<CUILabel>("", GG::FORMAT_LEFT);
 
+            m_war_indicator =      GG::Wnd::Create<DiplomaticStatusIndicator>(GG::X0, Height(), m_empire_id, DIPLO_WAR);
+            m_peace_indicator =    GG::Wnd::Create<DiplomaticStatusIndicator>(GG::X0, Height(), m_empire_id, DIPLO_PEACE);
+            m_allied_indicator =   GG::Wnd::Create<DiplomaticStatusIndicator>(GG::X0, Height(), m_empire_id, DIPLO_ALLIED);
+
             //AttachChild(m_player_name_text);
             AttachChild(m_empire_name_text);
             AttachChild(m_empire_ship_text);
@@ -140,6 +256,9 @@ namespace {
             AttachChild(m_empire_production_text);
             AttachChild(m_empire_research_text);
             AttachChild(m_empire_detection_text);
+            AttachChild(m_war_indicator);
+            AttachChild(m_peace_indicator);
+            AttachChild(m_allied_indicator);
 
             DoLayout();
             Update();
@@ -183,7 +302,7 @@ namespace {
                 ErrorLogger() << "PlayerDataPanel::Render couldn't get client app!";
                 return;
             }
-            if (m_player_id != app->PlayerID()) {
+            if (m_empire_id != app->EmpireID()) {
                 // render diplomacy icon
                 switch (m_diplo_status) {
                 case DIPLO_WAR:                 WarIcon()->OrthoBlit(    UpperLeft() + m_diplo_status_icon_ul, UpperLeft() + m_diplo_status_icon_ul + ICON_SIZE); break;
@@ -194,13 +313,15 @@ namespace {
                 }
             }
 
+            // render incoming diplomatic message icon, if there is one
+            const DiplomaticMessage& incoming_message_to_client =
+                Empires().GetDiplomaticMessage(m_empire_id, app->EmpireID());
+            if (incoming_message_to_client.GetType() != DiplomaticMessage::INVALID_DIPLOMATIC_MESSAGE_TYPE)
+                MessageIcon()->OrthoBlit(UpperLeft() + m_diplo_msg_ul, UpperLeft() + m_diplo_msg_ul + ICON_SIZE);
+
             // render player status icon
-            switch (m_player_status) {
-            case Message::PLAYING_TURN:     PlayingIcon()->OrthoBlit(UpperLeft() + m_player_status_icon_ul, UpperLeft() + m_player_status_icon_ul + ICON_SIZE); break;
-            case Message::RESOLVING_COMBAT: CombatIcon()->OrthoBlit( UpperLeft() + m_player_status_icon_ul, UpperLeft() + m_player_status_icon_ul + ICON_SIZE); break;
-            case Message::WAITING:          WaitingIcon()->OrthoBlit(UpperLeft() + m_player_status_icon_ul, UpperLeft() + m_player_status_icon_ul + ICON_SIZE); break;
-            default:    break;
-            }
+            if (const auto *empire = GetEmpire(m_empire_id))
+                (empire->Ready() ? WaitingIcon() : PlayingIcon())->OrthoBlit(UpperLeft() + m_player_status_icon_ul, UpperLeft() + m_player_status_icon_ul + ICON_SIZE);
 
             // render player type icon
             switch (m_player_type) {
@@ -214,7 +335,12 @@ namespace {
             if (m_host)
                 HostIcon()->OrthoBlit(UpperLeft() + m_host_icon_ul, UpperLeft() + m_host_icon_ul + ICON_SIZE);
 
+            // render diplomatic status indicators
+            m_war_indicator->Render();
+            m_peace_indicator->Render();
+            m_allied_indicator->Render();
 
+            // render win/lose icon
             switch (m_win_status)
             {
             case WON:     WonIcon()->OrthoBlit(UpperLeft() + m_win_status_icon_ul, UpperLeft() + m_win_status_icon_ul + ICON_SIZE); break;
@@ -223,7 +349,7 @@ namespace {
             }
         }
 
-        void            Select(bool b)
+        void Select(bool b)
         { m_selected = b; }
 
         void SizeMove(const GG::Pt& ul, const GG::Pt& lr) override {
@@ -233,33 +359,40 @@ namespace {
                 DoLayout();
         }
 
-        void            Update() {
+        void Update() {
             const ClientApp* app = ClientApp::GetApp();
             if (!app) {
                 ErrorLogger() << "PlayerDataPanel::Update couldn't get client app!";
                 return;
             }
 
+            // empire name
+            std::string empire_name;
             const std::map<int, PlayerInfo>& players = app->Players();
 
             auto player_it = players.find(m_player_id);
-            if (player_it == players.end()) {
-                ErrorLogger() << "PlayerDataPanel::Update couldn't find player with id " << m_player_id;
-                return;
+            if (player_it != players.end()) {
+                const PlayerInfo& player_info = player_it->second;
+
+                m_player_type = player_info.client_type;
+                m_host = player_info.host;
+                empire_name = player_info.name;
+            } else {
+                m_player_type = Networking::INVALID_CLIENT_TYPE;
+                m_host = false;
             }
-            const PlayerInfo& player_info = player_it->second;
 
             // if player has an empire, get its name and colour.  (Some player types might not have empires...)
             GG::Clr empire_color = ClientUI::TextColor();
-            std::string empire_name;
-            const Empire* empire = GetEmpire(player_info.empire_id);
+            const Empire* empire = GetEmpire(m_empire_id);
             if (empire) {
                 empire_color = empire->Color();
+                // ignore player name
                 empire_name = empire->Name();
-                if (player_info.empire_id == ALL_EMPIRES || player_info.empire_id == app->EmpireID())
+                if (m_empire_id == ALL_EMPIRES || m_empire_id == app->EmpireID())
                     m_diplo_status = INVALID_DIPLOMATIC_STATUS;
                 else
-                    m_diplo_status = Empires().GetDiplomaticStatus(player_info.empire_id, app->EmpireID());
+                    m_diplo_status = Empires().GetDiplomaticStatus(m_empire_id, app->EmpireID());
                 if (empire->Won())
                     m_win_status = WON; // even if you later get eliminated, you still won
                 else if (empire->Eliminated())
@@ -283,7 +416,7 @@ namespace {
             const std::set<int>& this_client_known_destroyed_objects = GetUniverse().EmpireKnownDestroyedObjectIDs(HumanClientApp::GetApp()->EmpireID());
             const std::set<int>& this_client_stale_object_info       = GetUniverse().EmpireStaleKnowledgeObjectIDs(HumanClientApp::GetApp()->EmpireID());
 
-            for (auto& ship : objects.FindObjects<Ship>()) {
+            for (auto& ship : objects.all<Ship>()) {
                 if (empire) {
                     if (ship->Owner() == empire->EmpireID()
                         && !this_client_known_destroyed_objects.count(ship->ID())
@@ -293,12 +426,12 @@ namespace {
                 }
             }
 
-            for (auto& planet : objects.FindObjects<Planet>()) {
+            for (auto& planet : objects.all<Planet>()) {
                 if (empire) {
                     if (planet->Owner() == empire->EmpireID()) {
                         empires_planet_count      += 1;
-                        empires_production_points += planet->InitialMeterValue(METER_INDUSTRY);
-                        empires_research_points   += planet->InitialMeterValue(METER_RESEARCH);
+                        empires_production_points += planet->GetMeter(METER_INDUSTRY)->Initial();
+                        empires_research_points   += planet->GetMeter(METER_RESEARCH)->Initial();
                     }
                 }
             }
@@ -341,17 +474,14 @@ namespace {
             m_empire_research_text->SetText(research_text);
             m_empire_detection_text->SetText(detection_text);
 
-            m_player_type = player_info.client_type;
-            m_host = player_info.host;
+            m_war_indicator->Update();
+            m_peace_indicator->Update();
+            m_allied_indicator->Update();
         }
-
-        void            SetStatus(Message::PlayerStatus player_status)
-        { m_player_status = player_status; }
-
     private:
-        int             IconSize() const   { return Value(Height()) - 2; }
+        int IconSize() const   { return Value(Height()) - 2; }
 
-        void            DoLayout() {
+        void DoLayout() {
             const GG::X PLAYER_NAME_WIDTH(ClientUI::Pts()       * 10);
             const GG::X EMPIRE_NAME_WIDTH(ClientUI::Pts()       * 10);
             const GG::X EMPIRE_SHIP_WIDTH(ClientUI::Pts()       * 16/5);
@@ -360,15 +490,19 @@ namespace {
             const GG::X EMPIRE_RESEARCH_WIDTH(ClientUI::Pts()   * 16/5);
             const GG::X EMPIRE_DETECTION_WIDTH(ClientUI::Pts()  * 16/5);
 
-
             GG::X left(DATA_PANEL_BORDER);
             GG::Y top(DATA_PANEL_BORDER);
             GG::Y bottom(ClientHeight());
             GG::X PAD(3);
 
+            int diplo_status_width = (Empires().NumEmpires() - Empires().NumEliminatedEmpires() + 1) * (IconSize() + Value(PAD));
+
             m_diplo_status_icon_ul = GG::Pt(left, top);
             left += GG::X(IconSize()) + PAD;
 
+            m_diplo_msg_ul = GG::Pt(left, top);
+            left += GG::X(IconSize());
+
             //m_player_name_text->SizeMove(GG::Pt(left, top), GG::Pt(left + PLAYER_NAME_WIDTH, bottom));
             //left += PLAYER_NAME_WIDTH;
 
@@ -416,18 +550,34 @@ namespace {
 
             m_win_status_icon_ul = GG::Pt(left, top);
             left += GG::X(IconSize()) + PAD;
+
+            m_war_indicator->SizeMove(GG::Pt(left, top), GG::Pt(GG::X(left + diplo_status_width), bottom));
+            left += diplo_status_width;
+
+            m_peace_indicator->SizeMove(GG::Pt(left, top), GG::Pt(GG::X(left + diplo_status_width), bottom));
+            left += diplo_status_width;
+
+            m_allied_indicator->SizeMove(GG::Pt(left, top), GG::Pt(GG::X(left + diplo_status_width), bottom));
+            left += diplo_status_width;
+
         }
 
-        int                     m_player_id;
-        //std::shared_ptr<GG::Label>            m_player_name_text;
-        std::shared_ptr<GG::Label>              m_empire_name_text;
-        std::shared_ptr<GG::Label>              m_empire_ship_text;
-        std::shared_ptr<GG::Label>              m_empire_planet_text;
-        std::shared_ptr<GG::Label>              m_empire_production_text;
-        std::shared_ptr<GG::Label>              m_empire_research_text;
-        std::shared_ptr<GG::Label>              m_empire_detection_text;
+        int                                         m_player_id;
+        int                                         m_empire_id;
+        //std::shared_ptr<GG::Label>                  m_player_name_text;
+        std::shared_ptr<GG::Label>                  m_empire_name_text;
+        std::shared_ptr<GG::Label>                  m_empire_ship_text;
+        std::shared_ptr<GG::Label>                  m_empire_planet_text;
+        std::shared_ptr<GG::Label>                  m_empire_production_text;
+        std::shared_ptr<GG::Label>                  m_empire_research_text;
+        std::shared_ptr<GG::Label>                  m_empire_detection_text;
+
+        std::shared_ptr<DiplomaticStatusIndicator>  m_war_indicator;
+        std::shared_ptr<DiplomaticStatusIndicator>  m_peace_indicator;
+        std::shared_ptr<DiplomaticStatusIndicator>  m_allied_indicator;
 
         GG::Pt                  m_diplo_status_icon_ul;
+        GG::Pt                  m_diplo_msg_ul;
         GG::Pt                  m_ship_icon_ul;
         GG::Pt                  m_planet_icon_ul;
         GG::Pt                  m_production_icon_ul;
@@ -439,16 +589,15 @@ namespace {
         GG::Pt                  m_win_status_icon_ul;
 
         DiplomaticStatus        m_diplo_status;
-        Message::PlayerStatus   m_player_status;
         Networking::ClientType  m_player_type;
-        bool                    m_host;
+        bool                    m_host = false;
         enum {
             WON,
             LOST,
             NEITHER
-        }                       m_win_status;
+        }                       m_win_status = NEITHER;
 
-        bool                    m_selected;
+        bool                    m_selected = false;
     };
 
 
@@ -457,11 +606,14 @@ namespace {
     ////////////////////////////////////////////////
     class PlayerRow : public GG::ListBox::Row {
     public:
-        PlayerRow(GG::X w, GG::Y h, int player_id) :
-            GG::ListBox::Row(w, h, "", GG::ALIGN_NONE, 0),
+        PlayerRow(GG::X w, GG::Y h, int player_id, int empire_id) :
+            GG::ListBox::Row(w, h),
             m_player_id(player_id),
+            m_empire_id(empire_id),
             m_panel(nullptr)
         {
+            SetMargin(0);
+            SetRowAlignment(GG::ALIGN_NONE);
             SetName("PlayerRow");
             SetChildClippingMode(ClipToClient);
         }
@@ -469,7 +621,7 @@ namespace {
         void CompleteConstruction() override {
 
             GG::ListBox::Row::CompleteConstruction();
-            m_panel = GG::Wnd::Create<PlayerDataPanel>(Width(), Height(), m_player_id);
+            m_panel = GG::Wnd::Create<PlayerDataPanel>(Width(), Height(), m_player_id, m_empire_id);
             push_back(m_panel);
         }
 
@@ -477,16 +629,15 @@ namespace {
             return m_player_id;
         }
 
+        int     EmpireID() const {
+            return m_empire_id;
+        }
+
         void    Update() {
             if (m_panel)
                 m_panel->Update();
         }
 
-        void    SetStatus(Message::PlayerStatus player_status) {
-            if (m_panel)
-                m_panel->SetStatus(player_status);
-        }
-
         /** This function overridden because otherwise, rows don't expand
           * larger than their initial size when resizing the list. */
         void SizeMove(const GG::Pt& ul, const GG::Pt& lr) override {
@@ -499,6 +650,7 @@ namespace {
 
     private:
         int                 m_player_id;
+        int                 m_empire_id;
         std::shared_ptr<PlayerDataPanel>    m_panel;
     };
 }
@@ -521,19 +673,17 @@ public:
     void SizeMove(const GG::Pt& ul, const GG::Pt& lr) override {
         const GG::Pt old_size = Size();
         CUIListBox::SizeMove(ul, lr);
-        //std::cout << "PlayerListBox::SizeMove size: (" << Value(Width()) << ", " << Value(Height()) << ")" << std::endl;
         if (old_size != Size()) {
             const GG::Pt row_size = ListRowSize();
-            //std::cout << "PlayerListBox::SizeMove list row size: (" << Value(row_size.x) << ", " << Value(row_size.y) << ")" << std::endl;
             for (auto& row : *this)
                 row->Resize(row_size);
         }
     }
 
-    GG::Pt          ListRowSize() const
+    GG::Pt ListRowSize() const
     { return GG::Pt(Width() - ClientUI::ScrollWidth() - 5, ListRowHeight()); }
 
-    static GG::Y    ListRowHeight()
+    static GG::Y ListRowHeight()
     { return GG::Y(ClientUI::Pts() * 3/2); }
 };
 
@@ -544,13 +694,18 @@ public:
 PlayerListWnd::PlayerListWnd(const std::string& config_name) :
     CUIWnd(UserString("PLAYERS_LIST_PANEL_TITLE"),
            GG::INTERACTIVE | GG::DRAGABLE | GG::ONTOP | GG::RESIZABLE | CLOSABLE | PINABLE,
-           config_name),
-    m_player_list(nullptr)
+           config_name)
 {}
 
 void PlayerListWnd::CompleteConstruction() {
     CUIWnd::CompleteConstruction();
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
     m_player_list = GG::Wnd::Create<PlayerListBox>();
     m_player_list->SetHiliteColor(GG::CLR_ZERO);
     m_player_list->SetStyle(GG::LIST_NOSORT);
@@ -565,7 +720,7 @@ void PlayerListWnd::CompleteConstruction() {
     Empires().DiplomaticStatusChangedSignal.connect(
         boost::bind(&PlayerListWnd::Update, this));
     Empires().DiplomaticMessageChangedSignal.connect(
-        boost::bind(&PlayerListWnd::Update, this));
+        boost::bind(&PlayerListWnd::PlayerListWnd::HandleDiplomaticMessageChange, this, _1, _2));
     DoLayout();
 
     Refresh();
@@ -584,17 +739,39 @@ std::set<int> PlayerListWnd::SelectedPlayerIDs() const {
     return retval;
 }
 
-void PlayerListWnd::HandlePlayerStatusUpdate(Message::PlayerStatus player_status, int about_player_id) {
-    for (auto& row : *m_player_list) {
-        if (PlayerRow* player_row = dynamic_cast<PlayerRow*>(row.get())) {
-            if (about_player_id == Networking::INVALID_PLAYER_ID) {
-                player_row->SetStatus(player_status);
-            } else if (player_row->PlayerID() == about_player_id) {
-                player_row->SetStatus(player_status);
-                return;
-            }
+void PlayerListWnd::HandleDiplomaticMessageChange(int empire1_id, int empire2_id) {
+    Update();
+
+    const ClientApp* app = ClientApp::GetApp();
+    if (!app) {
+        ErrorLogger() << "PlayerListWnd::HandleDiplomaticMessageChange couldn't get client app!";
+        return;
+    }
+    int client_empire_id = app->EmpireID();
+    if (client_empire_id == ALL_EMPIRES)
+        return;
+
+    DiplomaticMessage message = Empires().GetDiplomaticMessage(empire1_id, empire2_id);
+    bool active_message = message.GetType() != DiplomaticMessage::INVALID_DIPLOMATIC_MESSAGE_TYPE;
+
+    // only show PlayerListWnd if there is a new diplomatic offer for the client empire
+    if (active_message && (empire2_id == client_empire_id)) {
+        Show();
+        Flash();
+    };
+
+    // if there is no more pending messages, stop flashing
+    active_message = false;
+    for (const auto& empire : Empires()) {
+        message = Empires().GetDiplomaticMessage(empire.first, client_empire_id);
+        if (message.GetType() != DiplomaticMessage::INVALID_DIPLOMATIC_MESSAGE_TYPE) {
+            active_message = true;
+            break;
         }
     }
+
+    if (!active_message)
+        StopFlash();
 }
 
 void PlayerListWnd::Update() {
@@ -614,17 +791,29 @@ void PlayerListWnd::Refresh() {
         ErrorLogger() << "PlayerListWnd::Refresh couldn't get client app!";
         return;
     }
-    const std::map<int, PlayerInfo>& players = app->Players();
 
     const GG::Pt row_size = m_player_list->ListRowSize();
 
-    for (const auto& player : players) {
-        int player_id = player.first;
-        auto player_row = GG::Wnd::Create<PlayerRow>(row_size.x, row_size.y, player_id);
+    // first fill empires
+    for (const auto& empire : Empires()) {
+        int player_id = app->EmpirePlayerID(empire.first);
+        auto player_row = GG::Wnd::Create<PlayerRow>(row_size.x, row_size.y, player_id, empire.first);
         m_player_list->Insert(player_row);
         player_row->Resize(row_size);
     }
 
+    // second fill players without empires
+    const std::map<int, PlayerInfo>& players = app->Players();
+
+    for (const auto& player : players) {
+        if (player.second.empire_id == ALL_EMPIRES) {
+            int player_id = player.first;
+            auto player_row = GG::Wnd::Create<PlayerRow>(row_size.x, row_size.y, player_id, ALL_EMPIRES);
+            m_player_list->Insert(player_row);
+            player_row->Resize(row_size);
+        }
+    }
+
     this->SetSelectedPlayers(initially_selected_players);
 }
 
@@ -658,9 +847,8 @@ void PlayerListWnd::SetSelectedPlayers(const std::set<int>& player_ids) {
         PlayerSelectionChanged(m_player_list->Selections());
 }
 
-void PlayerListWnd::Clear() {
-    m_player_list->Clear();
-}
+void PlayerListWnd::Clear()
+{ m_player_list->Clear(); }
 
 void PlayerListWnd::SizeMove(const GG::Pt& ul, const GG::Pt& lr) {
     const GG::Pt old_size = Size();
@@ -669,14 +857,25 @@ void PlayerListWnd::SizeMove(const GG::Pt& ul, const GG::Pt& lr) {
         DoLayout();
 }
 
-void PlayerListWnd::DoLayout()
-{
+void PlayerListWnd::DoLayout() {
     if (m_player_list)
         m_player_list->SizeMove(GG::Pt(), GG::Pt(ClientWidth(), ClientHeight() - GG::Y(INNER_BORDER_ANGLE_OFFSET)));
 }
 
-void PlayerListWnd::CloseClicked()
-{ ClosingSignal(); }
+void PlayerListWnd::CloseClicked() {
+    ClosingSignal();
+    StopFlash();
+}
+
+void PlayerListWnd::LClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) {
+    CUIWnd::LClick(pt, mod_keys);
+    StopFlash();
+}
+
+void PlayerListWnd::LDrag(const GG::Pt& pt, const GG::Pt& move, GG::Flags<GG::ModKey> mod_keys) {
+    CUIWnd::LDrag(pt, move, mod_keys);
+    StopFlash();
+}
 
 void PlayerListWnd::PlayerSelectionChanged(const GG::ListBox::SelectionSet& rows) {
     // mark as selected all PlayerDataPanel that are in \a rows and mark as not
@@ -720,15 +919,15 @@ namespace {
     {
         auto premade_message = DiplomacyMessage(message(client_empire_id, clicked_empire_id));
         auto &networking = HumanClientApp::GetApp()->Networking();
-        return std::bind(&ClientNetworking::SendMessage, &networking, premade_message);
+        return boost::bind(&ClientNetworking::SendMessage, &networking, premade_message);
     }
 
 }
 
 void PlayerListWnd::PlayerRightClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys) {
     // check that a valid player was clicked and that it wasn't this client's own player
-    int clicked_player_id = PlayerInRow(it);
-    if (clicked_player_id == Networking::INVALID_PLAYER_ID)
+    int clicked_empire_id = EmpireInRow(it);
+    if (clicked_empire_id == ALL_EMPIRES)
         return;
     const ClientApp* app = ClientApp::GetApp();
     if (!app) {
@@ -740,19 +939,9 @@ void PlayerListWnd::PlayerRightClicked(GG::ListBox::iterator it, const GG::Pt& p
         return;
     int client_empire_id = app->EmpireID();
 
-    // get empire id of clicked player
-    const std::map<int, PlayerInfo>& players = app->Players();
-    auto clicked_player_it = players.find(clicked_player_id);
-    if (clicked_player_it == players.end()) {
-        ErrorLogger() << "PlayerListWnd::PlayerRightClicked couldn't find player with id " << clicked_player_id;
-        return;
-    }
-    const PlayerInfo& clicked_player_info = clicked_player_it->second;
-    int clicked_empire_id = clicked_player_info.empire_id;
-
     if (!GetEmpire(clicked_empire_id)) {
         ErrorLogger() << "PlayerListWnd::PlayerRightClicked tried to look up empire id "
-                      << clicked_empire_id << " for player " << clicked_player_id
+                      << clicked_empire_id
                       << " but couldn't find such an empire";
         return;
     }
@@ -783,7 +972,7 @@ void PlayerListWnd::PlayerRightClicked(GG::ListBox::iterator it, const GG::Pt& p
     {
         // get diplomatic status between client and clicked empires
         DiplomaticStatus diplo_status = Empires().GetDiplomaticStatus(clicked_empire_id, client_empire_id);
-        if (diplo_status == INVALID_DIPLOMATIC_STATUS && clicked_player_id != client_player_id) {
+        if (diplo_status == INVALID_DIPLOMATIC_STATUS && clicked_empire_id != client_empire_id) {
             ErrorLogger() << "PlayerListWnd::PlayerRightClicked found invalid diplomatic status between client and clicked empires.";
             return;
         }
@@ -867,3 +1056,13 @@ int PlayerListWnd::PlayerInRow(GG::ListBox::iterator it) const {
 
     return Networking::INVALID_PLAYER_ID;
 }
+
+int PlayerListWnd::EmpireInRow(GG::ListBox::iterator it) const {
+    if (it == m_player_list->end())
+        return ALL_EMPIRES;
+
+    if (PlayerRow* player_row = dynamic_cast<PlayerRow*>(it->get()))
+        return player_row->EmpireID();
+
+    return ALL_EMPIRES;
+}
