@@ -3,10 +3,10 @@
 
 #include "AccordionPanel.h"
 #include "../universe/EnumsFwd.h"
+#include "../universe/UniverseObject.h"
 
 #include <memory>
 
-
 class MultiIconValueIndicator;
 class MultiMeterStatusBar;
 class PopCenter;
@@ -28,8 +28,6 @@ public:
     /** \name Mutators */ //@{
     void PreRender() override;
 
-    bool EventFilter(GG::Wnd* w, const GG::WndEvent& event) override;
-
     /** expands or collapses panel to show details or just summary info */
     void ExpandCollapse(bool expanded);
 
@@ -50,10 +48,7 @@ private:
     void ExpandCollapseButtonPressed();
 
     /** object id for the PopulationCenter that this panel displays */
-    int m_popcenter_id;
-
-    /** returns the PopCenter object with id m_popcenter_id */
-    std::shared_ptr<const PopCenter> GetPopCenter() const;
+    int m_popcenter_id = INVALID_OBJECT_ID;
 
     /** Icons for the associated meter type. */
     std::vector<std::pair<MeterType, std::shared_ptr<StatisticIcon>>> m_meter_stats;
