@@ -4,7 +4,6 @@
 
 #include "../util/i18n.h"
 #include "../util/Logger.h"
-#include "../universe/Effect.h"
 #include "../universe/ResourceCenter.h"
 #include "../universe/UniverseObject.h"
 #include "../universe/Enums.h"
@@ -33,10 +32,7 @@ namespace {
 
 ResourcePanel::ResourcePanel(GG::X w, int object_id) :
     AccordionPanel(w, GG::Y(ClientUI::Pts()*2)),
-    m_rescenter_id(object_id),
-    m_meter_stats(),
-    m_multi_icon_value_indicator(nullptr),
-    m_multi_meter_status_bar(nullptr)
+    m_rescenter_id(object_id)
 {}
 
 void ResourcePanel::CompleteConstruction() {
@@ -44,14 +40,14 @@ void ResourcePanel::CompleteConstruction() {
 
     SetName("ResourcePanel");
 
-    auto res = GetResCenter();
+    auto res = Objects().get<ResourceCenter>(m_rescenter_id);
     if (!res)
         throw std::invalid_argument("Attempted to construct a ResourcePanel with an UniverseObject that is not a ResourceCenter");
 
     m_expand_button->LeftPressedSignal.connect(
         boost::bind(&ResourcePanel::ExpandCollapseButtonPressed, this));
 
-    const auto obj = GetUniverseObject(m_rescenter_id);
+    const auto obj = Objects().get(m_rescenter_id);
     if (!obj) {
         ErrorLogger() << "Invalid object id " << m_rescenter_id;
         return;
@@ -65,12 +61,23 @@ void ResourcePanel::CompleteConstruction() {
                             METER_SUPPLY, METER_STOCKPILE})
     {
         auto stat = GG::Wnd::Create<StatisticIcon>(
-            ClientUI::MeterIcon(meter), obj->InitialMeterValue(meter),
+            ClientUI::MeterIcon(meter), obj->GetMeter(meter)->Initial(),
             3, false, MeterIconSize().x, MeterIconSize().y);
-        stat->InstallEventFilter(shared_from_this());
         AttachChild(stat);
         m_meter_stats.push_back({meter, stat});
         meters.push_back({meter, AssociatedMeterType(meter)});
+        stat->RightClickedSignal.connect([meter](const GG::Pt& pt) {
+            std::string meter_string = boost::lexical_cast<std::string>(meter);
+
+            auto pedia_zoom_to_article_action = [meter_string]() {
+                ClientUI::GetClientUI()->ZoomToMeterTypeArticle(meter_string); };
+
+            auto popup = GG::Wnd::Create<CUIPopupMenu>(pt.x, pt.y);
+            std::string popup_label = boost::io::str(FlexibleFormat(UserString("ENC_LOOKUP")) %
+                                                                    UserString(meter_string));
+            popup->AddMenuItem(GG::MenuItem(popup_label, false, false, pedia_zoom_to_article_action));
+            popup->Run();
+        });
     }
 
     // attach and show meter bars and large resource indicators
@@ -95,41 +102,6 @@ void ResourcePanel::ExpandCollapse(bool expanded) {
     RequirePreRender();
 }
 
-bool ResourcePanel::EventFilter(GG::Wnd* w, const GG::WndEvent& event) {
-    if (event.Type() != GG::WndEvent::RClick)
-        return false;
-    const GG::Pt& pt = event.Point();
-
-    MeterType meter_type = INVALID_METER_TYPE;
-    for (const auto& meter_stat : m_meter_stats) {
-        if (meter_stat.second.get() == w) {
-            meter_type = meter_stat.first;
-            break;
-        }
-    }
-
-    if (meter_type == INVALID_METER_TYPE)
-        return false;
-
-    std::string meter_string = boost::lexical_cast<std::string>(meter_type);
-    std::string meter_title;
-    if (UserStringExists(meter_string))
-        meter_title = UserString(meter_string);
-    if (meter_title.empty())
-        return false;
-
-    bool retval = false;
-    auto pedia_zoom_to_article_action = [&meter_string, &retval]() {
-        retval = ClientUI::GetClientUI()->ZoomToMeterTypeArticle(meter_string); };
-
-    auto popup = GG::Wnd::Create<CUIPopupMenu>(pt.x, pt.y);
-    std::string popup_label = boost::io::str(FlexibleFormat(UserString("ENC_LOOKUP")) % meter_title);
-    popup->AddMenuItem(GG::MenuItem(popup_label, false, false, pedia_zoom_to_article_action));
-    popup->Run();
-
-    return retval;
-}
-
 
 
 namespace {
@@ -157,7 +129,7 @@ void ResourcePanel::Update() {
         m_multi_icon_value_indicator->ClearToolTip(meter_stat.first);
     }
 
-    auto obj = GetUniverseObject(m_rescenter_id);
+    auto obj = Objects().get(m_rescenter_id);
     if (!obj) {
         ErrorLogger() << "BuildingPanel::Update couldn't get object with id " << m_rescenter_id;
         return;
@@ -169,7 +141,7 @@ void ResourcePanel::Update() {
 
     // tooltips
     for (auto& meter_stat : m_meter_stats) {
-        meter_stat.second->SetValue(obj->InitialMeterValue(meter_stat.first));
+        meter_stat.second->SetValue(obj->GetMeter(meter_stat.first)->Initial());
 
         auto browse_wnd = GG::Wnd::Create<MeterBrowseWnd>(m_rescenter_id, meter_stat.first, AssociatedMeterType(meter_stat.first));
         meter_stat.second->SetBrowseInfoWnd(browse_wnd);
@@ -249,13 +221,4 @@ void ResourcePanel::DoLayout() {
     SetCollapsed(!s_expanded_map[m_rescenter_id]);
 }
 
-std::shared_ptr<const ResourceCenter> ResourcePanel::GetResCenter() const {
-    auto res = GetResourceCenter(m_rescenter_id);
-    if (!res) {
-        ErrorLogger() << "ResourcePanel tried to get an object with an invalid m_rescenter_id";
-        return nullptr;
-    }
-    return res;
-}
-
 std::map<int, bool> ResourcePanel::s_expanded_map;
