@@ -15,7 +15,6 @@
 #include <GG/Button.h>
 #include <GG/Clr.h>
 #include <GG/dialogs/ThreeButtonDlg.h>
-#include <GG/DrawUtil.h>
 #include <GG/utf8/checked.h>
 
 #include <boost/filesystem/path.hpp>
@@ -32,10 +31,10 @@ using std::vector;
 using std::string;
 
 namespace {
-    const GG::X SAVE_FILE_DIALOG_WIDTH ( 600 );
-    const GG::Y SAVE_FILE_DIALOG_HEIGHT ( 400 );
-    const GG::X SAVE_FILE_DIALOG_MIN_WIDTH ( 160 );
-    const GG::Y SAVE_FILE_DIALOG_MIN_HEIGHT ( 100 );
+    const GG::X SAVE_FILE_DIALOG_WIDTH(600);
+    const GG::Y SAVE_FILE_DIALOG_HEIGHT(400);
+    const GG::X SAVE_FILE_DIALOG_MIN_WIDTH(160);
+    const GG::Y SAVE_FILE_DIALOG_MIN_HEIGHT(100);
 
     const std::string SAVE_FILE_WND_NAME = "dialog.save";
 
@@ -93,8 +92,7 @@ namespace {
     bool temp_bool = RegisterOptions(&AddOptions);
 
     /// Creates a text control that support resizing and word wrap.
-    std::shared_ptr<GG::Label> CreateResizingText(const std::string& string, GG::X width)
-    {
+    std::shared_ptr<GG::Label> CreateResizingText(const std::string& string, GG::X width) {
         // Calculate the extent manually to ensure the control stretches to full
         // width when possible.  Otherwise it would always word break.
         GG::Flags<GG::TextFormat> fmt = GG::FORMAT_NONE;
@@ -110,12 +108,12 @@ namespace {
         return text;
     }
 
-    bool Prompt(const std::string& question){
+    bool Prompt(const std::string& question) {
         std::shared_ptr<GG::Font> font = ClientUI::GetFont();
-        auto prompt = GG::Wnd::Create<GG::ThreeButtonDlg>(
+        auto prompt = GG::GUI::GetGUI()->GetStyleFactory()->NewThreeButtonDlg(
             PROMT_WIDTH, PROMPT_HEIGHT, question, font,
             ClientUI::CtrlColor(), ClientUI::CtrlBorderColor(), ClientUI::CtrlColor(), ClientUI::TextColor(),
-            std::size_t(2), UserString("YES"), UserString("CANCEL"), "");
+            2, UserString("YES"), UserString("CANCEL"));
         prompt->Run();
         return prompt->Result() == 0;
     }
@@ -131,14 +129,14 @@ public:
         return columns;
     }
 
-    static std::shared_ptr<GG::Control> TitleForColumn(const SaveFileColumn& column)
-    {
+    static std::shared_ptr<GG::Control> TitleForColumn(const SaveFileColumn& column) {
         auto retval = GG::Wnd::Create<CUILabel>(column.Title(), GG::FORMAT_LEFT);
         retval->Resize(GG::Pt(GG::X1, ClientUI::GetFont()->Height()));
         return retval;
     }
 
-    static std::shared_ptr<GG::Control> CellForColumn(const SaveFileColumn& column, const FullPreview& full, GG::X max_width)
+    static std::shared_ptr<GG::Control> CellForColumn(const SaveFileColumn& column,
+                                                      const FullPreview& full, GG::X max_width)
     {
         GG::Clr color = ClientUI::TextColor();
         std::string value = ColumnInPreview(full, column.m_name);
@@ -381,7 +379,7 @@ public:
     void Init() override {
         SaveFileRow::Init();
         for (unsigned int i = 0; i < m_columns->size(); ++i) {
-            if (i==0) {
+            if (i == 0) {
                 auto label = GG::Wnd::Create<CUILabel>(PATH_DELIM_BEGIN + m_filename + PATH_DELIM_END,
                                                        GG::FORMAT_NOWRAP | GG::FORMAT_LEFT);
                 label->Resize(GG::Pt(DirectoryNameSize(), ClientUI::GetFont()->Height()));
@@ -395,7 +393,6 @@ public:
         }
 
         AdjustColumns();
-
         GetLayout()->PreRender();
     }
 
@@ -440,12 +437,11 @@ public:
         SaveFileRow::Init();
         VarText browse_text(UserStringNop("SAVE_DIALOG_ROW_BROWSE_TEMPLATE"));
 
-        for (const auto& column : *m_columns) {
+        for (const auto& column : *m_columns)
             push_back(SaveFileColumn::CellForColumn(column, m_full_preview, ClientWidth()));
-        }
-        for (const auto& column : *m_all_columns) {
+        for (const auto& column : *m_all_columns)
             browse_text.AddVariable(column.Name(), ColumnInPreview(m_full_preview, column.Name(), false));
-        }
+
         AdjustColumns();
         SetBrowseText(browse_text.GetText());
         GetLayout()->PreRender();
@@ -454,14 +450,12 @@ public:
     SortKeyType SortKey(std::size_t column) const override
     { return m_full_preview.preview.save_time; }
 
-    private:
+private:
     /** All possible columns. */
     std::shared_ptr<std::vector<SaveFileColumn>> m_all_columns;
-
     const FullPreview m_full_preview;
 };
 
-
 class SaveFileListBox : public CUIListBox {
 public:
     SaveFileListBox() :
@@ -530,9 +524,8 @@ public:
     /** Find local sub directories of \p path. */
     std::vector<std::string> FindLocalRelativeDirs(const fs::path& path) {
         std::vector<std::string> dirs;
-        if (path.has_parent_path() && path.parent_path() != path) {
-                dirs.push_back("..");
-        }
+        if (path.has_parent_path() && path.parent_path() != path)
+            dirs.push_back("..");
 
         fs::directory_iterator end_it;
         for (fs::directory_iterator it(path); it != end_it; ++it) {
@@ -550,9 +543,8 @@ public:
 
     void LoadDirectories(const std::vector<std::string>& dirs) {
         std::vector<std::shared_ptr<Row>> rows;
-        for (const auto& dir : dirs) {
+        for (const auto& dir : dirs)
             rows.push_back(GG::Wnd::Create<SaveFileDirectoryRow>(m_visible_columns, dir));
-        }
 
         // Insert rows enmasse to avoid per insertion vector sort costs.
         Insert(rows);
@@ -664,8 +656,7 @@ void SaveFileDialog::Init() {
 
         auto delete_btn = Wnd::Create<CUIButton>(UserString("DELETE"));
         m_layout->Add(delete_btn, 2, 3);
-        delete_btn->LeftClickedSignal.connect(
-            boost::bind(&SaveFileDialog::AskDelete, this));
+        delete_btn->LeftClickedSignal.connect(boost::bind(&SaveFileDialog::AskDelete, this));
 
         m_layout->SetMinimumRowHeight(2, delete_btn->MinUsableSize().y + GG::Y(Value(SAVE_FILE_BUTTON_MARGIN)));
         m_layout->SetMinimumColumnWidth(2, m_confirm_btn->MinUsableSize().x + 2*SAVE_FILE_BUTTON_MARGIN);
@@ -717,18 +708,18 @@ void SaveFileDialog::Init() {
 
     SetLayout(m_layout);
 
-    m_confirm_btn->LeftClickedSignal.connect(
-        boost::bind(&SaveFileDialog::Confirm, this));
-    cancel_btn->LeftClickedSignal.connect(
-        boost::bind(&SaveFileDialog::Cancel, this));
-    m_file_list->SelRowsChangedSignal.connect(
-        boost::bind(&SaveFileDialog::SelectionChanged, this, _1));
-    m_file_list->DoubleClickedRowSignal.connect(
-        boost::bind(&SaveFileDialog::DoubleClickRow, this, _1, _2, _3));
-    m_name_edit->EditedSignal.connect(
-        boost::bind(&SaveFileDialog::FileNameEdited, this, _1));
-    m_current_dir_edit->EditedSignal.connect(
-        boost::bind(&SaveFileDialog::DirectoryEdited, this, _1));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
+    m_confirm_btn->LeftClickedSignal.connect(boost::bind(&SaveFileDialog::Confirm, this));
+    cancel_btn->LeftClickedSignal.connect(boost::bind(&SaveFileDialog::Cancel, this));
+    m_file_list->SelRowsChangedSignal.connect(boost::bind(&SaveFileDialog::SelectionChanged, this, _1));
+    m_file_list->DoubleClickedRowSignal.connect(boost::bind(&SaveFileDialog::DoubleClickRow, this, _1, _2, _3));
+    m_name_edit->EditedSignal.connect(boost::bind(&SaveFileDialog::FileNameEdited, this, _1));
+    m_current_dir_edit->EditedSignal.connect(boost::bind(&SaveFileDialog::DirectoryEdited, this, _1));
 
     if (!m_load_only) {
         m_name_edit->SetText(std::string("save-") + FilenameTimestamp() + m_extension);
@@ -776,6 +767,7 @@ void SaveFileDialog::KeyPress(GG::Key key, std::uint32_t key_code_point, GG::Fla
                 Confirm();
             }
         }
+
     } else if (key == GG::GGK_DELETE) { // Delete would be better, but gets eaten by someone
         // Ask to delete selection on Delete, if valid and not editing text
         if (CheckChoiceValidity() &&
@@ -784,6 +776,7 @@ void SaveFileDialog::KeyPress(GG::Key key, std::uint32_t key_code_point, GG::Fla
         {
             AskDelete();
         }
+
     } else {
         // The keypress may have changed our choice
         CheckChoiceValidity();
@@ -998,9 +991,8 @@ std::string SaveFileDialog::GetDirPath() const {
     const std::string& path_edit_text = m_current_dir_edit->Text();
 
     //DebugLogger() << "SaveFileDialog::GetDirPath text: " << path_edit_text << " valid UTF-8: " << utf8::is_valid(path_edit_text.begin(), path_edit_text.end());
-    if (!m_server_previews) {
+    if (!m_server_previews)
         return path_edit_text;
-    }
 
     std::string dir = path_edit_text;
 
@@ -1047,9 +1039,8 @@ void SaveFileDialog::SetDirPath(const string& dir_path) {
 
 std::string SaveFileDialog::Result() const {
     std::string choice = m_name_edit->Text();
-    if (choice.empty()) {
+    if (choice.empty())
         return "";
-    }
 
     fs::path choice_path = FilenameToPath(choice);
     fs::path current_dir = FilenameToPath(GetDirPath());
