@@ -3,6 +3,7 @@
 #include <sstream>
 #include <iomanip>
 #include <cctype>
+#include <boost/algorithm/string/predicate.hpp>
 #include <boost/cast.hpp>
 #include <boost/filesystem/fstream.hpp>
 #include <GG/Button.h>
@@ -13,7 +14,7 @@
 #include "../util/OptionsDB.h"
 #include "../util/Directories.h"
 #include "../client/human/HumanClientApp.h"
-#include "../network/ClientNetworking.h"
+#include "../client/ClientNetworking.h"
 #include "ClientUI.h"
 #include "CUIControls.h"
 #include "Sound.h"
@@ -73,17 +74,7 @@ namespace {
 
 ServerConnectWnd::ServerConnectWnd() :
     CUIWnd(UserString("SCONNECT_WINDOW_TITLE"),
-           GG::INTERACTIVE | GG::MODAL),
-    m_host_or_join_radio_group(nullptr),
-    m_client_type_list(nullptr),
-    m_LAN_game_label(nullptr),
-    m_servers_lb(nullptr),
-    m_find_LAN_servers_bn(nullptr),
-    m_internet_game_label(nullptr),
-    m_IP_address_edit(nullptr),
-    m_player_name_edit(nullptr),
-    m_ok_bn(nullptr),
-    m_cancel_bn(nullptr)
+           GG::INTERACTIVE | GG::MODAL)
 {}
 
 void ServerConnectWnd::CompleteConstruction() {
@@ -140,6 +131,10 @@ void ServerConnectWnd::CompleteConstruction() {
 
     ResetDefaultPosition();
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+#endif
+
     m_host_or_join_radio_group->ButtonChangedSignal.connect(
         boost::bind(&ServerConnectWnd::EnableDisableControls, this));
     m_servers_lb->SelRowsChangedSignal.connect(
@@ -205,6 +200,18 @@ void ServerConnectWnd::PopulateServerList() {
         row->push_back(GG::Wnd::Create<CUILabel>(server));
         m_servers_lb->Insert(row);
     }
+    std::set<std::string> known_servers;
+    GetOptionsDB().FindOptions(known_servers, "network.known-servers", true);
+    for (const auto& option : known_servers) {
+        if (boost::algorithm::ends_with(option, ".address")) {
+            if (!GetOptionsDB().OptionExists(option))
+                GetOptionsDB().Add<std::string>(option, "OPTIONS_DB_SERVER_COOKIE", "");
+            std::string server = GetOptionsDB().Get<std::string>(option);
+            auto row = GG::Wnd::Create<GG::ListBox::Row>();
+            row->push_back(GG::Wnd::Create<CUILabel>(server));
+            m_servers_lb->Insert(row);
+        }
+    }
 }
 
 void ServerConnectWnd::ServerSelected(const GG::ListBox::SelectionSet& selections) {
