@@ -12,7 +12,6 @@
 #include "../util/SitRepEntry.h"
 #include "../universe/ShipDesign.h"
 
-#include <GG/DrawUtil.h>
 #include <GG/Layout.h>
 
 #include <boost/lexical_cast.hpp>
@@ -28,14 +27,9 @@ namespace {
 
     /** Adds options related to SitRepPanel to Options DB. */
     void AddOptions(OptionsDB& db) {
-        db.Add("ui.map.sitrep.invalid.shown",
-               UserStringNop("OPTIONS_DB_VERBOSE_SITREP_DESC"),
-               false, Validator<bool>());
-        db.Add<std::string>("ui.map.sitrep.hidden.stringlist",
-                            UserStringNop("OPTIONS_DB_HIDDEN_SITREP_TEMPLATES_DESC"),
-                            "");
-        db.Add("ui.map.sitrep.icon.size",
-               UserStringNop("OPTIONS_DB_UI_SITREP_ICONSIZE"),
+        db.Add("ui.map.sitrep.invalid.shown",                   UserStringNop("OPTIONS_DB_VERBOSE_SITREP_DESC"),            false);
+        db.Add<std::string>("ui.map.sitrep.hidden.stringlist",  UserStringNop("OPTIONS_DB_HIDDEN_SITREP_TEMPLATES_DESC"),   "");
+        db.Add("ui.map.sitrep.icon.size",                       UserStringNop("OPTIONS_DB_UI_SITREP_ICONSIZE"),
                24, RangedValidator<int>(12, 64));
     }
     bool temp_bool = RegisterOptions(&AddOptions);
@@ -130,7 +124,7 @@ namespace {
                 label_display_map[label] = sitrep_it->GetStringtableLookupFlag()? UserString(label) : label;
             }
             template_set.insert(label);
-            
+
         }
 
         return template_set;
@@ -254,12 +248,14 @@ namespace {
             m_link_text->SetDecorator(TextLinker::BROWSE_PATH_TAG, new PathTypeDecorator());
             AttachChild(m_link_text);
 
-            m_link_text->LinkClickedSignal.connect(
-                &HandleLinkClick);
-            m_link_text->LinkDoubleClickedSignal.connect(
-                &HandleLinkClick);
-            m_link_text->LinkRightClickedSignal.connect(
-                &HandleLinkClick);
+#if BOOST_VERSION >= 106000
+            using boost::placeholders::_1;
+            using boost::placeholders::_2;
+#endif
+
+            m_link_text->LinkClickedSignal.connect(&HandleLinkClick);
+            m_link_text->LinkDoubleClickedSignal.connect(&HandleLinkClick);
+            m_link_text->LinkRightClickedSignal.connect(&HandleLinkClick);
             m_link_text->RightClickedSignal.connect(
                 boost::bind(&SitRepDataPanel::RClick, this, _1, _2));
 
@@ -314,8 +310,8 @@ namespace {
         }
 
         const SitRepEntry&                  m_sitrep_entry;
-        std::shared_ptr<GG::StaticGraphic>  m_icon = nullptr;
-        std::shared_ptr<SitRepLinkText>     m_link_text = nullptr;
+        std::shared_ptr<GG::StaticGraphic>  m_icon;
+        std::shared_ptr<SitRepLinkText>     m_link_text;
     };
 
     ////////////////////////////////////////////////
@@ -325,7 +321,7 @@ namespace {
     class SitRepRow : public GG::ListBox::Row {
     public:
         SitRepRow(GG::X w, GG::Y h, const SitRepEntry& sitrep) :
-            GG::ListBox::Row(w, h, ""),
+            GG::ListBox::Row(w, h),
             m_sitrep(sitrep)
         {
             SetName("SitRepRow");
@@ -364,6 +360,12 @@ namespace {
                                                        ClientWidth() - GG::X(2 * GetLayout()->BorderMargin()),
                                                        ClientHeight() - GG::Y(2 * GetLayout()->BorderMargin()), m_sitrep);
             push_back(m_panel);
+
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
             m_panel->RightClickedSignal.connect(
                 boost::bind(&SitRepRow::RClick, this, _1, _2));
         }
@@ -371,7 +373,7 @@ namespace {
         const SitRepEntry& GetSitRepEntry() const { return m_panel->GetSitRepEntry(); }
 
     private:
-        std::shared_ptr<SitRepDataPanel>    m_panel = nullptr;
+        std::shared_ptr<SitRepDataPanel>    m_panel;
         const SitRepEntry                   m_sitrep;
     };
 }
@@ -404,18 +406,18 @@ void SitRepPanel::CompleteConstruction() {
     m_filter_button = Wnd::Create<CUIButton>(UserString("FILTERS"));
     AttachChild(m_filter_button);
 
-    m_prev_turn_button->LeftClickedSignal.connect(
-        boost::bind(&SitRepPanel::PrevClicked, this));
-    m_next_turn_button->LeftClickedSignal.connect(
-        boost::bind(&SitRepPanel::NextClicked, this));
-    m_last_turn_button->LeftClickedSignal.connect(
-        boost::bind(&SitRepPanel::LastClicked, this));
-    m_filter_button->LeftClickedSignal.connect(
-        boost::bind(&SitRepPanel::FilterClicked, this));
-    m_sitreps_lb->DoubleClickedRowSignal.connect(
-        boost::bind(&SitRepPanel::IgnoreSitRep, this, _1, _2, _3));
-    m_sitreps_lb->RightClickedRowSignal.connect(
-        boost::bind(&SitRepPanel::DismissalMenu, this, _1, _2, _3));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
+    m_prev_turn_button->LeftClickedSignal.connect(boost::bind(&SitRepPanel::PrevClicked, this));
+    m_next_turn_button->LeftClickedSignal.connect(boost::bind(&SitRepPanel::NextClicked, this));
+    m_last_turn_button->LeftClickedSignal.connect(boost::bind(&SitRepPanel::LastClicked, this));
+    m_filter_button->LeftClickedSignal.connect(boost::bind(&SitRepPanel::FilterClicked, this));
+    m_sitreps_lb->DoubleClickedRowSignal.connect(boost::bind(&SitRepPanel::IgnoreSitRep, this, _1, _2, _3));
+    m_sitreps_lb->RightClickedRowSignal.connect(boost::bind(&SitRepPanel::DismissalMenu, this, _1, _2, _3));
 
     CUIWnd::CompleteConstruction();
 
@@ -468,7 +470,6 @@ void SitRepPanel::SizeMove(const GG::Pt& ul, const GG::Pt& lr) {
 
     if (old_size != GG::Wnd::Size()) {
         DoLayout();
-        Update();
         if (!m_sitreps_lb->Empty())
             m_sitreps_lb->SetFirstRowShown(std::next(m_sitreps_lb->begin(),
                                                      first_visible_queue_row));
@@ -535,10 +536,13 @@ int SitRepPanel::GetNextNonEmptySitrepsTurn(std::map<int, std::list<SitRepEntry>
     if (turns.size() == 0)
         return INVALID_GAME_TURN;
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+#endif
+
     // Only one turn with visible sitreps
     if (turns.size() == 1) {
-        turns.begin()->second.remove_if(std::bind(&SitRepPanel::IsSitRepInvalid,
-                                                  this, std::placeholders::_1));
+        turns.begin()->second.remove_if(boost::bind(&SitRepPanel::IsSitRepInvalid, this, _1));
         // With no valid sitreps
         if (turns.begin()->second.empty()) {
             turns.clear();
@@ -562,8 +566,7 @@ int SitRepPanel::GetNextNonEmptySitrepsTurn(std::map<int, std::list<SitRepEntry>
     int step = forward ? 1 : -1;
 
     while (it != turns.end()) {
-        it->second.remove_if(std::bind(&SitRepPanel::IsSitRepInvalid,
-                                       this, std::placeholders::_1));
+        it->second.remove_if(boost::bind(&SitRepPanel::IsSitRepInvalid, this, _1));
 
         // If any valid sitreps, then exit
         if (!it->second.empty())
@@ -595,8 +598,10 @@ void SitRepPanel::NextClicked() {
     ShowSitRepsForTurn(GetNextNonEmptySitrepsTurn(turns, m_showing_turn, true));
 }
 
-void SitRepPanel::LastClicked()
-{ ShowSitRepsForTurn(CurrentTurn()); }
+void SitRepPanel::LastClicked() {
+    auto turns = GetUnvalidatedSitRepsSortedByTurn(HumanClientApp::GetApp()->EmpireID());
+    ShowSitRepsForTurn(GetNextNonEmptySitrepsTurn(turns, CurrentTurn(), false));    // search backwards from current turn for a non-empty sitrep turn
+}
 
 void SitRepPanel::FilterClicked() {
     std::map<int, std::string> menu_index_templates;
@@ -682,7 +687,7 @@ void SitRepPanel::DismissalMenu(GG::ListBox::iterator it, const GG::Pt& pt,
     separator_item.separator = true;
     int start_turn = 0;
     SitRepRow* sitrep_row = nullptr;
-    if (it != m_sitreps_lb->end()) 
+    if (it != m_sitreps_lb->end())
         sitrep_row = dynamic_cast<SitRepRow*>(it->get());
     submenu_ignore.label = entry_margin + UserString("SITREP_IGNORE_MENU");
     if (sitrep_row) {
@@ -860,7 +865,12 @@ void SitRepPanel::SetHiddenSitRepTemplates(const std::set<std::string>& template
 int SitRepPanel::NumVisibleSitrepsThisTurn() const {
     auto turns = GetUnvalidatedSitRepsSortedByTurn(HumanClientApp::GetApp()->EmpireID());
     auto& turn = turns[CurrentTurn()];
-    turn.remove_if(std::bind(&SitRepPanel::IsSitRepInvalid, this, std::placeholders::_1));
+
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+#endif
+
+    turn.remove_if(boost::bind(&SitRepPanel::IsSitRepInvalid, this, _1));
     return turn.size();
 }
 
