@@ -20,7 +20,6 @@
 #include "../util/OptionsDB.h"
 #include "../Empire/Empire.h"
 
-#include <GG/DrawUtil.h>
 #include <GG/StaticGraphic.h>
 #include <GG/utf8/checked.h>
 #include <GG/utf8/core.h>
@@ -99,7 +98,7 @@ OwnerColoredSystemName::OwnerColoredSystemName(int system_id, int font_size,
 
     int client_empire_id = HumanClientApp::GetApp()->EmpireID();
 
-    auto system = GetSystem(system_id);
+    auto system = Objects().get<System>(system_id);
     if (!system)
         return;
 
@@ -118,7 +117,7 @@ OwnerColoredSystemName::OwnerColoredSystemName(int system_id, int font_size,
     bool capital = false, homeworld = false, has_shipyard = false, has_neutrals = false, has_player_planet = false;
 
     std::set<int> owner_empire_ids;
-    auto system_planets = Objects().FindObjects<const Planet>(system->PlanetIDs());
+    auto system_planets = Objects().find<const Planet>(system->PlanetIDs());
 
     for (auto& planet : system_planets) {
         int planet_id = planet->ID();
@@ -151,7 +150,7 @@ OwnerColoredSystemName::OwnerColoredSystemName(int system_id, int font_size,
 
         // does planet contain a shipyard?
         if (!has_shipyard) {
-            for (auto& building : Objects().FindObjects<const Building>(planet->BuildingIDs())) {
+            for (auto& building : Objects().find<const Building>(planet->BuildingIDs())) {
                 int building_id = building->ID();
 
                 if (known_destroyed_object_ids.count(building_id))
@@ -166,7 +165,7 @@ OwnerColoredSystemName::OwnerColoredSystemName(int system_id, int font_size,
 
         // is planet populated by neutral species
         if (!has_neutrals) {
-            if (planet->Unowned() && !planet->SpeciesName().empty() && planet->InitialMeterValue(METER_POPULATION) > 0.0f)
+            if (planet->Unowned() && !planet->SpeciesName().empty() && planet->GetMeter(METER_POPULATION)->Initial() > 0.0f)
                 has_neutrals = true;
         }
 
@@ -246,14 +245,7 @@ void OwnerColoredSystemName::SizeMove(const GG::Pt& ul, const GG::Pt& lr) {
 SystemIcon::SystemIcon(GG::X x, GG::Y y, GG::X w, int system_id) :
     GG::Control(x, y, w, GG::Y(Value(w)), GG::INTERACTIVE),
     m_system_id(system_id),
-    m_tiny_graphic(nullptr),
-    m_selection_indicator(nullptr),
-    m_tiny_selection_indicator(nullptr),
-    m_mouseover_indicator(nullptr),
-    m_mouseover_unexplored_indicator(nullptr),
-    m_tiny_mouseover_indicator(nullptr),
     m_selected(false),
-    m_colored_name(nullptr),
     m_showing_name(false)
 {}
 
@@ -261,7 +253,7 @@ void SystemIcon::CompleteConstruction() {
     GG::Control::CompleteConstruction();
 
     ClientUI* ui = ClientUI::GetClientUI();
-    if (auto system = GetSystem(m_system_id)) {
+    if (auto system = Objects().get<System>(m_system_id)) {
         StarType star_type = system->GetStarType();
         m_disc_texture = ui->GetModuloTexture(ClientUI::ArtDir() / "stars",
                                               ClientUI::StarTypeFilePrefixes()[star_type],
@@ -647,7 +639,7 @@ void SystemIcon::Refresh() {
     std::string name;
     m_system_connection.disconnect();
 
-    auto system = GetSystem(m_system_id);
+    auto system = Objects().get<System>(m_system_id);
     if (system) {
         name = system->Name();
         m_system_connection = system->StateChangedSignal.connect(
