@@ -94,9 +94,6 @@ SystemResourceSummaryBrowseWnd::SystemResourceSummaryBrowseWnd(ResourceType reso
     m_resource_type(resource_type),
     m_system_id(system_id),
     m_empire_id(empire_id),
-    m_production_label(nullptr),
-    m_allocation_label(nullptr),
-    m_import_export_label(nullptr),
     row_height(1),
     production_label_top(0),
     allocation_label_top(0),
@@ -179,7 +176,7 @@ void SystemResourceSummaryBrowseWnd::UpdateProduction(GG::Y& top) {
     }
     m_production_labels_and_amounts.clear();
 
-    auto system = GetSystem(m_system_id);
+    auto system = Objects().get<System>(m_system_id);
     if (!system || m_resource_type == INVALID_RESOURCE_TYPE)
         return;
 
@@ -188,7 +185,7 @@ void SystemResourceSummaryBrowseWnd::UpdateProduction(GG::Y& top) {
 
 
     // add label-value pair for each resource-producing object in system to indicate amount of resource produced
-    auto objects = Objects().FindObjects<const UniverseObject>(system->ContainedObjectIDs());
+    auto objects = Objects().find<const UniverseObject>(system->ContainedObjectIDs());
 
     for (auto& obj : objects) {
         // display information only for the requested player
@@ -199,7 +196,7 @@ void SystemResourceSummaryBrowseWnd::UpdateProduction(GG::Y& top) {
         if (!rc) continue;
 
         std::string name = obj->Name();
-        double production = rc->InitialMeterValue(ResourceToMeter(m_resource_type));
+        double production = rc->GetMeter(ResourceToMeter(m_resource_type))->Initial();
         m_production += production;
 
         std::string amount_text = DoubleToString(production, 3, false);
@@ -270,7 +267,7 @@ void SystemResourceSummaryBrowseWnd::UpdateAllocation(GG::Y& top) {
     }
     m_allocation_labels_and_amounts.clear();
 
-    auto system = GetSystem(m_system_id);
+    auto system = Objects().get<System>(m_system_id);
     if (!system || m_resource_type == INVALID_RESOURCE_TYPE)
         return;
 
@@ -279,7 +276,7 @@ void SystemResourceSummaryBrowseWnd::UpdateAllocation(GG::Y& top) {
 
 
     // add label-value pair for each resource-consuming object in system to indicate amount of resource consumed
-    for (auto& obj : Objects().FindObjects<const UniverseObject>(system->ContainedObjectIDs())) {
+    for (auto& obj : Objects().find<const UniverseObject>(system->ContainedObjectIDs())) {
         // display information only for the requested player
         if (m_empire_id != ALL_EMPIRES && !obj->OwnedBy(m_empire_id))
             continue;   // if m_empire_id == ALL_EMPIRES, display resource production for all empires.  otherwise, skip this resource production if it's not owned by the requested player
@@ -294,7 +291,7 @@ void SystemResourceSummaryBrowseWnd::UpdateAllocation(GG::Y& top) {
         // don't add summary entries for objects that consume no resource.  (otherwise there would be a loooong pointless list of 0's
         if (allocation <= 0.0) {
             if (allocation < 0.0)
-                ErrorLogger() << "object " << obj->Name() << " is reported having negative " << boost::lexical_cast<std::string>(m_resource_type) << " consumption";
+                ErrorLogger() << "object " << obj->Name() << " is reported having negative " << m_resource_type << " consumption";
             continue;
         }
 
