@@ -12,16 +12,17 @@
 #include "../util/Logger.h"
 #include "../util/OptionsDB.h"
 #include "../util/Directories.h"
-#include "../universe/Tech.h"
-#include "../universe/Effect.h"
-#include "../universe/ValueRef.h"
+#include "../util/ScopedTimer.h"
+#include "../universe/Effects.h"
 #include "../universe/Enums.h"
+#include "../universe/Tech.h"
+#include "../universe/UnlockableItem.h"
+#include "../universe/ValueRef.h"
 #include "../Empire/Empire.h"
 #include "TechTreeLayout.h"
 #include "TechTreeArcs.h"
 #include "Hotkeys.h"
 
-#include <GG/DrawUtil.h>
 #include <GG/GLClientAndServerBuffer.h>
 #include <GG/GUI.h>
 #include <GG/Layout.h>
@@ -29,48 +30,42 @@
 
 #include <algorithm>
 
-#include <boost/timer.hpp>
-
 namespace {
     const std::string RES_PEDIA_WND_NAME = "research.pedia";
     const std::string RES_CONTROLS_WND_NAME = "research.control";
 
     // command-line options
     void AddOptions(OptionsDB& db) {
-        db.Add("ui.research.tree.spacing.horizontal", UserStringNop("OPTIONS_DB_UI_TECH_LAYOUT_HORZ_SPACING"), 0.25, RangedStepValidator<double>(0.25, 0.25, 4.0));
-        db.Add("ui.research.tree.spacing.vertical", UserStringNop("OPTIONS_DB_UI_TECH_LAYOUT_VERT_SPACING"), 0.75, RangedStepValidator<double>(0.25, 0.25, 4.0));
-        db.Add("ui.research.tree.zoom.scale", UserStringNop("OPTIONS_DB_UI_TECH_LAYOUT_ZOOM_SCALE"), 1.0, RangedStepValidator<double>(1.0, -25.0, 10.0));
-        db.Add("ui.research.control.graphic.size", UserStringNop("OPTIONS_DB_UI_TECH_CTRL_ICON_SIZE"), 3.0, RangedStepValidator<double>(0.25, 0.5,  12.0));
-        db.Add("ui." + RES_PEDIA_WND_NAME + ".hidden.enabled", UserStringNop("OPTIONS_DB_RESEARCH_PEDIA_HIDDEN"), false, Validator<bool>());
+        db.Add("ui.research.tree.spacing.horizontal",           UserStringNop("OPTIONS_DB_UI_TECH_LAYOUT_HORZ_SPACING"),
+               0.25,                    RangedStepValidator<double>(0.25, 0.25, 4.0));
+        db.Add("ui.research.tree.spacing.vertical",             UserStringNop("OPTIONS_DB_UI_TECH_LAYOUT_VERT_SPACING"),
+               0.75,                    RangedStepValidator<double>(0.25, 0.25, 4.0));
+        db.Add("ui.research.tree.zoom.scale",                   UserStringNop("OPTIONS_DB_UI_TECH_LAYOUT_ZOOM_SCALE"),
+               1.0,                     RangedStepValidator<double>(1.0, -25.0, 10.0));
+        db.Add("ui.research.control.graphic.size",              UserStringNop("OPTIONS_DB_UI_TECH_CTRL_ICON_SIZE"),
+               3.0,                     RangedStepValidator<double>(0.25, 0.5,  12.0));
+        db.Add("ui." + RES_PEDIA_WND_NAME + ".hidden.enabled",  UserStringNop("OPTIONS_DB_RESEARCH_PEDIA_HIDDEN"), false);
 
         // TechListBox::TechRow column widths
         int default_pts = 16;
-        db.Add("ui.research.list.column.graphic.width",     UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_GRAPHIC"),
+        db.Add("ui.research.list.column.graphic.width",         UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_GRAPHIC"),
                default_pts * 3,         StepValidator<int>(1));
-        db.Add("ui.research.list.column.name.width",        UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_NAME"),
+        db.Add("ui.research.list.column.name.width",            UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_NAME"),
                default_pts * 18,        StepValidator<int>(1));
-        db.Add("ui.research.list.column.cost.width",        UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_COST"),
+        db.Add("ui.research.list.column.cost.width",            UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_COST"),
                default_pts * 8,         StepValidator<int>(1));
-        db.Add("ui.research.list.column.time.width",        UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_TIME"),
+        db.Add("ui.research.list.column.time.width",            UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_TIME"),
                default_pts * 6,         StepValidator<int>(1));
-        db.Add("ui.research.list.column.category.width",    UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_CATEGORY"),
+        db.Add("ui.research.list.column.category.width",        UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_CATEGORY"),
                default_pts * 12,        StepValidator<int>(1));
-        db.Add("ui.research.list.column.description.width", UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_DESCRIPTION"),
+        db.Add("ui.research.list.column.description.width",     UserStringNop("OPTIONS_DB_UI_TECH_LISTBOX_COL_WIDTH_DESCRIPTION"),
                default_pts * 18,        StepValidator<int>(1));
 
         // Default status for TechTreeControl filter.
-        db.Add<bool>("ui.research.status.unresearchable.shown",
-                     UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_UNRESEARCHABLE"),
-                     false,        Validator<bool>());
-        db.Add<bool>("ui.research.status.partial.shown",
-                     UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_HAS_RESEARCHED_PREREQ"),
-                     true,         Validator<bool>());
-        db.Add<bool>("ui.research.status.researchable.shown",
-                     UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_RESEARCHABLE"),
-                     true,         Validator<bool>());
-        db.Add<bool>("ui.research.status.completed.shown",
-                     UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_COMPLETED"),
-                     true,         Validator<bool>());
+        db.Add<bool>("ui.research.status.unresearchable.shown", UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_UNRESEARCHABLE"),         false);
+        db.Add<bool>("ui.research.status.partial.shown",        UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_HAS_RESEARCHED_PREREQ"),  true);
+        db.Add<bool>("ui.research.status.researchable.shown",   UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_RESEARCHABLE"),           true);
+        db.Add<bool>("ui.research.status.completed.shown",      UserStringNop("OPTIONS_DB_UI_TECH_TREE_STATUS_COMPLETED"),              true);
     }
     bool temp_bool = RegisterOptions(&AddOptions);
 
@@ -115,7 +110,7 @@ namespace {
 }
 
 ///////////////////////////
-// TechRowBrowseWnd //
+//   TechRowBrowseWnd    //
 ///////////////////////////
 std::shared_ptr<GG::BrowseInfoWnd> TechRowBrowseWnd(const std::string& tech_name, int empire_id) {
     const Empire* empire = GetEmpire(empire_id);
@@ -577,25 +572,25 @@ private:
     bool TreeZoomOutKeyboard();
     void ConnectKeyboardAcceleratorSignals();
 
-    double                  m_scale;
+    double                  m_scale = INITIAL_SCALE;
     std::set<std::string>   m_categories_shown;
     std::set<TechStatus>    m_tech_statuses_shown;
     std::string             m_selected_tech_name;
     std::string             m_browsed_tech_name;
     TechTreeLayout          m_graph;
 
-    std::map<std::string, std::shared_ptr<TechPanel>>   m_techs;
-    TechTreeArcs                        m_dependency_arcs;
+    std::map<std::string, std::shared_ptr<TechPanel>> m_techs;
+    TechTreeArcs                    m_dependency_arcs;
 
-    std::shared_ptr<LayoutSurface> m_layout_surface;
-    std::shared_ptr<GG::Scroll>    m_vscroll;
-    std::shared_ptr<GG::Scroll>    m_hscroll;
-    double         m_scroll_position_x;     //actual scroll position
-    double         m_scroll_position_y;
-    double         m_drag_scroll_position_x;//position when drag started
-    double         m_drag_scroll_position_y;
-    std::shared_ptr<GG::Button>    m_zoom_in_button;
-    std::shared_ptr<GG::Button>    m_zoom_out_button;
+    std::shared_ptr<LayoutSurface>  m_layout_surface;
+    std::shared_ptr<GG::Scroll>     m_vscroll;
+    std::shared_ptr<GG::Scroll>     m_hscroll;
+    double                          m_scroll_position_x = 0.0;      //actual scroll position
+    double                          m_scroll_position_y = 0.0;
+    double                          m_drag_scroll_position_x = 0.0; //position when drag started
+    double                          m_drag_scroll_position_y = 0.0;
+    std::shared_ptr<GG::Button>     m_zoom_in_button;
+    std::shared_ptr<GG::Button>     m_zoom_out_button;
 };
 
 
@@ -674,15 +669,7 @@ private:
 TechTreeWnd::LayoutPanel::TechPanel::TechPanel(const std::string& tech_name, const LayoutPanel* panel) :
     GG::Wnd(GG::X0, GG::Y0, TechPanelWidth(), TechPanelHeight(), GG::INTERACTIVE),
     m_tech_name(tech_name),
-    m_name_text(),
-    m_cost_and_duration_text(),
-    m_eta_text(),
     m_layout_panel(panel),
-    m_icon(nullptr),
-    m_unlock_icons(),
-    m_name_label(nullptr),
-    m_cost_and_duration_label(nullptr),
-    m_eta_label(nullptr),
     m_colour(GG::CLR_GRAY),
     m_status(TS_RESEARCHABLE),
     m_browse_highlight(false),
@@ -970,7 +957,7 @@ void TechTreeWnd::LayoutPanel::TechPanel::Update() {
             GG::Y icon_top = icon_bottom - icon_height;
 
             // add icons for unlocked items
-            for (const ItemSpec& item : tech->UnlockedItems()) {
+            for (const UnlockableItem& item : tech->UnlockedItems()) {
                 std::shared_ptr<GG::Texture> texture;
                 switch (item.type) {
                 case UIT_BUILDING:  texture = ClientUI::BuildingIcon(item.name);    break;
@@ -991,17 +978,17 @@ void TechTreeWnd::LayoutPanel::TechPanel::Update() {
             std::set<std::string> specials_affected;
             std::set<std::string> parts_whose_meters_are_affected;
             for (auto& effects_group : tech->Effects()) {
-                for (Effect::EffectBase* effect : effects_group->EffectsList()) {
+                for (Effect::Effect* effect : effects_group->EffectsList()) {
                     if (const Effect::SetMeter* set_meter_effect = dynamic_cast<const Effect::SetMeter*>(effect)) {
                         meters_affected.insert(set_meter_effect->GetMeterType());
 
                     } else if (const Effect::SetShipPartMeter* set_ship_part_meter_effect = dynamic_cast<const Effect::SetShipPartMeter*>(effect)) {
-                        const ValueRef::ValueRefBase<std::string>* part_name = set_ship_part_meter_effect->GetPartName();
+                        const ValueRef::ValueRef<std::string>* part_name = set_ship_part_meter_effect->GetPartName();
                         if (part_name && part_name->ConstantExpr())
                             parts_whose_meters_are_affected.insert(part_name->Eval());
 
                     } else if (const Effect::AddSpecial* add_special_effect = dynamic_cast<const Effect::AddSpecial*>(effect)) {
-                        const ValueRef::ValueRefBase<std::string>* special_name = add_special_effect->GetSpecialName();
+                        const ValueRef::ValueRef<std::string>* special_name = add_special_effect->GetSpecialName();
                         if (special_name && special_name->ConstantExpr())
                             specials_affected.insert(special_name->Eval());
                     }
@@ -1062,18 +1049,7 @@ void TechTreeWnd::LayoutPanel::TechPanel::Update() {
 // TechTreeWnd::LayoutPanel                     //
 //////////////////////////////////////////////////
 TechTreeWnd::LayoutPanel::LayoutPanel(GG::X w, GG::Y h) :
-    GG::Wnd(GG::X0, GG::Y0, w, h, GG::INTERACTIVE),
-    m_scale(INITIAL_SCALE),
-    m_categories_shown(),
-    m_tech_statuses_shown(),
-    m_selected_tech_name(),
-    m_browsed_tech_name(),
-    m_graph(),
-    m_layout_surface(nullptr),
-    m_vscroll(nullptr),
-    m_hscroll(nullptr),
-    m_zoom_in_button(nullptr),
-    m_zoom_out_button(nullptr)
+    GG::Wnd(GG::X0, GG::Y0, w, h, GG::INTERACTIVE)
 {}
 
 void TechTreeWnd::LayoutPanel::CompleteConstruction() {
@@ -1101,22 +1077,21 @@ void TechTreeWnd::LayoutPanel::CompleteConstruction() {
     AttachChild(m_zoom_in_button);
     AttachChild(m_zoom_out_button);
 
-    m_layout_surface->DraggedSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::TreeDraggedSlot, this, _1));
-    m_layout_surface->ButtonUpSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::TreeDragEnd, this, _1));
-    m_layout_surface->ButtonDownSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::TreeDragBegin, this, _1));
-    m_layout_surface->ZoomedSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::TreeZoomedSlot, this, _1));
-    m_vscroll->ScrolledSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::ScrolledSlot, this, _1, _2, _3, _4));
-    m_hscroll->ScrolledSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::ScrolledSlot, this, _1, _2, _3, _4));
-    m_zoom_in_button->LeftClickedSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::TreeZoomedSlot, this, 1));
-    m_zoom_out_button->LeftClickedSignal.connect(
-        boost::bind(&TechTreeWnd::LayoutPanel::TreeZoomedSlot, this, -1));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+    using boost::placeholders::_4;
+#endif
+
+    m_layout_surface->DraggedSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::TreeDraggedSlot, this, _1));
+    m_layout_surface->ButtonUpSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::TreeDragEnd, this, _1));
+    m_layout_surface->ButtonDownSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::TreeDragBegin, this, _1));
+    m_layout_surface->ZoomedSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::TreeZoomedSlot, this, _1));
+    m_vscroll->ScrolledSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::ScrolledSlot, this, _1, _2, _3, _4));
+    m_hscroll->ScrolledSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::ScrolledSlot, this, _1, _2, _3, _4));
+    m_zoom_in_button->LeftClickedSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::TreeZoomedSlot, this, 1));
+    m_zoom_out_button->LeftClickedSignal.connect(boost::bind(&TechTreeWnd::LayoutPanel::TreeZoomedSlot, this, -1));
 
     ConnectKeyboardAcceleratorSignals();
 
@@ -1397,7 +1372,7 @@ void TechTreeWnd::LayoutPanel::Layout(bool keep_position) {
 
     std::set<std::string> visible_techs;
 
-    // create new tech panels and new dependency arcs 
+    // create new tech panels and new dependency arcs
     for (const auto& tech : manager) {
         if (!tech) continue;
         const std::string& tech_name = tech->Name();
@@ -1408,12 +1383,15 @@ void TechTreeWnd::LayoutPanel::Layout(bool keep_position) {
         auto& tech_panel = m_techs[tech_name];
         tech_panel->MoveTo(GG::Pt(node->GetX(), node->GetY()));
         m_layout_surface->AttachChild(tech_panel);
+
+#if BOOST_VERSION >= 106000
+        using boost::placeholders::_1;
+#endif
+
         tech_panel->TechLeftClickedSignal.connect(
             boost::bind(&TechTreeWnd::LayoutPanel::SelectTech, this, _1));
-        tech_panel->TechDoubleClickedSignal.connect(
-            TechDoubleClickedSignal);
-        tech_panel->TechPediaDisplaySignal.connect(
-            TechPediaDisplaySignal);
+        tech_panel->TechDoubleClickedSignal.connect(TechDoubleClickedSignal);
+        tech_panel->TechPediaDisplaySignal.connect(TechPediaDisplaySignal);
 
         visible_techs.insert(tech_name);
     }
@@ -1553,10 +1531,10 @@ private:
 
         void Render() override;
 
-        const std::string&          GetTech() { return m_tech; }
-        static std::vector<GG::X>   ColWidths(GG::X total_width);
-        static std::vector<GG::Alignment> ColAlignments();
-        void                        Update();
+        const std::string&                  GetTech() { return m_tech; }
+        static std::vector<GG::X>           ColWidths(GG::X total_width);
+        static std::vector<GG::Alignment>   ColAlignments();
+        void                                Update();
 
     private:
         std::string m_tech;
@@ -1564,17 +1542,17 @@ private:
         bool m_enqueued;
     };
 
-    void    Populate(bool update = true);
-    void    TechDoubleClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
-    void    TechLeftClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
-    void    TechRightClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
-    void    ToggleSortCol(unsigned int col);
+    void Populate(bool update = true);
+    void TechDoubleClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
+    void TechLeftClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
+    void TechRightClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
+    void ToggleSortCol(unsigned int col);
 
-    std::set<std::string>                   m_categories_shown;
-    std::set<TechStatus>                    m_tech_statuses_shown;
-    std::unordered_map<std::string, std::shared_ptr<TechRow>> m_tech_row_cache;
-    std::shared_ptr<GG::ListBox::Row>                       m_header_row;
-    size_t                                  m_previous_sort_col;
+    std::set<std::string>                                       m_categories_shown;
+    std::set<TechStatus>                                        m_tech_statuses_shown;
+    std::unordered_map<std::string, std::shared_ptr<TechRow>>   m_tech_row_cache;
+    std::shared_ptr<GG::ListBox::Row>                           m_header_row;
+    size_t                                                      m_previous_sort_col;
 };
 
 void TechTreeWnd::TechListBox::TechRow::Render() {
@@ -1629,11 +1607,11 @@ bool TechTreeWnd::TechListBox::TechRowCmp(const GG::ListBox::Row& lhs, const GG:
 }
 
 TechTreeWnd::TechListBox::TechRow::TechRow(GG::X w, const std::string& tech_name) :
-    CUIListBox::Row(w, GG::Y(ClientUI::Pts() * 2 + 5), "TechListBox::TechRow"),
+    CUIListBox::Row(w, GG::Y(ClientUI::Pts() * 2 + 5)),
     m_tech(tech_name),
     m_background_color(ClientUI::WndColor()),
     m_enqueued(false)
-{}
+{ SetDragDropDataType("TechListBox::TechRow"); }
 
 void TechTreeWnd::TechListBox::TechRow::CompleteConstruction() {
 
@@ -1749,12 +1727,15 @@ TechTreeWnd::TechListBox::TechListBox(GG::X w, GG::Y h) :
 void TechTreeWnd::TechListBox::CompleteConstruction() {
     CUIListBox::CompleteConstruction();
 
-    DoubleClickedRowSignal.connect(
-        boost::bind(&TechListBox::TechDoubleClicked, this, _1, _2, _3));
-    LeftClickedRowSignal.connect(
-        boost::bind(&TechListBox::TechLeftClicked, this, _1, _2, _3));
-    RightClickedRowSignal.connect(
-        boost::bind(&TechListBox::TechRightClicked, this, _1, _2, _3));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
+    DoubleClickedRowSignal.connect(boost::bind(&TechListBox::TechDoubleClicked, this, _1, _2, _3));
+    LeftClickedRowSignal.connect(boost::bind(&TechListBox::TechLeftClicked, this, _1, _2, _3));
+    RightClickedRowSignal.connect(boost::bind(&TechListBox::TechRightClicked, this, _1, _2, _3));
 
     SetStyle(GG::LIST_NOSEL);
 
@@ -1772,7 +1753,7 @@ void TechTreeWnd::TechListBox::CompleteConstruction() {
     GG::X row_width = Width() - ClientUI::ScrollWidth() - ClientUI::Pts();
     std::vector<GG::X> col_widths = TechRow::ColWidths(row_width);
     const GG::Y HEIGHT(Value(col_widths[0]));
-    m_header_row = GG::Wnd::Create<GG::ListBox::Row>(row_width, HEIGHT, "");
+    m_header_row = GG::Wnd::Create<GG::ListBox::Row>(row_width, HEIGHT);
 
     auto graphic_col = GG::Wnd::Create<CUILabel>("");  // graphic
     graphic_col->Resize(GG::Pt(col_widths[0], HEIGHT));
@@ -1846,7 +1827,7 @@ void TechTreeWnd::TechListBox::Update(bool populate /* = true */) {
     DebugLogger() << "Tech List Box Updating";
 
     double insertion_elapsed = 0.0;
-    boost::timer insertion_timer;
+    ScopedTimer insertion_timer;
     GG::X row_width = Width() - ClientUI::ScrollWidth() - ClientUI::Pts();
 
     // Try to preserve the first row, only works if a row for the tech is still visible
@@ -1874,7 +1855,7 @@ void TechTreeWnd::TechListBox::Update(bool populate /* = true */) {
             tech_row->Update();
             insertion_timer.restart();
             auto listbox_row_it = Insert(tech_row);
-            insertion_elapsed += insertion_timer.elapsed();
+            insertion_elapsed += insertion_timer.duration();
             if (!first_tech_set && row.first == first_tech_shown) {
                 first_tech_set = true;
                 SetFirstRowShown(listbox_row_it);
@@ -1904,7 +1885,7 @@ void TechTreeWnd::TechListBox::Populate(bool update /* = true*/) {
 
     GG::X row_width = Width() - ClientUI::ScrollWidth() - ClientUI::Pts();
 
-    boost::timer creation_timer;
+    ScopedTimer creation_timer;
 
     // Skip lookup check when starting with empty cache
     bool new_cache = m_tech_row_cache.empty();
@@ -1913,9 +1894,7 @@ void TechTreeWnd::TechListBox::Populate(bool update /* = true*/) {
             m_tech_row_cache.emplace(tech->Name(), GG::Wnd::Create<TechRow>(row_width, tech->Name()));
     }
 
-    auto creation_elapsed = creation_timer.elapsed();
-
-    DebugLogger() << "Tech List Box Populating Done,  Creation time = " << (creation_elapsed * 1000) << "ms";
+    DebugLogger() << "Tech List Box Populating Done,  Creation time = " << creation_timer.DurationString();
 
     if (update)
         Update(false);
@@ -2019,41 +1998,39 @@ void TechTreeWnd::TechListBox::TechDoubleClicked(GG::ListBox::iterator it, const
 //////////////////////////////////////////////////
 TechTreeWnd::TechTreeWnd(GG::X w, GG::Y h, bool initially_hidden /*= true*/) :
     GG::Wnd(GG::X0, GG::Y0, w, h, GG::INTERACTIVE),
-    m_tech_tree_controls(nullptr),
-    m_enc_detail_panel(nullptr),
-    m_layout_panel(nullptr),
-    m_tech_list(nullptr),
     m_init_flag(initially_hidden)
-{
-}
+{}
 
 void TechTreeWnd::CompleteConstruction() {
     GG::Wnd::CompleteConstruction();
 
     Sound::TempUISoundDisabler sound_disabler;
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
     m_layout_panel = GG::Wnd::Create<LayoutPanel>(Width(), Height());
-    m_layout_panel->TechSelectedSignal.connect(
-        boost::bind(&TechTreeWnd::TechLeftClickedSlot, this, _1, _2));
+    m_layout_panel->TechSelectedSignal.connect(boost::bind(&TechTreeWnd::TechLeftClickedSlot, this, _1, _2));
     m_layout_panel->TechDoubleClickedSignal.connect(
-        [this](const std::string& tech_name, GG::Flags<GG::ModKey> modkeys){ this->AddTechToResearchQueue(tech_name, modkeys & GG::MOD_KEY_CTRL); });
-    m_layout_panel->TechPediaDisplaySignal.connect(
-        boost::bind(&TechTreeWnd::TechPediaDisplaySlot, this, _1));
+        [this](const std::string& tech_name, GG::Flags<GG::ModKey> modkeys)
+    { this->AddTechToResearchQueue(tech_name, modkeys & GG::MOD_KEY_CTRL); });
+    m_layout_panel->TechPediaDisplaySignal.connect(boost::bind(&TechTreeWnd::TechPediaDisplaySlot, this, _1));
     AttachChild(m_layout_panel);
 
     m_tech_list = GG::Wnd::Create<TechListBox>(Width(), Height());
-    m_tech_list->TechLeftClickedSignal.connect(
-        boost::bind(&TechTreeWnd::TechLeftClickedSlot, this, _1, _2));
+    m_tech_list->TechLeftClickedSignal.connect(boost::bind(&TechTreeWnd::TechLeftClickedSlot, this, _1, _2));
     m_tech_list->TechDoubleClickedSignal.connect(
-        [this](const std::string& tech_name, GG::Flags<GG::ModKey> modkeys){ this->AddTechToResearchQueue(tech_name, modkeys & GG::MOD_KEY_CTRL); });
+        [this](const std::string& tech_name, GG::Flags<GG::ModKey> modkeys)
+    { this->AddTechToResearchQueue(tech_name, modkeys & GG::MOD_KEY_CTRL); });
     m_tech_list->TechPediaDisplaySignal.connect(
         boost::bind(&TechTreeWnd::TechPediaDisplaySlot, this, _1));
 
     m_enc_detail_panel = GG::Wnd::Create<EncyclopediaDetailPanel>(GG::ONTOP | GG::INTERACTIVE | GG::DRAGABLE | GG::RESIZABLE | CLOSABLE | PINABLE, RES_PEDIA_WND_NAME);
     m_tech_tree_controls =  GG::Wnd::Create<TechTreeControls>(RES_CONTROLS_WND_NAME);
 
-    m_enc_detail_panel->ClosingSignal.connect(
-        boost::bind(&TechTreeWnd::HidePedia, this));
+    m_enc_detail_panel->ClosingSignal.connect(boost::bind(&TechTreeWnd::HidePedia, this));
 
     InitializeWindows();
     // Make sure the controls don't overlap the bottom scrollbar
@@ -2070,8 +2047,7 @@ void TechTreeWnd::CompleteConstruction() {
     AttachChild(m_tech_tree_controls);
 
     // connect category button clicks to update display
-    for (auto& cat_button : m_tech_tree_controls->m_cat_buttons)
-    {
+    for (auto& cat_button : m_tech_tree_controls->m_cat_buttons) {
         const std::string& category_name = cat_button.first;
         cat_button.second->CheckedSignal.connect(
             [this, category_name](bool checked) {
@@ -2094,8 +2070,7 @@ void TechTreeWnd::CompleteConstruction() {
     );
 
     // connect status and type button clicks to update display
-    for (auto& status_button : m_tech_tree_controls->m_status_buttons)
-    {
+    for (auto& status_button : m_tech_tree_controls->m_status_buttons) {
         TechStatus tech_status = status_button.first;
         status_button.second->CheckedSignal.connect(
             [this, tech_status](bool checked){ this->SetTechStatus(tech_status, checked); });
