@@ -1,6 +1,7 @@
 #include "AIClientApp.h"
 
-#include "../../python/AI/AIFramework.h"
+#include "AIFramework.h"
+#include "../ClientNetworking.h"
 #include "../../util/Logger.h"
 #include "../../util/LoggerWithOptionsDB.h"
 #include "../../util/OptionsDB.h"
@@ -9,7 +10,6 @@
 #include "../../util/i18n.h"
 #include "../util/AppInterface.h"
 #include "../../network/Message.h"
-#include "../../network/ClientNetworking.h"
 #include "../util/Random.h"
 #include "../util/Version.h"
 
@@ -46,10 +46,11 @@ namespace {
      */
     template <typename T>
     void AddTraitBypassOption(OptionsDB& db, std::string const & root, std::string ROOT,
-                                 T def, ValidatorBase const & validator) {
+                              T def, ValidatorBase const & validator)
+    {
         std::string option_root = "ai.trait." + root + ".";
         std::string user_string_root = "OPTIONS_DB_AI_CONFIG_TRAIT_"+ROOT;
-        db.Add<bool>(option_root + "force.enabled", UserStringNop(user_string_root + "_FORCE"), false, Validator<bool>());
+        db.Add<bool>(option_root + "force.enabled", UserStringNop(user_string_root + "_FORCE"), false);
         db.Add<T>(option_root + "default", UserStringNop(user_string_root + "_FORCE_VALUE"), def, validator);
 
         for (int ii = 1; ii <= IApp::MAX_AI_PLAYERS(); ++ii) {
@@ -113,9 +114,6 @@ AIClientApp::~AIClientApp() {
     DebugLogger() << "AIClientApp exited cleanly for ai client " << PlayerName();
 }
 
-void AIClientApp::operator()()
-{ Run(); }
-
 void AIClientApp::ExitApp(int code) {
     DebugLogger() << "Initiating Exit (code " << code << " - " << (code ? "error" : "normal") << " termination)";
     if (code)
@@ -129,7 +127,7 @@ int AIClientApp::EffectsProcessingThreads() const
 AIClientApp* AIClientApp::GetApp()
 { return static_cast<AIClientApp*>(s_app); }
 
-const AIBase* AIClientApp::GetAI()
+const PythonAI* AIClientApp::GetAI()
 { return m_AI.get(); }
 
 void AIClientApp::Run() {
@@ -157,7 +155,7 @@ void AIClientApp::Run() {
                 else
                     std::this_thread::sleep_for(std::chrono::milliseconds(10));
 
-            } catch (boost::python::error_already_set) {
+            } catch (const boost::python::error_already_set&) {
                 /* If the python interpreter is still running then keep
                    going, otherwise exit.*/
                 m_AI->HandleErrorAlreadySet();
@@ -167,7 +165,8 @@ void AIClientApp::Run() {
         }
     } catch (const NormalExitException&) {
         // intentionally empty.
-    } catch (boost::python::error_already_set) {
+    } catch (const boost::python::error_already_set&) {
+        m_AI->HandleErrorAlreadySet();
         HandlePythonAICrash();
     }
 
@@ -248,7 +247,6 @@ void AIClientApp::HandleMessage(const Message& msg) {
         SaveGameUIData ui_data;         // ignored
         bool state_string_available;    // ignored, as save_state_string is sent even if not set by ExtractMessageData
         std::string save_state_string;
-        m_player_status.clear();
 
         ExtractGameStartMessageData(msg,                     single_player_game,     m_empire_id,
                                     m_current_turn,          m_empires,              m_universe,
@@ -324,17 +322,15 @@ void AIClientApp::HandleMessage(const Message& msg) {
         break;
     }
 
-    case Message::SAVE_GAME_DATA_REQUEST: {
-        //DebugLogger() << "AIClientApp::HandleMessage Message::SAVE_GAME_DATA_REQUEST";
-        Networking().SendMessage(ClientSaveDataMessage(Orders(), m_AI->GetSaveStateString()));
-        //DebugLogger() << "AIClientApp::HandleMessage sent save data message";
+    case Message::PLAYER_INFO:
+        ExtractPlayerInfoMessageData(msg, m_player_info);
         break;
-    }
 
     case Message::SAVE_GAME_COMPLETE:
         break;
 
     case Message::TURN_UPDATE: {
+        m_orders.Reset();
         //DebugLogger() << "AIClientApp::HandleMessage : extracting turn update message data";
         ExtractTurnUpdateMessageData(msg,                     m_empire_id,        m_current_turn,
                                      m_empires,               m_universe,         GetSpeciesManager(),
@@ -372,7 +368,8 @@ void AIClientApp::HandleMessage(const Message& msg) {
         std::string data;
         int player_id;
         boost::posix_time::ptime timestamp;
-        ExtractServerPlayerChatMessageData(msg, player_id, timestamp, data);
+        bool pm;
+        ExtractServerPlayerChatMessageData(msg, player_id, timestamp, data, pm);
         m_AI->HandleChatMessage(player_id, data);
         break;
     }
@@ -401,10 +398,17 @@ void AIClientApp::HandleMessage(const Message& msg) {
 
     case Message::CHECKSUM: {
         TraceLogger() << "(AIClientApp) CheckSum.";
-        VerifyCheckSum(msg);
+        bool result = VerifyCheckSum(msg);
+        if (!result) {
+            ErrorLogger() << "Wrong checksum";
+            throw std::runtime_error("AI got incorrect checksum.");
+        }
         break;
     }
 
+    case Message::TURN_TIMEOUT:
+        break;
+
     default: {
         ErrorLogger() << "AIClientApp::HandleMessage : Received unknown Message type code " << msg.Type();
         break;
