@@ -7,7 +7,6 @@
 #include <vector>
 
 
-class AIBase;
 class PythonAI;
 
 /** the application framework for an AI player FreeOrion client.*/
@@ -28,7 +27,8 @@ public:
     AIClientApp& operator=(const AIClientApp&&) = delete;
 
     /** \name Mutators */ //@{
-    void                operator()();   ///< external interface to Run()
+    //! Executes main event handler
+    void                Run();
     void                ExitApp(int code = 0); ///< does basic clean-up, then calls exit(); callable from anywhere in user code via GetApp()
     void                SetPlayerName(const std::string& player_name) { m_player_name = player_name; }
     //@}
@@ -36,15 +36,19 @@ public:
     /** \name Accessors */ //@{
     int EffectsProcessingThreads() const override;
 
+    /** @brief Return the player name of this client
+     *
+     * @return An UTF-8 encoded and NUL terminated string containing the player
+     *      name of this client.
+     */
     const std::string& PlayerName() const
     { return m_player_name; }
     //@}
 
     static AIClientApp* GetApp();       ///< returns a AIClientApp pointer to the singleton instance of the app
-    const AIBase*       GetAI();        ///< returns pointer to AIBase implementation of AI for this client
+    const PythonAI*     GetAI();        ///< returns pointer to AIBase implementation of AI for this client
 
 private:
-    void                Run();          ///< initializes app state, then executes main event handler/render loop (PollAndRender())
     void                ConnectToServer();
     void                StartPythonAI();
     void                HandlePythonAICrash();
