@@ -25,13 +25,10 @@ protected:
 
 public:
     ClientApp(const ClientApp&) = delete;
-
     ClientApp(ClientApp&&) = delete;
-
     ~ClientApp() override = default;
 
     const ClientApp& operator=(const ClientApp&) = delete;
-
     ClientApp& operator=(ClientApp&&) = delete;
 
     /** @brief Return the player identifier of this client
@@ -71,16 +68,6 @@ public:
     const std::map<int, PlayerInfo>& Players() const;
     /** @} */
 
-    /** @brief Return the player statuses in game
-     *
-     * @return Return a map containing PlayerStatus instances as value and
-     *      their player identifier as key.
-     *
-     * @{ */
-    std::map<int, Message::PlayerStatus>& PlayerStatus();
-    const std::map<int, Message::PlayerStatus>& PlayerStatus() const;
-    /** @} */
-
     /** @brief Return the ::Universe known to this client
      *
      * @return A reference to the single ::Universe instance representing
@@ -161,8 +148,14 @@ public:
      */
     std::string GetVisibleObjectName(std::shared_ptr<const UniverseObject> object) override;
 
-    /** @brief Send the OrderSet to the server and start a new turn */
-    virtual void StartTurn();
+    /** @brief Send the OrderSet and UI data to the server and start a new turn */
+    virtual void StartTurn(const SaveGameUIData& ui_data);
+
+    /** @brief Send the OrderSet and AI state to the server and start a new turn */
+    virtual void StartTurn(const std::string& save_state_string);
+
+    /** @brief Send turn orders updates to server without starting new turn */
+    void SendPartialOrders();
 
     /** \brief Handle server acknowledgement of receipt of orders and clear
         the orders. */
@@ -172,8 +165,10 @@ public:
      *
      * @return The EmpireManager instance in charge of maintaining the Empire
      *      object instances.
-     */
+     * @{ */
     EmpireManager& Empires() override;
+    const EmpireManager& Empires() const;
+    /** @} */
 
     /** @brief Return the Empire identified by @a empire_id
      *
@@ -225,20 +220,13 @@ public:
      */
     virtual void HandleTurnUpdate() {}
 
-    /** @brief Set whether the current game is a single player game or not
+    /** @brief Set the Message::PlayerStatus @a status for @a empire_id
      *
-     * @param single_player Set true if the game is a single player game,
-     *      false if not.
-     */
-    void SetSinglePlayerGame(bool single_player = true);
-
-    /** @brief Set the Message::PlayerStatus @a status for @a player_id
-     *
-     * @param player_id A player identifier.
+     * @param player_id A empire identifier.
      * @param status The new Message::PlayerStatus of the player identified by
-     *      @a player_id.
+     *      @a empire_id.
      */
-    void SetPlayerStatus(int player_id, Message::PlayerStatus status);
+    void SetEmpireStatus(int empire_id, Message::PlayerStatus status);
 
     /** @brief Return the singleton instance of this Application
      *
@@ -246,8 +234,11 @@ public:
      */
     static ClientApp* GetApp();
 
-    /** Compare content checksum from server with client content checksum. */
-    void VerifyCheckSum(const Message& msg);
+    /** @brief Compare content checksum from server with client content checksum.
+     *
+     * @return true if verify successed.
+     */
+    bool VerifyCheckSum(const Message& msg);
 
 protected:
     Universe                    m_universe;
@@ -261,11 +252,6 @@ protected:
     /** Indexed by player id, contains info about all players in the game */
 
     std::map<int, PlayerInfo>   m_player_info;
-    /** Indexed by player id, contains the last known PlayerStatus for each
-     *      player.
-     */
-    std::map<int, Message::PlayerStatus>
-                                m_player_status;
 };
 
 #endif // _ClientApp_h_
