@@ -17,10 +17,10 @@
 #include "../../UI/ServerConnectWnd.h"
 #include "../../UI/Sound.h"
 #include "../../network/Message.h"
-#include "../../network/ClientNetworking.h"
+#include "../ClientNetworking.h"
 #include "../../util/i18n.h"
 #include "../../util/LoggerWithOptionsDB.h"
-#include "../util/GameRules.h"
+#include "../../util/GameRules.h"
 #include "../../util/OptionsDB.h"
 #include "../../util/Process.h"
 #include "../../util/SaveGamePreviewUtils.h"
@@ -28,6 +28,7 @@
 #include "../../util/SitRepEntry.h"
 #include "../../util/Directories.h"
 #include "../../util/Version.h"
+#include "../../util/ScopedTimer.h"
 #include "../../universe/Planet.h"
 #include "../../universe/Species.h"
 #include "../../universe/Enums.h"
@@ -40,6 +41,7 @@
 #include <GG/Cursor.h>
 #include <GG/utf8/checked.h>
 
+#include <boost/algorithm/string/replace.hpp>
 #include <boost/algorithm/string/trim.hpp>
 #include <boost/lexical_cast.hpp>
 #include <boost/filesystem/operations.hpp>
@@ -48,6 +50,7 @@
 #include <boost/optional/optional.hpp>
 #include <boost/serialization/vector.hpp>
 #include <boost/algorithm/string.hpp>
+#include <boost/uuid/uuid_io.hpp>
 #include <boost/uuid/nil_generator.hpp>
 #include <boost/uuid/string_generator.hpp>
 
@@ -103,7 +106,6 @@ namespace {
         db.Add("save.auto.turn.interval",                   UserStringNop("OPTIONS_DB_AUTOSAVE_TURNS"),                     1,                  RangedValidator<int>(1, 50));
         db.Add("save.auto.file.limit",                      UserStringNop("OPTIONS_DB_AUTOSAVE_LIMIT"),                     10,                 RangedValidator<int>(1, 10000));
         db.Add("save.auto.initial.enabled",                 UserStringNop("OPTIONS_DB_AUTOSAVE_GALAXY_CREATION"),           true,               Validator<bool>());
-        db.Add("save.auto.exit.enabled",                    UserStringNop("OPTIONS_DB_AUTOSAVE_GAME_CLOSE"),                true,               Validator<bool>());
         db.Add("ui.input.mouse.button.swap.enabled",        UserStringNop("OPTIONS_DB_UI_MOUSE_LR_SWAP"),                   false);
         db.Add("ui.input.keyboard.repeat.delay",            UserStringNop("OPTIONS_DB_KEYPRESS_REPEAT_DELAY"),              360,                RangedValidator<int>(0, 1000));
         db.Add("ui.input.keyboard.repeat.interval",         UserStringNop("OPTIONS_DB_KEYPRESS_REPEAT_INTERVAL"),           20,                 RangedValidator<int>(0, 1000));
@@ -193,24 +195,24 @@ void HumanClientApp::AddWindowSizeOptionsAfterMainStart(OptionsDB& db) {
     const int max_width_plus_one = HumanClientApp::MaximumPossibleWidth() + 1;
     const int max_height_plus_one = HumanClientApp::MaximumPossibleHeight() + 1;
 
-    db.Add("video.fullscreen.width", UserStringNop("OPTIONS_DB_APP_WIDTH"),            DEFAULT_WIDTH,       RangedValidator<int>(MIN_WIDTH, max_width_plus_one));
-    db.Add("video.fullscreen.height", UserStringNop("OPTIONS_DB_APP_HEIGHT"),          DEFAULT_HEIGHT,      RangedValidator<int>(MIN_HEIGHT, max_height_plus_one));
-    db.Add("video.windowed.width",  UserStringNop("OPTIONS_DB_APP_WIDTH_WINDOWED"),    DEFAULT_WIDTH,       RangedValidator<int>(MIN_WIDTH, max_width_plus_one));
-    db.Add("video.windowed.height", UserStringNop("OPTIONS_DB_APP_HEIGHT_WINDOWED"),   DEFAULT_HEIGHT,      RangedValidator<int>(MIN_HEIGHT, max_height_plus_one));
-    db.Add("video.windowed.left", UserStringNop("OPTIONS_DB_APP_LEFT_WINDOWED"),  DEFAULT_LEFT,        OrValidator<int>( RangedValidator<int>(-max_width_plus_one, max_width_plus_one), DiscreteValidator<int>(DEFAULT_LEFT) ));
-    db.Add("video.windowed.top", UserStringNop("OPTIONS_DB_APP_TOP_WINDOWED"),    DEFAULT_TOP,         RangedValidator<int>(-max_height_plus_one, max_height_plus_one));
+    db.Add("video.fullscreen.width", UserStringNop("OPTIONS_DB_APP_WIDTH"),             DEFAULT_WIDTH,  RangedValidator<int>(MIN_WIDTH, max_width_plus_one));
+    db.Add("video.fullscreen.height", UserStringNop("OPTIONS_DB_APP_HEIGHT"),           DEFAULT_HEIGHT, RangedValidator<int>(MIN_HEIGHT, max_height_plus_one));
+    db.Add("video.windowed.width",  UserStringNop("OPTIONS_DB_APP_WIDTH_WINDOWED"),     DEFAULT_WIDTH,  RangedValidator<int>(MIN_WIDTH, max_width_plus_one));
+    db.Add("video.windowed.height", UserStringNop("OPTIONS_DB_APP_HEIGHT_WINDOWED"),    DEFAULT_HEIGHT, RangedValidator<int>(MIN_HEIGHT, max_height_plus_one));
+    db.Add("video.windowed.left", UserStringNop("OPTIONS_DB_APP_LEFT_WINDOWED"),        DEFAULT_LEFT,   OrValidator<int>( RangedValidator<int>(-max_width_plus_one, max_width_plus_one), DiscreteValidator<int>(DEFAULT_LEFT) ));
+    db.Add("video.windowed.top", UserStringNop("OPTIONS_DB_APP_TOP_WINDOWED"),          DEFAULT_TOP,    RangedValidator<int>(-max_height_plus_one, max_height_plus_one));
+}
+
+std::string HumanClientApp::EncodeServerAddressOption(const std::string& server) {
+    std::string server_encoded = boost::replace_all_copy(server, ".", "_");
+    boost::replace_all(server_encoded, ":", "_");
+    return "network.known-servers._" + server_encoded;
 }
 
 HumanClientApp::HumanClientApp(int width, int height, bool calculate_fps, const std::string& name,
                                int x, int y, bool fullscreen, bool fake_mode_change) :
     ClientApp(),
-    SDLGUI(width, height, calculate_fps, name, x, y, fullscreen, fake_mode_change),
-    m_single_player_game(true),
-    m_game_started(false),
-    m_connected(false),
-    m_auto_turns(0),
-    m_have_window_focus(true),
-    m_game_saves_in_progress()
+    SDLGUI(width, height, calculate_fps, name, x, y, fullscreen, fake_mode_change)
 {
 #ifdef ENABLE_CRASH_BACKTRACE
     signal(SIGSEGV, SigHandler);
@@ -244,11 +246,14 @@ HumanClientApp::HumanClientApp(int width, int height, bool calculate_fps, const
     RegisterLoggerWithOptionsDB("server", true);
     RegisterLoggerWithOptionsDB("combat_log");
     RegisterLoggerWithOptionsDB("combat");
+    RegisterLoggerWithOptionsDB("supply");
     RegisterLoggerWithOptionsDB("effects");
+    RegisterLoggerWithOptionsDB("conditions");
     RegisterLoggerWithOptionsDB("FSM");
     RegisterLoggerWithOptionsDB("network");
     RegisterLoggerWithOptionsDB("python");
     RegisterLoggerWithOptionsDB("timer");
+    RegisterLoggerWithOptionsDB("IDallocator");
 
     InfoLogger() << FreeOrionVersionString();
 
@@ -260,6 +265,19 @@ HumanClientApp::HumanClientApp(int width, int height, bool calculate_fps, const
 
     LogDependencyVersions();
 
+    float version_number = GetGLVersion();
+    if (version_number < 2.0f) {
+        ErrorLogger() << "OpenGL version is less than 2; FreeOrion will likely crash while starting up...";
+        if (!GetOptionsDB().Get<bool>("version.gl.check.done")) {
+            auto mb_result = SDL_ShowSimpleMessageBox(SDL_MESSAGEBOX_WARNING, UserString("OPENGL_VERSION_LOW_TITLE").c_str(),
+                                                      UserString("OPENGL_VERSION_LOW_TEXT").c_str(), nullptr);
+            if (mb_result)
+                std::cerr << "OpenGL version is less than 2; FreeOrion will likely crash during initialization";
+        }
+    } else if (version_number < 2.1f) {
+        ErrorLogger() << "OpenGL version is less than 2.1; FreeOrion may crash during initialization";
+    }
+
     SetStyleFactory(std::make_shared<CUIStyle>());
 
     SetMinDragTime(0);
@@ -274,7 +292,7 @@ HumanClientApp::HumanClientApp(int width, int height, bool calculate_fps, const
 
         Sound::GetSound().SetMusicVolume(GetOptionsDB().Get<int>("audio.music.volume"));
         Sound::GetSound().SetUISoundsVolume(GetOptionsDB().Get<int>("audio.effects.volume"));
-    } catch (Sound::InitializationFailureException const &) {
+    } catch (const Sound::InitializationFailureException&) {
         inform_user_sound_failed = true;
     }
 
@@ -304,38 +322,22 @@ HumanClientApp::HumanClientApp(int width, int height, bool calculate_fps, const
                                 GetOptionsDB().Get<int>("ui.input.mouse.button.repeat.interval"));
     EnableModalAcceleratorSignals(true);
 
-    WindowResizedSignal.connect(
-        boost::bind(&HumanClientApp::HandleWindowResize, this, _1, _2));
-    FocusChangedSignal.connect(
-        boost::bind(&HumanClientApp::HandleFocusChange, this, _1));
-    WindowMovedSignal.connect(
-        boost::bind(&HumanClientApp::HandleWindowMove, this, _1, _2));
-    WindowClosingSignal.connect(
-        boost::bind(&HumanClientApp::HandleAppQuitting, this));
-    AppQuittingSignal.connect(
-        boost::bind(&HumanClientApp::HandleAppQuitting, this));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
+    WindowResizedSignal.connect(boost::bind(&HumanClientApp::HandleWindowResize,this, _1, _2));
+    FocusChangedSignal.connect( boost::bind(&HumanClientApp::HandleFocusChange, this, _1));
+    WindowMovedSignal.connect(  boost::bind(&HumanClientApp::HandleWindowMove,  this, _1, _2));
+    WindowClosingSignal.connect(boost::bind(&HumanClientApp::HandleAppQuitting, this));
+    AppQuittingSignal.connect(  boost::bind(&HumanClientApp::HandleAppQuitting, this));
 
     SetStringtableDependentOptionDefaults();
     SetGLVersionDependentOptionDefaults();
 
     this->SetMouseLRSwapped(GetOptionsDB().Get<bool>("ui.input.mouse.button.swap.enabled"));
 
-    auto named_key_maps = parse::keymaps(GetResourceDir() / "scripting/keymaps.inf");
-    TraceLogger() << "Keymaps:";
-    for (auto& km : named_key_maps) {
-        TraceLogger() << "Keymap name = \"" << km.first << "\"";
-        for (auto& keys : km.second)
-            TraceLogger() << "    " << char(keys.first) << " : " << char(keys.second);
-    }
-    auto km_it = named_key_maps.find("TEST");
-    if (km_it != named_key_maps.end()) {
-        const auto int_key_map = km_it->second;
-        std::map<GG::Key, GG::Key> key_map;
-        for (const auto& int_key : int_key_map)
-        { key_map[GG::Key(int_key.first)] = GG::Key(int_key.second); }
-        this->SetKeyMap(key_map);
-    }
-
     ConnectKeyboardAcceleratorSignals();
 
     m_auto_turns = GetOptionsDB().Get<int>("auto-advance-n-turns");
@@ -363,9 +365,9 @@ void HumanClientApp::ConnectKeyboardAcceleratorSignals() {
     // Add global hotkeys
     HotkeyManager *hkm = HotkeyManager::GetManager();
 
-    hkm->Connect(boost::bind(&HumanClientApp::HandleHotkeyExitApp, this),          "exit",
+    hkm->Connect(boost::bind(&HumanClientApp::HandleHotkeyExitApp, this), "exit",
                  NoModalWndsOpenCondition);
-    hkm->Connect(boost::bind(&HumanClientApp::HandleHotkeyResetGame, this),        "quit",
+    hkm->Connect(boost::bind(&HumanClientApp::HandleHotkeyResetGame, this), "quit",
                  NoModalWndsOpenCondition);
     hkm->Connect(boost::bind(&HumanClientApp::ToggleFullscreen, this), "video.fullscreen",
                  NoModalWndsOpenCondition);
@@ -388,17 +390,11 @@ bool HumanClientApp::CanSaveNow() const {
         return false;
 
     // can't save while AIs are playing their turns...
-    for (const auto& entry : m_player_info) {
-        const PlayerInfo& info = entry.second;
-        if (info.client_type != Networking::CLIENT_TYPE_AI_PLAYER)
+    for (const auto& entry : Empires()) {
+        if (GetEmpireClientType(entry.first) != Networking::CLIENT_TYPE_AI_PLAYER)
             continue;   // only care about AIs
 
-        auto status_it = m_player_status.find(entry.first);
-
-        if (status_it == this->m_player_status.end()) {
-            return false;  // missing status for AI; can't assume it's ready
-        }
-        if (status_it->second != Message::WAITING) {
+        if (!entry.second->Ready()) {
             return false;
         }
     }
@@ -486,7 +482,11 @@ void HumanClientApp::StartServer() {
         args.push_back("--singleplayer");
         args.push_back("--skip-checksum");
     }
+    DebugLogger() << "Launching server process with args: ";
+    for (auto arg : args)
+        DebugLogger() << arg;
     m_server_process = Process(SERVER_CLIENT_EXE, args);
+    DebugLogger() << "... finished launching server process.";
 }
 
 void HumanClientApp::FreeServer() {
@@ -497,6 +497,7 @@ void HumanClientApp::FreeServer() {
 }
 
 void HumanClientApp::NewSinglePlayerGame(bool quickstart) {
+    TraceLogger() << "HumanClientApp::NewSinglePlayerGame start";
     ClearPreviousPendingSaves(m_game_saves_in_progress);
 
     if (!GetOptionsDB().Get<bool>("network.server.external.force")) {
@@ -514,106 +515,113 @@ void HumanClientApp::NewSinglePlayerGame(bool quickstart) {
     }
 
     bool ended_with_ok = false;
-    std::vector<std::pair<std::string, std::string>> game_rules = GetGameRules().GetRulesAsStrings();
+    auto game_rules = GetGameRules().GetRulesAsStrings();
     if (!quickstart) {
+        DebugLogger() << "Initializing galaxy setup window";
         auto galaxy_wnd = GG::Wnd::Create<GalaxySetupWnd>();
+        TraceLogger() << "Running galaxy setup window";
         galaxy_wnd->Run();
         ended_with_ok = galaxy_wnd->EndedWithOk();
+        TraceLogger() << "Setup ran, " << (ended_with_ok ? "ended with OK" : "ended without OK");
         if (ended_with_ok)
             game_rules = galaxy_wnd->GetRulesAsStrings();
+        TraceLogger() << "Got rules as strings";
     }
 
+
     m_connected = m_networking->ConnectToLocalHostServer();
     if (!m_connected) {
+        DebugLogger() << "Not connected; returning to intro screen and showing timed out error";
         ResetToIntro(true);
         ClientUI::MessageBox(UserString("ERR_CONNECT_TIMED_OUT"), true);
         return;
     }
 
-    if (quickstart || ended_with_ok) {
-
-        SinglePlayerSetupData setup_data;
-        setup_data.m_new_game = true;
-        setup_data.m_filename.clear();  // not used for new game
-
-        // get values stored in options from previous time game was run or
-        // from just having run GalaxySetupWnd
-
-        // GalaxySetupData
-        setup_data.SetSeed(GetOptionsDB().Get<std::string>("setup.seed"));
-        setup_data.m_size = GetOptionsDB().Get<int>("setup.star.count");
-        setup_data.m_shape = GetOptionsDB().Get<Shape>("setup.galaxy.shape");
-        setup_data.m_age = GetOptionsDB().Get<GalaxySetupOption>("setup.galaxy.age");
-        setup_data.m_starlane_freq = GetOptionsDB().Get<GalaxySetupOption>("setup.starlane.frequency");
-        setup_data.m_planet_density = GetOptionsDB().Get<GalaxySetupOption>("setup.planet.density");
-        setup_data.m_specials_freq =    GetOptionsDB().Get<GalaxySetupOption>("setup.specials.frequency");
-        setup_data.m_monster_freq =     GetOptionsDB().Get<GalaxySetupOption>("setup.monster.frequency");
-        setup_data.m_native_freq =      GetOptionsDB().Get<GalaxySetupOption>("setup.native.frequency");
-        setup_data.m_ai_aggr =          GetOptionsDB().Get<Aggression>("setup.ai.aggression");
-        setup_data.m_game_rules =       game_rules;
-
-
-        // SinglePlayerSetupData contains a map of PlayerSetupData, for
-        // the human and AI players.  Need to compile this information
-        // from the specified human options and number of requested AIs
-
-        // Human player setup data
-        PlayerSetupData human_player_setup_data;
-        human_player_setup_data.m_player_name = GetOptionsDB().Get<std::string>("setup.player.name");
-        human_player_setup_data.m_empire_name = GetOptionsDB().Get<std::string>("setup.empire.name");
-
-        // DB stores index into array of available colours, so need to get that array to look up value of index.
-        // if stored value is invalid, use a default colour
-        const std::vector<GG::Clr>& empire_colours = EmpireColors();
-        int colour_index = GetOptionsDB().Get<int>("setup.empire.color.index");
-        if (colour_index >= 0 && colour_index < static_cast<int>(empire_colours.size()))
-            human_player_setup_data.m_empire_color = empire_colours[colour_index];
-        else
-            human_player_setup_data.m_empire_color = GG::CLR_GREEN;
-
-        human_player_setup_data.m_starting_species_name = GetOptionsDB().Get<std::string>("setup.initial.species");
-        if (human_player_setup_data.m_starting_species_name == "1")
-            human_player_setup_data.m_starting_species_name = "SP_HUMAN";   // kludge / bug workaround for bug with options storage and retreival.  Empty-string options are stored, but read in as "true" boolean, and converted to string equal to "1"
-
-        if (human_player_setup_data.m_starting_species_name != "RANDOM" &&
-            !GetSpecies(human_player_setup_data.m_starting_species_name))
-        {
-            const SpeciesManager& sm = GetSpeciesManager();
-            if (sm.NumPlayableSpecies() < 1)
-                human_player_setup_data.m_starting_species_name.clear();
-            else
-                human_player_setup_data.m_starting_species_name = sm.playable_begin()->first;
-        }
-
-        human_player_setup_data.m_save_game_empire_id = ALL_EMPIRES; // not used for new games
-        human_player_setup_data.m_client_type = Networking::CLIENT_TYPE_HUMAN_PLAYER;
-
-        // add to setup data players
-        setup_data.m_players.push_back(human_player_setup_data);
-
-
-        // AI player setup data.  One entry for each requested AI
-        int num_AIs = GetOptionsDB().Get<int>("setup.ai.player.count");
-        for (int ai_i = 1; ai_i <= num_AIs; ++ai_i) {
-            PlayerSetupData ai_setup_data;
-
-            ai_setup_data.m_player_name = "AI_" + std::to_string(ai_i);
-            ai_setup_data.m_empire_name.clear();                // leave blank, to be set by server in Universe::GenerateEmpires
-            ai_setup_data.m_empire_color = GG::CLR_ZERO;        // to be set by server
-            ai_setup_data.m_starting_species_name.clear();      // leave blank, to be set by server
-            ai_setup_data.m_save_game_empire_id = ALL_EMPIRES;  // not used for new games
-            ai_setup_data.m_client_type = Networking::CLIENT_TYPE_AI_PLAYER;
-
-            setup_data.m_players.push_back(ai_setup_data);
-        }
-
-        m_networking->SendMessage(HostSPGameMessage(setup_data));
-        m_fsm->process_event(HostSPGameRequested());
-
-    } else {
+    if (!(quickstart || ended_with_ok)) {
         ErrorLogger() << "HumanClientApp::NewSinglePlayerGame failed to start new game, killing server.";
         ResetToIntro(true);
     }
+
+    SinglePlayerSetupData setup_data;
+    setup_data.m_new_game = true;
+    setup_data.m_filename.clear();  // not used for new game
+
+    // get values stored in options from previous time game was run or
+    // from just having run GalaxySetupWnd
+
+    // GalaxySetupData
+    setup_data.SetSeed(GetOptionsDB().Get<std::string>("setup.seed"));
+    setup_data.m_size =             GetOptionsDB().Get<int>("setup.star.count");
+    setup_data.m_shape =            GetOptionsDB().Get<Shape>("setup.galaxy.shape");
+    setup_data.m_age =              GetOptionsDB().Get<GalaxySetupOption>("setup.galaxy.age");
+    setup_data.m_starlane_freq =    GetOptionsDB().Get<GalaxySetupOption>("setup.starlane.frequency");
+    setup_data.m_planet_density =   GetOptionsDB().Get<GalaxySetupOption>("setup.planet.density");
+    setup_data.m_specials_freq =    GetOptionsDB().Get<GalaxySetupOption>("setup.specials.frequency");
+    setup_data.m_monster_freq =     GetOptionsDB().Get<GalaxySetupOption>("setup.monster.frequency");
+    setup_data.m_native_freq =      GetOptionsDB().Get<GalaxySetupOption>("setup.native.frequency");
+    setup_data.m_ai_aggr =          GetOptionsDB().Get<Aggression>("setup.ai.aggression");
+    setup_data.m_game_rules =       game_rules;
+
+
+    // SinglePlayerSetupData contains a map of PlayerSetupData, for
+    // the human and AI players.  Need to compile this information
+    // from the specified human options and number of requested AIs
+
+    // Human player setup data
+    PlayerSetupData human_player_setup_data;
+    human_player_setup_data.m_player_name = GetOptionsDB().Get<std::string>("setup.player.name");
+    human_player_setup_data.m_empire_name = GetOptionsDB().Get<std::string>("setup.empire.name");
+
+    // DB stores index into array of available colours, so need to get that array to look up value of index.
+    // if stored value is invalid, use a default colour
+    const std::vector<GG::Clr>& empire_colours = EmpireColors();
+    int colour_index = GetOptionsDB().Get<int>("setup.empire.color.index");
+    if (colour_index >= 0 && colour_index < static_cast<int>(empire_colours.size()))
+        human_player_setup_data.m_empire_color = empire_colours[colour_index];
+    else
+        human_player_setup_data.m_empire_color = GG::CLR_GREEN;
+
+    human_player_setup_data.m_starting_species_name = GetOptionsDB().Get<std::string>("setup.initial.species");
+    if (human_player_setup_data.m_starting_species_name == "1")
+        human_player_setup_data.m_starting_species_name = "SP_HUMAN";   // kludge / bug workaround for bug with options storage and retreival.  Empty-string options are stored, but read in as "true" boolean, and converted to string equal to "1"
+
+    if (human_player_setup_data.m_starting_species_name != "RANDOM" &&
+        !GetSpecies(human_player_setup_data.m_starting_species_name))
+    {
+        const SpeciesManager& sm = GetSpeciesManager();
+        if (sm.NumPlayableSpecies() < 1)
+            human_player_setup_data.m_starting_species_name.clear();
+        else
+            human_player_setup_data.m_starting_species_name = sm.playable_begin()->first;
+    }
+
+    human_player_setup_data.m_save_game_empire_id = ALL_EMPIRES; // not used for new games
+    human_player_setup_data.m_client_type = Networking::CLIENT_TYPE_HUMAN_PLAYER;
+
+    // add to setup data players
+    setup_data.m_players.push_back(human_player_setup_data);
+
+
+    // AI player setup data.  One entry for each requested AI
+    int num_AIs = GetOptionsDB().Get<int>("setup.ai.player.count");
+    for (int ai_i = 1; ai_i <= num_AIs; ++ai_i) {
+        PlayerSetupData ai_setup_data;
+
+        ai_setup_data.m_player_name = "AI_" + std::to_string(ai_i);
+        ai_setup_data.m_empire_name.clear();                // leave blank, to be set by server in Universe::GenerateEmpires
+        ai_setup_data.m_empire_color = GG::CLR_ZERO;        // to be set by server
+        ai_setup_data.m_starting_species_name.clear();      // leave blank, to be set by server
+        ai_setup_data.m_save_game_empire_id = ALL_EMPIRES;  // not used for new games
+        ai_setup_data.m_client_type = Networking::CLIENT_TYPE_AI_PLAYER;
+
+        setup_data.m_players.push_back(ai_setup_data);
+    }
+
+
+    TraceLogger() << "Sending host SP setup message";
+    m_networking->SendMessage(HostSPGameMessage(setup_data));
+    m_fsm->process_event(HostSPGameRequested());
+    TraceLogger() << "HumanClientApp::NewSinglePlayerGame done";
 }
 
 void HumanClientApp::MultiPlayerGame() {
@@ -665,9 +673,13 @@ void HumanClientApp::MultiPlayerGame() {
     } else {
         boost::uuids::uuid cookie = boost::uuids::nil_uuid();
         try {
-            if (!GetOptionsDB().OptionExists("network.server.cookie." + server_dest))
-                GetOptionsDB().Add<std::string>("network.server.cookie." + server_dest, "OPTIONS_DB_SERVER_COOKIE", "");
-            std::string cookie_str = GetOptionsDB().Get<std::string>("network.server.cookie." + server_dest);
+            std::string cookie_option = EncodeServerAddressOption(server_dest);
+            if (!GetOptionsDB().OptionExists(cookie_option + ".cookie"))
+                GetOptionsDB().Add<std::string>(cookie_option + ".cookie", "OPTIONS_DB_SERVER_COOKIE", boost::uuids::to_string(cookie));
+            if (!GetOptionsDB().OptionExists(cookie_option + ".address"))
+                GetOptionsDB().Add<std::string>(cookie_option + ".address", "OPTIONS_DB_SERVER_COOKIE", "");
+            GetOptionsDB().Set(cookie_option + ".address", server_dest);
+            std::string cookie_str = GetOptionsDB().Get<std::string>(cookie_option + ".cookie");
             boost::uuids::string_generator gen;
             cookie = gen(cookie_str);
         } catch(const std::exception& err) {
@@ -907,7 +919,7 @@ void HumanClientApp::Reinitialize() {
 float HumanClientApp::GLVersion() const
 { return GetGLVersion(); }
 
-void HumanClientApp::StartTurn() {
+void HumanClientApp::StartTurn(const SaveGameUIData& ui_data) {
     DebugLogger() << "HumanClientApp::StartTurn";
 
     if (const Empire* empire = GetEmpire(EmpireID())) {
@@ -929,10 +941,14 @@ void HumanClientApp::StartTurn() {
         Autosave();
     }
 
-    ClientApp::StartTurn();
+    ClientApp::StartTurn(ui_data);
     m_fsm->process_event(TurnEnded());
 }
 
+void HumanClientApp::UnreadyTurn() {
+    m_networking->SendMessage(UnreadyMessage());
+}
+
 void HumanClientApp::HandleTurnPhaseUpdate(Message::TurnProgressPhase phase_id) {
     ClientApp::HandleTurnPhaseUpdate(phase_id);
 
@@ -970,13 +986,13 @@ void HumanClientApp::HandleMessage(Message& msg) {
     case Message::JOIN_GAME:                m_fsm->process_event(JoinGame(msg));                break;
     case Message::HOST_ID:                  m_fsm->process_event(HostID(msg));                  break;
     case Message::LOBBY_UPDATE:             m_fsm->process_event(LobbyUpdate(msg));             break;
-    case Message::SAVE_GAME_DATA_REQUEST:   m_fsm->process_event(SaveGameDataRequest(msg));     break;
     case Message::SAVE_GAME_COMPLETE:       m_fsm->process_event(SaveGameComplete(msg));        break;
     case Message::CHECKSUM:                 m_fsm->process_event(CheckSum(msg));                break;
     case Message::GAME_START:               m_fsm->process_event(GameStart(msg));               break;
     case Message::TURN_UPDATE:              m_fsm->process_event(TurnUpdate(msg));              break;
     case Message::TURN_PARTIAL_UPDATE:      m_fsm->process_event(TurnPartialUpdate(msg));       break;
     case Message::TURN_PROGRESS:            m_fsm->process_event(TurnProgress(msg));            break;
+    case Message::UNREADY:                  m_fsm->process_event(TurnRevoked(msg));             break;
     case Message::PLAYER_STATUS:            m_fsm->process_event(::PlayerStatus(msg));          break;
     case Message::PLAYER_CHAT:              m_fsm->process_event(PlayerChat(msg));              break;
     case Message::DIPLOMACY:                m_fsm->process_event(Diplomacy(msg));               break;
@@ -988,30 +1004,23 @@ void HumanClientApp::HandleMessage(Message& msg) {
     case Message::AUTH_REQUEST:             m_fsm->process_event(AuthRequest(msg));             break;
     case Message::CHAT_HISTORY:             m_fsm->process_event(ChatHistory(msg));             break;
     case Message::SET_AUTH_ROLES:           HandleSetAuthRoles(msg);                            break;
+    case Message::TURN_TIMEOUT:             m_fsm->process_event(TurnTimeout(msg));             break;
+    case Message::PLAYER_INFO:              m_fsm->process_event(PlayerInfoMsg(msg));           break;
     default:
         ErrorLogger() << "HumanClientApp::HandleMessage : Received an unknown message type \"" << msg.Type() << "\".";
     }
 }
 
-void HumanClientApp::HandleSaveGameDataRequest() {
-    if (INSTRUMENT_MESSAGE_HANDLING)
-        std::cerr << "HumanClientApp::HandleSaveGameDataRequest(" << Message::SAVE_GAME_DATA_REQUEST << ")\n";
-    SaveGameUIData ui_data;
-    m_ui->GetSaveGameUIData(ui_data);
-    m_networking->SendMessage(ClientSaveDataMessage(Orders(), ui_data));
-}
-
 void HumanClientApp::UpdateCombatLogs(const Message& msg){
-    DebugLogger() << "HCL Update Combat Logs";
+    ScopedTimer timer("HumanClientApp::UpdateCombatLogs");
 
     // Unpack the combat logs from the message
     std::vector<std::pair<int, CombatLog>> logs;
     ExtractDispatchCombatLogsMessageData(msg, logs);
 
     // Update the combat log manager with the completed logs.
-    for (auto it = logs.begin(); it != logs.end(); ++it) {
+    for (auto it = logs.begin(); it != logs.end(); ++it)
         GetCombatLogManager().CompleteLog(it->first, it->second);
-    }
 }
 
 void HumanClientApp::HandleSaveGamePreviews(const Message& msg) {
@@ -1156,8 +1165,15 @@ void HumanClientApp::HandleTurnUpdate()
 
 void HumanClientApp::UpdateCombatLogManager() {
     boost::optional<std::vector<int>> incomplete_ids = GetCombatLogManager().IncompleteLogIDs();
-    if (incomplete_ids)
-        m_networking->SendMessage(RequestCombatLogsMessage(*incomplete_ids));
+    if (incomplete_ids) {
+        for (auto it = incomplete_ids->begin(); it != incomplete_ids->end();) {
+            // request at most 50 logs per message to avoid trying to allocate too much space to send all at once
+            std::vector<int> a_few_log_ids;
+            for (unsigned int count = 0; count < 50 && it != incomplete_ids->end(); ++it, ++count)
+                a_few_log_ids.push_back(*it);
+            m_networking->SendMessage(RequestCombatLogsMessage(a_few_log_ids));
+        }
+    }
 }
 
 namespace {
@@ -1191,8 +1207,17 @@ namespace {
             if (files_by_write_time.empty())
                 return boost::none;
 
-            // Return the newest
-            return PathToString(files_by_write_time.rbegin()->second);
+            // Return the newest file that has a valid header
+            for (auto file_it = files_by_write_time.rbegin();
+                 file_it != files_by_write_time.rend(); ++file_it)
+            {
+                auto file = file_it->second;
+                // attempt to load header
+                if (SaveFileWithValidHeader(file))
+                    return PathToString(file);  // load succeeded, return path to OK file
+            }
+
+            return boost::none;
 
         } catch (const boost::filesystem::filesystem_error& e) {
             ErrorLogger() << "File system error " << e.what() << " while finding newest autosave";
@@ -1366,9 +1391,8 @@ void HumanClientApp::ContinueSinglePlayerGame() {
         LoadSinglePlayerGame(*file);
 }
 
-bool HumanClientApp::IsLoadGameAvailable() const {
-    return bool(NewestSinglePlayerSavegame());
-}
+bool HumanClientApp::IsLoadGameAvailable() const
+{ return bool(NewestSinglePlayerSavegame()); }
 
 std::string HumanClientApp::SelectLoadFile() {
     return ClientUI::GetClientUI()->GetFilenameWithSaveFileDialog(
@@ -1391,30 +1415,6 @@ void HumanClientApp::ResetClientData(bool save_connection) {
     ClearPreviousPendingSaves(m_game_saves_in_progress);
 }
 
-namespace {
-    // Ask the player if they want to wait for the save game to complete
-    // The dialog automatically closes if the save completes while the user is waiting
-    class SaveGamePendingDialog : public GG::ThreeButtonDlg {
-        public:
-        SaveGamePendingDialog(bool reset, boost::signals2::signal<void()>& save_completed_signal) :
-            GG::ThreeButtonDlg(
-                GG::X(320), GG::Y(200), UserString("SAVE_GAME_IN_PROGRESS"),
-                ClientUI::GetFont(ClientUI::Pts()+2),
-                ClientUI::WndColor(), ClientUI::WndOuterBorderColor(),
-                ClientUI::CtrlColor(), ClientUI::TextColor(), 1,
-                (reset ? UserString("ABORT_SAVE_AND_RESET") : UserString("ABORT_SAVE_AND_EXIT")))
-        {
-            save_completed_signal.connect(
-                boost::bind(&SaveGamePendingDialog::SaveCompletedHandler, this));
-        }
-
-        void SaveCompletedHandler() {
-            DebugLogger() << "SaveGamePendingDialog::SaveCompletedHandler save game completed handled.";
-            m_done = true;
-        }
-    };
-}
-
 void HumanClientApp::ResetToIntro(bool skip_savegame)
 { ResetOrExitApp(true, skip_savegame); }
 
@@ -1425,19 +1425,67 @@ void HumanClientApp::ExitSDL(int exit_code)
 { SDLGUI::ExitApp(exit_code); }
 
 void HumanClientApp::ResetOrExitApp(bool reset, bool skip_savegame, int exit_code /* = 0*/) {
+    if (m_exit_handled) {
+        static int repeat_count = 0;
+        if (repeat_count++ > 2) {
+            m_exit_handled = false;
+            skip_savegame = true;
+        } else {
+            return;
+        }
+    }
+    m_exit_handled = true;
     DebugLogger() << (reset ? "HumanClientApp::ResetToIntro" : "HumanClientApp::ExitApp");
 
     auto was_playing = m_game_started;
     m_game_started = false;
 
-    // Only save if not exiting due to an error.
+    // Only save or allow user to cancel if not exiting due to an error.
     if (!skip_savegame) {
+        // Check if this is a multiplayer game and the player has not set status to ready
+        if (was_playing && !m_single_player_game &&
+            m_empires.GetEmpire(m_empire_id) != nullptr &&
+            !m_empires.GetEmpire(m_empire_id)->Ready() &&
+            GetClientType() == Networking::CLIENT_TYPE_HUMAN_PLAYER)
+        {
+            std::shared_ptr<GG::Font> font = ClientUI::GetFont();
+            auto prompt = GG::GUI::GetGUI()->GetStyleFactory()->NewThreeButtonDlg(
+                GG::X(275), GG::Y(75), UserString("GAME_MENU_CONFIRM_NOT_READY"), font,
+                ClientUI::CtrlColor(), ClientUI::CtrlBorderColor(), ClientUI::CtrlColor(), ClientUI::TextColor(),
+                2, UserString("YES"), UserString("CANCEL"));
+            prompt->Run();
+            if (prompt->Result() != 0) {
+                // User aborted exit/resign, reset variables
+                m_game_started = was_playing;
+                m_exit_handled = false;
+                return;
+            }
+        }
+
         if (was_playing && GetOptionsDB().Get<bool>("save.auto.exit.enabled"))
             Autosave();
 
         if (!m_game_saves_in_progress.empty()) {
             DebugLogger() << "save game in progress. Checking with player.";
-            auto dlg = GG::Wnd::Create<SaveGamePendingDialog>(reset, this->SaveGamesCompletedSignal);
+            // Ask the player if they want to wait for the save game to complete
+            auto dlg = GG::GUI::GetGUI()->GetStyleFactory()->NewThreeButtonDlg(
+                GG::X(320), GG::Y(200), UserString("SAVE_GAME_IN_PROGRESS"),
+                ClientUI::GetFont(ClientUI::Pts()+2),
+                ClientUI::WndColor(), ClientUI::WndOuterBorderColor(),
+                ClientUI::CtrlColor(), ClientUI::TextColor(), 1,
+                (reset ?
+                    UserString("ABORT_SAVE_AND_RESET") :
+                    UserString("ABORT_SAVE_AND_EXIT")));
+            // The dialog automatically closes if the save completes while the
+            // user is waiting
+            this->SaveGamesCompletedSignal.connect(
+                [dlg](){
+                    DebugLogger() << "SaveGamePendingDialog::SaveCompletedHandler save game completed handled.";
+
+                    dlg->EndRun();
+                }
+            );
+
             dlg->Run();
         }
     }
@@ -1445,12 +1493,14 @@ void HumanClientApp::ResetOrExitApp(bool reset, bool skip_savegame, int exit_cod
     // Create an action to reset to intro or quit the app as appropriate.
     std::function<void()> after_server_shutdown_action;
     if (reset)
-        after_server_shutdown_action = std::bind(&HumanClientApp::ResetClientData, this, false);
+        after_server_shutdown_action = boost::bind(&HumanClientApp::ResetClientData, this, false);
     else
         // This throws to exit the GUI
-        after_server_shutdown_action = std::bind(&HumanClientApp::ExitSDL, this, exit_code);
+        after_server_shutdown_action = boost::bind(&HumanClientApp::ExitSDL, this, exit_code);
 
     m_fsm->process_event(StartQuittingGame(m_server_process, std::move(after_server_shutdown_action)));
+
+    m_exit_handled = false;
 }
 
 void HumanClientApp::InitAutoTurns(int auto_turns) {
@@ -1543,7 +1593,9 @@ void HumanClientApp::OpenURL(const std::string& url) {
     command += url;
 
     // execute open command
-    system(command.c_str());
+    int rv = system(command.c_str());
+    if (rv != 0)
+        ErrorLogger() << "HumanClientApp::OpenURL `" << command << "` returned a non-zero exit code: " << rv;
 }
 
 void HumanClientApp::BrowsePath(const boost::filesystem::path& browse_path) {
