@@ -3,10 +3,10 @@
 
 #include "../ClientApp.h"
 #include "../../util/Process.h"
+#include "../../UI/SDLGUI.h"
 #include "../../UI/ClientUI.h"
 #include "../../util/OptionsDB.h"
 
-#include <GG/SDL/SDLGUI.h>
 
 #include <memory>
 #include <queue>
@@ -19,7 +19,7 @@ struct PreviewInformation;
 /** the application framework class for the human player FreeOrion client. */
 class HumanClientApp :
     public ClientApp,
-    public GG::SDLGUI
+    public SDLGUI
 {
 public:
     typedef boost::signals2::signal<void (bool)> FullscreenSwitchSignalType;
@@ -32,18 +32,14 @@ public:
                    bool fullscreen, bool fake_mode_change);
 
     HumanClientApp(const HumanClientApp&) = delete;
-
     HumanClientApp(HumanClientApp&&) = delete;
-
     ~HumanClientApp() override;
 
     const HumanClientApp& operator=(const HumanClientApp&) = delete;
-
     HumanClientApp& operator=(const HumanClientApp&&) = delete;
 
     /** \name Accessors */ //@{
     int EffectsProcessingThreads() const override;
-
     bool SinglePlayerGame() const;  ///< returns true iff this game is a single-player game
     bool CanSaveNow() const;        ///< returns true / false to indicate whether this client can currently safely initiate a game save
     int  AutoTurnsLeft() const;     ///< returns number of turns left to execute automatically
@@ -52,11 +48,11 @@ public:
 
     /** \name Mutators */ //@{
     void HandleTurnUpdate() override;           ///< Handle background events that need starting when the turn updates
-    void StartTurn() override;
+    void StartTurn(const SaveGameUIData& ui_data) override;
+    void UnreadyTurn();                         ///< Revoke ready state of turn orders.
 
     /** \brief Handle UI and state updates with changes in turn phase. */
     void HandleTurnPhaseUpdate(Message::TurnProgressPhase phase_id) override;
-
     void SetSinglePlayerGame(bool sp = true);
     void NewSinglePlayerGame(bool quickstart = false);
     void MultiPlayerGame();                     ///< shows multiplayer connection window, and then transitions to multiplayer lobby if connected
@@ -88,7 +84,6 @@ public:
       * to the server save directory. */
     void RequestSavePreviews(const std::string& relative_directory);
     void Autosave();                    ///< Autosaves the current game, iff autosaves are enabled and any turn number requirements are met
-
     void ContinueSinglePlayerGame();    ///< Load the newest single player autosave and continue playing game
     bool IsLoadGameAvailable() const;
     std::string SelectLoadFile();       ///< Lets the user select a multiplayer save to load
@@ -100,10 +95,8 @@ public:
     { return *m_ui.get(); }
 
     void Reinitialize();
-
     float GLVersion() const;
 
-    void HandleSaveGameDataRequest();
     void UpdateCombatLogs(const Message& msg);
     /** Update any open SaveGameDialog with previews from the server. */
     void HandleSaveGamePreviews(const Message& msg);
@@ -128,6 +121,9 @@ public:
         OSX will not tolerate static initialization of SDL, to check screen size. */
     static void AddWindowSizeOptionsAfterMainStart(OptionsDB& db);
 
+    /** Converts server address to correct option name */
+    static std::string EncodeServerAddressOption(const std::string& server);
+
     /** If hosting then send the logger state to the server. */
     void            SendLoggingConfigToServer();
 
@@ -182,16 +178,17 @@ private:
     /** The only instance of the ClientUI. */
     std::unique_ptr<ClientUI> m_ui;
 
-    bool m_single_player_game;  ///< true when this game is a single-player game
-    bool m_game_started;        ///< true when a game is currently in progress
-    bool m_connected;           ///< true if we are in a state in which we are supposed to be connected to the server
-    int  m_auto_turns;          ///< auto turn counter
-    bool m_have_window_focus;
+    bool m_single_player_game = true;   ///< true when this game is a single-player game
+    bool m_game_started = false;        ///< true when a game is currently in progress
+    bool m_exit_handled = false;        ///< true when the exit logic is already being handled
+    bool m_connected = false;           ///< true if we are in a state in which we are supposed to be connected to the server
+    int  m_auto_turns = 0;              ///< auto turn counter
+    bool m_have_window_focus = true;
 
     /** Filenames of all in progress saves.  There maybe multiple saves in
         progress if a player and an autosave are initiated at the same time. */
-    std::queue<std::string>     m_game_saves_in_progress;
-    boost::signals2::signal<void ()> SaveGamesCompletedSignal;
+    std::queue<std::string>             m_game_saves_in_progress;
+    boost::signals2::signal<void ()>    SaveGamesCompletedSignal;
 };
 
 #endif // _HumanClientApp_h_
