@@ -224,7 +224,10 @@ struct MPLobby : boost::statechart::state<MPLobby, HumanClientFSM> {
         boost::statechart::custom_reaction<StartQuittingGame>,
         boost::statechart::custom_reaction<Error>,
         boost::statechart::custom_reaction<CheckSum>,
-        boost::statechart::custom_reaction<ChatHistory>
+        boost::statechart::custom_reaction<ChatHistory>,
+        boost::statechart::custom_reaction<PlayerStatus>,
+        boost::statechart::custom_reaction<SaveGameComplete>,
+        boost::statechart::custom_reaction<TurnProgress>
     > reactions;
 
     MPLobby(my_context ctx);
@@ -241,6 +244,9 @@ struct MPLobby : boost::statechart::state<MPLobby, HumanClientFSM> {
     boost::statechart::result react(const Error& msg);
     boost::statechart::result react(const CheckSum& msg);
     boost::statechart::result react(const ChatHistory& msg);
+    boost::statechart::result react(const PlayerStatus& msg);
+    boost::statechart::result react(const SaveGameComplete& msg);
+    boost::statechart::result react(const TurnProgress& msg);
 
     CLIENT_ACCESSOR
 };
@@ -262,7 +268,9 @@ struct PlayingGame : boost::statechart::state<PlayingGame, HumanClientFSM, Waiti
         boost::statechart::custom_reaction<Error>,
         boost::statechart::custom_reaction<TurnProgress>,
         boost::statechart::custom_reaction<TurnPartialUpdate>,
-        boost::statechart::custom_reaction<LobbyUpdate>
+        boost::statechart::custom_reaction<LobbyUpdate>,
+        boost::statechart::custom_reaction<TurnTimeout>,
+        boost::statechart::custom_reaction<PlayerInfoMsg>
     > reactions;
 
     PlayingGame(my_context ctx);
@@ -280,6 +288,8 @@ struct PlayingGame : boost::statechart::state<PlayingGame, HumanClientFSM, Waiti
     boost::statechart::result react(const TurnProgress& msg);
     boost::statechart::result react(const TurnPartialUpdate& msg);
     boost::statechart::result react(const LobbyUpdate& msg);
+    boost::statechart::result react(const TurnTimeout& msg);
+    boost::statechart::result react(const PlayerInfoMsg& msg);
 
     CLIENT_ACCESSOR
 };
@@ -309,18 +319,18 @@ struct WaitingForTurnData : boost::statechart::state<WaitingForTurnData, Playing
     typedef boost::statechart::state<WaitingForTurnData, PlayingGame> Base;
 
     typedef boost::mpl::list<
-        boost::statechart::custom_reaction<SaveGameDataRequest>,
         boost::statechart::custom_reaction<SaveGameComplete>,
         boost::statechart::custom_reaction<TurnUpdate>,
+        boost::statechart::custom_reaction<TurnRevoked>,
         boost::statechart::custom_reaction<DispatchCombatLogs>
     > reactions;
 
     WaitingForTurnData(my_context ctx);
     ~WaitingForTurnData();
 
-    boost::statechart::result react(const SaveGameDataRequest& d);
     boost::statechart::result react(const SaveGameComplete& d);
     boost::statechart::result react(const TurnUpdate& msg);
+    boost::statechart::result react(const TurnRevoked& msg);
     boost::statechart::result react(const DispatchCombatLogs& msg);
 
     CLIENT_ACCESSOR
@@ -332,7 +342,6 @@ struct PlayingTurn : boost::statechart::state<PlayingTurn, PlayingGame> {
     typedef boost::statechart::state<PlayingTurn, PlayingGame> Base;
 
     typedef boost::mpl::list<
-        boost::statechart::custom_reaction<SaveGameDataRequest>,
         boost::statechart::custom_reaction<SaveGameComplete>,
         boost::statechart::custom_reaction<AdvanceTurn>,
         boost::statechart::custom_reaction<TurnUpdate>,
@@ -344,7 +353,6 @@ struct PlayingTurn : boost::statechart::state<PlayingTurn, PlayingGame> {
     PlayingTurn(my_context ctx);
     ~PlayingTurn();
 
-    boost::statechart::result react(const SaveGameDataRequest& d);
     boost::statechart::result react(const SaveGameComplete& d);
     boost::statechart::result react(const AdvanceTurn& d);
     boost::statechart::result react(const TurnUpdate& msg);
