@@ -12,9 +12,8 @@
 CombatEvent::CombatEvent() {}
 
 boost::optional<int> CombatEvent::PrincipalFaction(int viewing_empire_id) const {
-    ErrorLogger() << "A combat logger expected this event to be "
-        "associated with a faction: "<< this->DebugString();
-
+    ErrorLogger() << "A combat logger expected this event to be associated with a faction: "
+                  << this->DebugString();
     return boost::optional<int>();
 }
 
