@@ -9,6 +9,7 @@
 #include "../util/Export.h"
 
 #include <memory>
+#include <string>
 #include <vector>
 
 
@@ -40,7 +41,7 @@ struct FO_COMMON_API CombatEvent {
     /** Generate the combat log details.
         Describe how it happened in enough detail to avoid a trip to the Pedia. */
     virtual std::string CombatLogDetails(int viewing_empire_id) const
-    { return std::string(""); }
+    { return ""; }
 
     /** If the combat event is composed of smaller events then return a vector of the sub events,
         otherwise returns an empty vector.
@@ -74,7 +75,7 @@ struct FO_COMMON_API CombatEvent {
 
 private:
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
