@@ -21,9 +21,11 @@ namespace {
     // would be better in CombatSystem, but that is server-only, and rules need
     // to exist on client and server.
     void AddRules(GameRules& rules) {
-        // makes all buildings cost 1 PP and take 1 turn to produce
         rules.Add<int>("RULE_NUM_COMBAT_ROUNDS", "RULE_NUM_COMBAT_ROUNDS_DESC",
-                       "", 3, true, RangedValidator<int>(1, 20));
+                       "", 3, true, RangedValidator<int>(2, 20));
+        rules.Add<bool>("RULE_AGGRESSIVE_SHIPS_COMBAT_VISIBLE", "RULE_AGGRESSIVE_SHIPS_COMBAT_VISIBLE_DESC",
+                        "", false, true);
+
     }
     bool temp_bool = RegisterGameRules(&AddRules);
 
@@ -44,6 +46,7 @@ namespace {
         case OBJ_SYSTEM:
             return VarText::SYSTEM_ID_TAG;
         case OBJ_FIELD:
+        case OBJ_FIGHTER:
         default:
             return EMPTY_STRING;
         }
@@ -85,7 +88,7 @@ namespace {
     /// with the content being the public name from the point of view of empire_id.
     /// Returns UserString("ENC_COMBAT_UNKNOWN_OBJECT") if object_id is not found.
     std::string PublicNameLink(int empire_id, int object_id) {
-        auto object = GetUniverseObject(object_id);
+        auto object = Objects().get(object_id);
         if (object) {
             const std::string& name = object->PublicName(empire_id);
             const std::string& tag = LinkTag(object->ObjectType());
@@ -138,11 +141,10 @@ std::string BoutBeginEvent::DebugString() const {
     return ss.str();
 }
 
-std::string BoutBeginEvent::CombatLogDescription(int viewing_empire_id) const {
-    return str(FlexibleFormat(UserString("ENC_ROUND_BEGIN")) % bout);
-}
+std::string BoutBeginEvent::CombatLogDescription(int viewing_empire_id) const
+{ return str(FlexibleFormat(UserString("ENC_ROUND_BEGIN")) % bout); }
 
-template <class Archive>
+template <typename Archive>
 void BoutBeginEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(bout);
@@ -167,10 +169,12 @@ void BoutBeginEvent::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive& a
 ///////// BoutEvent /////////////
 //////////////////////////////////////////
 BoutEvent::BoutEvent():
-    bout(-1), events() {}
+    bout(-1)
+{}
 
 BoutEvent::BoutEvent(int _bout):
-    bout(_bout), events() {}
+    bout(_bout)
+{}
 
 void BoutEvent::AddEvent(const CombatEventPtr& event)
 { events.push_back(event); }
@@ -187,17 +191,16 @@ std::string BoutEvent::CombatLogDescription(int viewing_empire_id) const {
 
 std::vector<ConstCombatEventPtr> BoutEvent::SubEvents(int viewing_empire_id) const {
     std::vector<ConstCombatEventPtr> all_events;
-    for (CombatEventPtr event : events) {
+    for (CombatEventPtr event : events)
         all_events.push_back(event);
-    }
     return all_events;
 }
 
-template <class Archive>
+template <typename Archive>
 void BoutEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(bout)
-        & BOOST_SERIALIZATION_NVP(events);
+       & BOOST_SERIALIZATION_NVP(events);
 }
 
 BOOST_CLASS_VERSION(BoutEvent, 4)
@@ -221,7 +224,8 @@ void BoutEvent::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive& ar, co
 //////////////////////////////////////////
 
 SimultaneousEvents::SimultaneousEvents() :
-    events() {}
+    events()
+{}
 
 void SimultaneousEvents::AddEvent(const CombatEventPtr& event)
 { events.push_back(event); }
@@ -232,9 +236,8 @@ std::string SimultaneousEvents::DebugString() const {
     return ss.str();
 }
 
-std::string SimultaneousEvents::CombatLogDescription(int viewing_empire_id) const {
-    return "";
-}
+std::string SimultaneousEvents::CombatLogDescription(int viewing_empire_id) const
+{ return ""; }
 
 std::vector<ConstCombatEventPtr> SimultaneousEvents::SubEvents(int viewing_empire_id) const {
     // Sort the events by viewing empire, then ALL_EMPIRES and then
@@ -273,7 +276,7 @@ std::vector<ConstCombatEventPtr> SimultaneousEvents::SubEvents(int viewing_empir
 }
 
 
-template <class Archive>
+template <typename Archive>
 void SimultaneousEvents::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(events);
@@ -299,102 +302,72 @@ void SimultaneousEvents::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchiv
 ///////// InitialStealthEvent /////////////
 //////////////////////////////////////////
 
-InitialStealthEvent::InitialStealthEvent() :
-    target_empire_id_to_invisble_obj_id()
+InitialStealthEvent::InitialStealthEvent()
 {}
 
-InitialStealthEvent::InitialStealthEvent(const StealthInvisbleMap &x) :
-    target_empire_id_to_invisble_obj_id(x)
+InitialStealthEvent::InitialStealthEvent(const EmpireToObjectVisibilityMap& x) :
+    empire_to_object_visibility(x)
 {}
 
 std::string InitialStealthEvent::DebugString() const {
     std::stringstream ss;
     ss << "InitialStealthEvent: ";
-    if (target_empire_id_to_invisble_obj_id.size() > 4) {
-        ss << target_empire_id_to_invisble_obj_id.size() << " events.";
-    } else {
-        for (const auto& attack_empire : target_empire_id_to_invisble_obj_id) {
-            ss << " Attacking Empire: " << EmpireLink(attack_empire.first) << "\n";
-            for (const auto& target_empire : attack_empire.second) {
-                ss << " Target Empire: " << EmpireLink(target_empire.first) << " Targets: ";
+    for (const auto& empire_object_vis : empire_to_object_visibility) {
+        ss << " Viewing Empire: " << EmpireLink(empire_object_vis.first) << "\n";
 
-                if (target_empire.second.size() > 4) {
-                    ss << target_empire.second.size() << " attackers.";
-                } else {
-                    for (const auto& attacker : target_empire.second) {
-                        ss << FighterOrPublicNameLink(ALL_EMPIRES, attacker.first, target_empire.first);
-                    }
-                }
-                ss << "\n";
-            }
+        for (const auto& viewed_object : empire_object_vis.second) {
+            const auto obj = Objects().get(viewed_object.first);
+            int owner_id = obj ? obj->Owner() : ALL_EMPIRES;
+            ss << FighterOrPublicNameLink(ALL_EMPIRES, viewed_object.first, owner_id);
         }
+        ss << "\n";
     }
-
     return ss.str();
 }
 
 std::string InitialStealthEvent::CombatLogDescription(int viewing_empire_id) const {
+    DebugLogger() << "CombatLogDescription for InitialStealthEvent viewing empire empire: " << viewing_empire_id;
+
     std::string desc = "";
 
-    //Viewing empire stealth first
-    for (const auto& attack_empire : target_empire_id_to_invisble_obj_id) {
-        if (attack_empire.first == viewing_empire_id)
+    for (const auto& detector_empire : empire_to_object_visibility) {
+        int detector_empire_id = detector_empire.first;
+        DebugLogger() << "CombatLogDescription for InitialStealthEvent for detector empire: " << detector_empire_id;
+
+        const auto& visible_objects = detector_empire.second;
+        if (visible_objects.empty()) {
+            DebugLogger() << " ... no object info recorded for detector empire: " << detector_empire_id;
             continue;
-
-        auto target_empire = attack_empire.second.find(viewing_empire_id);
-        if (target_empire != attack_empire.second.end() &&
-            !target_empire->second.empty())
-        {
-            std::vector<std::string> cloaked_attackers;
-            for (auto& attacker : target_empire->second) {
-                 std::string attacker_link = FighterOrPublicNameLink(viewing_empire_id, attacker.first, viewing_empire_id);
-                // It doesn't matter if targets of viewing empire have no_visibility or basic_visibility
-                 cloaked_attackers.push_back(attacker_link);
-            }
-
-            if (!cloaked_attackers.empty()) {
-                desc += "\n"; //< Add \n at start of the report and between each empire
-                std::vector<std::string> attacker_empire_link(1, EmpireLink(attack_empire.first));
-                desc += FlexibleFormatList(attacker_empire_link, cloaked_attackers,
-                                           UserString("ENC_COMBAT_INITIAL_STEALTH_LIST")).str();
-            }
         }
-    }
 
-    //Viewing empire defending
-    auto attack_empire = target_empire_id_to_invisble_obj_id.find(viewing_empire_id);
-    if (attack_empire != target_empire_id_to_invisble_obj_id.end() &&
-        !attack_empire->second.empty())
-    {
-        for (auto& target_empire : attack_empire->second) {
-            if (target_empire.first == viewing_empire_id)
+        // Check Visibility of objects, report those that are not visible.
+        std::vector<std::string> cloaked_attackers;
+        for (auto& object_vis : visible_objects) {
+            const auto obj = Objects().get(object_vis.first);
+            const auto name = obj ? obj->Name() : UserString("UNKNOWN");
+            DebugLogger() << " ... object: " << name << " (" << object_vis.first << ") has vis: " << object_vis.second;
+            if (object_vis.second > VIS_NO_VISIBILITY)
                 continue;
+            std::string attacker_link = FighterOrPublicNameLink(
+                viewing_empire_id, object_vis.first, ALL_EMPIRES); // all empires specifies empire to use for link color if this is a fighter
+            cloaked_attackers.push_back(attacker_link);
+        }
 
-            std::vector<std::string> cloaked_attackers;
-            for (const auto& attacker : target_empire.second) {
-                std::string attacker_link = FighterOrPublicNameLink(viewing_empire_id, attacker.first, viewing_empire_id);
-                // Don't even report on targets with no_visibility it is supposed to be a surprise
-                if (attacker.second >= VIS_BASIC_VISIBILITY )
-                    cloaked_attackers.push_back(attacker_link);
-            }
-
-            if (!cloaked_attackers.empty()) {
-                if (!desc.empty())
-                    desc += "\n";
-                std::vector<std::string> attacker_empire_link(1, EmpireLink(attack_empire->first));
-                desc += FlexibleFormatList(attacker_empire_link, cloaked_attackers,
-                                           UserString("ENC_COMBAT_INITIAL_STEALTH_LIST")).str();
-            }
+        if (!cloaked_attackers.empty()) {
+            desc += "\n"; //< Add \n at start of the report and between each empire
+            std::vector<std::string> detector_empire_link(1, EmpireLink(detector_empire.first));
+            desc += FlexibleFormatList(detector_empire_link, cloaked_attackers,
+                                       UserString("ENC_COMBAT_INITIAL_STEALTH_LIST")).str();
         }
     }
 
     return desc;
 }
 
-template <class Archive>
+template <typename Archive>
 void InitialStealthEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
-    ar & BOOST_SERIALIZATION_NVP(target_empire_id_to_invisble_obj_id);
+    ar & BOOST_SERIALIZATION_NVP(empire_to_object_visibility);
 }
 
 BOOST_CLASS_VERSION(InitialStealthEvent, 4)
@@ -418,21 +391,15 @@ void InitialStealthEvent::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchi
 //////////////////////////////////////////
 
 StealthChangeEvent::StealthChangeEvent() :
-    bout(-1),
-    events()
+    bout(-1)
 {}
 
 StealthChangeEvent::StealthChangeEvent(int bout_) :
-    bout(bout_),
-    events()
+    bout(bout_)
 {}
 
 StealthChangeEvent::StealthChangeEventDetail::StealthChangeEventDetail() :
-    attacker_id(INVALID_OBJECT_ID),
-    target_id(INVALID_OBJECT_ID),
-    attacker_empire_id(INVALID_OBJECT_ID),
-    target_empire_id(INVALID_OBJECT_ID),
-    visibility()
+    StealthChangeEventDetail(INVALID_OBJECT_ID, INVALID_OBJECT_ID, ALL_EMPIRES, ALL_EMPIRES, VIS_NO_VISIBILITY)
 {}
 
 StealthChangeEvent::StealthChangeEventDetail::StealthChangeEventDetail(
@@ -453,7 +420,6 @@ std::string StealthChangeEvent::StealthChangeEventDetail::DebugString() const {
 }
 
 std::string StealthChangeEvent::StealthChangeEventDetail::CombatLogDescription(int viewing_empire_id) const {
-
     std::string attacker_link = FighterOrPublicNameLink(viewing_empire_id, attacker_id, attacker_empire_id);
     std::string target_link = FighterOrPublicNameLink(viewing_empire_id, target_id, target_empire_id);
     std::string empire_link = EmpireLink(target_empire_id);
@@ -466,8 +432,9 @@ std::string StealthChangeEvent::StealthChangeEventDetail::CombatLogDescription(i
 }
 
 
-void StealthChangeEvent::AddEvent(int attacker_id_, int target_id_, int attacker_empire_
-                             , int target_empire_, Visibility new_visibility_) {
+void StealthChangeEvent::AddEvent(int attacker_id_, int target_id_, int attacker_empire_,
+                                  int target_empire_, Visibility new_visibility_)
+{
     events[target_empire_].push_back(
         std::make_shared<StealthChangeEventDetail>(
             attacker_id_, target_id_, attacker_empire_, target_empire_, new_visibility_));
@@ -501,9 +468,8 @@ std::string StealthChangeEvent::CombatLogDescription(int viewing_empire_id) cons
     std::string desc = "";
     for (const auto& target : events) {
         std::vector<std::string> uncloaked_attackers;
-        for (const auto event : target.second) {
+        for (const auto event : target.second)
             uncloaked_attackers.push_back(FighterOrPublicNameLink(viewing_empire_id, event->attacker_id, event->attacker_empire_id));
-        }
 
         if (!uncloaked_attackers.empty()) {
             if (!desc.empty())
@@ -519,21 +485,18 @@ std::string StealthChangeEvent::CombatLogDescription(int viewing_empire_id) cons
     return desc;
 }
 
-bool StealthChangeEvent::AreSubEventsEmpty(int viewing_empire_id) const {
-    return events.empty();
-}
+bool StealthChangeEvent::AreSubEventsEmpty(int viewing_empire_id) const
+{ return events.empty(); }
+
 std::vector<ConstCombatEventPtr> StealthChangeEvent::SubEvents(int viewing_empire_id) const {
     std::vector<ConstCombatEventPtr> all_events;
-    for (const auto& target : events) {
-
-        for (const auto event : target.second){
+    for (const auto& target : events)
+        for (const auto event : target.second)
             all_events.push_back(std::dynamic_pointer_cast<CombatEvent>(event));
-        }
-    }
     return all_events;
 }
 
-template <class Archive>
+template <typename Archive>
 void StealthChangeEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(bout)
@@ -555,7 +518,7 @@ void StealthChangeEvent::serialize<freeorion_xml_oarchive>(freeorion_xml_oarchiv
 template
 void StealthChangeEvent::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive& ar, const unsigned int version);
 
-template <class Archive>
+template <typename Archive>
 void StealthChangeEvent::StealthChangeEventDetail::serialize(Archive& ar, const unsigned int version) {
     ar  & BOOST_SERIALIZATION_NVP(attacker_id)
         & BOOST_SERIALIZATION_NVP(target_id)
@@ -591,7 +554,8 @@ WeaponFireEvent::WeaponFireEvent() :
     power(0.0f),
     shield(0.0f),
     damage(0.0f),
-    attacker_owner_id(ALL_EMPIRES)
+    attacker_owner_id(ALL_EMPIRES),
+    target_owner_id(INVALID_OBJECT_ID)
 {}
 
 WeaponFireEvent::WeaponFireEvent(
@@ -603,9 +567,6 @@ WeaponFireEvent::WeaponFireEvent(
     attacker_id(attacker_id_),
     target_id( target_id_),
     weapon_name(weapon_name_),
-    power(),
-    shield(),
-    damage(),
     attacker_owner_id(attacker_owner_id_),
     target_owner_id(target_owner_id_)
 { std::tie(power, shield, damage) = power_shield_damage; }
@@ -654,27 +615,36 @@ boost::optional<int> WeaponFireEvent::PrincipalFaction(int viewing_empire_id) co
 }
 
 
-template <class Archive>
+template <typename Archive>
 void WeaponFireEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
-    ar & BOOST_SERIALIZATION_NVP(bout)
-       & BOOST_SERIALIZATION_NVP(round)
-       & BOOST_SERIALIZATION_NVP(attacker_id)
-       & BOOST_SERIALIZATION_NVP(target_id)
-       & BOOST_SERIALIZATION_NVP(weapon_name)
-       & BOOST_SERIALIZATION_NVP(power)
-       & BOOST_SERIALIZATION_NVP(shield)
-       & BOOST_SERIALIZATION_NVP(damage)
-       & BOOST_SERIALIZATION_NVP(target_owner_id)
-       & BOOST_SERIALIZATION_NVP(attacker_owner_id);
 
-    if (version < 3) {
-        int target_destroyed = 0;
-        ar & BOOST_SERIALIZATION_NVP (target_destroyed);
+    if (version < 5) {
+        ar & BOOST_SERIALIZATION_NVP(bout)
+           & BOOST_SERIALIZATION_NVP(round)
+           & BOOST_SERIALIZATION_NVP(attacker_id)
+           & BOOST_SERIALIZATION_NVP(target_id)
+           & BOOST_SERIALIZATION_NVP(weapon_name)
+           & BOOST_SERIALIZATION_NVP(power)
+           & BOOST_SERIALIZATION_NVP(shield)
+           & BOOST_SERIALIZATION_NVP(damage)
+           & BOOST_SERIALIZATION_NVP(target_owner_id)
+           & BOOST_SERIALIZATION_NVP(attacker_owner_id);
+    } else {
+        ar & boost::serialization::make_nvp("b", bout)
+           & boost::serialization::make_nvp("r", round)
+           & boost::serialization::make_nvp("a", attacker_id)
+           & boost::serialization::make_nvp("t", target_id)
+           & boost::serialization::make_nvp("w", weapon_name)
+           & boost::serialization::make_nvp("p", power)
+           & boost::serialization::make_nvp("s", shield)
+           & boost::serialization::make_nvp("d", damage)
+           & boost::serialization::make_nvp("to", target_owner_id)
+           & boost::serialization::make_nvp("ao", attacker_owner_id);
     }
 }
 
-BOOST_CLASS_VERSION(WeaponFireEvent, 4)
+BOOST_CLASS_VERSION(WeaponFireEvent, 5)
 BOOST_CLASS_EXPORT(WeaponFireEvent)
 
 template
@@ -712,7 +682,7 @@ std::string IncapacitationEvent::DebugString() const {
 
 
 std::string IncapacitationEvent::CombatLogDescription(int viewing_empire_id) const {
-    auto object = GetUniverseObject(object_id);
+    auto object = Objects().get(object_id);
     std::string template_str, object_str;
     int owner_id = object_owner_id;
 
@@ -742,19 +712,25 @@ std::string IncapacitationEvent::CombatLogDescription(int viewing_empire_id) con
     return str(FlexibleFormat(template_str) % owner_string % object_link);
 }
 
-boost::optional<int> IncapacitationEvent::PrincipalFaction(int viewing_empire_id) const {
-    return object_owner_id;
-}
+boost::optional<int> IncapacitationEvent::PrincipalFaction(int viewing_empire_id) const
+{ return object_owner_id; }
 
 
-template <class Archive>
+template <typename Archive>
 void IncapacitationEvent::serialize (Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
-    ar & BOOST_SERIALIZATION_NVP(bout)
-       & BOOST_SERIALIZATION_NVP(object_id)
-       & BOOST_SERIALIZATION_NVP(object_owner_id);
+    if (version < 2) {
+        ar & BOOST_SERIALIZATION_NVP(bout)
+           & BOOST_SERIALIZATION_NVP(object_id)
+           & BOOST_SERIALIZATION_NVP(object_owner_id);
+    } else {
+        ar & boost::serialization::make_nvp("b", bout)
+           & boost::serialization::make_nvp("i", object_id)
+           & boost::serialization::make_nvp("o", object_owner_id);
+    }
 }
 
+BOOST_CLASS_VERSION(IncapacitationEvent, 2)
 BOOST_CLASS_EXPORT(IncapacitationEvent)
 
 template
@@ -775,13 +751,11 @@ void IncapacitationEvent::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchi
 //////////////////////////////////////////
 
 FightersAttackFightersEvent::FightersAttackFightersEvent() :
-    bout(-1),
-    events()
+    bout(-1)
 {}
 
 FightersAttackFightersEvent::FightersAttackFightersEvent(int bout_) :
-    bout(bout_),
-    events()
+    bout(bout_)
 {}
 
 void FightersAttackFightersEvent::AddEvent(int attacker_empire_, int target_empire_)
@@ -809,7 +783,8 @@ std::string FightersAttackFightersEvent::CombatLogDescription(int viewing_empire
     // then the remainder.
     auto show_events_for_empire =
         [&ss, &num_events_remaining, &events_to_show, &viewing_empire_id]
-        (boost::optional<int> show_attacker) {
+        (boost::optional<int> show_attacker)
+    {
             int attacker_empire;
             int target_empire;
             for (const auto& index_and_event : events_to_show) {
@@ -846,7 +821,7 @@ std::string FightersAttackFightersEvent::CombatLogDescription(int viewing_empire
 }
 
 
-template <class Archive>
+template <typename Archive>
 void FightersAttackFightersEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(bout)
@@ -911,11 +886,10 @@ std::string FighterLaunchEvent::CombatLogDescription(int viewing_empire_id) cons
               % std::abs(number_launched));
 }
 
-boost::optional<int> FighterLaunchEvent::PrincipalFaction(int viewing_empire_id) const {
-    return fighter_owner_empire_id;
-}
+boost::optional<int> FighterLaunchEvent::PrincipalFaction(int viewing_empire_id) const
+{ return fighter_owner_empire_id; }
 
-template <class Archive>
+template <typename Archive>
 void FighterLaunchEvent::serialize (Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(bout)
@@ -945,13 +919,11 @@ void FighterLaunchEvent::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchiv
 //////////////////////////////////////////
 
 FightersDestroyedEvent::FightersDestroyedEvent() :
-    bout(-1),
-    events()
+    bout(-1)
 {}
 
 FightersDestroyedEvent::FightersDestroyedEvent(int bout_) :
-    bout(bout_),
-    events()
+    bout(bout_)
 {}
 
 void FightersDestroyedEvent::AddEvent(int target_empire_)
@@ -979,7 +951,8 @@ std::string FightersDestroyedEvent::CombatLogDescription(int viewing_empire_id)
     // ALL_EMPIRES and then the remainder.
     auto show_events_for_empire =
         [&ss, &num_events_remaining, &events_to_show, &viewing_empire_id]
-        (boost::optional<int> show_empire_id) {
+        (boost::optional<int> show_empire_id)
+    {
             int count;
             int target_empire_id;
             for (const auto& index_and_event : events_to_show) {
@@ -1002,7 +975,7 @@ std::string FightersDestroyedEvent::CombatLogDescription(int viewing_empire_id)
                 if (count == 1) {
                     const std::string& template_str = UserString("ENC_COMBAT_FIGHTER_INCAPACITATED_STR");
                     ss << str(FlexibleFormat(template_str) % target_empire_link % target_link);
-                }else {
+                } else {
                     const std::string& template_str = UserString("ENC_COMBAT_FIGHTER_INCAPACITATED_REPEATED_STR");
                     ss << str(FlexibleFormat(template_str) % count_str % target_empire_link % target_link);
                 }
@@ -1020,7 +993,7 @@ std::string FightersDestroyedEvent::CombatLogDescription(int viewing_empire_id)
 }
 
 
-template <class Archive>
+template <typename Archive>
 void FightersDestroyedEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(bout)
@@ -1051,20 +1024,19 @@ void FightersDestroyedEvent::serialize<freeorion_xml_iarchive>(freeorion_xml_iar
 WeaponsPlatformEvent::WeaponsPlatformEvent() :
     bout(-1),
     attacker_id(INVALID_OBJECT_ID),
-    attacker_owner_id(INVALID_OBJECT_ID),
-    events()
+    attacker_owner_id(INVALID_OBJECT_ID)
 {}
 
 WeaponsPlatformEvent::WeaponsPlatformEvent(int bout_, int attacker_id_, int attacker_owner_id_) :
     bout(bout_),
     attacker_id(attacker_id_),
-    attacker_owner_id(attacker_owner_id_),
-    events()
+    attacker_owner_id(attacker_owner_id_)
 {}
 
 void WeaponsPlatformEvent::AddEvent(
     int round_, int target_id_, int target_owner_id_, std::string const & weapon_name_,
-    float power_, float shield_, float damage_) {
+    float power_, float shield_, float damage_)
+{
     events[target_id_].push_back(
         std::make_shared<WeaponFireEvent>(
             bout, round_, attacker_id, target_id_, weapon_name_,
@@ -1076,11 +1048,9 @@ std::string WeaponsPlatformEvent::DebugString() const {
     std::stringstream desc;
     desc << "WeaponsPlatformEvent bout = " << bout << " attacker_id = "
         << attacker_id << " attacker_owner = "<< attacker_owner_id;
-    for (const auto& target : events) {
-        for (const auto attack : target.second) {
+    for (const auto& target : events)
+        for (const auto attack : target.second)
             desc << std::endl << attack->DebugString();
-        }
-    }
     return desc.str();
 }
 
@@ -1101,13 +1071,11 @@ std::string WeaponsPlatformEvent::CombatLogDescription(int viewing_empire_id) co
                                     fire_event->target_owner_id));
 
         double damage = 0.0f;
-        for (auto attack_it : target.second) {
+        for (auto attack_it : target.second)
             damage += attack_it->damage;
-        }
 
         if (damage <= 0.0f) {
             undamaged_target_links.push_back(target_public_name);
-
         } else {
             damaged_target_links.push_back(
                 str(FlexibleFormat(UserString("ENC_COMBAT_PLATFORM_TARGET_AND_DAMAGE"))
@@ -1136,31 +1104,27 @@ std::string WeaponsPlatformEvent::CombatLogDescription(int viewing_empire_id) co
     return desc;
 }
 
-bool WeaponsPlatformEvent::AreSubEventsEmpty(int viewing_empire_id) const {
-    return events.empty();
-}
+bool WeaponsPlatformEvent::AreSubEventsEmpty(int viewing_empire_id) const
+{ return events.empty(); }
 
 std::vector<ConstCombatEventPtr> WeaponsPlatformEvent::SubEvents(int viewing_empire_id) const {
     std::vector<ConstCombatEventPtr> all_events;
-    for (const auto& target : events) {
-        for (auto event : target.second) {
+    for (const auto& target : events)
+        for (auto event : target.second)
             all_events.push_back(std::dynamic_pointer_cast<CombatEvent>(event));
-        }
-    }
     return all_events;
 }
 
-boost::optional<int> WeaponsPlatformEvent::PrincipalFaction(int viewing_empire_id) const {
-    return attacker_owner_id;
-}
+boost::optional<int> WeaponsPlatformEvent::PrincipalFaction(int viewing_empire_id) const
+{ return attacker_owner_id; }
 
-template <class Archive>
+template <typename Archive>
 void WeaponsPlatformEvent::serialize(Archive& ar, const unsigned int version) {
     ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(CombatEvent);
     ar & BOOST_SERIALIZATION_NVP(bout)
-        & BOOST_SERIALIZATION_NVP(attacker_id)
-        & BOOST_SERIALIZATION_NVP(attacker_owner_id)
-        & BOOST_SERIALIZATION_NVP(events);
+       & BOOST_SERIALIZATION_NVP(attacker_id)
+       & BOOST_SERIALIZATION_NVP(attacker_owner_id)
+       & BOOST_SERIALIZATION_NVP(events);
 }
 
 BOOST_CLASS_VERSION(WeaponsPlatformEvent, 4)
