@@ -1,14 +1,32 @@
 from collections import Counter
-from logging import warn
+from functools import reduce
+from logging import warning, error
 
 import freeOrionAIInterface as fo
 import FleetUtilsAI
+from aistate_interface import get_aistate
 from EnumsAI import MissionType
-from freeorion_tools import get_ai_tag_grade, dict_to_tuple, tuple_to_dict, cache_by_session
-from ShipDesignAI import get_part_type
-from AIDependencies import INVALID_ID
+from freeorion_tools import dict_to_tuple, tuple_to_dict, cache_for_current_turn
+from ShipDesignAI import get_ship_part
+from AIDependencies import INVALID_ID, CombatTarget
 
 
+_issued_errors = []
+
+
+def get_allowed_targets(partname: str) -> int:
+    """Return the allowed targets for a given hangar or shortrange weapon"""
+    try:
+        return CombatTarget.PART_ALLOWED_TARGETS[partname]
+    except KeyError:
+        if partname not in _issued_errors:
+            error("AI has no targeting information for weapon part %s. Will assume any target allowed."
+                  "Please update CombatTarget.PART_ALLOWED_TARGETS in AIDependencies.py ")
+            _issued_errors.append(partname)
+        return CombatTarget.ANY
+
+
+@cache_for_current_turn
 def get_empire_standard_fighter():
     """Get the current empire standard fighter stats, i.e. the most common shiptype within the empire.
 
@@ -33,33 +51,40 @@ def default_ship_stats():
     :return: Some weak standard ship
     :rtype: ShipCombatStats
     """
-    attacks = (4.0, 1)
+    attacks = (6.0, 1)
     structure = 15
     shields = 0
     fighters = 0
     launch_rate = 0
     fighter_damage = 0
-    return ShipCombatStats(stats=(attacks, structure, shields, fighters, launch_rate, fighter_damage))
+    flak_shots = 0
+    has_interceptors = False
+    damage_vs_planets = 0
+    has_bomber = False
+    return ShipCombatStats(stats=(attacks, structure, shields,
+                                  fighters, launch_rate, fighter_damage,
+                                  flak_shots, has_interceptors,
+                                  damage_vs_planets, has_bomber))
 
 
-class ShipCombatStats(object):
+class ShipCombatStats:
     """Stores all relevant stats of a ship for combat strength evaluation."""
-    class BasicStats(object):
+    class BasicStats:
         """Stores non-fighter-related stats."""
         def __init__(self, attacks, structure, shields):
             """
 
             :param attacks:
-            :type attacks: dict|None
+            :type attacks: dict[float, int]|None
             :param structure:
             :type structure: int|None
             :param shields:
             :type shields: int|None
             :return:
             """
-            self.structure = 1 if structure is None else structure
-            self.shields = 0 if shields is None else shields
-            self.attacks = {} if attacks is None else tuple_to_dict(attacks)
+            self.structure = 1.0 if structure is None else structure
+            self.shields = 0.0 if shields is None else shields
+            self.attacks = {} if attacks is None else tuple_to_dict(attacks)  # type: dict[float, int]
 
         def get_stats(self, hashable=False):
             """
@@ -75,15 +100,12 @@ class ShipCombatStats(object):
         def __str__(self):
             return str(self.get_stats())
 
-    class FighterStats(object):
+    class FighterStats:
         """ Stores fighter-related stats """
-        def __init__(self, stat_tuple=None, capacity=0, launch_rate=0, damage=0):
-            if stat_tuple and isinstance(stat_tuple, tuple):
-                self.capacity, self.launch_rate, self.damage = stat_tuple
-            else:
-                self.capacity = capacity
-                self.launch_rate = launch_rate
-                self.damage = damage
+        def __init__(self, capacity, launch_rate, damage):
+            self.capacity = capacity
+            self.launch_rate = launch_rate
+            self.damage = damage
 
         def __str__(self):
             return str(self.get_stats())
@@ -94,15 +116,48 @@ class ShipCombatStats(object):
             """
             return self.capacity, self.launch_rate, self.damage
 
+    class AntiFighterStats:
+        def __init__(self, flak_shots: int, has_interceptors: bool):
+            """
+            :param flak_shots: number of shots per bout with flak weapon part
+            :param has_interceptors: true if mounted hangar parts have interceptor ability (interceptors/fighters)
+            """
+            self.flak_shots = flak_shots
+            self.has_interceptors = has_interceptors
+
+        def __str__(self):
+            return str(self.get_stats())
+
+        def get_stats(self):
+            """
+            :return: flak_shots, has_interceptors
+            """
+            return self.flak_shots, self.has_interceptors
+
+    class AntiPlanetStats:
+        def __init__(self, damage_vs_planets, has_bomber):
+            self.damage_vs_planets = damage_vs_planets
+            self.has_bomber = has_bomber
+
+        def get_stats(self):
+            return self.damage_vs_planets, self.has_bomber
+
+        def __str__(self):
+            return str(self.get_stats())
+
     def __init__(self, ship_id=INVALID_ID, consider_refuel=False, stats=None):
         self.__ship_id = ship_id
         self._consider_refuel = consider_refuel
         if stats:
             self._basic_stats = self.BasicStats(*stats[0:3])  # TODO: Should probably determine size dynamically
-            self._fighter_stats = self.FighterStats(*stats[3:])
+            self._fighter_stats = self.FighterStats(*stats[3:6])
+            self._anti_fighter_stats = self.AntiFighterStats(*stats[6:8])
+            self._anti_planet_stats = self.AntiPlanetStats(*stats[8:])
         else:
             self._basic_stats = self.BasicStats(None, None, None)
             self._fighter_stats = self.FighterStats(None, None, None)
+            self._anti_fighter_stats = self.AntiFighterStats(0, False)
+            self._anti_planet_stats = self.AntiPlanetStats(0, False)
             self.__get_stats_from_ship()
 
     def __hash__(self):
@@ -128,35 +183,56 @@ class ShipCombatStats(object):
         fighter_launch_rate = 0
         fighter_capacity = 0
         fighter_damage = 0
+        flak_shots = 0
+        has_bomber = False
+        has_interceptors = False
+        damage_vs_planets = 0
         design = ship.design
         if design and (ship.isArmed or ship.hasFighters):
             meter_choice = fo.meterType.maxCapacity if self._consider_refuel else fo.meterType.capacity
             for partname in design.parts:
                 if not partname:
                     continue
-                pc = get_part_type(partname).partClass
+                pc = get_ship_part(partname).partClass
                 if pc == fo.shipPartClass.shortRange:
+                    allowed_targets = get_allowed_targets(partname)
                     damage = ship.currentPartMeterValue(meter_choice, partname)
-                    attacks[damage] = attacks.get(damage, 0) + 1
+                    shots = ship.currentPartMeterValue(fo.meterType.secondaryStat, partname)
+                    if allowed_targets & CombatTarget.SHIP:
+                        attacks[damage] = attacks.get(damage, 0) + shots
+                    if allowed_targets & CombatTarget.FIGHTER:
+                        flak_shots += 1
+                    if allowed_targets & CombatTarget.PLANET:
+                        damage_vs_planets += damage * shots
                 elif pc == fo.shipPartClass.fighterBay:
                     fighter_launch_rate += ship.currentPartMeterValue(fo.meterType.capacity, partname)
                 elif pc == fo.shipPartClass.fighterHangar:
-                    fighter_capacity += ship.currentPartMeterValue(meter_choice, partname)
+                    allowed_targets = get_allowed_targets(partname)
+                    # for hangars, capacity meter is already counting contributions from ALL hangars.
+                    fighter_capacity = ship.currentPartMeterValue(meter_choice, partname)
                     part_damage = ship.currentPartMeterValue(fo.meterType.secondaryStat, partname)
                     if part_damage != fighter_damage and fighter_damage > 0:
                         # the C++ code fails also in this regard, so FOCS content *should* not allow this.
                         # TODO: Depending on future implementation, might actually need to handle this case.
-                        print "WARNING: Multiple hangar types present on one ship, estimates expected to be wrong."
-                    fighter_damage = max(fighter_damage, part_damage)
+                        warning("Multiple hangar types present on one ship, estimates expected to be wrong.")
+                    if allowed_targets & CombatTarget.SHIP:
+                        fighter_damage = max(fighter_damage, part_damage)
+                    if allowed_targets & CombatTarget.PLANET:
+                        has_bomber = True
+                    if allowed_targets & CombatTarget.FIGHTER:
+                        has_interceptors = True
+
         self._basic_stats = self.BasicStats(attacks, structure, shields)
         self._fighter_stats = self.FighterStats(fighter_capacity, fighter_launch_rate, fighter_damage)
+        self._anti_fighter_stats = self.AntiFighterStats(flak_shots, has_interceptors)
+        self._anti_planet_stats = self.AntiPlanetStats(damage_vs_planets, has_bomber)
 
     def get_basic_stats(self, hashable=False):
         """Get non-fighter-related combat stats of the ship.
 
         :param hashable: if true, returns tuple instead of attacks-dict
         :return: attacks, structure, shields
-        :rtype: (dict|tuple, int, int)
+        :rtype: (dict|tuple, float, float)
         """
         return self._basic_stats.get_stats(hashable=hashable)
 
@@ -166,10 +242,21 @@ class ShipCombatStats(object):
         """
         return self._fighter_stats.get_stats()
 
+    def get_anti_fighter_stats(self):
+        """Get anti-fighter related stats
+        :return: flak_shots, has_interceptors
+        """
+        return self._anti_fighter_stats.get_stats()
+
+    def get_anti_planet_stats(self):
+        return self._anti_planet_stats.get_stats()
+
     def get_rating(self, enemy_stats=None, ignore_fighters=False):
         """Calculate a rating against specified enemy.
 
-        :param enemy_stats: Enemy stats to be rated against
+        If no enemy is specified, will rate against the empire standard enemy
+
+        :param enemy_stats: Enemy stats to be rated against - if None
         :type enemy_stats: ShipCombatStats
         :param ignore_fighters: If True, acts as if fighters are not launched
         :type ignore_fighters: bool
@@ -180,43 +267,63 @@ class ShipCombatStats(object):
         def _rating():
             return my_total_attack * my_structure
 
+        # The fighter rating calculations are heavily based upon the enemy stats.
+        # So, for now, we compare at least against a certain standard enemy.
+        enemy_stats = enemy_stats or get_aistate().get_standard_enemy()
+
         my_attacks, my_structure, my_shields = self.get_basic_stats()
-        e_avg_attack = 1
+        # e_avg_attack = 1
         if enemy_stats:
             e_attacks, e_structure, e_shields = enemy_stats.get_basic_stats()
             if e_attacks:
-                e_num_attacks = sum(n for n in e_attacks.values())
-                e_total_attack = sum(n*dmg for dmg, n in e_attacks.iteritems())
-                e_avg_attack = e_total_attack / e_num_attacks
-                e_net_attack = sum(n*max(dmg - my_shields, .001) for dmg, n in e_attacks.iteritems())
+                # e_num_attacks = sum(n for n in e_attacks.values())
+                e_total_attack = sum(n*dmg for dmg, n in e_attacks.items())
+                # e_avg_attack = e_total_attack / e_num_attacks
+                e_net_attack = sum(n*max(dmg - my_shields, .001) for dmg, n in e_attacks.items())
                 e_net_attack = max(e_net_attack, .1*e_total_attack)
                 shield_factor = e_total_attack / e_net_attack
                 my_structure *= max(1, shield_factor)
-            my_total_attack = sum(n*max(dmg - e_shields, .001) for dmg, n in my_attacks.iteritems())
+            my_total_attack = sum(n*max(dmg - e_shields, .001) for dmg, n in my_attacks.items())
         else:
-            my_total_attack = sum(n*dmg for dmg, n in my_attacks.iteritems())
+            my_total_attack = sum(n*dmg for dmg, n in my_attacks.items())
             my_structure += my_shields
 
         if ignore_fighters:
             return _rating()
 
-        # consider fighter attacks
-        capacity, launch_rate, fighter_damage = self.get_fighter_stats()
-        launched_1st_bout = min(capacity, launch_rate)
-        launched_2nd_bout = min(max(capacity - launch_rate, 0), launch_rate)
-        survival_rate = .2  # chance of a fighter launched in bout 1 to live in turn 3 TODO Actual estimation
-        total_fighter_damage = fighter_damage * (launched_1st_bout * (1+survival_rate) + launched_2nd_bout)
-        fighter_damage_per_bout = total_fighter_damage / 3
-        my_total_attack += fighter_damage_per_bout
+        my_total_attack += self.estimate_fighter_damage()
+
+        # TODO: Consider enemy fighters
 
-        # consider fighter protection factor
-        fighters_shot_down = (1-survival_rate**2) * launched_1st_bout + (1-survival_rate) * launched_2nd_bout
-        damage_prevented = fighters_shot_down * e_avg_attack
-        my_structure += damage_prevented
         return _rating()
 
+    def estimate_fighter_damage(self):
+        capacity, launch_rate, fighter_damage = self.get_fighter_stats()
+        if launch_rate == 0:
+            return 0
+        full_launch_bouts = capacity // launch_rate
+        survival_rate = 0.2  # TODO estimate chance of a fighter not to be shot down in a bout
+        flying_fighters = 0
+        total_fighter_damage = 0
+        # Cut that values down to a single turn (four bouts means max three launch bouts)
+        num_bouts = fo.getGameRules().getInt("RULE_NUM_COMBAT_ROUNDS")
+        for firing_bout in range(num_bouts - 1):
+            if firing_bout < full_launch_bouts:
+                flying_fighters = (flying_fighters * survival_rate) + launch_rate
+            elif firing_bout == full_launch_bouts:
+                # now handle a bout with lower capacity launch
+                flying_fighters = (flying_fighters * survival_rate) + (capacity % launch_rate)
+            else:
+                flying_fighters = (flying_fighters * survival_rate)
+            total_fighter_damage += fighter_damage * flying_fighters
+        return total_fighter_damage / num_bouts
+
     def get_rating_vs_planets(self):
-        return self.get_rating(ignore_fighters=True)
+        """Heuristic to estimate combat strength against planets"""
+        damage = self._anti_planet_stats.damage_vs_planets
+        if self._anti_planet_stats.has_bomber:
+            damage += self.estimate_fighter_damage()
+        return damage * (self._basic_stats.structure + self._basic_stats.shields)
 
     def get_stats(self, hashable=False):
         """ Get all combat related stats of the ship.
@@ -224,10 +331,11 @@ class ShipCombatStats(object):
         :param hashable: if true, return tuple instead of dict for attacks
         :return: attacks, structure, shields, fighter-capacity, fighter-launch_rate, fighter-damage
         """
-        return self.get_basic_stats(hashable=hashable) + self.get_fighter_stats()
+        return (self.get_basic_stats(hashable=hashable) + self.get_fighter_stats()
+                + self.get_anti_fighter_stats() + self.get_anti_planet_stats())
 
 
-class FleetCombatStats(object):
+class FleetCombatStats:
     """Stores combat related stats of the fleet."""
     def __init__(self, fleet_id=INVALID_ID, consider_refuel=False):
         self.__fleet_id = fleet_id
@@ -259,10 +367,10 @@ class FleetCombatStats(object):
         :return: Rating of the fleet
         :rtype: float
         """
-        return combine_ratings_list(map(lambda x: x.get_rating(enemy_stats, ignore_fighters), self.__ship_stats))
+        return combine_ratings_list([x.get_rating(enemy_stats, ignore_fighters) for x in self.__ship_stats])
 
     def get_rating_vs_planets(self):
-        return self.get_rating(ignore_fighters=True)
+        return combine_ratings_list([x.get_rating_vs_planets() for x in self.__ship_stats])
 
     def __get_stats_from_fleet(self):
         """Calculate fleet combat stats (i.e. the stats of all its ships)."""
@@ -291,43 +399,8 @@ def get_fleet_rating_against_planets(fleet_id):
     return FleetCombatStats(fleet_id, consider_refuel=False).get_rating_vs_planets()
 
 
-@cache_by_session
-def _get_species_grades(species_name, grade_type):
-    spec_tags = []
-    if species_name:
-        species = fo.getSpecies(species_name)
-        if species:
-            spec_tags = species.tags
-        else:
-            warn("get_species_grades() couldn't retrieve species '%s'\n" % species_name)
-    return get_ai_tag_grade(spec_tags, grade_type)
-
-
-def get_pilot_weapons_grade(species_name):
-    """
-    Return pilot grade string.
-
-    :rtype str
-    """
-    return _get_species_grades(species_name, 'WEAPONS')
-
-
-def get_species_troops_grade(species_name):
-    """
-    Return troop grade string.
-
-    :rtype str
-    """
-    return _get_species_grades(species_name, 'ATTACKTROOPS')
-
-
-def get_species_shield_grade(species_name):
-    """
-    Return shield grade string.
-
-    :rtype str
-    """
-    return _get_species_grades(species_name, 'SHIELDS')
+def get_ship_rating(ship_id, enemy_stats=None):
+    return ShipCombatStats(ship_id, consider_refuel=False).get_rating(enemy_stats)
 
 
 def weight_attack_troops(troops, grade):
@@ -368,8 +441,8 @@ def combine_ratings(rating1, rating2):
     A natural extension for the combined rating of two ships is
     r_tot = (a_1+a_2)*(s_1+s_2)                                                     (2)
 
-    Assuming         a_i \approx s_i                                                (3)
-    It follows that  a_i \approx \sqrt(r_i) \approx s_i                             (4)
+    Assuming         a_i approx s_i                                                 (3)
+    It follows that  a_i approx sqrt(r_i) approx s_i                                (4)
     And thus         r_tot = (sqrt(r_1)+sqrt(r_2))^2 = r1 + r2 + 2*sqrt(r1*r2)      (5)
 
     Note that this function has commutative and associative properties.
@@ -394,7 +467,7 @@ def combine_ratings_list(ratings_list):
     :return: combined rating
     :rtype: float
     """
-    return reduce(combine_ratings, ratings_list) if ratings_list else 0
+    return reduce(combine_ratings, ratings_list, 0)
 
 
 def rating_needed(target, current=0):
