@@ -1,25 +1,24 @@
 import math
-from logging import debug, info, warn
+from logging import debug, info, warning
 
-from turn_state import state
 import freeOrionAIInterface as fo
-from common.print_utils import Table, Text, Float
 
-import FreeOrionAI as foAI
-import AIstate
+from aistate_interface import get_aistate
 import AIDependencies
+import AIstate
+import ColonisationAI
+import CombatRatingsAI
 import EspionageAI
 import FleetUtilsAI
-import PlanetUtilsAI
-import universe_object
-from MoveUtilsAI import can_travel_to_system
-import ProductionAI
-import ColonisationAI
 import MilitaryAI
+import PlanetUtilsAI
+import ProductionAI
+from AIDependencies import INVALID_ID, Tags
 from EnumsAI import MissionType, PriorityType
-import CombatRatingsAI
-from freeorion_tools import tech_is_complete, AITimer, get_partial_visibility_turn
-from AIDependencies import INVALID_ID
+from common.print_utils import Table, Text, Float
+from freeorion_tools import tech_is_complete, AITimer, get_partial_visibility_turn, get_species_tag_grade
+from target import TargetPlanet, TargetSystem
+from turn_state import state
 
 MAX_BASE_TROOPERS_GOOD_INVADERS = 20
 MAX_BASE_TROOPERS_POOR_INVADERS = 10
@@ -36,14 +35,15 @@ def get_invasion_fleets():
     empire_id = fo.empireID()
 
     home_system_id = PlanetUtilsAI.get_capital_sys_id()
-    visible_system_ids = list(foAI.foAIstate.visInteriorSystemIDs) + list(foAI.foAIstate.visBorderSystemIDs)
+    aistate = get_aistate()
+    visible_system_ids = list(aistate.visInteriorSystemIDs) + list(aistate.visBorderSystemIDs)
 
     if home_system_id != INVALID_ID:
         accessible_system_ids = [sys_id for sys_id in visible_system_ids if
                                  (sys_id != INVALID_ID) and universe.systemsConnected(sys_id, home_system_id,
                                                                                       empire_id)]
     else:
-        print "Warning: Empire has no identifiable homeworld; will treat all visible planets as accessible."
+        debug("Empire has no identifiable homeworld; will treat all visible planets as accessible.")
         # TODO: check if any troop ships owned, use their system as home system
         accessible_system_ids = visible_system_ids
 
@@ -61,14 +61,14 @@ def get_invasion_fleets():
     invasion_fleet_ids = FleetUtilsAI.get_empire_fleet_ids_by_role(MissionType.INVASION)
     num_invasion_fleets = len(FleetUtilsAI.extract_fleet_ids_without_mission_types(invasion_fleet_ids))
 
-    print "Current Invasion Targeted SystemIDs: ", PlanetUtilsAI.sys_name_ids(AIstate.invasionTargetedSystemIDs)
-    print "Current Invasion Targeted PlanetIDs: ", PlanetUtilsAI.planet_string(invasion_targeted_planet_ids)
-    print invasion_fleet_ids and "Invasion Fleet IDs: %s" % invasion_fleet_ids or "Available Invasion Fleets: 0"
-    print "Invasion Fleets Without Missions: %s" % num_invasion_fleets
+    debug("Current Invasion Targeted SystemIDs: %s" % PlanetUtilsAI.sys_name_ids(AIstate.invasionTargetedSystemIDs))
+    debug("Current Invasion Targeted PlanetIDs: %s" % PlanetUtilsAI.planet_string(invasion_targeted_planet_ids))
+    debug(invasion_fleet_ids and "Invasion Fleet IDs: %s" % invasion_fleet_ids or "Available Invasion Fleets: 0")
+    debug("Invasion Fleets Without Missions: %s" % num_invasion_fleets)
 
     invasion_timer.start("planning troop base production")
     reserved_troop_base_targets = []
-    if foAI.foAIstate.character.may_invade_with_bases():
+    if aistate.character.may_invade_with_bases():
         available_pp = {}
         for el in empire.planetsWithAvailablePP:  # keys are sets of ints; data is doubles
             avail_pp = el.data()
@@ -85,7 +85,7 @@ def get_invasion_fleets():
         # we lost our base trooper source planet since it was first added to list).
         #
         # For planning and tracking base troopers under construction, we use a dictionary store in
-        # foAI.foAIstate.qualifyingTroopBaseTargets, keyed by the invasion target planet ID.  We only store values
+        # get_aistate().qualifyingTroopBaseTargets, keyed by the invasion target planet ID.  We only store values
         # for invasion targets that appear likely to be suitable for base trooper use, and store a 2-item list.
         # The first item in this list is the ID of the planet where we expect to build the base troopers, and the second
         # entry initially is set to INVALID_ID (-1).  The presence of this entry in qualifyingTroopBaseTargets
@@ -95,13 +95,12 @@ def get_invasion_fleets():
         # same as the source planet originally identified, but we could consider reevaluating that, or use that second
         # value to instead record how many base troopers have been queued, so that on later turns we can assess if the
         # process got delayed & perhaps more troopers need to be queued).
-
-        secure_ai_fleet_missions = foAI.foAIstate.get_fleet_missions_with_any_mission_types([MissionType.SECURE,
-                                                                                             MissionType.MILITARY])
+        secure_ai_fleet_missions = aistate.get_fleet_missions_with_any_mission_types([MissionType.SECURE,
+                                                                                      MissionType.MILITARY])
 
         # Pass 1: identify qualifying base troop invasion targets
         for pid in invadable_planet_ids:  # TODO: reorganize
-            if pid in foAI.foAIstate.qualifyingTroopBaseTargets:
+            if pid in aistate.qualifyingTroopBaseTargets:
                 continue
             planet = universe.getPlanet(pid)
             if not planet:
@@ -126,25 +125,25 @@ def get_invasion_fleets():
                 troops_per_ship = best_base_trooper_here.troopCapacity
                 if not troops_per_ship:
                     continue
-                species_troop_grade = CombatRatingsAI.get_species_troops_grade(planet2.speciesName)
+                species_troop_grade = get_species_tag_grade(planet2.speciesName, Tags.ATTACKTROOPS)
                 troops_per_ship = CombatRatingsAI.weight_attack_troops(troops_per_ship, species_troop_grade)
                 if troops_per_ship > best_trooper_count:
                     best_base_planet = pid2
                     best_trooper_count = troops_per_ship
             if best_base_planet != INVALID_ID:
-                foAI.foAIstate.qualifyingTroopBaseTargets.setdefault(pid, [best_base_planet, INVALID_ID])
+                aistate.qualifyingTroopBaseTargets.setdefault(pid, [best_base_planet, INVALID_ID])
 
         # Pass 2: for each target previously identified for base troopers, check that still qualifies and
         # check how many base troopers would be needed; if reasonable then queue up the troops and record this in
-        # foAI.foAIstate.qualifyingTroopBaseTargets
-        for pid in foAI.foAIstate.qualifyingTroopBaseTargets.keys():
+        # get_aistate().qualifyingTroopBaseTargets
+        for pid in list(aistate.qualifyingTroopBaseTargets.keys()):
             planet = universe.getPlanet(pid)
             if planet and planet.owner == empire_id:
-                del foAI.foAIstate.qualifyingTroopBaseTargets[pid]
+                del aistate.qualifyingTroopBaseTargets[pid]
                 continue
             if pid in invasion_targeted_planet_ids:  # TODO: consider overriding standard invasion mission
                 continue
-            if foAI.foAIstate.qualifyingTroopBaseTargets[pid][1] != -1:
+            if aistate.qualifyingTroopBaseTargets[pid][1] != -1:
                 reserved_troop_base_targets.append(pid)
                 if planet:
                     all_invasion_targeted_system_ids.add(planet.systemID)
@@ -152,12 +151,12 @@ def get_invasion_fleets():
                 continue  # already building for here
             _, planet_troops = evaluate_invasion_planet(pid, secure_ai_fleet_missions, True)
             sys_id = planet.systemID
-            this_sys_status = foAI.foAIstate.systemStatus.get(sys_id, {})
+            this_sys_status = aistate.systemStatus.get(sys_id, {})
             troop_tally = 0
             for _fid in this_sys_status.get('myfleets', []):
                 troop_tally += FleetUtilsAI.count_troops_in_fleet(_fid)
             if troop_tally > planet_troops:  # base troopers appear unneeded
-                del foAI.foAIstate.qualifyingTroopBaseTargets[pid]
+                del aistate.qualifyingTroopBaseTargets[pid]
                 continue
             if (planet.currentMeterValue(fo.meterType.shield) > 0 and
                     (this_sys_status.get('myFleetRating', 0) < 0.8 * this_sys_status.get('totalThreat', 0) or
@@ -165,25 +164,25 @@ def get_invasion_fleets():
                 # this system not secured, so ruling out invasion base troops for now
                 # don't immediately delete from qualifyingTroopBaseTargets or it will be opened up for regular troops
                 continue
-            loc = foAI.foAIstate.qualifyingTroopBaseTargets[pid][0]
+            loc = aistate.qualifyingTroopBaseTargets[pid][0]
             best_base_trooper_here = ProductionAI.get_best_ship_info(PriorityType.PRODUCTION_ORBITAL_INVASION, loc)[1]
             loc_planet = universe.getPlanet(loc)
             if best_base_trooper_here is None:  # shouldn't be possible at this point, but just to be safe
-                warn("Could not find a suitable orbital invasion design at %s" % loc_planet)
+                warning("Could not find a suitable orbital invasion design at %s" % loc_planet)
                 continue
             # TODO: have TroopShipDesigner give the expected number of troops including species effects directly
             troops_per_ship = best_base_trooper_here.troopCapacity
-            species_troop_grade = CombatRatingsAI.get_species_troops_grade(loc_planet.speciesName)
+            species_troop_grade = get_species_tag_grade(loc_planet.speciesName, Tags.ATTACKTROOPS)
             troops_per_ship = CombatRatingsAI.weight_attack_troops(troops_per_ship, species_troop_grade)
             if not troops_per_ship:
-                warn("The best orbital invasion design at %s seems not to have any troop capacity." % loc_planet)
+                warning("The best orbital invasion design at %s seems not to have any troop capacity." % loc_planet)
                 continue
             _, col_design, build_choices = ProductionAI.get_best_ship_info(PriorityType.PRODUCTION_ORBITAL_INVASION,
                                                                            loc)
             if not col_design:
                 continue
             if loc not in build_choices:
-                warn('Best troop design %s can not be produced at planet with id: %s\d' % (col_design, build_choices))
+                warning('Best troop design %s can not be produced at planet with id: %s' % (col_design, build_choices))
                 continue
             n_bases = math.ceil((planet_troops + 1) / troops_per_ship)  # TODO: reconsider this +1 safety factor
             # TODO: evaluate cost and time-to-build of best base trooper here versus cost and time-to-build-and-travel
@@ -193,18 +192,18 @@ def get_invasion_fleets():
             # ship and we would need no more than MAX_BASE_TROOPERS_GOOD_INVADERS base troop ships
             if (n_bases > MAX_BASE_TROOPERS_POOR_INVADERS or
                     (troops_per_ship > 1 and n_bases > MAX_BASE_TROOPERS_GOOD_INVADERS)):
-                print "ruling out base invasion troopers for %s due to high number (%d) required." % (planet, n_bases)
-                del foAI.foAIstate.qualifyingTroopBaseTargets[pid]
+                debug("ruling out base invasion troopers for %s due to high number (%d) required." % (planet, n_bases))
+                del aistate.qualifyingTroopBaseTargets[pid]
                 continue
-            print "Invasion base planning, need %d troops at %d pership, will build %d ships." % (
-                (planet_troops + 1), troops_per_ship, n_bases)
+            debug("Invasion base planning, need %d troops at %d per ship, will build %d ships." % (
+                (planet_troops + 1), troops_per_ship, n_bases))
             retval = fo.issueEnqueueShipProductionOrder(col_design.id, loc)
-            print "Enqueueing %d Troop Bases at %s for %s" % (n_bases, PlanetUtilsAI.planet_string(loc),
-                                                              PlanetUtilsAI.planet_string(pid))
+            debug("Enqueueing %d Troop Bases at %s for %s" % (n_bases, PlanetUtilsAI.planet_string(loc),
+                                                              PlanetUtilsAI.planet_string(pid)))
             if retval != 0:
                 all_invasion_targeted_system_ids.add(planet.systemID)
                 reserved_troop_base_targets.append(pid)
-                foAI.foAIstate.qualifyingTroopBaseTargets[pid][1] = loc
+                aistate.qualifyingTroopBaseTargets[pid][1] = loc
                 fo.issueChangeProductionQuantityOrder(empire.productionQueue.size - 1, 1, int(n_bases))
                 fo.issueRequeueProductionOrder(empire.productionQueue.size - 1, 0)
 
@@ -231,9 +230,9 @@ def get_invasion_fleets():
         ])
     info(invasion_table)
 
-    sorted_planets = filter(lambda x: x[1] > 0, sorted_planets)
+    sorted_planets = [x for x in sorted_planets if x[1] > 0]
     # export opponent planets for other AI modules
-    AIstate.opponentPlanetIDs = [pid for pid, _, _ in sorted_planets]
+    AIstate.opponentPlanetIDs = [pid for pid, __, __ in sorted_planets]
     AIstate.invasionTargets = sorted_planets
 
     # export invasion targeted systems for other AI modules
@@ -243,12 +242,12 @@ def get_invasion_fleets():
 
 
 def get_invasion_targeted_planet_ids(planet_ids, mission_type):
-    invasion_feet_missions = foAI.foAIstate.get_fleet_missions_with_any_mission_types([mission_type])
+    invasion_feet_missions = get_aistate().get_fleet_missions_with_any_mission_types([mission_type])
     targeted_planets = []
     for pid in planet_ids:
         # add planets that are target of a mission
         for mission in invasion_feet_missions:
-            target = universe_object.Planet(pid)
+            target = TargetPlanet(pid)
             if mission.has_target(mission_type, target):
                 targeted_planets.append(pid)
     return targeted_planets
@@ -270,11 +269,11 @@ def assign_invasion_values(planet_ids):
     neighbor_values = {}
     neighbor_val_ratio = .95
     universe = fo.getUniverse()
-    secure_missions = foAI.foAIstate.get_fleet_missions_with_any_mission_types([MissionType.SECURE,
-                                                                                MissionType.MILITARY])
+    secure_missions = get_aistate().get_fleet_missions_with_any_mission_types([MissionType.SECURE,
+                                                                               MissionType.MILITARY])
     for pid in planet_ids:
         planet_values[pid] = neighbor_values.setdefault(pid, evaluate_invasion_planet(pid, secure_missions))
-        print "planet %d, values %s" % (pid, planet_values[pid])
+        debug("planet %d, values %s", pid, planet_values[pid])
         planet = universe.getPlanet(pid)
         species_name = (planet and planet.speciesName) or ""
         species = fo.getSpecies(species_name)
@@ -314,7 +313,7 @@ def evaluate_invasion_planet(planet_id, secure_fleet_missions, verbose=True):
 
     planet = universe.getPlanet(planet_id)
     if planet is None:
-        print "Invasion AI couldn't access any info for planet id %d" % planet_id
+        debug("Invasion AI couldn't access any info for planet id %d" % planet_id)
         return [0, 0]
 
     system_id = planet.systemID
@@ -342,13 +341,16 @@ def evaluate_invasion_planet(planet_id, secure_fleet_missions, verbose=True):
     # get a baseline evaluation of the planet as determined by ColonisationAI
     species_name = planet.speciesName
     species = fo.getSpecies(species_name)
+    empire_research_list = tuple(element.tech for element in fo.getEmpire().researchQueue)
     if not species or AIDependencies.TAG_DESTROYED_ON_CONQUEST in species.tags:
         # this call iterates over this Empire's available species with which it could colonize after an invasion
         planet_eval = ColonisationAI.assign_colonisation_values([planet_id], MissionType.INVASION, None, detail)
         colony_base_value = max(0.75 * planet_eval.get(planet_id, [0])[0],
-                                ColonisationAI.evaluate_planet(planet_id, MissionType.OUTPOST, None, detail))
+                                ColonisationAI.evaluate_planet(
+                                    planet_id, MissionType.OUTPOST, None, detail, empire_research_list))
     else:
-        colony_base_value = ColonisationAI.evaluate_planet(planet_id, MissionType.INVASION, species_name, detail)
+        colony_base_value = ColonisationAI.evaluate_planet(
+            planet_id, MissionType.INVASION, species_name, detail, empire_research_list)
 
     # Add extra score for all buildings on the planet
     building_values = {"BLD_IMPERIAL_PALACE": 1000,
@@ -401,14 +403,15 @@ def evaluate_invasion_planet(planet_id, secure_fleet_missions, verbose=True):
         if homeworld and homeworld.systemID != INVALID_ID and system_id != INVALID_ID:
             least_jumps_path = list(universe.leastJumpsPath(homeworld.systemID, system_id, empire_id))
             max_jumps = len(least_jumps_path)
-    system_status = foAI.foAIstate.systemStatus.get(system_id, {})
+    aistate = get_aistate()
+    system_status = aistate.systemStatus.get(system_id, {})
     system_fleet_treat = system_status.get('fleetThreat', 1000)
     system_monster_threat = system_status.get('monsterThreat', 0)
     sys_total_threat = system_fleet_treat + system_monster_threat + system_status.get('planetThreat', 0)
     max_path_threat = system_fleet_treat
     mil_ship_rating = MilitaryAI.cur_best_mil_ship_rating()
     for path_sys_id in least_jumps_path:
-        path_leg_status = foAI.foAIstate.systemStatus.get(path_sys_id, {})
+        path_leg_status = aistate.systemStatus.get(path_sys_id, {})
         path_leg_threat = path_leg_status.get('fleetThreat', 1000) + path_leg_status.get('monsterThreat', 0)
         if path_leg_threat > 0.5 * mil_ship_rating:
             clear_path = False
@@ -441,12 +444,11 @@ def evaluate_invasion_planet(planet_id, secure_fleet_missions, verbose=True):
     system_secured = system_secured and system_status.get('myFleetRating', 0)
 
     if verbose:
-        print ("Invasion eval of %s\n"
-               " - maxShields: %.1f\n"
-               " - sysFleetThreat: %.1f\n"
-               " - sysMonsterThreat: %.1f") % (
-            planet, planet.currentMeterValue(fo.meterType.maxShield), system_fleet_treat,
-            system_monster_threat)
+        debug("Invasion eval of %s\n"
+              " - maxShields: %.1f\n"
+              " - sysFleetThreat: %.1f\n"
+              " - sysMonsterThreat: %.1f",
+              planet, planet.currentMeterValue(fo.meterType.maxShield), system_fleet_treat, system_monster_threat)
     enemy_val = 0
     if planet.owner != -1:  # value in taking this away from an enemy
         enemy_val = 20 * (planet.currentMeterValue(fo.meterType.targetIndustry) +
@@ -471,8 +473,8 @@ def evaluate_invasion_planet(planet_id, secure_fleet_missions, verbose=True):
         design = fo.getShipDesign(design_id)
         cost_per_ship = design.productionCost(empire_id, loc)
         build_time = design.productionTime(empire_id, loc)
-        troops_per_ship = CombatRatingsAI.weight_attack_troops(design.troopCapacity,
-                                                               CombatRatingsAI.get_species_troops_grade(species_here))
+        troops_per_ship = CombatRatingsAI.weight_attack_troops(
+            design.troopCapacity, get_species_tag_grade(species_here, Tags.ATTACKTROOPS))
         planned_troops = troops if system_secured else min(troops + troop_regen*(max_jumps + build_time), max_troops)
         planned_troops += .01  # we must attack with more troops than there are defenders
         ships_needed = math.ceil((planned_troops+_TROOPS_SAFETY_MARGIN) / float(troops_per_ship))
@@ -484,7 +486,7 @@ def evaluate_invasion_planet(planet_id, secure_fleet_missions, verbose=True):
     cost_score = (normalized_cost**2 / 50.0) * troop_cost
 
     base_score = colony_base_value + bld_tally + tech_tally + enemy_val - cost_score
-    # If the AI does have enough total miltary to attack this target, and the target is more than minimally valuable,
+    # If the AI does have enough total military to attack this target, and the target is more than minimally valuable,
     # don't let the threat_factor discount the adjusted value below MIN_INVASION_SCORE +1, so that if there are no
     # other targets the AI could still pursue this one.  Otherwise, scoring pressure from
     # MilitaryAI.get_preferred_max_military_portion_for_single_battle might prevent the AI from attacking heavily
@@ -495,16 +497,16 @@ def evaluate_invasion_planet(planet_id, secure_fleet_missions, verbose=True):
     if clear_path:
         planet_score *= 1.5
     if verbose:
-        print (' - planet score: %.2f\n'
-               ' - planned troops: %.2f\n'
-               ' - projected troop cost: %.1f\n'
-               ' - threat factor: %s\n'
-               ' - planet detail: %s\n'
-               ' - popval: %.1f\n'
-               ' - bldval: %s\n'
-               ' - enemyval: %s') % (planet_score, planned_troops, troop_cost,
-                                     threat_factor, detail, colony_base_value, bld_tally, enemy_val)
-        print (' - system secured: %s' % system_secured)
+        debug(' - planet score: %.2f\n'
+              ' - planned troops: %.2f\n'
+              ' - projected troop cost: %.1f\n'
+              ' - threat factor: %s\n'
+              ' - planet detail: %s\n'
+              ' - popval: %.1f\n'
+              ' - bldval: %s\n'
+              ' - enemyval: %s',
+              planet_score, planned_troops, troop_cost, threat_factor, detail, colony_base_value, bld_tally, enemy_val)
+        debug(' - system secured: %s' % system_secured)
     return [planet_score, planned_troops]
 
 
@@ -528,23 +530,23 @@ def send_invasion_fleets(fleet_ids, evaluated_planets, mission_type):
         min_stats = {'rating': 0, 'troopCapacity': ptroops}
         target_stats = {'rating': 10,
                         'troopCapacity': ptroops + _TROOPS_SAFETY_MARGIN,
-                        'target_system': universe_object.System(sys_id),
-                        'move_path_func': can_travel_to_system}
+                        'target_system': TargetSystem(sys_id)}
         these_fleets = FleetUtilsAI.get_fleets_for_mission(target_stats, min_stats, found_stats,
                                                            starting_system=sys_id, fleet_pool_set=invasion_fleet_pool,
                                                            fleet_list=found_fleets)
         if not these_fleets:
             if not FleetUtilsAI.stats_meet_reqs(found_stats, min_stats):
-                print "Insufficient invasion troop allocation for system %d ( %s ) -- requested %s , found %s" % (
-                    sys_id, universe.getSystem(sys_id).name, min_stats, found_stats)
+                debug("Insufficient invasion troop allocation for system %d ( %s ) -- requested %s , found %s" % (
+                    sys_id, universe.getSystem(sys_id).name, min_stats, found_stats))
                 invasion_fleet_pool.update(found_fleets)
                 continue
             else:
                 these_fleets = found_fleets
-        target = universe_object.Planet(planet_id)
-        print "assigning invasion fleets %s to target %s" % (these_fleets, target)
+        target = TargetPlanet(planet_id)
+        debug("assigning invasion fleets %s to target %s" % (these_fleets, target))
+        aistate = get_aistate()
         for fleetID in these_fleets:
-            fleet_mission = foAI.foAIstate.get_fleet_mission(fleetID)
+            fleet_mission = aistate.get_fleet_mission(fleetID)
             fleet_mission.clear_fleet_orders()
             fleet_mission.clear_target()
             fleet_mission.set_target(mission_type, target)
@@ -556,6 +558,7 @@ def assign_invasion_bases():
     all_troopbase_fleet_ids = FleetUtilsAI.get_empire_fleet_ids_by_role(MissionType.ORBITAL_INVASION)
     available_troopbase_fleet_ids = set(FleetUtilsAI.extract_fleet_ids_without_mission_types(all_troopbase_fleet_ids))
 
+    aistate = get_aistate()
     for fid in list(available_troopbase_fleet_ids):
         if fid not in available_troopbase_fleet_ids:  # entry may have been discarded in previous loop iterations
             continue
@@ -564,15 +567,15 @@ def assign_invasion_bases():
             continue
         sys_id = fleet.systemID
         system = universe.getSystem(sys_id)
-        available_planets = set(system.planetIDs).intersection(set(foAI.foAIstate.qualifyingTroopBaseTargets.keys()))
-        print "Considering Base Troopers in %s, found planets %s and registered targets %s with status %s" % (
+        available_planets = set(system.planetIDs).intersection(set(aistate.qualifyingTroopBaseTargets.keys()))
+        debug("Considering Base Troopers in %s, found planets %s and registered targets %s with status %s" % (
             system.name, list(system.planetIDs), available_planets,
-            [(pid, foAI.foAIstate.qualifyingTroopBaseTargets[pid]) for pid in available_planets])
-        targets = [pid for pid in available_planets if foAI.foAIstate.qualifyingTroopBaseTargets[pid][1] != -1]
+            [(pid, aistate.qualifyingTroopBaseTargets[pid]) for pid in available_planets]))
+        targets = [pid for pid in available_planets if aistate.qualifyingTroopBaseTargets[pid][1] != -1]
         if not targets:
-            print "Failure: found no valid target for troop base in system %s" % system
+            debug("Failure: found no valid target for troop base in system %s" % system)
             continue
-        status = foAI.foAIstate.systemStatus.get(sys_id, {})
+        status = aistate.systemStatus.get(sys_id, {})
         local_base_troops = set(status.get('myfleets', [])).intersection(available_troopbase_fleet_ids)
 
         target_id = INVALID_ID
@@ -599,14 +602,15 @@ def assign_invasion_bases():
             FleetUtilsAI.merge_fleet_a_into_b(fid2, fid)
             available_troopbase_fleet_ids.discard(fid2)
         available_troopbase_fleet_ids.discard(fid)
-        foAI.foAIstate.qualifyingTroopBaseTargets[target_id][1] = -1  # TODO: should probably delete
-        target = universe_object.Planet(target_id)
-        fleet_mission = foAI.foAIstate.get_fleet_mission(fid)
+        aistate.qualifyingTroopBaseTargets[target_id][1] = -1  # TODO: should probably delete
+        target = TargetPlanet(target_id)
+        fleet_mission = aistate.get_fleet_mission(fid)
         fleet_mission.set_target(MissionType.ORBITAL_INVASION, target)
 
 
 def assign_invasion_fleets_to_invade():
     """Assign fleet targets to invadable planets."""
+    aistate = get_aistate()
 
     assign_invasion_bases()
 
@@ -615,5 +619,5 @@ def assign_invasion_fleets_to_invade():
     send_invasion_fleets(invasion_fleet_ids, AIstate.invasionTargets, MissionType.INVASION)
     all_invasion_fleet_ids = FleetUtilsAI.get_empire_fleet_ids_by_role(MissionType.INVASION)
     for fid in FleetUtilsAI.extract_fleet_ids_without_mission_types(all_invasion_fleet_ids):
-        this_mission = foAI.foAIstate.get_fleet_mission(fid)
+        this_mission = aistate.get_fleet_mission(fid)
         this_mission.check_mergers(context="Post-send consolidation of unassigned troops")
