@@ -3,9 +3,10 @@ The TechsListAI module provides functions that describes dependencies between
 various technologies to help the AI decide which technologies should be
 researched next.
 """
-from logging import warn
+from logging import warning, debug
 
 import freeOrionAIInterface as fo  # pylint: disable=import-error
+import AIDependencies as Dep
 
 
 def unusable_techs():
@@ -26,7 +27,7 @@ def defense_techs_1():
     ]
 
 
-class TechGroup(object):
+class TechGroup:
     """ Base class for Tech groups.
 
     A TechGroup consists of some techs which need to be researched before progressing to the next TechGroup.
@@ -82,12 +83,12 @@ class TechGroup(object):
                     # Do not display error message as those should be shown only once per game session
                     # by the initial test_tech_integrity() call.
                     msg = "Try to enqueue tech from empty list"
-                    warn(msg)
+                    warning(msg)
                     self._errors.append(msg)
                     continue
             if tech_name in self._tech_queue:
                 msg = "Tech is already in queue: %s" % tech_name
-                warn(msg)
+                warning(msg)
                 self._errors.append(msg)
             else:
                 self._tech_queue.append(tech_name)
@@ -110,23 +111,25 @@ class TechGroup1(TechGroup):
             "GRO_PLANET_ECOL",
             "LRN_ALGO_ELEGANCE",
             "GRO_SUBTER_HAB",
-            "LRN_ARTIF_MINDS",
-            "CON_ORBITAL_CON",  # not a economy tech in the strictest sense but bonus supply often equals more planets
+            Dep.LRN_ARTIF_MINDS_1,
             "PRO_ROBOTIC_PROD",
         ])
         self.weapon.extend([
+            "SHP_WEAPON_ARC_DISRUPTOR_1",
             "SHP_WEAPON_1_2",
-            "SHP_FIGHTERS_1",
             "SHP_WEAPON_1_3",
+            "SHP_FIGHTERS_1",
             "SHP_WEAPON_1_4",
         ])
         self.defense.extend([
             "DEF_GARRISON_1",
+            "DEF_DEFENSE_NET_1",
         ])
         self.hull.extend([
             "SHP_MIL_ROBO_CONT",
+            "SHP_ORG_HULL",
         ])
-        # always start with the same first 7 techs; leaves 2 econ, 3 weap, 1 hull
+        # always start with the same first 8 techs; leaves 1 econ, 4 weap, 2 hull
         self.enqueue(
             self.economy,
             self.economy,
@@ -135,6 +138,7 @@ class TechGroup1(TechGroup):
             self.economy,
             self.weapon,
             self.defense,
+            self.defense,
         )
 
 
@@ -145,7 +149,7 @@ class TechGroup1a(TechGroup1):
             self.weapon,
             self.weapon,
             self.weapon,
-            self.economy,
+            self.weapon,
             self.economy,
             self.hull,
         )
@@ -160,7 +164,7 @@ class TechGroup1b(TechGroup1):
             self.economy,
             self.weapon,
             self.weapon,
-            self.economy,
+            self.weapon,
         )
 
 
@@ -168,14 +172,13 @@ class TechGroup1SparseA(TechGroup1):
     def __init__(self):
         super(TechGroup1SparseA, self).__init__()
         self.enqueue(
-            self.economy,
             self.economy,
             self.hull,
             self.weapon,
             self.weapon,
             self.weapon,
-
-            "SHP_SPACE_FLUX_DRIVE"
+            "SHP_SPACE_FLUX_DRIVE",
+            self.weapon,
         )
 
 
@@ -185,16 +188,31 @@ class TechGroup1SparseB(TechGroup1):
         self.enqueue(
             self.economy,
             self.economy,
-            "PRO_FUSION_GEN",
-            "GRO_SYMBIOTIC_BIO",
             self.weapon,
-            self.weapon,
-            self.weapon,
-            "PRO_ORBITAL_GEN",
             self.hull,
             "SHP_ZORTRIUM_PLATE",
-            "SHP_SPACE_FLUX_DRIVE"
+            self.weapon,
+            "PRO_NANOTECH_PROD",
+            Dep.PRO_AUTO_1,
+            "PRO_EXOBOTS",
+            "CON_ORBITAL_CON",  # not a economy tech in the strictest sense but bonus supply often equals more planets
+            "GRO_GENETIC_MED",
+            "GRO_SYMBIOTIC_BIO",
+            "PRO_MICROGRAV_MAN",
+            "GRO_XENO_GENETICS",
+            "LRN_FORCE_FIELD",
+            "SHP_ASTEROID_HULLS",
+            "PRO_FUSION_GEN",
+            "SHP_WEAPON_2_1",
+            self.hull,
+            "SHP_MULTICELL_CAST",
+            "SHP_DEUTERIUM_TANK",
+            "SHP_WEAPON_2_2",
+            "PRO_ORBITAL_GEN",
+            "SPY_DETECT_2",
+            "SHP_SPACE_FLUX_DRIVE",
         )
+        self.weapon = []
 
 
 class TechGroup1SparseC(TechGroup1):
@@ -203,22 +221,23 @@ class TechGroup1SparseC(TechGroup1):
         self.enqueue(
             self.economy,
             self.economy,
-            self.weapon,
             "SHP_ORG_HULL",
-            self.weapon,
+            "SHP_MULTICELL_CAST",
             "PRO_NANOTECH_PROD",
-            "GRO_GENETIC_ENG",
-            "PRO_SENTIENT_AUTOMATION",
+            Dep.PRO_AUTO_1,
+            self.weapon,
+            "CON_ORBITAL_CON",  # not a economy tech in the strictest sense but bonus supply often equals more planets
             "GRO_GENETIC_MED",
             "GRO_SYMBIOTIC_BIO",
-            "PRO_MICROGRAV_MAN",
             "PRO_EXOBOTS",
+            "SHP_DEUTERIUM_TANK",  # more reach for more scouting and planets
+            "PRO_MICROGRAV_MAN",
             "GRO_XENO_GENETICS",
             "SHP_ASTEROID_HULLS",
             "PRO_FUSION_GEN",
             "SHP_WEAPON_2_1",
             "SHP_ZORTRIUM_PLATE",
-            self.hull,
+            "SHP_MIL_ROBO_CONT",
             "LRN_FORCE_FIELD",
             "SHP_WEAPON_2_2",
             "PRO_ORBITAL_GEN",
@@ -232,24 +251,19 @@ class TechGroup2(TechGroup):
     def __init__(self):
         super(TechGroup2, self).__init__()
         self.economy.extend([
-            "GRO_SYMBIOTIC_BIO",
             "PRO_FUSION_GEN",
-            "PRO_SENTIENT_AUTOMATION",
+            Dep.PRO_AUTO_1,
             "PRO_EXOBOTS",
+            "GRO_SYMBIOTIC_BIO",
+            "CON_ORBITAL_CON",  # not a economy tech in the strictest sense but bonus supply often equals more planets
             # "PRO_MICROGRAV_MAN",  # handled by fast-forwarding when we have asteroids
             # "PRO_ORBITAL_GEN",    # handled by fast-forwarding when we have a GG
-
         ])
         self.armor.extend([
             "SHP_ZORTRIUM_PLATE",
         ])
-        self.defense.extend([
-            "DEF_DEFENSE_NET_1",
-            "SPY_DETECT_2",
-            "DEF_GARRISON_2",
-            "LRN_FORCE_FIELD",
-        ])
         self.hull.extend([
+            "SHP_MULTICELL_CAST",
             "SHP_SPACE_FLUX_DRIVE",
             # "SHP_ASTEROID_HULLS",  # should be handled by fast-forwarding when having ASteroids
             # "SHP_DOMESTIC_MONSTER",  # should be handled by fast-forwarding when having nest
@@ -266,44 +280,57 @@ class TechGroup2(TechGroup):
 class TechGroup2A(TechGroup2):
     def __init__(self):
         super(TechGroup2A, self).__init__()
+        self.defense.extend([
+            "SPY_DETECT_2",
+            "DEF_GARRISON_2",
+            "LRN_FORCE_FIELD",
+        ])
         self.enqueue(
-            self.economy,
             self.armor,
+            self.economy,
+            self.economy,
+            self.economy,
+            self.defense,
             self.defense,
             self.hull,
-            self.economy,
-            self.defense,
-            self.defense,
             self.weapon,
             self.weapon,
             self.defense,
             self.economy,
+            self.economy,
             self.weapon,
             self.weapon,
             self.weapon,
-            self.economy
+            self.economy,
+            self.hull,
         )
 
 
 class TechGroup2B(TechGroup2):
     def __init__(self):
         super(TechGroup2B, self).__init__()
+        self.defense.extend([
+            "LRN_FORCE_FIELD",
+            "SPY_DETECT_2",
+            "DEF_GARRISON_2",
+        ])
         self.enqueue(
             self.armor,
+            self.economy,
+            self.economy,
+            self.defense,
             self.hull,
-            self.economy,
-            self.defense,
             self.weapon,
             self.weapon,
             self.economy,
             self.defense,
             self.defense,
-            self.defense,
             self.weapon,
             self.weapon,
             self.weapon,
             self.economy,
-            self.economy
+            self.economy,
+            self.hull,
         )
 
 
@@ -311,13 +338,14 @@ class TechGroup2SparseA(TechGroup2):
     def __init__(self):
         super(TechGroup2SparseA, self).__init__()
         self.enqueue(
+            self.armor,
             self.hull,
             self.economy,
             self.economy,
-            self.armor,
-            self.defense,
             self.economy,
             self.economy,
+            self.economy,
+            Dep.LRN_ARTIF_MINDS_1,
             self.defense,
             self.defense,
             self.weapon,
@@ -325,7 +353,8 @@ class TechGroup2SparseA(TechGroup2):
             self.defense,
             self.weapon,
             self.weapon,
-            self.weapon
+            self.weapon,
+            self.hull,
         )
 
 
@@ -333,21 +362,23 @@ class TechGroup2SparseB(TechGroup2):
     def __init__(self):
         super(TechGroup2SparseB, self).__init__()
         self.enqueue(
+            self.armor,
             self.hull,
             self.economy,
             self.economy,
             self.economy,
             self.economy,
-            self.defense,
+            self.economy,
+            Dep.LRN_ARTIF_MINDS_1,
             self.defense,
             self.weapon,
             self.weapon,
             self.defense,
             self.defense,
-            self.armor,
             self.weapon,
             self.weapon,
-            self.weapon
+            self.weapon,
+            self.hull,
         )
 
 
@@ -355,7 +386,6 @@ class TechGroup3(TechGroup):
     def __init__(self):
         super(TechGroup3, self).__init__()
         self.hull.extend([
-            "SHP_ORG_HULL",
             "SHP_ASTEROID_REFORM",
             "SHP_HEAVY_AST_HULL",
             "SHP_CONTGRAV_MAINT",
@@ -365,8 +395,10 @@ class TechGroup3(TechGroup):
             "GRO_GENETIC_ENG",
             "GRO_GENETIC_MED",
             "GRO_XENO_GENETICS",
+            Dep.LRN_ARTIF_MINDS_2,
             "LRN_QUANT_NET",
             "PRO_SOL_ORB_GEN",
+            Dep.PRO_AUTO_2,
             "PRO_INDUSTRY_CENTER_II",
             "GRO_XENO_HYBRIDS",
             "CON_ORBITAL_HAB",
@@ -386,6 +418,7 @@ class TechGroup3(TechGroup):
             "DEF_PLAN_BARRIER_SHLD_3",
         ])
         self.misc.extend([
+            "SHP_DEUTERIUM_TANK",
             "SHP_BASIC_DAM_CONT",
             "SHP_INTSTEL_LOG",
             "SHP_FLEET_REPAIR",
@@ -414,11 +447,13 @@ class TechGroup3A(TechGroup3):
         self.enqueue(
             self.hull,
             self.economy,
+            self.misc,
             self.defense,
             self.defense,
             self.economy,
             self.economy,
             self.economy,
+            self.economy,
             self.defense,
             self.misc,
             self.defense,
@@ -428,6 +463,7 @@ class TechGroup3A(TechGroup3):
             self.economy,
             self.misc,
             self.hull,
+            self.economy,
             self.hull,
             self.misc,
             self.economy,
@@ -451,7 +487,7 @@ class TechGroup3A(TechGroup3):
             self.weapon,
             self.weapon,
             self.weapon,
-            self.weapon
+            self.weapon,
         )
 
 
@@ -461,6 +497,7 @@ class TechGroup3B(TechGroup3):
         self.enqueue(
             self.hull,
             self.economy,
+            self.misc,
             self.defense,
             self.defense,
             self.economy,
@@ -473,6 +510,7 @@ class TechGroup3B(TechGroup3):
             self.defense,
             self.economy,
             self.weapon,
+            self.economy,
             self.misc,
             self.misc,
             self.economy,
@@ -480,6 +518,7 @@ class TechGroup3B(TechGroup3):
             self.weapon,
             self.weapon,
             self.hull,
+            self.economy,
             self.hull,
             self.misc,
             self.economy,
@@ -498,7 +537,7 @@ class TechGroup3B(TechGroup3):
             self.defense,
             self.economy,
             self.misc,
-            self.economy
+            self.economy,
         )
 
 
@@ -507,6 +546,7 @@ class TechGroup3Sparse(TechGroup3):
         super(TechGroup3Sparse, self).__init__()
         self.enqueue(
             self.hull,
+            self.misc,
             self.defense,
             self.defense,
             self.economy,
@@ -519,7 +559,9 @@ class TechGroup3Sparse(TechGroup3):
             self.weapon,
             self.weapon,
             self.defense,
+            self.economy,
             self.defense,
+            self.economy,
             self.weapon,
             self.misc,
             self.misc,
@@ -559,7 +601,8 @@ class TechGroup4(TechGroup):
         ])
         self.enqueue(
             self.hull,
-            self.hull
+            self.hull,
+            "SHP_ANTIMATTER_TANK",
         )
 
 
@@ -635,27 +678,27 @@ def test_tech_integrity():
         TechGroup4,
         TechGroup5
     ]
-    print "Checking TechGroup integrity..."
+    debug("Checking TechGroup integrity...")
     for group in tech_groups:
-        print "Checking %s: " % group.__name__,
+        debug("Checking %s: " % group.__name__)
         error_occured = False
         this_group = group()
         techs = this_group.get_techs()
         for tech in techs:
             if not fo.getTech(tech):
-                warn("In %s: Tech %s seems not to exist!" % (group.__name__, tech))
+                warning("In %s: Tech %s seems not to exist!" % (group.__name__, tech))
                 error_occured = True
         for err in this_group.get_errors():
-            warn(err, exc_info=True)
+            warning(err, exc_info=True)
             error_occured = True
         if not error_occured:
-            print "Seems to be OK!"
+            debug("Seems to be OK!")
 
 
 def sparse_galaxy_techs(index):
     # return primary_meta_techs()
     result = []
-    print "Choosing Research Techlist Index %d" % index
+    debug("Choosing Research Techlist Index %d" % index)
     if index == 0:
         result = TechGroup1a().get_techs()  # early org_hull
         result += TechGroup2A().get_techs()  # prioritizes growth & defense over weapons
@@ -663,25 +706,25 @@ def sparse_galaxy_techs(index):
         result += TechGroup4().get_techs()
         result += TechGroup5().get_techs()  #
     elif index == 1:
-        result = TechGroup1b().get_techs()  # early _lrn_artif_minds
+        result = TechGroup1b().get_techs()  # early lrn_nascent_ai
         result += TechGroup2B().get_techs()  # prioritizes growth & defense over weapons
         result += TechGroup3B().get_techs()
         result += TechGroup4().get_techs()
         result += TechGroup5().get_techs()  #
     elif index == 2:
-        result = TechGroup1SparseA().get_techs()  # early _lrn_artif_minds
+        result = TechGroup1SparseA().get_techs()  # early lrn_nascent_ai
         result += TechGroup2SparseA().get_techs()  # prioritizes growth & defense over weapons
         result += TechGroup3Sparse().get_techs()
         result += TechGroup4().get_techs()
         result += TechGroup5().get_techs()  #
     elif index == 3:
-        result = TechGroup1SparseC().get_techs()  # early org_hull
+        result = TechGroup1SparseB().get_techs()  # early org_hull
         result += TechGroup2SparseB().get_techs()
         result += TechGroup3A().get_techs()
         result += TechGroup4().get_techs()
         result += TechGroup5().get_techs()  #
     elif index == 4:
-        result = TechGroup1SparseC().get_techs()  # early _lrn_artif_minds
+        result = TechGroup1SparseC().get_techs()  # early pro_adaptive_auto
         result += TechGroup2SparseB().get_techs()
         result += TechGroup3B().get_techs()  # faster plasma weaps
         result += TechGroup4().get_techs()
@@ -696,7 +739,7 @@ def primary_meta_techs(index=0):
     # index = 1 - index
     result = []
 
-    print "Choosing Research Techlist Index %d" % index
+    debug("Choosing Research Techlist Index %d" % index)
     if index == 0:
         result = TechGroup1a().get_techs()  # early org_hull
         result += TechGroup2A().get_techs()  # prioritizes growth & defense over weapons
@@ -784,7 +827,7 @@ def primary_meta_techs(index=0):
 # "GRO_XENO_GENETICS",
 # "GRO_XENO_HYBRIDS",
 # "LRN_ALGO_ELEGANCE",
-# "LRN_ARTIF_MINDS",
+# "LRN_ARTIF_MINDS", Dep.LRN_ARTIF_MINDS_2
 # "LRN_ART_BLACK_HOLE",
 # "LRN_DISTRIB_THOUGHT",
 # "LRN_ENCLAVE_VOID",
@@ -793,6 +836,7 @@ def primary_meta_techs(index=0):
 # "LRN_GATEWAY_VOID",
 # "LRN_GRAVITONICS",
 # "LRN_MIND_VOID",
+# "LRN_NASCENT_AI", Dep.LRN_ARTIF_MINDS_1
 # "LRN_NDIM_SUBSPACE",
 # "LRN_OBSERVATORY_I",
 # "LRN_PHYS_BRAIN",
@@ -806,6 +850,7 @@ def primary_meta_techs(index=0):
 # "LRN_TRANSLING_THT",
 # "LRN_UNIF_CONC",
 # "LRN_XENOARCH",
+# "PRO_ADAPTIVE_AUTOMATION", Dep.PRO_AUTO_1
 # "PRO_EXOBOTS",
 # "PRO_FUSION_GEN",
 # "PRO_INDUSTRY_CENTER_I",
@@ -817,7 +862,7 @@ def primary_meta_techs(index=0):
 # "PRO_NEUTRONIUM_EXTRACTION",
 # "PRO_ORBITAL_GEN",
 # "PRO_ROBOTIC_PROD",
-# "PRO_SENTIENT_AUTOMATION",
+# "PRO_SENTIENT_AUTOMATION", Dep.PRO_AUTO_2
 # "PRO_SINGULAR_GEN",
 # "PRO_SOL_ORB_GEN",
 # "PRO_ZERO_GEN",
