@@ -2,7 +2,7 @@ import cProfile
 import os
 import pstats
 import time
-import StringIO
+from io import StringIO
 
 
 def profile(save_path, sort_by='cumulative'):
@@ -14,7 +14,7 @@ def profile(save_path, sort_by='cumulative'):
     Result stored in user directory in profile catalog. See lne in logs for exact position.
 
     :param save_path: path to save profile, for example:
-        os.path.join(fo.getUserDataDir(), 'profiling', base_path, foAI.foAIstate.uid)
+        os.path.join(fo.getUserDataDir(), 'profiling', base_path, get_aistate().uid)
     :type save_path: str
     :param sort_by: sort stats https://docs.python.org/2/library/profile.html#pstats.Stats.sort_stats
     :type sort_by: str
@@ -28,8 +28,8 @@ def profile(save_path, sort_by='cumulative'):
             result = function(*args, **kwargs)
             end = time.clock()
             pr.disable()
-            print "Profile %s tooks %f s, saved to %s" % (function.__name__, end - start, save_path)
-            s = StringIO.StringIO()
+            print("Profile %s tooks %f s, saved to %s" % (function.__name__, end - start, save_path))
+            s = StringIO()
             ps = pstats.Stats(pr, stream=s).strip_dirs().sort_stats(sort_by)
             ps.print_stats()
 
