@@ -1,17 +1,15 @@
-import os.path
 import random
 
 import freeorion as fo
 
-from starsystems import star_types_real, pick_star_type
-from planets import calc_planet_size, calc_planet_type, planet_sizes_real, planet_types_real
+import universe_statistics
 from names import get_name_list, random_name
-from options import (HS_ACCEPTABLE_PLANET_TYPES, HS_MIN_PLANETS_IN_VICINITY_TOTAL,
-                     HS_MIN_PLANETS_IN_VICINITY_PER_SYSTEM, HS_MIN_DISTANCE_PRIORITY_LIMIT, HS_MAX_JUMP_DISTANCE_LIMIT,
-                     HS_VICINITY_RANGE, HS_MIN_SYSTEMS_IN_VICINITY, HS_ACCEPTABLE_PLANET_SIZES)
-
-from util import report_error
-import statistics
+from options import (HS_ACCEPTABLE_PLANET_SIZES, HS_ACCEPTABLE_PLANET_TYPES, HS_MAX_JUMP_DISTANCE_LIMIT,
+                     HS_MIN_DISTANCE_PRIORITY_LIMIT, HS_MIN_PLANETS_IN_VICINITY_PER_SYSTEM,
+                     HS_MIN_PLANETS_IN_VICINITY_TOTAL, HS_MIN_SYSTEMS_IN_VICINITY, HS_VICINITY_RANGE)
+from planets import calc_planet_size, calc_planet_type, planet_sizes_real, planet_types_real
+from starsystems import pick_star_type, star_types_real
+from util import report_error, unique_product
 
 
 def get_empire_name_generator():
@@ -84,7 +82,7 @@ def min_planets_in_vicinity_limit(num_systems):
     return min(HS_MIN_PLANETS_IN_VICINITY_TOTAL, num_systems * HS_MIN_PLANETS_IN_VICINITY_PER_SYSTEM)
 
 
-class HomeSystemFinder(object):
+class HomeSystemFinder:
     """Finds a set of home systems with a least ''num_home_systems'' systems."""
     def __init__(self, _num_home_systems):
         # cache of sytem merits
@@ -147,10 +145,10 @@ class HomeSystemFinder(object):
 
             if len(local_pool) < self.num_home_systems:
                 if not best_candidate:
-                    print ("Failing in find_home_systems_for_min_jump_distance because "
-                           "current_merit_lower_bound = {} trims local pool to {} systems "
-                           "which is less than num_home_systems {}.".format(
-                               current_merit_lower_bound, len(local_pool), self.num_home_systems))
+                    print("Failing in find_home_systems_for_min_jump_distance because "
+                          "current_merit_lower_bound = {} trims local pool to {} systems "
+                          "which is less than num_home_systems {}.".format(
+                              current_merit_lower_bound, len(local_pool), self.num_home_systems))
                 break
 
             attempts = min(attempts - 1, len(local_pool))
@@ -179,13 +177,14 @@ class HomeSystemFinder(object):
 
             # If we have a better candidate, set the new lower bound and try for a better candidate.
             if merit > current_merit_lower_bound:
-                print ("Home system set merit lower bound improved from {} to "
-                       "{}".format(current_merit_lower_bound, merit))
+                print("Home system set merit lower bound improved from {} to "
+                      "{}".format(current_merit_lower_bound, merit))
                 current_merit_lower_bound = merit
                 best_candidate = [s for (_, s) in merit_system]
 
-                # Quit sucessfully if the lowest merit system meets the minimum threshold
-                if merit >= min_planets_in_vicinity_limit(fo.systems_within_jumps_unordered(HS_VICINITY_RANGE, [system])):
+                # Quit successfully if the lowest merit system meets the minimum threshold
+                if merit >= min_planets_in_vicinity_limit(
+                        len(fo.systems_within_jumps_unordered(HS_VICINITY_RANGE, [system]))):
                     break
 
         return best_candidate
@@ -205,16 +204,16 @@ def find_home_systems(num_home_systems, pool_list, jump_distance, min_jump_dista
     # try to find home systems, decrease the min jumps until enough systems can be found, or the jump distance drops
     # below the specified minimum jump distance (which means failure)
     while jump_distance >= min_jump_distance:
-        print "Trying to find", num_home_systems, "home systems that are at least", jump_distance, "jumps apart..."
+        print("Trying to find", num_home_systems, "home systems that are at least", jump_distance, "jumps apart...")
 
         # try to pick our home systems by iterating over the pools we got
         for pool, pool_label in pool_list:
-            print "...use", pool_label
+            print("...use", pool_label)
 
             # check if the pool has enough systems to pick from
             if len(pool) <= num_home_systems:
                 # no, the pool has less systems than home systems requested, so just skip trying using that pool
-                print "...pool only has", len(pool), "systems, skip trying to use it"
+                print("...pool only has", len(pool), "systems, skip trying to use it")
                 continue
 
             # try to pick home systems
@@ -222,11 +221,11 @@ def find_home_systems(num_home_systems, pool_list, jump_distance, min_jump_dista
             # check if we got enough
             if len(home_systems) >= num_home_systems:
                 # yes, we got what we need, return the home systems we found
-                print "...", len(home_systems), "systems found"
+                print("...", len(home_systems), "systems found")
                 return home_systems
             else:
                 # no, try next pool
-                print "...only", len(home_systems), "systems found"
+                print("...only", len(home_systems), "systems found")
 
         # we did not find enough home systems with the current jump distance requirement,
         # so decrease the jump distance and try again
@@ -240,7 +239,7 @@ def add_planets_to_vicinity(vicinity, num_planets, gsd):
     """
     Adds the specified number of planets to the specified systems.
     """
-    print "Adding", num_planets, "planets to the following systems:", vicinity
+    print("Adding", num_planets, "planets to the following systems:", vicinity)
 
     # first, compile a list containing all the free orbits in the specified systems
     # begin with adding the free orbits of all systems that have a real star (that is, no neutron star, black hole,
@@ -280,7 +279,7 @@ def add_planets_to_vicinity(vicinity, num_planets, gsd):
     if len(free_orbits_map) < num_planets:
         report_error("Python add_planets_to_vicinity: less free orbits than planets to add - cancelled")
 
-    print "...free orbits available:", free_orbits_map
+    print("...free orbits available:", free_orbits_map)
     # as we will pop the free orbits from this list afterwards, shuffle it to randomize the order of the orbits
     random.shuffle(free_orbits_map)
 
@@ -295,10 +294,10 @@ def add_planets_to_vicinity(vicinity, num_planets, gsd):
             # if it is a black hole or has no star, change the star type
             # pick a star type, continue until we get a real star
             # don't accept neutron, black hole or no star
-            print "...system picked to add a planet has star type", star_type
+            print("...system picked to add a planet has star type", star_type)
             while star_type not in star_types_real:
                 star_type = pick_star_type(gsd.age)
-            print "...change that to", star_type
+            print("...change that to", star_type)
             fo.sys_set_star_type(system, star_type)
 
         # pick a planet size, continue until we get a size that matches the HS_ACCEPTABLE_PLANET_SIZES option
@@ -310,7 +309,7 @@ def add_planets_to_vicinity(vicinity, num_planets, gsd):
         planet_type = calc_planet_type(star_type, orbit, planet_size)
 
         # finally, create the planet in the system and orbit we got
-        print "...adding", planet_size, planet_type, "planet to system", system
+        print("...adding", planet_size, planet_type, "planet to system", system)
         if fo.create_planet(planet_size, planet_type, system, orbit, "") == fo.invalid_object():
             report_error("Python add_planets_to_vicinity: create planet in system %d failed" % system)
 
@@ -322,7 +321,7 @@ def compile_home_system_list(num_home_systems, systems, gsd):
     """
     Compiles a list with a requested number of home systems.
     """
-    print "Compile home system list:", num_home_systems, "systems requested"
+    print("Compile home system list:", num_home_systems, "systems requested")
 
     # if the list of systems to choose home systems from is empty, report an error and return empty list
     if not systems:
@@ -336,7 +335,7 @@ def compile_home_system_list(num_home_systems, systems, gsd):
     #     and with large galaxies an excessive amount of time can be used in failed attempts
     # b.) lower than the minimum jump distance limit that should be considered high priority (see options.py),
     #     otherwise no attempt at all would be made to enforce the other requirements for home systems (see below)
-    min_jumps = min(HS_MAX_JUMP_DISTANCE_LIMIT, max(int(float(len(systems)) / float(num_home_systems * 2)),
+    min_jumps = min(HS_MAX_JUMP_DISTANCE_LIMIT, max(int(len(systems) / (num_home_systems * 2)),
                                                     HS_MIN_DISTANCE_PRIORITY_LIMIT))
 
     # home systems must have a certain minimum of systems and planets in their near vicinity
@@ -356,9 +355,9 @@ def compile_home_system_list(num_home_systems, systems, gsd):
             pool_matching_sys_limit.append(system)
             if count_planets_in_systems(systems_in_vicinity) >= min_planets_in_vicinity_limit(len(systems_in_vicinity)):
                 pool_matching_sys_and_planet_limit.append(system)
-    print (len(pool_matching_sys_and_planet_limit),
-           "systems meet the min systems and planets in the near vicinity limit")
-    print len(pool_matching_sys_limit), "systems meet the min systems in the near vicinity limit"
+    print(len(pool_matching_sys_and_planet_limit),
+          "systems meet the min systems and planets in the near vicinity limit")
+    print(len(pool_matching_sys_limit), "systems meet the min systems in the near vicinity limit")
 
     # now try to pick the requested number of home systems
     # we will do this by calling find_home_systems, which takes a list of tuples defining the pools from which to pick
@@ -368,7 +367,7 @@ def compile_home_system_list(num_home_systems, systems, gsd):
     # to start with the min_jumps jumps distance we calculated above, but not to go lower than
     # HS_MIN_DISTANCE_PRIORITY_LIMIT
 
-    print "First attempt: trying to pick home systems from the filtered pools of preferred systems"
+    print("First attempt: trying to pick home systems from the filtered pools of preferred systems")
     pool_list = [
         # the better pool is of course the one where all systems meet BOTH the min systems and planets limit
         (pool_matching_sys_and_planet_limit, "pool of systems that meet both the min systems and planets limit"),
@@ -383,7 +382,7 @@ def compile_home_system_list(num_home_systems, systems, gsd):
     # again with the min_jumps jump distance limit and specifying 0 as number of required home systems to pick as much
     # systems as possible
     if len(home_systems) < num_home_systems:
-        print "Second attempt: trying to pick home systems from all systems"
+        print("Second attempt: trying to pick home systems from all systems")
         home_systems = find_home_systems(num_home_systems, [(systems, "complete pool")], min_jumps, 1)
 
     # check if the selection process delivered a list with enough home systems
@@ -408,14 +407,14 @@ def compile_home_system_list(num_home_systems, systems, gsd):
         # if this home system has no "real" star, change star type to a randomly selected "real" star
         if fo.sys_get_star_type(home_system) not in star_types_real:
             star_type = random.choice(star_types_real)
-            print "Home system", home_system, "has star type", fo.sys_get_star_type(home_system),\
-                  ", changing that to", star_type
+            print("Home system", home_system, "has star type", fo.sys_get_star_type(home_system), ", changing that to",
+                  star_type)
             fo.sys_set_star_type(home_system, star_type)
 
         # if this home system has no planets, create one in a random orbit
         # we take random values for type and size, as these will be set to suitable values later
         if not fo.sys_get_planets(home_system):
-            print "Home system", home_system, "has no planets, adding one"
+            print("Home system", home_system, "has no planets, adding one")
             planet = fo.create_planet(random.choice(planet_sizes_real),
                                       random.choice(planet_types_real),
                                       home_system, random.randint(0, fo.sys_get_num_orbits(home_system) - 1), "")
@@ -426,15 +425,15 @@ def compile_home_system_list(num_home_systems, systems, gsd):
 
     # finally, check again if all home systems meet the criteria of having the required minimum number of planets
     # within their near vicinity, if not, add the missing number of planets
-    print "Checking if home systems have the required minimum of planets within the near vicinity..."
+    print("Checking if home systems have the required minimum of planets within the near vicinity...")
     for home_system in home_systems:
         # calculate the number of missing planets, and add them if this number is > 0
         systems_in_vicinity = fo.systems_within_jumps_unordered(HS_VICINITY_RANGE, [home_system])
         num_systems_in_vicinity = len(systems_in_vicinity)
         num_planets_in_vicinity = count_planets_in_systems(systems_in_vicinity)
         num_planets_to_add = min_planets_in_vicinity_limit(num_systems_in_vicinity) - num_planets_in_vicinity
-        print "Home system", home_system, "has", num_systems_in_vicinity, "systems and", num_planets_in_vicinity,\
-            "planets in the near vicinity, required minimum:", min_planets_in_vicinity_limit(num_systems_in_vicinity)
+        print("Home system", home_system, "has", num_systems_in_vicinity, "systems and", num_planets_in_vicinity,
+              "planets in the near vicinity, required minimum:", min_planets_in_vicinity_limit(num_systems_in_vicinity))
         if num_planets_to_add > 0:
             systems_in_vicinity.remove(home_system)  # don't add planets to the home system, so remove it from the list
             # sort the systems_in_vicinity before adding, since the C++ engine doesn't guarrantee the same
@@ -453,17 +452,17 @@ def setup_empire(empire, empire_name, home_system, starting_species, player_name
 
     # set empire name, if no one is given, pick one randomly
     if not empire_name:
-        print "No empire name set for player", player_name, ", picking one randomly"
+        print("No empire name set for player", player_name, ", picking one randomly")
         empire_name = next(empire_name_generator)
     fo.empire_set_name(empire, empire_name)
-    print "Empire name for player", player_name, "is", empire_name
+    print("Empire name for player", player_name, "is", empire_name)
 
     # check starting species, if no one is given, pick one randomly
     if starting_species == "RANDOM" or not starting_species:
-        print "Picking random starting species for player", player_name
+        print("Picking random starting species for player", player_name)
         starting_species = next(starting_species_pool)
-    print "Starting species for player", player_name, "is", starting_species
-    statistics.empire_species[starting_species] += 1
+    print("Starting species for player", player_name, "is", starting_species)
+    universe_statistics.empire_species[starting_species] += 1
 
     # pick a planet from the specified home system as homeworld
     planet_list = fo.sys_get_planets(home_system)
@@ -483,54 +482,106 @@ def setup_empire(empire, empire_name, home_system, starting_species, player_name
     preferred_focus = fo.species_preferred_focus(starting_species)
     if preferred_focus in available_foci:
         # if yes, set the homeworld focus to the preferred focus
-        print "Player", player_name, ": setting preferred focus", preferred_focus, "on homeworld"
+        print("Player", player_name, ": setting preferred focus", preferred_focus, "on homeworld")
         fo.planet_set_focus(homeworld, preferred_focus)
     elif len(available_foci) > 0:
         # if no, and there is at least one available focus,
         # just take the first of the list
         if preferred_focus == "":
-            print "Player", player_name, ": starting species", starting_species, "has no preferred focus, using",\
-                  available_foci[0], "instead"
+            print("Player", player_name, ": starting species", starting_species, "has no preferred focus, using",
+                  available_foci[0], "instead")
         else:
-            print "Player", player_name, ": preferred focus", preferred_focus, "for starting species",\
-                  starting_species, "not available on homeworld, using", available_foci[0], "instead"
+            print("Player", player_name, ": preferred focus", preferred_focus, "for starting species", starting_species,
+                  "not available on homeworld, using", available_foci[0], "instead")
         fo.planet_set_focus(homeworld, available_foci[0])
     else:
         # if no focus is available on the homeworld, don't set any focus
-        print "Player", player_name, ": no available foci on homeworld for starting species", starting_species
+        print("Player", player_name, ": no available foci on homeworld for starting species", starting_species)
 
     # give homeworld starting buildings
-    print "Player", player_name, ": add starting buildings to homeworld"
+    print("Player", player_name, ": add starting buildings to homeworld")
     for item in fo.load_starting_buildings():
         fo.create_building(item.name, homeworld, empire)
 
     # unlock starting techs, buildings, hulls, ship parts, etc.
     # use default content file
-    print "Player", player_name, ": add unlocked items"
-    for item in fo.load_item_spec_list():
+    print("Player", player_name, ": add unlocked items")
+    for item in fo.load_unlockable_item_list():
         fo.empire_unlock_item(empire, item.type, item.name)
 
     # add premade ship designs to empire
-    print "Player", player_name, ": add premade ship designs"
+    print("Player", player_name, ": add premade ship designs")
     for ship_design in fo.design_get_premade_list():
         fo.empire_add_ship_design(empire, ship_design)
 
     # add starting fleets to empire
     # use default content file
-    print "Player", player_name, ": add starting fleets"
+    print("Player", player_name, ": add starting fleets")
     fleet_plans = fo.load_fleet_plan_list()
     for fleet_plan in fleet_plans:
+        # should fleet be aggressive? check if any ships are armed.
+        should_be_aggressive = False
+        for ship_design in fleet_plan.ship_designs():
+            design = fo.getPredefinedShipDesign(ship_design)
+            if design is None:
+                report_error("Looked up null design with name %s", ship_design)
+            elif design.isArmed:
+                should_be_aggressive = True
+                break
+
         # first, create the fleet
-        fleet = fo.create_fleet(fleet_plan.name(), home_system, empire)
+        fleet = fo.create_fleet(fleet_plan.name(), home_system, empire, should_be_aggressive)
         # if the fleet couldn't be created, report an error and try to continue with the next fleet plan
         if fleet == fo.invalid_object():
             report_error("Python setup empire: couldn't create fleet %s" % fleet_plan.name())
             continue
+
         # second, iterate over the list of ship design names in the fleet plan
         for ship_design in fleet_plan.ship_designs():
             # create a ship in the fleet
             # if the ship couldn't be created, report an error and try to continue with the next ship design
             if fo.create_ship("", ship_design, starting_species, fleet) == fo.invalid_object():
-                report_error("Python setup empire: couldn't create ship %s for fleet %s"
+                report_error("Python setup empire: couldn't create ship of design %s for fleet %s"
                              % (ship_design, fleet_plan.name()))
+
     return True
+
+
+def home_system_layout(home_systems, systems):
+    """
+    Home systems layout generation to place teams.
+    Returns map from home system to neighbor home systems.
+    """
+    # for each system found nearest home systems
+    # maybe multiple if home worlds placed on the same jump distnace
+    system_hs = {}
+    for system in systems:
+        nearest_hs = set()
+        nearest_dist = None
+        for hs in home_systems:
+            dist = fo.jump_distance(system, hs)
+            if nearest_dist is None or nearest_dist > dist:
+                nearest_dist = dist
+                nearest_hs = {hs}
+            elif nearest_dist == dist:
+                nearest_hs.add(hs)
+        system_hs[system] = nearest_hs
+
+    # homeworld is connected to the other
+    # if both are nearest for some system
+    # if each of them is nearest for systems on the starline ends
+    home_system_connections = {}
+    for system, connected_home_systems in system_hs.items():
+        if len(connected_home_systems) >= 2:
+            for hs1, hs2 in unique_product(connected_home_systems, connected_home_systems):
+                home_system_connections.setdefault(hs1, set()).add(hs2)
+                home_system_connections.setdefault(hs2, set()).add(hs1)
+
+    for system, connected_home_systems in system_hs.items():
+        adj_systems = fo.systems_within_jumps_unordered(1, [system])
+        for system2 in adj_systems:
+            connected_home_systems2 = system_hs.get(system2, set())
+            for hs1, hs2 in unique_product(connected_home_systems, connected_home_systems2):
+                home_system_connections.setdefault(hs1, set()).add(hs2)
+                home_system_connections.setdefault(hs2, set()).add(hs1)
+    return home_system_connections
