@@ -1,7 +1,9 @@
 import math
 import random
 import sys
+import itertools
 from hashlib import md5
+from typing import Iterable, Iterator, Tuple
 
 error_list = []
 
@@ -26,10 +28,12 @@ def seed_rng(seed):
     # random.jumpahead(999999)
 
 
-def distance((x1, y1), (x2, y2)):
+def distance(start, end):
     """
     Calculates linear distance between two coordinates.
     """
+    x1, y1 = start
+    x2, y2 = end
     return math.hypot(float(x1) - float(x2), float(y1) - float(y2))
 
 
@@ -38,7 +42,16 @@ def report_error(msg):
     Handles error messages.
     """
     error_list.append(msg)
-    print >> sys.stderr, msg
+    print(msg, file=sys.stderr)
+
+
+def unique_product(first: Iterable[int], second: Iterable[int]) -> Iterator[Tuple[int, int]]:
+    """
+    Create all possible unique pairs for two iterables.
+    Both iterables should consist of comparable objects.
+    Pair is sorted in ascending order.
+    """
+    return filter(lambda x: x[0] < x[1], itertools.product(first, second))
 
 
 class MapGenerationError(RuntimeError):
