@@ -72,7 +72,6 @@ public:
         LOBBY_EXIT,             ///< sent to server by clients when a player leaves the multiplayer lobby, or by server to clients when a player leaves the multiplayer lobby
         START_MP_GAME,          ///< sent to server (by the "host" client only) when the settings in the MP lobby are satisfactory and it is time to start the game
         SAVE_GAME_INITIATE,     ///< sent to server (by the "host" client only) when a game is to be saved
-        SAVE_GAME_DATA_REQUEST, ///< sent to clients by the server when the game is being saved and the server needs save state info from clients
         SAVE_GAME_COMPLETE,     ///< sent to clients (by the "host" client only) when a game has been saved and written to disk
         LOAD_GAME,              ///< sent to server (by the "host" client only) when a game is to be loaded
         GAME_START,             ///< sent to each client before the first turn of a new or newly loaded game, instead of a TURN_UPDATE
@@ -81,7 +80,6 @@ public:
         TURN_ORDERS,            ///< sent to the server by a client that has orders to be processed at the end of a turn
         TURN_PROGRESS,          ///< sent to clients to display a turn progress message
         PLAYER_STATUS,          ///< sent to clients to inform them that a player has some status, such as having finished playing a turn and submitted orders, or is resolving combat, or is playing a turn normally
-        CLIENT_SAVE_DATA,       ///< sent to the server in response to a server request for the data needed to create a save file
         PLAYER_CHAT,            ///< sent when one player sends a chat message to another in multiplayer
         DIPLOMACY,              ///< sent by players to server or server to players to make or convey diplomatic proposals or declarations, or to accept / reject proposals from other players
         DIPLOMATIC_STATUS,      ///< sent by server to players to inform of mid-turn diplomatic status changes
@@ -103,7 +101,11 @@ public:
         AUTH_RESPONSE,          ///< sent by client to server to provide password or other credentials
         CHAT_HISTORY,           ///< sent by server to client to show previous messages
         SET_AUTH_ROLES,         ///< sent by server to client to set authorization roles
-        ELIMINATE_SELF          ///< sent by client to server if the player wants to resign
+        ELIMINATE_SELF,         ///< sent by client to server if the player wants to resign
+        UNREADY,                ///< sent by client to server to revoke ready state of turn orders and sent by server to client to acknowledge it
+        TURN_PARTIAL_ORDERS,    ///< sent to the server by a client that has changes in orders to be stored
+        TURN_TIMEOUT,           ///< sent by server to client to notify about remaining time before turn advance
+        PLAYER_INFO             ///< sent by server to client to notify about changes in the player data
     )
 
     GG_CLASS_ENUM(TurnProgressPhase,
@@ -119,10 +121,10 @@ public:
         STARTING_AIS            ///< creating AI clients
     )
 
+    /// \todo change to EmpireStatus on compatibility breakage
     GG_CLASS_ENUM(PlayerStatus,
-        PLAYING_TURN,           ///< player is playing a turn, on the galax map
-        RESOLVING_COMBAT,       ///< player is resolving a combat interactively
-        WAITING                 ///< player is waiting for others to submit orders, to resolve combats, or for turn processing to complete
+        PLAYING_TURN,           ///< empire is playing a turn, on the galax map
+        WAITING                 ///< empire is waiting for others to submit orders, to resolve combats, or for turn processing to complete
     )
 
     GG_CLASS_ENUM(EndGameReason,
@@ -193,7 +195,8 @@ FO_COMMON_API Message HostSPGameMessage(const SinglePlayerSetupData& setup_data)
 /** creates a minimal HOST_MP_GAME message used to initiate multiplayer "lobby" setup*/
 FO_COMMON_API Message HostMPGameMessage(const std::string& host_player_name);
 
-/** creates a JOIN_GAME message.  The sender's player name, client type, and cookie are sent in the message.*/
+/** creates a JOIN_GAME message.  The sender's player name, client type, and
+  * cookie are sent in the message.*/
 FO_COMMON_API Message JoinGameMessage(const std::string& player_name,
                                       Networking::ClientType client_type,
                                       boost::uuids::uuid cookie);
@@ -202,31 +205,32 @@ FO_COMMON_API Message JoinGameMessage(const std::string& player_name,
 FO_COMMON_API Message HostIDMessage(int host_player_id);
 
 /** creates a GAME_START message.  Contains the initial game state visible to the player.*/
-FO_COMMON_API Message GameStartMessage(bool single_player_game, int empire_id, int current_turn,
-                                       const EmpireManager& empires, const Universe& universe,
-                                       const SpeciesManager& species, CombatLogManager& combat_logs,
-                                       const SupplyManager& supply, const std::map<int, PlayerInfo>& players,
-                                       const GalaxySetupData& galaxy_setup_data, bool use_binary_serialization);
+FO_COMMON_API Message GameStartMessage(
+    bool single_player_game, int empire_id, int current_turn,
+    const EmpireManager& empires, const Universe& universe,
+    const SpeciesManager& species, CombatLogManager& combat_logs,
+    const SupplyManager& supply, const std::map<int, PlayerInfo>& players,
+    GalaxySetupData galaxy_setup_data, bool use_binary_serialization);
 
 /** creates a GAME_START message.  Contains the initial game state visible to
   * the player.  Also includes data loaded from a saved game. */
-FO_COMMON_API Message GameStartMessage(bool single_player_game, int empire_id, int current_turn,
-                                       const EmpireManager& empires, const Universe& universe,
-                                       const SpeciesManager& species, CombatLogManager& combat_logs,
-                                       const SupplyManager& supply,
-                                       const std::map<int, PlayerInfo>& players, const OrderSet& orders,
-                                       const SaveGameUIData* ui_data,
-                                       const GalaxySetupData& galaxy_setup_data, bool use_binary_serialization);
+FO_COMMON_API Message GameStartMessage(
+    bool single_player_game, int empire_id, int current_turn,
+    const EmpireManager& empires, const Universe& universe,
+    const SpeciesManager& species, CombatLogManager& combat_logs,
+    const SupplyManager& supply, const std::map<int, PlayerInfo>& players,
+    const OrderSet& orders, const SaveGameUIData* ui_data,
+    GalaxySetupData galaxy_setup_data, bool use_binary_serialization);
 
 /** creates a GAME_START message.  Contains the initial game state visible to
   * the player.  Also includes state string loaded from a saved game. */
-FO_COMMON_API Message GameStartMessage(bool single_player_game, int empire_id, int current_turn,
-                                       const EmpireManager& empires, const Universe& universe,
-                                       const SpeciesManager& species, CombatLogManager& combat_logs,
-                                       const SupplyManager& supply,
-                                       const std::map<int, PlayerInfo>& players, const OrderSet& orders,
-                                       const std::string* save_state_string,
-                                       const GalaxySetupData& galaxy_setup_data, bool use_binary_serialization);
+FO_COMMON_API Message GameStartMessage(
+    bool single_player_game, int empire_id, int current_turn,
+    const EmpireManager& empires, const Universe& universe,
+    const SpeciesManager& species, CombatLogManager& combat_logs,
+    const SupplyManager& supply, const std::map<int, PlayerInfo>& players,
+    const OrderSet& orders, const std::string* save_state_string,
+    GalaxySetupData galaxy_setup_data, bool use_binary_serialization);
 
 /** creates a HOST_SP_GAME acknowledgement message.  The \a player_id is the ID
   * of the receiving player.  This message should only be sent by the server.*/
@@ -241,14 +245,24 @@ FO_COMMON_API Message HostMPAckMessage(int player_id);
   * This message should only be sent by the server.*/
 FO_COMMON_API Message JoinAckMessage(int player_id, boost::uuids::uuid cookie);
 
-/** creates a TURN_ORDERS message. */
-FO_COMMON_API Message TurnOrdersMessage(const OrderSet& orders);
+/** creates a TURN_ORDERS message, including UI data but without a state string. */
+FO_COMMON_API Message TurnOrdersMessage(const OrderSet& orders, const SaveGameUIData& ui_data);
+
+/** creates a TURN_ORDERS message, without UI data but with a state string. */
+FO_COMMON_API Message TurnOrdersMessage(const OrderSet& orders, const std::string& save_state_string);
+
+/** creates a TURN_PARTIAL_ORDERS message with orders changes. */
+FO_COMMON_API Message TurnPartialOrdersMessage(const std::pair<OrderSet, std::set<int>>& orders_updates);
+
+/** creates a TURN_TIMEOUT message with remaining time \a timeout_. */
+FO_COMMON_API Message TurnTimeoutMessage(int timeout_remainig);
 
 /** creates a TURN_PROGRESS message. */
 FO_COMMON_API Message TurnProgressMessage(Message::TurnProgressPhase phase_id);
 
 /** creates a PLAYER_STATUS message. */
-FO_COMMON_API Message PlayerStatusMessage(int about_player_id, Message::PlayerStatus player_status);
+FO_COMMON_API Message PlayerStatusMessage(Message::PlayerStatus player_status,
+                                          int about_empire_id);
 
 /** creates a TURN_UPDATE message. */
 FO_COMMON_API Message TurnUpdateMessage(int empire_id, int current_turn,
@@ -261,24 +275,10 @@ FO_COMMON_API Message TurnUpdateMessage(int empire_id, int current_turn,
 FO_COMMON_API Message TurnPartialUpdateMessage(int empire_id, const Universe& universe,
                                                bool use_binary_serialization);
 
-/** creates a CLIENT_SAVE_DATA message, including UI data but without a state string. */
-FO_COMMON_API Message ClientSaveDataMessage(const OrderSet& orders, const SaveGameUIData& ui_data);
-
-/** creates a CLIENT_SAVE_DATA message, without UI data but with a state string. */
-FO_COMMON_API Message ClientSaveDataMessage(const OrderSet& orders, const std::string& save_state_string);
-
-/** creates a CLIENT_SAVE_DATA message, without UI data and without a state string. */
-FO_COMMON_API Message ClientSaveDataMessage(const OrderSet& orders);
-
 /** creates a SAVE_GAME_INITIATE request message.  This message should only be sent by
   * the host player.*/
 FO_COMMON_API Message HostSaveGameInitiateMessage(const std::string& filename);
 
-/** creates a SAVE_GAME_DATA_REQUEST data request message.  This message should
-    only be sent by the server to get game data from a client, or to respond to
-    the host player requesting a save be initiated. */
-FO_COMMON_API Message ServerSaveGameDataRequestMessage();
-
 /** creates a SAVE_GAME_COMPLETE complete message.  This message should only be
     sent by the server to inform clients that the last initiated save has been
     completed successfully. */
@@ -314,7 +314,8 @@ FO_COMMON_API Message DispatchSavePreviewsMessage(const PreviewInformation& prev
 FO_COMMON_API Message RequestCombatLogsMessage(const std::vector<int>& ids);
 
 /** returns combat logs to the client */
-FO_COMMON_API Message DispatchCombatLogsMessage(const std::vector<std::pair<int, const CombatLog>>& logs);
+FO_COMMON_API Message DispatchCombatLogsMessage(const std::vector<std::pair<int, const CombatLog>>& logs,
+                                                bool use_binary_serialization);
 
 /** Sends logger configuration details to server or ai process. */
 FO_COMMON_API Message LoggerConfigMessage(int sender, const std::set<std::tuple<std::string, std::string, LogLevel>>& options);
@@ -338,13 +339,12 @@ FO_COMMON_API Message ChatHistoryMessage(const std::vector<std::reference_wrappe
 
 /** creates an PLAYER_CHAT message containing a chat string to be broadcast to player \a receiver, or all players if \a
     receiver is Networking::INVALID_PLAYER_ID. Note that the receiver of this message is always the server.*/
-FO_COMMON_API Message PlayerChatMessage(const std::string& text, int receiver = Networking::INVALID_PLAYER_ID);
+FO_COMMON_API Message PlayerChatMessage(const std::string& text, std::set<int> recipients, bool pm);
 
 /** creates an PLAYER_CHAT message containing a chat string from \a sender at \a timestamp to be displayed in chat.
     This message should only be sent by the server.*/
-FO_COMMON_API Message ServerPlayerChatMessage(int sender,
-                                              const boost::posix_time::ptime& timestamp,
-                                              const std::string& text);
+FO_COMMON_API Message ServerPlayerChatMessage(int sender, const boost::posix_time::ptime& timestamp,
+                                              const std::string& text, bool pm = false);
 
 /** creates a START_MP_GAME used to finalize the multiplayer lobby setup.*/
 FO_COMMON_API Message StartMPGameMessage();
@@ -364,6 +364,12 @@ FO_COMMON_API Message SetAuthorizationRolesMessage(const Networking::AuthRoles&
 /** creates a ELIMINATE_SELF message to resign from the game. */
 FO_COMMON_API Message EliminateSelfMessage();
 
+/** creates a UNREADY message to revoke ready state of turn orders or acknowledge it */
+FO_COMMON_API Message UnreadyMessage();
+
+/** creates a PLAYER_INFO message to notify player about changes in the player list. */
+FO_COMMON_API Message PlayerInfoMessage(const std::map<int, PlayerInfo>& players);
+
 ////////////////////////////////////////////////
 // Message data extractors
 ////////////////////////////////////////////////
@@ -377,12 +383,11 @@ FO_COMMON_API void ExtractLobbyUpdateMessageData(const Message& msg, Multiplayer
 
 FO_COMMON_API void ExtractChatHistoryMessage(const Message& msg, std::vector<ChatHistoryEntity>& chat_history);
 
-FO_COMMON_API void ExtractPlayerChatMessageData(const Message& msg, int& receiver, std::string& data);
+FO_COMMON_API void ExtractPlayerChatMessageData(const Message& msg, std::set<int>& recipients, std::string& data, bool& pm);
 
 FO_COMMON_API void ExtractServerPlayerChatMessageData(const Message& msg,
-                                                      int& sender,
-                                                      boost::posix_time::ptime& timestamp,
-                                                      std::string& data);
+                                                      int& sender, boost::posix_time::ptime& timestamp,
+                                                      std::string& data, bool& pm);
 
 FO_COMMON_API void ExtractGameStartMessageData(const Message& msg, bool& single_player_game, int& empire_id,
                                                int& current_turn, EmpireManager& empires, Universe& universe,
@@ -401,7 +406,14 @@ FO_COMMON_API void ExtractJoinGameMessageData(const Message& msg, std::string& p
 FO_COMMON_API void ExtractJoinAckMessageData(const Message& msg, int& player_id,
                                              boost::uuids::uuid& cookie);
 
-FO_COMMON_API void ExtractTurnOrdersMessageData(const Message& msg, OrderSet& orders);
+FO_COMMON_API void ExtractTurnOrdersMessageData(const Message& msg,
+                                                OrderSet& orders,
+                                                bool& ui_data_available,
+                                                SaveGameUIData& ui_data,
+                                                bool& save_state_string_available,
+                                                std::string& save_state_string);
+
+FO_COMMON_API void ExtractTurnPartialOrdersMessageData(const Message& msg, OrderSet& added, std::set<int>& deleted);
 
 FO_COMMON_API void ExtractTurnUpdateMessageData(const Message& msg, int empire_id, int& current_turn, EmpireManager& empires,
                                                 Universe& universe, SpeciesManager& species, CombatLogManager& combat_logs,
@@ -409,14 +421,11 @@ FO_COMMON_API void ExtractTurnUpdateMessageData(const Message& msg, int empire_i
 
 FO_COMMON_API void ExtractTurnPartialUpdateMessageData(const Message& msg, int empire_id, Universe& universe);
 
-FO_COMMON_API void ExtractClientSaveDataMessageData(const Message& msg, OrderSet& orders,
-                                                    bool& ui_data_available, SaveGameUIData& ui_data,
-                                                    bool& save_state_string_available,
-                                                    std::string& save_state_string);
-
 FO_COMMON_API void ExtractTurnProgressMessageData(const Message& msg, Message::TurnProgressPhase& phase_id);
 
-FO_COMMON_API void ExtractPlayerStatusMessageData(const Message& msg, int& about_player_id, Message::PlayerStatus& status);
+FO_COMMON_API void ExtractPlayerStatusMessageData(const Message& msg,
+                                                  Message::PlayerStatus& status,
+                                                  int& about_empire_id);
 
 FO_COMMON_API void ExtractHostSPGameMessageData(const Message& msg, SinglePlayerSetupData& setup_data, std::string& client_version_string);
 
@@ -448,4 +457,6 @@ FO_COMMON_API void ExtractAuthResponseMessageData(const Message& msg, std::strin
 
 FO_COMMON_API void ExtractSetAuthorizationRolesMessage(const Message &msg, Networking::AuthRoles& roles);
 
+FO_COMMON_API void ExtractPlayerInfoMessageData(const Message &msg, std::map<int, PlayerInfo>& players);
+
 #endif // _Message_h_
