@@ -6,12 +6,12 @@
 #include "ValueRefParser.h"
 #include "CommonParamsParser.h"
 
-#include "../universe/Building.h"
+#include "../universe/BuildingType.h"
 #include "../universe/Enums.h"
+#include "../universe/Condition.h"
 #include "../universe/ValueRef.h"
+#include "../util/Directories.h"
 
-//TODO: replace with std::make_unique when transitioning to C++14
-#include <boost/smart_ptr/make_unique.hpp>
 
 #define DEBUG_PARSERS 0
 
@@ -34,7 +34,7 @@ namespace {
                          const std::string& icon,
                          bool& pass)
     {
-        auto building_type = boost::make_unique<BuildingType>(
+        auto building_type = std::make_unique<BuildingType>(
             name, description, *common_params.OpenEnvelope(pass), capture_result, icon);
 
         building_types.insert(std::make_pair(building_type->Name(), std::move(building_type)));
@@ -48,7 +48,8 @@ namespace {
     struct grammar : public parse::detail::grammar<start_rule_signature> {
         grammar(const parse::lexer& tok,
                 const std::string& filename,
-                const parse::text_iterator& first, const parse::text_iterator& last) :
+                const parse::text_iterator& first,
+                const parse::text_iterator& last) :
             grammar::base_type(start),
             condition_parser(tok, label),
             string_grammar(tok, label, condition_parser),
@@ -104,15 +105,15 @@ namespace {
 
         using start_rule = parse::detail::rule<start_rule_signature>;
 
-        parse::detail::Labeller label;
-        const parse::conditions_parser_grammar condition_parser;
-        const parse::string_parser_grammar string_grammar;
-        parse::detail::tags_grammar tags_parser;
-        parse::detail::common_params_rules common_rules;
-        parse::capture_result_enum_grammar capture_result_enum;
-        parse::detail::rule<CaptureResult ()> capture;
-        building_type_rule          building_type;
-        start_rule                  start;
+        parse::detail::Labeller                 label;
+        const parse::conditions_parser_grammar  condition_parser;
+        const parse::string_parser_grammar      string_grammar;
+        parse::detail::tags_grammar             tags_parser;
+        parse::detail::common_params_rules      common_rules;
+        parse::capture_result_enum_grammar      capture_result_enum;
+        parse::detail::rule<CaptureResult ()>   capture;
+        building_type_rule                      building_type;
+        start_rule                              start;
     };
 }
 
@@ -120,9 +121,9 @@ namespace parse {
     start_rule_payload buildings(const boost::filesystem::path& path) {
         const lexer lexer;
         start_rule_payload building_types;
-        for (const boost::filesystem::path& file : ListScripts(path)) {
+
+        for (const auto& file : ListDir(path, IsFOCScript))
             /*auto success =*/ detail::parse_file<grammar, start_rule_payload>(lexer, file, building_types);
-        }
 
         return building_types;
     }
