@@ -1,8 +1,8 @@
 #include "ConditionParser1.h"
 
-#include "../universe/Condition.h"
-#include "../universe/ValueRef.h"
+#include "../universe/Conditions.h"
 #include "../universe/Enums.h"
+#include "../universe/ValueRef.h"
 
 #include <boost/spirit/include/phoenix.hpp>
 
@@ -144,6 +144,11 @@ namespace parse { namespace detail {
             [ _val = construct_movable_(new_<Condition::Not>(deconstruct_movable_(_1, _pass))) ]
             ;
 
+        ordered_alternatives_of
+            = ( omit_[tok.OrderedAlternativesOf_] > '[' > +condition_parser > lit(']'))
+            [ _val = construct_movable_(new_<Condition::OrderedAlternativesOf>(deconstruct_movable_vector_(_1, _pass))) ]
+            ;
+
         described
             = ( omit_[tok.Described_]
                 > label(tok.Description_) > tok.string
@@ -168,6 +173,7 @@ namespace parse { namespace detail {
             |   and_
             |   or_
             |   not_
+            |   ordered_alternatives_of
             |   described
             ;
 
@@ -187,6 +193,7 @@ namespace parse { namespace detail {
         and_.name("And");
         or_.name("Or");
         not_.name("Not");
+        ordered_alternatives_of.name("OrderedAlternativesOf");
         described.name("Described");
 
 #if DEBUG_CONDITION_PARSERS
@@ -204,6 +211,7 @@ namespace parse { namespace detail {
         debug(and_);
         debug(or_);
         debug(not_);
+        debug(ordered_alternatives_of);
         debug(described);
 #endif
     }
