@@ -1,8 +1,8 @@
 #include "ConditionParser2.h"
 
-#include "../universe/Condition.h"
-#include "../universe/ValueRef.h"
+#include "../universe/Conditions.h"
 #include "../universe/Enums.h"
+#include "../universe/ValueRef.h"
 
 #include <boost/spirit/include/phoenix.hpp>
 
@@ -46,7 +46,7 @@ namespace parse { namespace detail {
             ;
 
         enqueued
-            %=   enqueued1
+            %=  enqueued1
             |   enqueued3
             |   enqueued2 /* enqueued2 must come after enqueued3 or enqueued2 would always dominate because of its optional components*/
             |   enqueued4
@@ -54,7 +54,7 @@ namespace parse { namespace detail {
 
         enqueued1
             =   (   (omit_[tok.Enqueued_]
-                     >>  label(tok.Type_)   >>   omit_[tok.Building_])
+                    >>  label(tok.Type_)   >>   omit_[tok.Building_])
                     > -(label(tok.Name_)   >    string_grammar)
                     > -(label(tok.Empire_) >    int_rules.expr)
                     > -(label(tok.Low_)    >    castable_int_rules.flexible_int)
@@ -69,7 +69,7 @@ namespace parse { namespace detail {
 
         enqueued2
             =   (   (omit_[tok.Enqueued_]
-                     >>  label(tok.Type_)   >>   omit_[tok.Ship_])
+                    >>  label(tok.Type_)   >>   omit_[tok.Ship_])
                     > -(label(tok.Design_) >    int_rules.expr)
                     > -(label(tok.Empire_) >    int_rules.expr)
                     > -(label(tok.Low_)    >    castable_int_rules.flexible_int)
@@ -83,8 +83,8 @@ namespace parse { namespace detail {
 
         enqueued3
             =   (   (omit_[tok.Enqueued_]
-                     >>  label(tok.Type_)   >>   omit_[tok.Ship_]
-                     >>  label(tok.Name_)   ) >    string_grammar
+                    >>  label(tok.Type_)   >>   omit_[tok.Ship_]
+                    >>  label(tok.Name_) ) >    string_grammar
                     > -(label(tok.Empire_) >    int_rules.expr)
                     > -(label(tok.Low_)    >    castable_int_rules.flexible_int)
                     > -(label(tok.High_)   >    castable_int_rules.flexible_int)
@@ -113,7 +113,7 @@ namespace parse { namespace detail {
             =   (   omit_[tok.DesignHasPart_]
                     > -(label(tok.Low_)   > castable_int_rules.flexible_int)
                     > -(label(tok.High_)  > castable_int_rules.flexible_int)
-                   >   label(tok.Name_)  > string_grammar
+                    >   label(tok.Name_)  > string_grammar
                 ) [ _val = construct_movable_(new_<Condition::DesignHasPart>(
                     deconstruct_movable_(_3, _pass),
                     deconstruct_movable_(_1, _pass),
@@ -124,7 +124,7 @@ namespace parse { namespace detail {
             =   (   omit_[tok.DesignHasPartClass_]
                     > -(label(tok.Low_)   > castable_int_rules.flexible_int)
                     > -(label(tok.High_)  > castable_int_rules.flexible_int)
-                   >   label(tok.Class_)  > ship_part_class_enum
+                    >   label(tok.Class_) > ship_part_class_enum
                 ) [ _val = construct_movable_(new_<Condition::DesignHasPartClass>(
                     _3,
                     deconstruct_movable_(_1, _pass),
@@ -134,7 +134,13 @@ namespace parse { namespace detail {
         in_system
             =   (   omit_[tok.InSystem_]
                     >  -(label(tok.ID_)  > int_rules.expr)
-                ) [ _val = construct_movable_(new_<Condition::InSystem>(deconstruct_movable_(_1, _pass))) ]
+                ) [ _val = construct_movable_(new_<Condition::InOrIsSystem>(deconstruct_movable_(_1, _pass))) ]
+            ;
+
+        on_planet
+            =   (   omit_[tok.OnPlanet_]
+                    >  -(label(tok.ID_)  > int_rules.expr)
+                ) [ _val = construct_movable_(new_<Condition::OnPlanet>(deconstruct_movable_(_1, _pass))) ]
             ;
 
         start
@@ -143,6 +149,7 @@ namespace parse { namespace detail {
             |    design_has_part
             |    design_has_part_class
             |    in_system
+            |    on_planet
             ;
 
         has_special_since_turn.name("HasSpecialSinceTurn");
@@ -150,6 +157,7 @@ namespace parse { namespace detail {
         design_has_part.name("DesignHasPart");
         design_has_part_class.name("DesignHasPartClass");
         in_system.name("InSystem");
+        on_planet.name("OnPlanet");
 
 #if DEBUG_CONDITION_PARSERS
         debug(has_special_since_turn);
@@ -157,6 +165,7 @@ namespace parse { namespace detail {
         debug(design_has_part);
         debug(design_has_part_class);
         debug(in_system);
+        debug(on_planet);
 #endif
     }
 
