@@ -1,5 +1,6 @@
 #include "ValueRefParser.h"
 
+#include "Parse.h"
 #include "MovableEnvelope.h"
 #include "../universe/ValueRef.h"
 
@@ -145,3 +146,20 @@ parse::double_parser_rules::double_parser_rules(
     debug(double_complex_variable);
 #endif
 }
+
+namespace parse {
+    bool double_free_variable(std::string& text) {
+        const lexer tok;
+        boost::spirit::qi::in_state_type in_state;
+        parse::detail::simple_double_parser_rules simple_double_rules(tok);
+
+        text_iterator first = text.begin();
+        text_iterator last = text.end();
+        token_iterator it = tok.begin(first, last);
+
+        bool success = boost::spirit::qi::phrase_parse(
+            it, tok.end(), simple_double_rules.free_variable_name, in_state("WS")[tok.self]);
+
+        return success;
+    }
+}
