@@ -1,7 +1,8 @@
 #include "EffectParser2.h"
 
 #include "ValueRefParser.h"
-#include "../universe/Effect.h"
+#include "../universe/Condition.h"
+#include "../universe/Effects.h"
 #include "../universe/Enums.h"
 #include "../universe/ValueRef.h"
 
@@ -54,7 +55,6 @@ namespace parse { namespace detail {
                 _a,
                 deconstruct_movable_(_b, _pass),
                 _c)) ]
-
             ;
 
         set_ship_part_meter
