@@ -4,8 +4,8 @@
 #include "ValueRefParser.h"
 #include "ConditionParserImpl.h"
 #include "MovableEnvelope.h"
-
 #include "../universe/ValueRef.h"
+#include "../util/Directories.h"
 
 #include <boost/spirit/include/phoenix.hpp>
 
@@ -13,15 +13,15 @@
 #define DEBUG_PARSERS 0
 #if DEBUG_PARSERS
 namespace std {
-    inline ostream& operator<<(ostream& os, const std::map<std::string, std::unique_ptr<ValueRef::ValueRefBase<double>>>&)
+    inline ostream& operator<<(ostream& os, const std::map<std::string, std::unique_ptr<ValueRef::ValueRef<double>>>&)
     { return os; }
-    inline ostream& operator<<(ostream& os, const std::map<std::string, parse::detail::MovableEnvelope<ValueRef::ValueRefBase<double>>>&)
+    inline ostream& operator<<(ostream& os, const std::map<std::string, parse::detail::MovableEnvelope<ValueRef::ValueRef<double>>>&)
     { return os; }
 }
 #endif
 
 namespace {
-    using start_rule_payload = std::map<std::string, std::unique_ptr<ValueRef::ValueRefBase<double>>>;
+    using start_rule_payload = std::map<std::string, std::unique_ptr<ValueRef::ValueRef<double>>>;
     using start_rule_signature = void(start_rule_payload&);
 
     struct grammar : public parse::detail::grammar<
@@ -62,7 +62,7 @@ namespace {
 
             start
                 =   (+stat [ insert(_a, _1) ])
-                [ _r1 = phoenix::bind(&parse::detail::OpenEnvelopes<std::string, ValueRef::ValueRefBase<double>>, _a, _pass) ]
+                [ _r1 = phoenix::bind(&parse::detail::OpenEnvelopes<std::string, ValueRef::ValueRef<double>>, _a, _pass) ]
                 ;
 
             stat.name("Double Statistic ValueRef");
@@ -97,7 +97,7 @@ namespace parse {
         const lexer lexer;
         start_rule_payload all_stats;
 
-        for (const boost::filesystem::path& file : ListScripts(path)) {
+        for (const auto& file : ListDir(path, IsFOCScript)) {
             start_rule_payload stats_;
             if (/*auto success =*/ detail::parse_file<grammar, start_rule_payload>(lexer, file, stats_)) {
                 for (auto&& stat : stats_) {
