@@ -3,6 +3,7 @@
 #include "ParseImpl.h"
 
 #include "../universe/Encyclopedia.h"
+#include "../util/Directories.h"
 
 #include <boost/spirit/include/phoenix.hpp>
 
@@ -72,7 +73,7 @@ namespace {
             qi::on_error<qi::fail>(start, parse::report_error(filename, first, last, _1, _2, _3, _4));
         }
 
-        using  strings_rule = parse::detail::rule<void (ArticleMap&)>;
+        using strings_rule = parse::detail::rule<void (ArticleMap&)>;
 
         using start_rule = parse::detail::rule<start_rule_signature>;
 
@@ -85,12 +86,10 @@ namespace {
 namespace parse {
     ArticleMap encyclopedia_articles(const boost::filesystem::path& path) {
         const lexer lexer;
-        std::vector<boost::filesystem::path> file_list = ListScripts(path);
-
         ArticleMap articles;
-        for (const boost::filesystem::path& file : file_list) {
+
+        for (const auto& file : ListDir(path, IsFOCScript))
             /*auto success =*/ detail::parse_file<grammar, ArticleMap>(lexer, file, articles);
-        }
 
         return articles;
     }
