@@ -3,12 +3,11 @@
 #include "ParseImpl.h"
 #include "MovableEnvelope.h"
 
-#include "../universe/UniverseGenerator.h"
+#include "../universe/Condition.h"
+#include "../universe/FleetPlan.h"
 #include "../util/Directories.h"
 
 #include <boost/spirit/include/phoenix.hpp>
-//TODO: replace with std::make_unique when transitioning to C++14
-#include <boost/smart_ptr/make_unique.hpp>
 
 #define DEBUG_PARSERS 0
 
@@ -26,7 +25,7 @@ namespace {
         bool lookup_names)
     {
         plans.push_back(
-            boost::make_unique<FleetPlan>(
+            std::make_unique<FleetPlan>(
                 fleet_name, ship_design_names, lookup_names));
     }
     BOOST_PHOENIX_ADAPT_FUNCTION(void, insert_fleet_plan_, insert_fleet_plan, 4)
@@ -56,9 +55,8 @@ namespace {
 
             fleet_plan
                 =  ( omit_[tok.Fleet_]
-                >    label(tok.Name_) > tok.string
-                >    label(tok.Ships_)
-                >    one_or_more_string_tokens )
+                >    label(tok.Name_)   >   tok.string
+                >    label(tok.Ships_)  >   one_or_more_string_tokens )
                 [ insert_fleet_plan_(_r1, _1, _2, phoenix::val(true)) ]
                 ;
 
