@@ -1,5 +1,6 @@
 #include "ValueRefParser.h"
 
+#include "Parse.h"
 #include "MovableEnvelope.h"
 #include "../universe/ValueRef.h"
 
@@ -32,6 +33,7 @@ parse::detail::simple_int_parser_rules::simple_int_parser_rules(const parse::lex
         |   tok.FleetID_
         |   tok.PlanetID_
         |   tok.SystemID_
+        |   tok.ContainerID_
         |   tok.FinalDestinationID_
         |   tok.NextSystemID_
         |   tok.NearestSystemID_
@@ -41,16 +43,19 @@ parse::detail::simple_int_parser_rules::simple_int_parser_rules(const parse::lex
         |   tok.LastTurnActiveInBattle_
         |   tok.LastTurnAttackedByShip_
         |   tok.LastTurnBattleHere_
+        |   tok.LastTurnColonized_
         |   tok.LastTurnConquered_
         |   tok.LastTurnResupplied_
         |   tok.Orbit_
         |   tok.SpeciesID_
         |   tok.TurnsSinceFocusChange_
         |   tok.ETA_
+        |   tok.LaunchedFrom_
         ;
 
     free_variable_name
-        =   tok.CurrentTurn_
+        =   tok.CombatBout_
+        |   tok.CurrentTurn_
         |   tok.GalaxyAge_
         |   tok.GalaxyMaxAIAggression_
         |   tok.GalaxyMonsterFrequency_
@@ -60,6 +65,7 @@ parse::detail::simple_int_parser_rules::simple_int_parser_rules(const parse::lex
         |   tok.GalaxySize_
         |   tok.GalaxySpecialFrequency_
         |   tok.GalaxyStarlaneFrequency_
+        |   tok.UsedInDesignID_
         ;
 
     constant
@@ -128,3 +134,20 @@ parse::int_arithmetic_rules::int_arithmetic_rules(
         |   int_complex_grammar
         ;
 }
+
+namespace parse {
+    bool int_free_variable(std::string& text) {
+        const lexer tok;
+        boost::spirit::qi::in_state_type in_state;
+        parse::detail::simple_int_parser_rules simple_int_rules(tok);
+
+        text_iterator first = text.begin();
+        text_iterator last = text.end();
+        token_iterator it = tok.begin(first, last);
+
+        bool success = boost::spirit::qi::phrase_parse(
+            it, tok.end(), simple_int_rules.free_variable_name, in_state("WS")[tok.self]);
+
+        return success;
+    }
+}
