@@ -10,6 +10,8 @@
 #include <boost/filesystem/path.hpp>
 #include <boost/uuid/uuid.hpp>
 
+#include "../util/GameRules.h"
+
 #include <map>
 #include <set>
 #include <vector>
@@ -24,7 +26,6 @@ struct ParsedShipDesign;
 class Special;
 class Species;
 struct EncyclopediaArticle;
-class GameRules;
 struct UnlockableItem;
 
 namespace ValueRef {
@@ -69,7 +70,7 @@ namespace parse {
     FO_PARSE_API std::vector<std::unique_ptr<MonsterFleetPlan>> monster_fleet_plans(const boost::filesystem::path& path);
     FO_PARSE_API std::map<std::string, std::unique_ptr<ValueRef::ValueRef<double>>> statistics(const boost::filesystem::path& path);
     FO_PARSE_API std::map<std::string, std::vector<EncyclopediaArticle>> encyclopedia_articles(const boost::filesystem::path& path);
-    FO_PARSE_API GameRules game_rules(const boost::filesystem::path& path);
+    FO_PARSE_API GameRules::GameRulesTypeMap game_rules(const boost::filesystem::path& path);
     FO_PARSE_API bool read_file(const boost::filesystem::path& path, std::string& file_contents);
 
     FO_PARSE_API void file_substitution(std::string& text, const boost::filesystem::path& file_search_path);
