@@ -52,14 +52,18 @@
     (Capture)                                   \
     (CaptureResult)                             \
     (Category)                                  \
+    (Ceil)                                      \
     (Class)                                     \
     (ClockwiseNextPlanetType)                   \
     (Colony)                                    \
     (Colour)                                    \
+    (CombatBout)                                \
+    (CombatTargets)                             \
     (Condition)                                 \
     (Construction)                              \
     (Consumption)                               \
     (ContainedBy)                               \
+    (ContainerID)                               \
     (Contains)                                  \
     (Core)                                      \
     (Cos)                                       \
@@ -102,10 +106,15 @@
     (EffectsGroups)                             \
     (Else)                                      \
     (Empire)                                    \
+    (EmpireHasBuildingAvailable)                \
+    (EmpireHasShipDesignAvailable)              \
+    (EmpireHasShipPartAvailable)                \
+    (EmpireHasTechResearched)                   \
     (EmpireMeter)                               \
     (EmpireMeterValue)                          \
     (EmpireObjectVisibility)                    \
     (EmpireShipsDestroyed)                      \
+    (EmpireStockpile)                           \
     (Enabled)                                   \
     (Endpoint)                                  \
     (EnemyOf)                                   \
@@ -121,6 +130,7 @@
 #define TOKEN_SEQ_4                             \
     (Field)                                     \
     (FieldType)                                 \
+    (Fighter)                                   \
     (FighterBay)                                \
     (FighterHangar)                             \
     (FighterWeapon)                             \
@@ -128,6 +138,7 @@
     (Fleet)                                     \
     (FleetID)                                   \
     (FleetSupplyableByEmpire)                   \
+    (Floor)                                     \
     (Foci)                                      \
     (Focus)                                     \
     (FocusType)                                 \
@@ -171,7 +182,6 @@
     (HullSpeed)                                 \
     (HullStealth)                               \
     (HullStructure)                             \
-    (HullType)                                  \
     (Human)                                     \
     (Icon)                                      \
     (ID)                                        \
@@ -185,9 +195,7 @@
     (Invisible)                                 \
     (Item)                                      \
     (Jumps)                                     \
-    (JumpsBetween)                              \
-    (Keymap)                                    \
-    (Keys)
+    (JumpsBetween)
 
 #define TOKEN_SEQ_6                             \
     (Label)                                     \
@@ -195,8 +203,10 @@
     (LastTurnActiveInBattle)                    \
     (LastTurnAttackedByShip)                    \
     (LastTurnBattleHere)                        \
+    (LastTurnColonized)                         \
     (LastTurnConquered)                         \
     (LastTurnResupplied)                        \
+    (LaunchedFrom)                              \
     (LeastHappySpecies)                         \
     (LocalCandidate)                            \
     (Location)                                  \
@@ -211,6 +221,7 @@
     (MaxDefense)                                \
     (MaxFuel)                                   \
     (MaximumNumberOf)                           \
+    (MaxSecondaryStat)                          \
     (MaxShield)                                 \
     (MaxStockpile)                              \
     (MaxStructure)                              \
@@ -252,6 +263,10 @@
     (NextTurnPopGrowth)                         \
     (NextYoungerStarType)                       \
     (NoDefaultCapacityEffect)                   \
+    (NoDefaultFuelEffect)                       \
+    (NoDefaultSpeedEffect)                      \
+    (NoDefaultStealthEffect)                    \
+    (NoDefaultStructureEffect)                  \
     (None)                                      \
     (NoOp)                                      \
     (NoStar)                                    \
@@ -269,6 +284,7 @@
     (Off)                                       \
     (On)                                        \
     (OneOf)                                     \
+    (OnPlanet)                                  \
     (Opinion)                                   \
     (Or)                                        \
     (Orange)                                    \
@@ -280,7 +296,6 @@
     (Owner)                                     \
     (OwnerHasShipPartAvailable)                 \
     (OwnerHasTech)                              \
-    (OwnerTradeStockpile)                       \
     (Parameters)                                \
     (Part)                                      \
     (PartCapacity)                              \
@@ -294,8 +309,8 @@
     (Parts)                                     \
     (PartOfClassInShipDesign)                   \
     (PartsInShipDesign)                         \
-    (PartType)                                  \
     (Passive)                                   \
+    (PeaceWith)                                 \
     (Planet)                                    \
     (Planetbound)                               \
     (PlanetEnvironment)                         \
@@ -351,7 +366,9 @@
     (Retain)                                    \
     (RMS)                                       \
     (RootCandidate)                             \
-    (Scope)
+    (Round)                                     \
+    (Scope)                                     \
+    (SecondaryStat)
 
 #define TOKEN_SEQ_11                            \
     (SetAggressive)                             \
@@ -415,8 +432,10 @@
 #define TOKEN_SEQ_13                            \
     (Shield)                                    \
     (ShipDesign)                                \
+    (ShipDesignCost)                            \
     (ShipDesignOrdering)                        \
     (ShipDesignsDestroyed)                      \
+    (ShipDesignsInProduction)                   \
     (ShipDesignsLost)                           \
     (ShipDesignsOwned)                          \
     (ShipDesignsProduced)                       \
@@ -513,6 +532,7 @@
     (TopPriorityEnqueuedTech)                   \
     (TopPriorityResearchableTech)               \
     (TopPriorityTransferrableTech)              \
+    (OrderedAlternativesOf)                     \
     (Toxic)                                     \
     (Trade)
 
@@ -532,6 +552,7 @@
     (Unproducible)                              \
     (Unresearchable)                            \
     (UpgradeVisibility)                         \
+    (UsedInDesignID)                            \
     (UserString)                                \
     (UUID)                                      \
     (Value)                                     \
