@@ -3,12 +3,6 @@
 #include "ServerApp.h"
 #include "../Empire/Empire.h"
 #include "../Empire/EmpireManager.h"
-#include "../universe/Building.h"
-#include "../universe/Fleet.h"
-#include "../universe/Ship.h"
-#include "../universe/Planet.h"
-#include "../universe/ShipDesign.h"
-#include "../universe/System.h"
 #include "../universe/Species.h"
 #include "../util/Directories.h"
 #include "../util/base64_filter.h"
@@ -42,13 +36,6 @@
 namespace fs = boost::filesystem;
 
 namespace {
-    std::map<int, SaveGameEmpireData> CompileSaveGameEmpireData(const EmpireManager& empire_manager) {
-        std::map<int, SaveGameEmpireData> retval;
-        for (const auto& entry : Empires())
-            retval[entry.first] = SaveGameEmpireData(entry.first, entry.second->Name(), entry.second->PlayerName(), entry.second->Color());
-        return retval;
-    }
-
     void CompileSaveGamePreviewData(const ServerSaveGameData& server_save_game_data,
                                     const std::vector<PlayerSaveGameData>& player_save_game_data,
                                     const std::map<int, SaveGameEmpireData>& empire_save_game_data,
@@ -59,6 +46,8 @@ namespace {
         preview.number_of_empires = empire_save_game_data.size();
         preview.save_time = boost::posix_time::to_iso_extended_string(boost::posix_time::second_clock::local_time());
 
+        DebugLogger() << "CompileSaveGamePreviewData(...) player_save_game_data size: " << player_save_game_data.size();
+
         if (player_save_game_data.empty()) {
             preview.main_player_name = UserString("NO_PLAYERS");
             preview.main_player_empire_name = UserString("NO_EMPIRE");
@@ -101,13 +90,20 @@ namespace {
     const std::string BINARY_MARKER("binary");
 }
 
+std::map<int, SaveGameEmpireData> CompileSaveGameEmpireData() {
+    std::map<int, SaveGameEmpireData> retval;
+    for (const auto& entry : Empires())
+        retval[entry.first] = SaveGameEmpireData(entry.first, entry.second->Name(), entry.second->PlayerName(), entry.second->Color(), entry.second->IsAuthenticated(), entry.second->Eliminated(), entry.second->Won());
+    return retval;
+}
+
 int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_game_data,
              const std::vector<PlayerSaveGameData>& player_save_game_data, const Universe& universe,
              const EmpireManager& empire_manager, const SpeciesManager& species_manager,
-             const CombatLogManager& combat_log_manager, const GalaxySetupData& galaxy_setup_data,
+             const CombatLogManager& combat_log_manager, GalaxySetupData galaxy_setup_data,
              bool multiplayer)
 {
-    ScopedTimer timer("SaveGame: " + filename, true);
+    SectionedScopedTimer timer("SaveGame");
 
     bool use_binary = GetOptionsDB().Get<bool>("save.format.binary.enabled");
     bool use_zlib_for_zml = GetOptionsDB().Get<bool>("save.format.xml.zlib.enabled");
@@ -115,7 +111,8 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
     GetUniverse().EncodingEmpire() = ALL_EMPIRES;
 
     DebugLogger() << "Compiling save empire and preview data";
-    std::map<int, SaveGameEmpireData> empire_save_game_data = CompileSaveGameEmpireData(empire_manager);
+    timer.EnterSection("compiling data");
+    std::map<int, SaveGameEmpireData> empire_save_game_data = CompileSaveGameEmpireData();
     SaveGamePreviewData save_preview_data;
     CompileSaveGamePreviewData(server_save_game_data, player_save_game_data,
                                empire_save_game_data, save_preview_data);
@@ -132,6 +129,7 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
 
 
     try {
+        timer.EnterSection("path management");
         fs::path path = FilenameToPath(filename);
 
         // A relative path should be relative to the save directory.
@@ -158,6 +156,8 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
                 }
             }
         }
+        timer.EnterSection("");
+
 
         // set up output archive / stream for saving
         fs::ofstream ofs(path, std::ios_base::binary);
@@ -166,11 +166,13 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
         pos_before_writing = ofs.tellp();
 
         bool save_completed_as_xml = false;
+        galaxy_setup_data.m_encoding_empire = ALL_EMPIRES;
 
         if (!use_binary) {
             if (use_zlib_for_zml) {
                 // Attempt compressed XML serialization
                 try {
+                    timer.EnterSection("xml prep / allocation");
                     // Two-tier serialization:
                     // main archive is uncompressed serialized header data first
                     // then contains a string for compressed second archive
@@ -198,19 +200,27 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
                     InsertDevice serial_inserter(serial_str);
                     boost::iostreams::stream<InsertDevice> s_sink(serial_inserter);
 
+                    timer.EnterSection("");
                     {
                         // create archive with (preallocated) buffer...
                         freeorion_xml_oarchive xoa(s_sink);
                         // serialize main gamestate info
+                        timer.EnterSection("player data to xml");
                         xoa << BOOST_SERIALIZATION_NVP(player_save_game_data);
+                        timer.EnterSection("empires to xml");
                         xoa << BOOST_SERIALIZATION_NVP(empire_manager);
+                        timer.EnterSection("species to xml");
                         xoa << BOOST_SERIALIZATION_NVP(species_manager);
+                        timer.EnterSection("combat logs to xml");
                         xoa << BOOST_SERIALIZATION_NVP(combat_log_manager);
+                        timer.EnterSection("universe to xml");
                         Serialize(xoa, universe);
+                        timer.EnterSection("");
                     }
 
                     s_sink.flush();
 
+                    timer.EnterSection("compression");
                     // wrap gamestate string in iostream::stream to extract serialized data
                     typedef boost::iostreams::basic_array_source<char> SourceDevice;
                     SourceDevice source(serial_str.data(), serial_str.size());
@@ -231,6 +241,7 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
                     save_preview_data.uncompressed_text_size = serial_str.size();
                     save_preview_data.compressed_text_size = compressed_str.size();
 
+                    timer.EnterSection("headers to xml");
                     // write to save file: uncompressed header serialized data, with compressed main archive string at end...
                     freeorion_xml_oarchive xoa2(ofs);
                     // serialize uncompressed save header info
@@ -242,6 +253,7 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
                     // append compressed gamestate info
                     xoa2 << BOOST_SERIALIZATION_NVP(compressed_str);
 
+                    timer.EnterSection("");
                     save_completed_as_xml = true;
                 } catch (...) {
                     save_completed_as_xml = false;  // redundant, but here for clarity
@@ -252,6 +264,7 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
                     save_preview_data.SetBinary(false);
                     save_preview_data.save_format_marker = XML_DIRECT_MARKER;
 
+                    timer.EnterSection("headers to xml");
                     // create archive with (preallocated) buffer...
                     freeorion_xml_oarchive xoa(ofs);
                     xoa << BOOST_SERIALIZATION_NVP(save_preview_data);
@@ -260,12 +273,14 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
                     xoa << BOOST_SERIALIZATION_NVP(player_save_header_data);
                     xoa << BOOST_SERIALIZATION_NVP(empire_save_game_data);
 
+                    timer.EnterSection("gamestate to xml");
                     xoa << BOOST_SERIALIZATION_NVP(player_save_game_data);
                     xoa << BOOST_SERIALIZATION_NVP(empire_manager);
                     xoa << BOOST_SERIALIZATION_NVP(species_manager);
                     xoa << BOOST_SERIALIZATION_NVP(combat_log_manager);
                     Serialize(xoa, universe);
 
+                    timer.EnterSection("");
                     save_completed_as_xml = true;
                 } catch (...) {
                     save_completed_as_xml = false;  // redundant, but here for clarity
@@ -278,6 +293,7 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
             save_preview_data.SetBinary(true);
             save_preview_data.save_format_marker = BINARY_MARKER;
 
+            timer.EnterSection("headers to binary");
             freeorion_bin_oarchive boa(ofs);
             boa << BOOST_SERIALIZATION_NVP(save_preview_data);
             boa << BOOST_SERIALIZATION_NVP(galaxy_setup_data);
@@ -285,12 +301,14 @@ int SaveGame(const std::string& filename, const ServerSaveGameData& server_save_
             boa << BOOST_SERIALIZATION_NVP(player_save_header_data);
             boa << BOOST_SERIALIZATION_NVP(empire_save_game_data);
 
+            timer.EnterSection("gamestate to binary");
             boa << BOOST_SERIALIZATION_NVP(player_save_game_data);
             boa << BOOST_SERIALIZATION_NVP(empire_manager);
             boa << BOOST_SERIALIZATION_NVP(species_manager);
             boa << BOOST_SERIALIZATION_NVP(combat_log_manager);
             Serialize(boa, universe);
 
+            timer.EnterSection("");
             DebugLogger() << "Done serializing";
         }
 
@@ -311,7 +329,7 @@ void LoadGame(const std::string& filename, ServerSaveGameData& server_save_game_
               EmpireManager& empire_manager, SpeciesManager& species_manager,
               CombatLogManager& combat_log_manager, GalaxySetupData& galaxy_setup_data)
 {
-    ScopedTimer timer("LoadGame: " + filename, true);
+    SectionedScopedTimer timer("LoadGame");
 
     // player notifications
     if (ServerApp* server = ServerApp::GetApp())
@@ -333,33 +351,40 @@ void LoadGame(const std::string& filename, ServerSaveGameData& server_save_game_
         if (!ifs)
             throw std::runtime_error(UNABLE_TO_OPEN_FILE);
 
-        try {
-            // first attempt binary deserialziation
+        std::string signature(5, '\0');
+        if (!ifs.read(&signature[0], 5))
+            throw std::runtime_error(UNABLE_TO_OPEN_FILE);
+        boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+
+        if (strncmp(signature.c_str(), "<?xml", 5)) {
+            // XML file format signature not found; try as binary
             freeorion_bin_iarchive ia(ifs);
             DebugLogger() << "Reading binary iarchive";
+            timer.EnterSection("binary headers");
             ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
             ia >> BOOST_SERIALIZATION_NVP(galaxy_setup_data);
             ia >> BOOST_SERIALIZATION_NVP(server_save_game_data);
             ia >> BOOST_SERIALIZATION_NVP(ignored_player_save_header_data);
             ia >> BOOST_SERIALIZATION_NVP(ignored_save_game_empire_data);
-
+            timer.EnterSection("binary player data");
             ia >> BOOST_SERIALIZATION_NVP(player_save_game_data);
+            timer.EnterSection("binary empires");
             ia >> BOOST_SERIALIZATION_NVP(empire_manager);
+            timer.EnterSection("binary species");
             ia >> BOOST_SERIALIZATION_NVP(species_manager);
+            timer.EnterSection("binary combat log");
             ia >> BOOST_SERIALIZATION_NVP(combat_log_manager);
+            timer.EnterSection("binary universe");
             Deserialize(ia, universe);
 
             DebugLogger() << "Done deserializing";
-        } catch (...) {
-            // if binary deserialization failed, try more-portable XML deserialization
-
-            // reset to start of stream (attempted binary serialization will have consumed some input...)
-            boost::iostreams::seek(ifs, 0, std::ios_base::beg);
-
+        } else {
             // create archive with (preallocated) buffer...
             freeorion_xml_iarchive xia(ifs);
+            DebugLogger() << "Reading XML iarchive";
             // read from save file: uncompressed header serialized data, with compressed main archive string at end...
             // deserialize uncompressed save header info
+            timer.EnterSection("xml headers");
             xia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
             xia >> BOOST_SERIALIZATION_NVP(galaxy_setup_data);
             xia >> BOOST_SERIALIZATION_NVP(server_save_game_data);
@@ -370,10 +395,15 @@ void LoadGame(const std::string& filename, ServerSaveGameData& server_save_game_
             if (ignored_save_preview_data.save_format_marker == XML_DIRECT_MARKER) {
                 // deserialize directly from file / disk to gamestate
 
+                timer.EnterSection("xml player data");
                 xia >> BOOST_SERIALIZATION_NVP(player_save_game_data);
+                timer.EnterSection("xml empires");
                 xia >> BOOST_SERIALIZATION_NVP(empire_manager);
+                timer.EnterSection("xml species");
                 xia >> BOOST_SERIALIZATION_NVP(species_manager);
+                timer.EnterSection("xml combat log");
                 xia >> BOOST_SERIALIZATION_NVP(combat_log_manager);
+                timer.EnterSection("xml universe");
                 Deserialize(xia, universe);
 
             } else {
@@ -381,6 +411,7 @@ void LoadGame(const std::string& filename, ServerSaveGameData& server_save_game_
                 if (BOOST_VERSION >= 106600 && ignored_save_preview_data.save_format_marker == XML_COMPRESSED_MARKER)
                     throw std::invalid_argument("Save Format Not Compatible with Boost Version " BOOST_LIB_VERSION);
 
+                timer.EnterSection("decompression");
                 // allocate buffers for compressed and deceompressed serialized gamestate
                 DebugLogger() << "Allocating buffers for XML deserialization...";
                 std::string serial_str, compressed_str;
@@ -389,13 +420,13 @@ void LoadGame(const std::string& filename, ServerSaveGameData& server_save_game_
                         DebugLogger() << "Based on header info for uncompressed state string, attempting to reserve: " << ignored_save_preview_data.uncompressed_text_size << " bytes";
                         serial_str.reserve(ignored_save_preview_data.uncompressed_text_size);
                     } else {
-                        serial_str.reserve(    std::pow(2.0, 29.0));
+                        serial_str.reserve(std::pow(2.0, 29.0));
                     }
                     if (ignored_save_preview_data.compressed_text_size > 0) {
                         DebugLogger() << "Based on header info for compressed state string, attempting to reserve: " << ignored_save_preview_data.compressed_text_size << " bytes";
                         compressed_str.reserve(ignored_save_preview_data.compressed_text_size);
                     } else {
-                        compressed_str.reserve(    std::pow(2.0, 26.0));
+                        compressed_str.reserve(std::pow(2.0, 26.0));
                     }
                 } catch (...) {
                     DebugLogger() << "Unable to preallocate full deserialization buffers. Attempting deserialization with dynamic buffer allocation.";
@@ -431,10 +462,15 @@ void LoadGame(const std::string& filename, ServerSaveGameData& server_save_game_
                 // create archive with (preallocated) buffer...
                 freeorion_xml_iarchive xia2(s_source);
                 // deserialize main gamestate info
+                timer.EnterSection("xml player data");
                 xia2 >> BOOST_SERIALIZATION_NVP(player_save_game_data);
+                timer.EnterSection("xml empires");
                 xia2 >> BOOST_SERIALIZATION_NVP(empire_manager);
+                timer.EnterSection("xml species");
                 xia2 >> BOOST_SERIALIZATION_NVP(species_manager);
+                timer.EnterSection("xml combat logs");
                 xia2 >> BOOST_SERIALIZATION_NVP(combat_log_manager);
+                timer.EnterSection("xml universe");
                 Deserialize(xia2, universe);
             }
         }
@@ -443,13 +479,13 @@ void LoadGame(const std::string& filename, ServerSaveGameData& server_save_game_
         ErrorLogger() << "LoadGame(...) failed!  Error: " << err.what();
         return;
     }
-    DebugLogger() << "LoadGame : Successfully loaded save file";
+    DebugLogger() << "LoadGame : Successfully loaded save file: " + filename;
 }
 
 void LoadGalaxySetupData(const std::string& filename, GalaxySetupData& galaxy_setup_data) {
     SaveGamePreviewData ignored_save_preview_data;
 
-    ScopedTimer timer("LoadGalaxySetupData: " + filename, true);
+    ScopedTimer timer("LoadGalaxySetupData");
 
     try {
         fs::path path = FilenameToPath(filename);
@@ -458,18 +494,21 @@ void LoadGalaxySetupData(const std::string& filename, GalaxySetupData& galaxy_se
         if (!ifs)
             throw std::runtime_error(UNABLE_TO_OPEN_FILE);
 
-        try {
-            // first attempt binary deserialziation
+        std::string signature(5, '\0');
+        if (!ifs.read(&signature[0], 5))
+            throw std::runtime_error(UNABLE_TO_OPEN_FILE);
+        boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+
+        if (strncmp(signature.c_str(), "<?xml", 5)) {
+            // XML file format signature not found; try as binary
+            DebugLogger() << "Attempting binary deserialization...";
             freeorion_bin_iarchive ia(ifs);
 
             ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
             ia >> BOOST_SERIALIZATION_NVP(galaxy_setup_data);
 
-        } catch(...) {
-            // if binary deserialization failed, try more-portable XML deserialization
-
-            // reset to start of stream (attempted binary serialization will have consumed some input...)
-            boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+        } else {
+            DebugLogger() << "Attempting XML deserialization...";
             freeorion_xml_iarchive ia(ifs);
 
             ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
@@ -498,8 +537,13 @@ void LoadPlayerSaveHeaderData(const std::string& filename, std::vector<PlayerSav
         if (!ifs)
             throw std::runtime_error(UNABLE_TO_OPEN_FILE);
 
-        try {
-            // first attempt binary deserialziation
+        std::string signature(5, '\0');
+        if (!ifs.read(&signature[0], 5))
+            throw std::runtime_error(UNABLE_TO_OPEN_FILE);
+        boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+
+        if (strncmp(signature.c_str(), "<?xml", 5)) {
+            // XML file format signature not found; try as binary
             DebugLogger() << "Attempting binary deserialization...";
             freeorion_bin_iarchive ia(ifs);
 
@@ -507,13 +551,8 @@ void LoadPlayerSaveHeaderData(const std::string& filename, std::vector<PlayerSav
             ia >> BOOST_SERIALIZATION_NVP(ignored_galaxy_setup_data);
             ia >> BOOST_SERIALIZATION_NVP(ignored_server_save_game_data);
             ia >> BOOST_SERIALIZATION_NVP(player_save_header_data);
-
-        } catch (...) {
-            // if binary deserialization failed, try more-portable XML deserialization
-            DebugLogger() << "Trying again with XML deserialization...";
-
-            // reset to start of stream (attempted binary serialization will have consumed some input...)
-            boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+        } else {
+            DebugLogger() << "Attempting XML deserialization...";
             freeorion_xml_iarchive ia(ifs);
 
             ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
@@ -521,6 +560,7 @@ void LoadPlayerSaveHeaderData(const std::string& filename, std::vector<PlayerSav
             ia >> BOOST_SERIALIZATION_NVP(ignored_server_save_game_data);
             ia >> BOOST_SERIALIZATION_NVP(player_save_header_data);
         }
+
         // skipping additional deserialization which is not needed for this function
         DebugLogger() << "Done reading player save game data...";
     } catch (const std::exception& e) {
@@ -529,11 +569,15 @@ void LoadPlayerSaveHeaderData(const std::string& filename, std::vector<PlayerSav
     }
 }
 
-void LoadEmpireSaveGameData(const std::string& filename, std::map<int, SaveGameEmpireData>& empire_save_game_data) {
+void LoadEmpireSaveGameData(const std::string& filename,
+                            std::map<int, SaveGameEmpireData>& empire_save_game_data,
+                            std::vector<PlayerSaveHeaderData>& player_save_header_data,
+                            GalaxySetupData& galaxy_setup_data,
+                            int& current_turn)
+{
     SaveGamePreviewData                 ignored_save_preview_data;
-    ServerSaveGameData                  ignored_server_save_game_data;
-    std::vector<PlayerSaveHeaderData>   ignored_player_save_header_data;
-    GalaxySetupData                     ignored_galaxy_setup_data;
+    ServerSaveGameData                  saved_server_save_game_data;
+    GalaxySetupData                     saved_galaxy_setup_data;
 
     ScopedTimer timer("LoadEmpireSaveGameData: " + filename, true);
 
@@ -545,27 +589,30 @@ void LoadEmpireSaveGameData(const std::string& filename, std::map<int, SaveGameE
         if (!ifs)
             throw std::runtime_error(UNABLE_TO_OPEN_FILE);
 
-        try {
-            // first attempt binary deserialziation
+        std::string signature(5, '\0');
+        if (!ifs.read(&signature[0], 5))
+            throw std::runtime_error(UNABLE_TO_OPEN_FILE);
+        boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+
+        if (strncmp(signature.c_str(), "<?xml", 5)) {
+            // XML file format signature not found; try as binary
+            DebugLogger() << "Attempting binary deserialization...";
             freeorion_bin_iarchive ia(ifs);
 
             ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
-            ia >> BOOST_SERIALIZATION_NVP(ignored_galaxy_setup_data);
-            ia >> BOOST_SERIALIZATION_NVP(ignored_server_save_game_data);
-            ia >> BOOST_SERIALIZATION_NVP(ignored_player_save_header_data);
+            ia >> BOOST_SERIALIZATION_NVP(saved_galaxy_setup_data);
+            ia >> BOOST_SERIALIZATION_NVP(saved_server_save_game_data);
+            ia >> BOOST_SERIALIZATION_NVP(player_save_header_data);
             ia >> BOOST_SERIALIZATION_NVP(empire_save_game_data);
 
-        } catch (...) {
-            // if binary deserialization failed, try more-portable XML deserialization
-
-            // reset to start of stream (attempted binary serialization will have consumed some input...)
-            boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+        } else {
+            DebugLogger() << "Attempting XML deserialization...";
             freeorion_xml_iarchive ia(ifs);
 
             ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
-            ia >> BOOST_SERIALIZATION_NVP(ignored_galaxy_setup_data);
-            ia >> BOOST_SERIALIZATION_NVP(ignored_server_save_game_data);
-            ia >> BOOST_SERIALIZATION_NVP(ignored_player_save_header_data);
+            ia >> BOOST_SERIALIZATION_NVP(saved_galaxy_setup_data);
+            ia >> BOOST_SERIALIZATION_NVP(saved_server_save_game_data);
+            ia >> BOOST_SERIALIZATION_NVP(player_save_header_data);
             ia >> BOOST_SERIALIZATION_NVP(empire_save_game_data);
         }
         // skipping additional deserialization which is not needed for this function
@@ -574,4 +621,18 @@ void LoadEmpireSaveGameData(const std::string& filename, std::map<int, SaveGameE
         ErrorLogger() << UserString("UNABLE_TO_READ_SAVE_FILE") << " LoadEmpireSaveGameData exception: " << ": " << e.what();
         throw e;
     }
+    galaxy_setup_data.m_seed = saved_galaxy_setup_data.m_seed;
+    galaxy_setup_data.m_size = saved_galaxy_setup_data.m_size;
+    galaxy_setup_data.m_shape = saved_galaxy_setup_data.m_shape;
+    galaxy_setup_data.m_age = saved_galaxy_setup_data.m_age;
+    galaxy_setup_data.m_starlane_freq = saved_galaxy_setup_data.m_starlane_freq;
+    galaxy_setup_data.m_planet_density = saved_galaxy_setup_data.m_planet_density;
+    galaxy_setup_data.m_specials_freq = saved_galaxy_setup_data.m_specials_freq;
+    galaxy_setup_data.m_monster_freq = saved_galaxy_setup_data.m_monster_freq;
+    galaxy_setup_data.m_native_freq = saved_galaxy_setup_data.m_native_freq;
+    galaxy_setup_data.m_ai_aggr = saved_galaxy_setup_data.m_ai_aggr;
+    galaxy_setup_data.m_game_rules = saved_galaxy_setup_data.m_game_rules;
+    galaxy_setup_data.m_game_uid = saved_galaxy_setup_data.m_game_uid;
+
+    current_turn = saved_server_save_game_data.m_current_turn;
 }
