@@ -15,6 +15,9 @@ struct PlayerSaveHeaderData;
 struct SaveGameEmpireData;
 struct ServerSaveGameData;
 
+/** Prepared empire data for save game or lobby. */
+std::map<int, SaveGameEmpireData> CompileSaveGameEmpireData();
+
 /** Saves the provided data to savefile \a filename. */
 int SaveGame(const std::string& filename,
              const ServerSaveGameData& server_save_game_data,
@@ -23,7 +26,7 @@ int SaveGame(const std::string& filename,
              const EmpireManager& empire_manager,
              const SpeciesManager& species_manager,
              const CombatLogManager& combat_log_manager,
-             const GalaxySetupData& galaxy_setup_data,
+             GalaxySetupData galaxy_setup_data,
              bool multiplayer);
 
 /** Loads the indicated data from savefile \a filename. */
@@ -44,8 +47,12 @@ void LoadPlayerSaveHeaderData(const std::string& filename,
 
 /** Loads from a savefile \a filename some basic empire information that is
   * useful when selecting which player will control which empire when reloading
-  * a saved game: player name, empire name, and empire colour (and empire id). */
+  * a saved game: player name, empire name, and empire colour (and empire id).
+  * Also loads galaxy setup data to show it in lobby window. */
 void LoadEmpireSaveGameData(const std::string& filename,
-                            std::map<int, SaveGameEmpireData>& empire_save_game_data);
+                            std::map<int, SaveGameEmpireData>& empire_save_game_data,
+                            std::vector<PlayerSaveHeaderData>& player_save_header_data,
+                            GalaxySetupData& galaxy_setup_data,
+                            int &current_turn);
 
 #endif
