@@ -1,11 +1,11 @@
 #ifndef _ServerApp_h_
 #define _ServerApp_h_
 
+#include "ServerFramework.h"
+#include "ServerNetworking.h"
 #include "../util/Process.h"
 #include "../Empire/EmpireManager.h"
 #include "../Empire/Supply.h"
-#include "../python/server/ServerFramework.h"
-#include "../network/ServerNetworking.h"
 #include "../universe/Universe.h"
 #include "../util/AppInterface.h"
 #include "../util/MultiplayerCommon.h"
@@ -20,57 +20,6 @@ struct GalaxySetupData;
 struct SaveGameUIData;
 struct ServerFSM;
 
-/** Contains basic data about a player in a game. */
-struct PlayerSaveHeaderData {
-    PlayerSaveHeaderData();
-
-    PlayerSaveHeaderData(const std::string& name, int empire_id,
-                         Networking::ClientType client_type);
-
-    std::string             m_name;
-    int                     m_empire_id;
-    Networking::ClientType  m_client_type;
-
-private:
-    friend class boost::serialization::access;
-    template <class Archive>
-    void serialize(Archive& ar, const unsigned int version);
-};
-
-/** Contains data that must be saved for a single player. */
-struct PlayerSaveGameData : public PlayerSaveHeaderData {
-    PlayerSaveGameData();
-
-    PlayerSaveGameData(const std::string& name, int empire_id,
-                       const std::shared_ptr<OrderSet>& orders,
-                       const std::shared_ptr<SaveGameUIData>& ui_data,
-                       const std::string& save_state_string,
-                       Networking::ClientType client_type);
-
-    std::shared_ptr<OrderSet>       m_orders;
-    std::shared_ptr<SaveGameUIData> m_ui_data;
-    std::string                     m_save_state_string;
-
-private:
-    friend class boost::serialization::access;
-    template <class Archive>
-    void serialize(Archive& ar, const unsigned int version);
-};
-
-/** contains data that must be retained by the server when saving and loading a
-  * game that isn't player data or the universe */
-struct ServerSaveGameData {
-    ServerSaveGameData();
-    ServerSaveGameData(int current_turn);
-
-    int m_current_turn;
-
-private:
-    friend class boost::serialization::access;
-    template <class Archive>
-    void serialize(Archive& ar, const unsigned int version);
-};
-
 /** the application framework class for the FreeOrion server. */
 class ServerApp : public IApp {
 public:
@@ -137,6 +86,13 @@ public:
 
     /** Returns chat history buffer. */
     const boost::circular_buffer<ChatHistoryEntity>& GetChatHistory() const;
+
+    /** Extracts player save game data. */
+    std::vector<PlayerSaveGameData> GetPlayerSaveGameData() const;
+
+    bool IsTurnExpired() const;
+
+    bool IsHaveWinner() const;
     //@}
 
 
@@ -151,17 +107,16 @@ public:
     /** creates an AI client child process for each element of \a AIs*/
     void    CreateAIClients(const std::vector<PlayerSetupData>& player_setup_data, int max_aggression = 4);
 
-    /**  Adds an existing empire to turn processing. The position the empire is
-      * in the vector is it's position in the turn processing.*/
-    void    AddEmpireTurn(int empire_id);
+    /** Adds save game data includes turn orders for the given empire for the current turn.
+      * \a save_game_data will be freed when all processing is done for the turn */
+    void    SetEmpireSaveGameData(int empire_id, std::unique_ptr<PlayerSaveGameData>&& save_game_data);
 
-    /** Removes an empire from turn processing. This is most likely called when
-      * an empire is eliminated from the game */
-    void    RemoveEmpireTurn(int empire_id);
+    /** Updated empire orders without changes in readiness status. Removes all \a deleted orders
+      * and insert \a added orders. */
+    void    UpdatePartialOrders(int empire_id, const OrderSet& added, const std::set<int>& deleted);
 
-    /** Adds turn orders for the given empire for the current turn. order_set
-      * will be freed when all processing is done for the turn */
-    void    SetEmpireTurnOrders(int empire_id, std::unique_ptr<OrderSet>&& order_set);
+    /** Revokes turn order's ready state for the given empire. */
+    void    RevokeEmpireTurnReadyness(int empire_id);
 
     /** Sets all empire turn orders to an empty set. */
     void    ClearEmpireTurnOrders();
@@ -223,6 +178,9 @@ public:
     /** Checks if \a auth match \a player_name and fill \a roles if successed. */
     bool IsAuthSuccessAndFillRoles(const std::string& player_name, const std::string& auth, Networking::AuthRoles& roles);
 
+    /** Returns list of player for multiplayer quickstart*/
+    std::list<PlayerSetupData> FillListPlayers();
+
     /** Adds new observing player to running game.
       * Simply sends GAME_START message so established player knows he is in the game. */
     void AddObserverPlayerIntoGame(const PlayerConnectionPtr& player_connection);
@@ -234,9 +192,17 @@ public:
     void DropPlayerEmpireLink(int planet_id);
 
     /** Adds new player to running game.
-      * Search empire by player's name and return true if success and false if no empire found.
-      * Simply sends GAME_START message so established player knows he is in the game. */
-    bool AddPlayerIntoGame(const PlayerConnectionPtr& player_connection);
+      * Search empire by player's name or delegation list if \a target_empire_id set and return
+      * empire id if success and ALL_EMPIRES if no empire found.
+      * Simply sends GAME_START message so established player knows he is in the game.
+      * Notificates the player about statuses of other empires. */
+    int AddPlayerIntoGame(const PlayerConnectionPtr& player_connection, int target_empire_id);
+
+    /** Get list of players delegated by \a player_name */
+    std::list<std::string> GetPlayerDelegation(const std::string& player_name);
+
+    /** Sets turn to be expired. Server doesn't wait for human player turns. */
+    void ExpireTurn();
     //@}
 
     void UpdateSavePreviews(const Message& msg, PlayerConnectionPtr player_connection);
@@ -244,13 +210,15 @@ public:
     /** Send the requested combat logs to the client.*/
     void UpdateCombatLogs(const Message& msg, PlayerConnectionPtr player_connection);
 
+    /** Loads chat history via python script. */
+    void LoadChatHistory();
+
     void PushChatMessage(const std::string& text,
                          const std::string& player_name,
                          GG::Clr text_color,
                          const boost::posix_time::ptime& timestamp);
 
     ServerNetworking&           Networking();     ///< returns the networking object for the server
-
 private:
     void    Run();          ///< initializes app state, then executes main event handler/render loop (Poll())
 
@@ -333,7 +301,15 @@ private:
       * between two empires. Updates those empires of the change. */
     void    HandleDiplomaticMessageChange(int empire1_id, int empire2_id);
 
-    boost::asio::io_service m_io_service;
+    /**  Adds an existing empire to turn processing. The position the empire is
+      * in the vector is it's position in the turn processing.*/
+    void    AddEmpireTurn(int empire_id, const PlayerSaveGameData& psgd);
+
+    /** Removes an empire from turn processing. This is most likely called when
+      * an empire is eliminated from the game */
+    void    RemoveEmpireTurn(int empire_id);
+
+    boost::asio::io_context m_io_context;
     boost::asio::signal_set m_signals;
 
     Universe                m_universe;
@@ -342,17 +318,22 @@ private:
     ServerNetworking        m_networking;
     ServerFSM*              m_fsm;
     PythonServer            m_python_server;
-    std::map<int, int>      m_player_empire_ids;    ///< map from player id to empire id that the player controls.
-    int                     m_current_turn;         ///< current turn number
-    std::vector<Process>    m_ai_client_processes;  ///< AI client child processes
-    bool                    m_single_player_game;   ///< true when the game being played is single-player
-    GalaxySetupData         m_galaxy_setup_data;    ///< stored setup data for the game currently being played
-    boost::circular_buffer<ChatHistoryEntity> m_chat_history; ///< Stored last chat messages.
+    std::map<int, int>      m_player_empire_ids;                ///< map from player id to empire id that the player controls.
+    int                     m_current_turn = INVALID_GAME_TURN; ///< current turn number
+    bool                    m_turn_expired = false;             ///< true when turn exceeds its timeout
+    std::vector<Process>    m_ai_client_processes;              ///< AI client child processes
+    bool                    m_single_player_game = false;       ///< true when the game being played is single-player
+    GalaxySetupData         m_galaxy_setup_data;                ///< stored setup data for the game currently being played
+    boost::circular_buffer<ChatHistoryEntity> m_chat_history;   ///< Stored last chat messages.
+
 
     /** Turn sequence map is used for turn processing. Each empire is added at
       * the start of a game or reload and then the map maintains OrderSets for
-      * that turn. */
-    std::map<int, std::unique_ptr<OrderSet>>         m_turn_sequence;
+      * that turn.
+      * The map contains pointer to orders from empire with ready state which should be true
+      * to advance turn.
+      * */
+    std::map<int, std::unique_ptr<PlayerSaveGameData>>  m_turn_sequence;
 
     // Give FSM and its states direct access.  We are using the FSM code as a
     // control-flow mechanism; it is all notionally part of this class.
@@ -369,30 +350,4 @@ private:
     friend struct ShuttingDownServer;
 };
 
-// template implementations
-template <class Archive>
-void PlayerSaveHeaderData::serialize(Archive& ar, const unsigned int version)
-{
-    ar  & BOOST_SERIALIZATION_NVP(m_name)
-        & BOOST_SERIALIZATION_NVP(m_empire_id)
-        & BOOST_SERIALIZATION_NVP(m_client_type);
-}
-
-template <class Archive>
-void PlayerSaveGameData::serialize(Archive& ar, const unsigned int version)
-{
-    ar  & BOOST_SERIALIZATION_NVP(m_name)
-        & BOOST_SERIALIZATION_NVP(m_empire_id)
-        & BOOST_SERIALIZATION_NVP(m_orders)
-        & BOOST_SERIALIZATION_NVP(m_ui_data)
-        & BOOST_SERIALIZATION_NVP(m_save_state_string)
-        & BOOST_SERIALIZATION_NVP(m_client_type);
-}
-
-template <class Archive>
-void ServerSaveGameData::serialize(Archive& ar, const unsigned int version)
-{
-    ar  & BOOST_SERIALIZATION_NVP(m_current_turn);
-}
-
 #endif // _ServerApp_h_
