@@ -13,6 +13,7 @@
 #include <boost/statechart/state.hpp>
 #include <boost/statechart/state_machine.hpp>
 #include <boost/asio/high_resolution_timer.hpp>
+#include <boost/asio/deadline_timer.hpp>
 
 #include <memory>
 #include <set>
@@ -78,8 +79,9 @@ struct MessageEventBase {
     (LeaveGame)                             \
     (SaveGameRequest)                       \
     (TurnOrders)                            \
+    (TurnPartialOrders)                     \
+    (RevokeReadiness)                       \
     (CombatTurnOrders)                      \
-    (ClientSaveData)                        \
     (RequestCombatLogs)                     \
     (PlayerChat)                            \
     (Diplomacy)                             \
@@ -116,11 +118,6 @@ struct ShuttingDownServer;
 struct WaitingForTurnEnd;
 struct ProcessingTurn;
 
-// Substates of WaitingForTurnEnd
-struct WaitingForTurnEndIdle;
-struct WaitingForSaveData;
-
-
 #define SERVER_ACCESSOR private: ServerApp& Server() { return context<ServerFSM>().Server(); }
 
 /** The finite state machine that represents the server's operation. */
@@ -130,6 +127,7 @@ struct ServerFSM : sc::state_machine<ServerFSM, Idle> {
     void unconsumed_event(const sc::event_base &event);
     ServerApp& Server();
     void HandleNonLobbyDisconnection(const Disconnection& d);
+    void UpdateIngameLobby();
     bool EstablishPlayer(const PlayerConnectionPtr& player_connection,
                          const std::string& player_name,
                          Networking::ClientType client_type,
@@ -279,7 +277,6 @@ struct WaitingForMPGameJoiners : sc::state<WaitingForMPGameJoiners, ServerFSM> {
     std::vector<PlayerSaveGameData>         m_player_save_game_data;
     std::shared_ptr<ServerSaveGameData>     m_server_save_game_data;
     std::set<std::string>                   m_expected_ai_player_names;
-    int                                     m_num_expected_players;
 
     SERVER_ACCESSOR
 };
@@ -299,7 +296,8 @@ struct PlayingGame : sc::state<PlayingGame, ServerFSM, WaitingForTurnEnd> {
         sc::custom_reaction<JoinGame>,
         sc::custom_reaction<AuthResponse>,
         sc::custom_reaction<EliminateSelf>,
-        sc::custom_reaction<Error>
+        sc::custom_reaction<Error>,
+        sc::custom_reaction<LobbyUpdate>
     > reactions;
 
     PlayingGame(my_context c);
@@ -315,12 +313,17 @@ struct PlayingGame : sc::state<PlayingGame, ServerFSM, WaitingForTurnEnd> {
     sc::result react(const AuthResponse& msg);
     sc::result react(const EliminateSelf& msg);
     sc::result react(const Error& msg);
+    sc::result react(const LobbyUpdate& msg);
 
     void EstablishPlayer(const PlayerConnectionPtr& player_connection,
                          const std::string& player_name,
                          Networking::ClientType client_type,
                          const std::string& client_version_string,
                          const Networking::AuthRoles& roles);
+    void TurnTimedoutHandler(const boost::system::error_code& error);
+
+    boost::asio::deadline_timer                     m_turn_timeout;
+    std::chrono::high_resolution_clock::time_point  m_start;
 
     SERVER_ACCESSOR
 };
@@ -329,64 +332,33 @@ struct PlayingGame : sc::state<PlayingGame, ServerFSM, WaitingForTurnEnd> {
 /** The substate of PlayingGame in which players are playing their turns and
   * the server is waiting for all players to finish their moves, after which
   * the server will process the turn. */
-struct WaitingForTurnEnd : sc::state<WaitingForTurnEnd, PlayingGame, WaitingForTurnEndIdle> {
+struct WaitingForTurnEnd : sc::state<WaitingForTurnEnd, PlayingGame> {
     typedef boost::mpl::list<
         sc::custom_reaction<TurnOrders>,
-        sc::custom_reaction<CheckTurnEndConditions>
+        sc::custom_reaction<TurnPartialOrders>,
+        sc::custom_reaction<RevokeReadiness>,
+        sc::custom_reaction<CheckTurnEndConditions>,
+        sc::custom_reaction<SaveGameRequest>
     > reactions;
 
     WaitingForTurnEnd(my_context c);
     ~WaitingForTurnEnd();
 
     sc::result react(const TurnOrders& msg);
+    sc::result react(const TurnPartialOrders& msg);
+    sc::result react(const RevokeReadiness& msg);
     sc::result react(const CheckTurnEndConditions& c);
-
-    std::string m_save_filename;
-
-    SERVER_ACCESSOR
-};
-
-
-/** The default substate of WaitingForTurnEnd. */
-struct WaitingForTurnEndIdle : sc::state<WaitingForTurnEndIdle, WaitingForTurnEnd> {
-    typedef boost::mpl::list<
-        sc::custom_reaction<SaveGameRequest>
-    > reactions;
-
-    WaitingForTurnEndIdle(my_context c);
-    ~WaitingForTurnEndIdle();
-
     sc::result react(const SaveGameRequest& msg);
 
-    SERVER_ACCESSOR
-};
+    void SaveTimedoutHandler(const boost::system::error_code& error);
 
-
-/** The substate of WaitingForTurnEnd in which a player has initiated a save
-  * and the server is waiting for all players to send their save data, after
-  * which the server will actually preform the save. */
-struct WaitingForSaveData : sc::state<WaitingForSaveData, WaitingForTurnEnd> {
-    typedef boost::mpl::list<
-        sc::custom_reaction<ClientSaveData>,
-        sc::deferral<SaveGameRequest>,
-        sc::deferral<TurnOrders>,
-        sc::deferral<PlayerChat>,
-        sc::deferral<Diplomacy>
-    > reactions;
-
-    WaitingForSaveData(my_context c);
-    ~WaitingForSaveData();
-
-    sc::result react(const ClientSaveData& msg);
-
-    std::set<int>                   m_needed_reponses;
-    std::set<int>                   m_players_responded;
-    std::vector<PlayerSaveGameData> m_player_save_game_data;
+    std::string                                     m_save_filename;
+    boost::asio::high_resolution_timer              m_timeout;
+    std::chrono::high_resolution_clock::time_point  m_start;
 
     SERVER_ACCESSOR
 };
 
-
 /** The substate of PlayingGame in which the server has received turn orders
   * from players and is determining what happens between turns.  This includes
   * executing orders, resolving combat, various steps in determining what
@@ -397,6 +369,8 @@ struct ProcessingTurn : sc::state<ProcessingTurn, PlayingGame> {
         sc::custom_reaction<ProcessTurn>,
         sc::deferral<SaveGameRequest>,
         sc::deferral<TurnOrders>,
+        sc::deferral<TurnPartialOrders>,
+        sc::deferral<RevokeReadiness>,
         sc::deferral<Diplomacy>,
         sc::custom_reaction<CheckTurnEndConditions>
     > reactions;
@@ -407,6 +381,8 @@ struct ProcessingTurn : sc::state<ProcessingTurn, PlayingGame> {
     sc::result react(const ProcessTurn& u);
     sc::result react(const CheckTurnEndConditions& c);
 
+    std::chrono::high_resolution_clock::time_point m_start;
+
     SERVER_ACCESSOR
 };
 
