@@ -2,6 +2,7 @@
 #define _Fighter_h_
 
 #include "UniverseObject.h"
+#include "../universe/Condition.h"
 #include "../util/Export.h"
 
 ////////////////////////////////////////////////
@@ -11,20 +12,16 @@
   * can be stored in the same container as other combat objects. */
 class FO_COMMON_API Fighter : public UniverseObject {
 public:
-    Fighter(int empire_id, int launched_from_id, const std::string& species_name, float damage);
+    Fighter(int empire_id, int launched_from_id, const std::string& species_name, float damage, const ::Condition::Condition* combat_targets);
     Fighter();
     ~Fighter();
 
     bool HostileToEmpire(int empire_id) const override;
-
     UniverseObjectType ObjectType() const override;
-
     std::string Dump(unsigned short ntabs = 0) const override;
-
     std::shared_ptr<UniverseObject> Accept(const UniverseObjectVisitor& visitor) const override;
-
     void Copy(std::shared_ptr<const UniverseObject> copied_object, int empire_id = ALL_EMPIRES) override;
-
+    const ::Condition::Condition* CombatTargets() const;
     float                       Damage() const;
     bool                        Destroyed() const;
     int                         LaunchedFrom() const;
@@ -39,6 +36,7 @@ private:
     bool        m_destroyed = false;                    // was attacked by anything -> destroyed
     int         m_launched_from_id = INVALID_OBJECT_ID; // from what object (ship?) was this fighter launched
     std::string m_species_name;
+    const ::Condition::Condition* m_combat_targets = nullptr;
 };
 
-#endif // _Ship_h_
+#endif // _Fighter_h_
