@@ -10,6 +10,7 @@
 #include "Field.h"
 #include "Enums.h"
 #include "../util/Logger.h"
+#include "../util/AppInterface.h"
 
 
 #define FOR_EACH_SPECIALIZED_MAP(f, ...)  { f(m_resource_centers, ##__VA_ARGS__);   \
@@ -24,6 +25,35 @@
 #define FOR_EACH_MAP(f, ...)              { f(m_objects, ##__VA_ARGS__);            \
                                             FOR_EACH_SPECIALIZED_MAP(f, ##__VA_ARGS__); }
 
+#define FOR_EACH_EXISTING_MAP(f, ...)     { f(m_existing_objects, ##__VA_ARGS__);          \
+                                            f(m_existing_resource_centers, ##__VA_ARGS__); \
+                                            f(m_existing_pop_centers, ##__VA_ARGS__);      \
+                                            f(m_existing_ships, ##__VA_ARGS__);            \
+                                            f(m_existing_fleets, ##__VA_ARGS__);           \
+                                            f(m_existing_planets, ##__VA_ARGS__);          \
+                                            f(m_existing_systems, ##__VA_ARGS__);          \
+                                            f(m_existing_buildings, ##__VA_ARGS__);        \
+                                            f(m_existing_fields, ##__VA_ARGS__); }
+
+
+namespace {
+    template <typename T>
+    static void ClearMap(ObjectMap::container_type<T>& map)
+    { map.clear(); }
+
+    template <typename T>
+    static void TryInsertIntoMap(ObjectMap::container_type<T>& map, std::shared_ptr<UniverseObject> item)
+    {
+        if (dynamic_cast<T*>(item.get()))
+            map[item->ID()] = std::dynamic_pointer_cast<T, UniverseObject>(item);
+    }
+
+    template <typename T>
+    void EraseFromMap(ObjectMap::container_type<T>& map, int id)
+    { map.erase(id); }
+}
+
+
 /////////////////////////////////////////////
 // class ObjectMap
 /////////////////////////////////////////////
@@ -39,8 +69,8 @@ void ObjectMap::Copy(const ObjectMap& copied_map, int empire_id/* = ALL_EMPIRES*
 
     // loop through objects in copied map, copying or cloning each depending
     // on whether there already is a corresponding object in this map
-    for (const_iterator<> it = copied_map.const_begin(); it != copied_map.const_end(); ++it)
-        this->CopyObject(*it, empire_id);
+    for (const auto& obj : copied_map.all())
+        this->CopyObject(obj, empire_id);
 }
 
 void ObjectMap::CopyForSerialize(const ObjectMap& copied_map) {
@@ -61,10 +91,10 @@ void ObjectMap::CopyObject(std::shared_ptr<const UniverseObject> source, int emp
     if (GetUniverse().GetObjectVisibilityByEmpire(source_id, empire_id) <= VIS_NO_VISIBILITY)
         return;
 
-    if (std::shared_ptr<UniverseObject> destination = this->Object(source_id)) {
+    if (auto destination = this->get(source_id)) {
         destination->Copy(source, empire_id); // there already is a version of this object present in this ObjectMap, so just update it
     } else {
-        InsertCore(std::shared_ptr<UniverseObject>(source->Clone()), empire_id); // this object is not yet present in this ObjectMap, so add a new UniverseObject object for it
+        insertCore(std::shared_ptr<UniverseObject>(source->Clone()), empire_id); // this object is not yet present in this ObjectMap, so add a new UniverseObject object for it
     }
 }
 
@@ -74,106 +104,21 @@ ObjectMap* ObjectMap::Clone(int empire_id) const {
     return result;
 }
 
-int ObjectMap::NumObjects() const
-{ return static_cast<int>(m_objects.size()); }
-
-bool ObjectMap::Empty() const
+bool ObjectMap::empty() const
 { return m_objects.empty(); }
 
-std::shared_ptr<const UniverseObject> ObjectMap::Object(int id) const
-{ return Object<UniverseObject>(id); }
-
-std::shared_ptr<UniverseObject> ObjectMap::Object(int id)
-{ return Object<UniverseObject>(id); }
-
-std::vector<std::shared_ptr<const UniverseObject>> ObjectMap::FindObjects(const std::vector<int>& object_ids) const {
-    std::vector<std::shared_ptr<const UniverseObject>> result;
-    for (int object_id : object_ids)
-        if (auto obj = Object(object_id))
-            result.push_back(obj);
-        else
-            ErrorLogger() << "ObjectMap::FindObjects couldn't find object with id " << object_id;
-    return result;
+int ObjectMap::HighestObjectID() const {
+    if (m_objects.empty())
+        return INVALID_OBJECT_ID;
+    return m_objects.rbegin()->first;
 }
 
-std::vector<std::shared_ptr<const UniverseObject>> ObjectMap::FindObjects(const std::set<int>& object_ids) const {
-    std::vector<std::shared_ptr<const UniverseObject>> result;
-    for (int object_id : object_ids)
-        if (auto obj = Object(object_id))
-            result.push_back(obj);
-        else
-            ErrorLogger() << "ObjectMap::FindObjects couldn't find object with id " << object_id;
-    return result;
-}
-
-std::vector<std::shared_ptr<UniverseObject>> ObjectMap::FindObjects(const std::vector<int>& object_ids) {
-    std::vector<std::shared_ptr<UniverseObject>> result;
-    for (int object_id : object_ids)
-        if (auto obj = Object(object_id))
-            result.push_back(obj);
-        else
-            ErrorLogger() << "ObjectMap::FindObjects couldn't find object with id " << object_id;
-    return result;
-}
-
-std::vector<std::shared_ptr<UniverseObject>> ObjectMap::FindObjects(const std::set<int>& object_ids) {
-    std::vector<std::shared_ptr<UniverseObject>> result;
-    for (int object_id : object_ids)
-        if (auto obj = Object(object_id))
-            result.push_back(obj);
-        else
-            ErrorLogger() << "ObjectMap::FindObjects couldn't find object with id " << object_id;
-    return result;
-}
-
-std::vector<std::shared_ptr<const UniverseObject>> ObjectMap::FindObjects(const UniverseObjectVisitor& visitor) const {
-    std::vector<std::shared_ptr<const UniverseObject>> result;
-    for (auto it = const_begin(); it != const_end(); ++it) {
-        if (auto obj = it->Accept(visitor))
-            result.push_back(Object(obj->ID()));
-    }
-    return result;
-}
-
-std::vector<std::shared_ptr<UniverseObject>> ObjectMap::FindObjects(const UniverseObjectVisitor& visitor) {
-    std::vector<std::shared_ptr<UniverseObject>> result;
-    for (const auto& obj : *this) {
-        if (std::shared_ptr<UniverseObject> match = obj->Accept(visitor))
-            result.push_back(Object(match->ID()));
-    }
-    return result;
-}
-
-std::vector<int> ObjectMap::FindObjectIDs(const UniverseObjectVisitor& visitor) const {
-    std::vector<int> result;
-    for (auto it = const_begin(); it != const_end(); ++it) {
-        if (it->Accept(visitor))
-            result.push_back(it->ID());
-    }
-    return result;
-}
-
-std::vector<int> ObjectMap::FindObjectIDs() const
-{ return FindObjectIDs<UniverseObject>(); }
-
-ObjectMap::iterator<> ObjectMap::begin()
-{ return begin<UniverseObject>(); }
-
-ObjectMap::iterator<> ObjectMap::end()
-{ return end<UniverseObject>(); }
-
-ObjectMap::const_iterator<> ObjectMap::const_begin() const
-{ return const_begin<UniverseObject>(); }
-
-ObjectMap::const_iterator<> ObjectMap::const_end() const
-{ return const_end<UniverseObject>(); }
-
-void ObjectMap::InsertCore(std::shared_ptr<UniverseObject> item, int empire_id/* = ALL_EMPIRES*/) {
+void ObjectMap::insertCore(std::shared_ptr<UniverseObject> item, int empire_id/* = ALL_EMPIRES*/) {
     FOR_EACH_MAP(TryInsertIntoMap, item);
     if (item &&
         !GetUniverse().EmpireKnownDestroyedObjectIDs(empire_id).count(item->ID()))
     {
-        auto this_item = this->Object(item->ID());
+        auto this_item = this->get(item->ID());
         m_existing_objects[item->ID()] = this_item;
         switch (item->ObjectType()) {
             case OBJ_BUILDING:
@@ -202,13 +147,14 @@ void ObjectMap::InsertCore(std::shared_ptr<UniverseObject> item, int empire_id/*
             case OBJ_SYSTEM:
                 m_existing_systems[item->ID()] = this_item;
                 break;
+            case OBJ_FIGHTER:
             default:
                 break;
         }
     }
 }
 
-std::shared_ptr<UniverseObject> ObjectMap::Remove(int id) {
+std::shared_ptr<UniverseObject> ObjectMap::erase(int id) {
     // search for object in objects map
     auto it = m_objects.find(id);
     if (it == m_objects.end())
@@ -219,23 +165,30 @@ std::shared_ptr<UniverseObject> ObjectMap::Remove(int id) {
     // and erase from pointer maps
     m_objects.erase(it);
     FOR_EACH_SPECIALIZED_MAP(EraseFromMap, id);
-    m_existing_objects.erase(id);
-    m_existing_buildings.erase(id);
-    m_existing_fields.erase(id);
-    m_existing_fleets.erase(id);
-    m_existing_ships.erase(id);
-    m_existing_planets.erase(id);
-    m_existing_pop_centers.erase(id);
-    m_existing_resource_centers.erase(id);
-    m_existing_systems.erase(id);
+    FOR_EACH_EXISTING_MAP(EraseFromMap, id);
     return result;
 }
 
-void ObjectMap::Clear()
-{ FOR_EACH_MAP(ClearMap); }
+void ObjectMap::clear() {
+    FOR_EACH_MAP(ClearMap);
+    FOR_EACH_EXISTING_MAP(ClearMap);
+}
 
-void ObjectMap::swap(ObjectMap& rhs)
-{ FOR_EACH_MAP(SwapMap, rhs); }
+void ObjectMap::swap(ObjectMap& rhs) {
+    // SwapMap uses ObjectMap::Map<T> but this function isn't available for the existing maps,
+    // so the FOR_EACH_EXISTING_MAP macro doesn't work with with SwapMap
+    // and it is instead necessary to write them out explicitly.
+    m_existing_objects.swap(rhs.m_existing_objects);
+    m_existing_buildings.swap(rhs.m_existing_buildings);
+    m_existing_fields.swap(rhs.m_existing_fields);
+    m_existing_fleets.swap(rhs.m_existing_fleets);
+    m_existing_ships.swap(rhs.m_existing_ships);
+    m_existing_planets.swap(rhs.m_existing_planets);
+    m_existing_pop_centers.swap(rhs.m_existing_pop_centers);
+    m_existing_resource_centers.swap(rhs.m_existing_resource_centers);
+    m_existing_systems.swap(rhs.m_existing_systems);
+    FOR_EACH_MAP(SwapMap, rhs);
+}
 
 std::vector<int> ObjectMap::FindExistingObjectIDs() const {
     std::vector<int> result;
@@ -245,21 +198,13 @@ std::vector<int> ObjectMap::FindExistingObjectIDs() const {
 }
 
 void ObjectMap::UpdateCurrentDestroyedObjects(const std::set<int>& destroyed_object_ids) {
-    m_existing_objects.clear();
-    m_existing_buildings.clear();
-    m_existing_fields.clear();
-    m_existing_fleets.clear();
-    m_existing_ships.clear();
-    m_existing_planets.clear();
-    m_existing_pop_centers.clear();
-    m_existing_resource_centers.clear();
-    m_existing_systems.clear();
+    FOR_EACH_EXISTING_MAP(ClearMap);
     for (const auto& entry : m_objects) {
         if (!entry.second)
             continue;
         if (destroyed_object_ids.count(entry.first))
             continue;
-        auto this_item = this->Object(entry.first);
+        auto this_item = this->get(entry.first);
         m_existing_objects[entry.first] = this_item;
         switch (entry.second->ObjectType()) {
             case OBJ_BUILDING:
@@ -288,6 +233,7 @@ void ObjectMap::UpdateCurrentDestroyedObjects(const std::set<int>& destroyed_obj
             case OBJ_SYSTEM:
                 m_existing_systems[entry.first] = this_item;
                 break;
+            case OBJ_FIGHTER:
             default:
                 break;
         }
@@ -296,14 +242,14 @@ void ObjectMap::UpdateCurrentDestroyedObjects(const std::set<int>& destroyed_obj
 
 void ObjectMap::AuditContainment(const std::set<int>& destroyed_object_ids) {
     // determine all objects that some other object thinks contains them
-    std::map<int, std::set<int>>    contained_objs;
-    std::map<int, std::set<int>>    contained_planets;
-    std::map<int, std::set<int>>    contained_buildings;
-    std::map<int, std::set<int>>    contained_fleets;
-    std::map<int, std::set<int>>    contained_ships;
-    std::map<int, std::set<int>>    contained_fields;
+    std::map<int, std::set<int>> contained_objs;
+    std::map<int, std::set<int>> contained_planets;
+    std::map<int, std::set<int>> contained_buildings;
+    std::map<int, std::set<int>> contained_fleets;
+    std::map<int, std::set<int>> contained_ships;
+    std::map<int, std::set<int>> contained_fields;
 
-    for (const auto& contained : *this) {
+    for (const auto& contained : all()) {
         if (destroyed_object_ids.count(contained->ID()))
             continue;
 
@@ -315,7 +261,7 @@ void ObjectMap::AuditContainment(const std::set<int>& destroyed_object_ids) {
             continue;
 
         // store systems' contained objects
-        if (this->Object(sys_id)) { // although this is expected to be a system, can't use Object<System> here due to CopyForSerialize not copying the type-specific objects info
+        if (this->get(sys_id)) { // although this is expected to be a system, can't use Object<System> here due to CopyForSerialize not copying the type-specific objects info
             contained_objs[sys_id].insert(contained_id);
 
             if (type == OBJ_PLANET)
@@ -331,18 +277,18 @@ void ObjectMap::AuditContainment(const std::set<int>& destroyed_object_ids) {
         }
 
         // store planets' contained buildings
-        if (type == OBJ_BUILDING && this->Object(alt_id))
+        if (type == OBJ_BUILDING && this->get(alt_id))
             contained_buildings[alt_id].insert(contained_id);
 
         // store fleets' contained ships
-        if (type == OBJ_SHIP && this->Object(alt_id))
+        if (type == OBJ_SHIP && this->get(alt_id))
             contained_ships[alt_id].insert(contained_id);
     }
 
     // set contained objects of all possible containers
-    for (const auto& obj : *this) {
+    for (const auto& obj : all()) {
         if (obj->ObjectType() == OBJ_SYSTEM) {
-            std::shared_ptr<System> sys = std::dynamic_pointer_cast<System>(obj);
+            auto sys = std::dynamic_pointer_cast<System>(obj);
             if (!sys)
                 continue;
             sys->m_objects =    contained_objs[sys->ID()];
@@ -351,13 +297,15 @@ void ObjectMap::AuditContainment(const std::set<int>& destroyed_object_ids) {
             sys->m_fleets =     contained_fleets[sys->ID()];
             sys->m_ships =      contained_ships[sys->ID()];
             sys->m_fields =     contained_fields[sys->ID()];
+
         } else if (obj->ObjectType() == OBJ_PLANET) {
-            std::shared_ptr<Planet> plt = std::dynamic_pointer_cast<Planet>(obj);
+            auto plt = std::dynamic_pointer_cast<Planet>(obj);
             if (!plt)
                 continue;
             plt->m_buildings =  contained_buildings[plt->ID()];
+
         } else if (obj->ObjectType() == OBJ_FLEET) {
-            std::shared_ptr<Fleet> flt = std::dynamic_pointer_cast<Fleet>(obj);
+            auto flt = std::dynamic_pointer_cast<Fleet>(obj);
             if (!flt)
                 continue;
             flt->m_ships =      contained_ships[flt->ID()];
@@ -367,21 +315,20 @@ void ObjectMap::AuditContainment(const std::set<int>& destroyed_object_ids) {
 
 void ObjectMap::CopyObjectsToSpecializedMaps() {
     FOR_EACH_SPECIALIZED_MAP(ClearMap);
-    for (auto it = Map<UniverseObject>().begin();
-         it != Map<UniverseObject>().end(); ++it)
-    { FOR_EACH_SPECIALIZED_MAP(TryInsertIntoMap, it->second); }
+    for (const auto& entry : Map<UniverseObject>())
+    { FOR_EACH_SPECIALIZED_MAP(TryInsertIntoMap, entry.second); }
 }
 
 std::string ObjectMap::Dump(unsigned short ntabs) const {
     std::ostringstream dump_stream;
     dump_stream << "ObjectMap contains UniverseObjects: " << std::endl;
-    for (const_iterator<> it = const_begin(); it != const_end(); ++it)
-        dump_stream << it->Dump(ntabs) << std::endl;
+    for (const auto& obj : all())
+        dump_stream << obj->Dump(ntabs) << std::endl;
     dump_stream << std::endl;
     return dump_stream.str();
 }
 
-std::shared_ptr<UniverseObject> ObjectMap::ExistingObject(int id) {
+std::shared_ptr<const UniverseObject> ObjectMap::ExistingObject(int id) const {
     auto it = m_existing_objects.find(id);
     if (it != m_existing_objects.end())
         return it->second;
@@ -390,96 +337,80 @@ std::shared_ptr<UniverseObject> ObjectMap::ExistingObject(int id) {
 
 // Static helpers
 
-template<class T>
-void ObjectMap::EraseFromMap(std::map<int, std::shared_ptr<T>>& map, int id)
-{ map.erase(id); }
-
-template<class T>
-void ObjectMap::ClearMap(std::map<int, std::shared_ptr<T>>& map)
-{ map.clear(); }
-
-template<class T>
-void ObjectMap::SwapMap(std::map<int, std::shared_ptr<T>>& map, ObjectMap& rhs)
+template <typename T>
+void ObjectMap::SwapMap(ObjectMap::container_type<T>& map, ObjectMap& rhs)
 { map.swap(rhs.Map<T>()); }
 
-template <class T>
-void ObjectMap::TryInsertIntoMap(std::map<int, std::shared_ptr<T>>& map,
-                                 std::shared_ptr<UniverseObject> item)
-{
-    if (dynamic_cast<T*>(item.get()))
-        map[item->ID()] = std::dynamic_pointer_cast<T, UniverseObject>(item);
-}
-
 // template specializations
 
 template <>
-const std::map<int, std::shared_ptr<UniverseObject>>& ObjectMap::Map() const
+const ObjectMap::container_type<UniverseObject>& ObjectMap::Map() const
 { return m_objects; }
 
 template <>
-const std::map<int, std::shared_ptr<ResourceCenter>>& ObjectMap::Map() const
+const ObjectMap::container_type<ResourceCenter>& ObjectMap::Map() const
 { return m_resource_centers; }
 
 template <>
-const std::map<int, std::shared_ptr<PopCenter>>& ObjectMap::Map() const
+const ObjectMap::container_type<PopCenter>& ObjectMap::Map() const
 { return m_pop_centers; }
 
 template <>
-const std::map<int, std::shared_ptr<Ship>>& ObjectMap::Map() const
+const ObjectMap::container_type<Ship>& ObjectMap::Map() const
 { return m_ships; }
 
 template <>
-const std::map<int, std::shared_ptr<Fleet>>& ObjectMap::Map() const
+const ObjectMap::container_type<Fleet>& ObjectMap::Map() const
 { return m_fleets; }
 
 template <>
-const std::map<int, std::shared_ptr<Planet>>& ObjectMap::Map() const
+const ObjectMap::container_type<Planet>& ObjectMap::Map() const
 { return m_planets; }
 
 template <>
-const std::map<int, std::shared_ptr<System>>& ObjectMap::Map() const
+const ObjectMap::container_type<System>& ObjectMap::Map() const
 { return m_systems; }
 
 template <>
-const std::map<int, std::shared_ptr<Building>>& ObjectMap::Map() const
+const ObjectMap::container_type<Building>& ObjectMap::Map() const
 { return m_buildings; }
 
 template <>
-const std::map<int, std::shared_ptr<Field>>& ObjectMap::Map() const
+const ObjectMap::container_type<Field>& ObjectMap::Map() const
 { return m_fields; }
 
 template <>
-std::map<int, std::shared_ptr<UniverseObject>>& ObjectMap::Map()
+ObjectMap::container_type<UniverseObject>& ObjectMap::Map()
 { return m_objects; }
 
 template <>
-std::map<int, std::shared_ptr<ResourceCenter>>& ObjectMap::Map()
+ObjectMap::container_type<ResourceCenter>& ObjectMap::Map()
 { return m_resource_centers; }
 
 template <>
-std::map<int, std::shared_ptr<PopCenter>>& ObjectMap::Map()
+ObjectMap::container_type<PopCenter>& ObjectMap::Map()
 { return m_pop_centers; }
 
 template <>
-std::map<int, std::shared_ptr<Ship>>& ObjectMap::Map()
+ObjectMap::container_type<Ship>& ObjectMap::Map()
 { return m_ships; }
 
 template <>
-std::map<int, std::shared_ptr<Fleet>>& ObjectMap::Map()
+ObjectMap::container_type<Fleet>& ObjectMap::Map()
 { return m_fleets; }
 
 template <>
-std::map<int, std::shared_ptr<Planet>>& ObjectMap::Map()
+ObjectMap::container_type<Planet>& ObjectMap::Map()
 { return m_planets; }
 
 template <>
-std::map<int, std::shared_ptr<System>>& ObjectMap::Map()
+ObjectMap::container_type<System>& ObjectMap::Map()
 { return m_systems; }
 
 template <>
-std::map<int, std::shared_ptr<Building>>& ObjectMap::Map()
+ObjectMap::container_type<Building>& ObjectMap::Map()
 { return m_buildings; }
 
 template <>
-std::map<int, std::shared_ptr<Field>>& ObjectMap::Map()
+ObjectMap::container_type<Field>& ObjectMap::Map()
 { return m_fields; }
