@@ -2,13 +2,13 @@
 
 #include "../util/Logger.h"
 #include "../util/ScopedTimer.h"
+#include "../util/AppInterface.h"
 #include "../Empire/EmpireManager.h"
 #include "Field.h"
 #include "Fleet.h"
 #include "Ship.h"
 #include "System.h"
 #include "UniverseObject.h"
-#include "ValueRef.h"
 #include "Universe.h"
 #include "Predicates.h"
 
@@ -41,7 +41,8 @@ namespace {
         The table is assumed symmetric.  If present row i element j will
         equal row j element i.
      */
-    template <class T> struct distance_matrix_storage {
+    template <typename T>
+    struct distance_matrix_storage {
         typedef T value_type;  ///< An integral type for number of hops.
         typedef std::vector<T>& row_ref;  ///< A reference to row type
 
@@ -85,7 +86,7 @@ namespace {
     //may be true that because this is a computed value that depends on
     //the system topology that almost never changes that the
     //synchronization costs way out-weigh the saved computation costs.
-    template <class Storage, class T = typename Storage::value_type, class Row = typename Storage::row_ref>
+    template <typename Storage, typename T = typename Storage::value_type, typename Row = typename Storage::row_ref>
     class distance_matrix_cache {
         public:
         distance_matrix_cache(Storage& the_storage) : m_storage(the_storage) {}
@@ -108,10 +109,10 @@ namespace {
         // the function so that the function still has the required signature.
 
         /// Cache miss handler
-        typedef boost::function<void (size_t &/*ii*/, Row /*row*/)> cache_miss_handler;
+        typedef std::function<void (size_t &/*ii*/, Row /*row*/)> cache_miss_handler;
 
         /// A function to examine an entire row cache hit
-        typedef boost::function<void (size_t &/*ii*/, const Row /*row*/)> cache_hit_handler;
+        typedef std::function<void (size_t &/*ii*/, const Row /*row*/)> cache_hit_handler;
 
         /** Retrieve a single element at (\p ii, \p jj).
           * On cache miss call the \p fill_row which must fill the row
@@ -224,7 +225,7 @@ namespace SystemPathing {
         struct FoundDestination {}; // exception type thrown when destination is found
 
         PathFindingShortCircuitingVisitor(int dest_system) : destination_system(dest_system) {}
-        template <class Vertex, class Graph>
+        template <typename Vertex, typename Graph>
         void operator()(Vertex u, Graph& g)
         {
             if (static_cast<int>(u) == destination_system)
@@ -238,7 +239,8 @@ namespace SystemPathing {
       *  - short-circuit exit on found match
       *  - maximum search depth
       */
-    template <class Graph, class Edge, class Vertex> class BFSVisitorImpl
+    template <typename Graph, typename Edge, typename Vertex>
+    class BFSVisitorImpl
     {
     public:
         class FoundDestination {};
@@ -308,7 +310,7 @@ namespace SystemPathing {
       * just that system in it, and the path lenth is 0.  If there is no path
       * between the two vertices, then the list is empty and the path length
       * is -1.0 */
-    template <class Graph>
+    template <typename Graph>
     std::pair<std::list<int>, double> ShortestPathImpl(const Graph& graph, int system1_id, int system2_id,
                                                        double linear_distance, const boost::unordered_map<int, size_t>& id_to_graph_index)
     {
@@ -388,7 +390,7 @@ namespace SystemPathing {
       * as system2_id, the path has just that system in it, and the path lenth
       * is 0.  If there is no path between the two vertices, then the list is
       * empty and the path length is -1 */
-    template <class Graph>
+    template <typename Graph>
     std::pair<std::list<int>, int> LeastJumpsPathImpl(const Graph& graph, int system1_id, int system2_id,
                                                       const boost::unordered_map<int, size_t>& id_to_graph_index,
                                                       int max_jumps = INT_MAX)
@@ -452,7 +454,7 @@ namespace SystemPathing {
         return retval;
     }
 
-    template <class Graph>
+    template <typename Graph>
     std::multimap<double, int> ImmediateNeighborsImpl(const Graph& graph, int system_id,
                                                       const boost::unordered_map<int, size_t>& id_to_graph_index)
     {
@@ -491,11 +493,8 @@ namespace {
         typedef boost::adjacency_list<boost::vecS, boost::vecS, boost::undirectedS,
                                       vertex_property_t, edge_property_t> SystemGraph;
 
-        struct EdgeVisibilityFilter     {
-            EdgeVisibilityFilter() :
-                m_graph(nullptr),
-                m_empire_id(ALL_EMPIRES)
-            {}
+        struct EdgeVisibilityFilter {
+            EdgeVisibilityFilter() {}
 
             EdgeVisibilityFilter(const SystemGraph* graph, int empire_id) :
                 m_graph(graph),
@@ -519,7 +518,7 @@ namespace {
                 int sys_id_2 = sys_id_property_map[sys_graph_index_2];
 
                 // look up lane between systems
-                std::shared_ptr<const System> system1 = GetEmpireKnownSystem(sys_id_1, m_empire_id);
+                std::shared_ptr<const System> system1 = EmpireKnownObjects(m_empire_id).get<System>(sys_id_1);
                 if (!system1) {
                     ErrorLogger() << "EdgeDescriptor::operator() couldn't find system with id " << sys_id_1;
                     return false;
@@ -532,8 +531,8 @@ namespace {
             }
 
             private:
-            const SystemGraph*      m_graph;
-            int                     m_empire_id;
+            const SystemGraph*  m_graph = nullptr;
+            int                 m_empire_id = ALL_EMPIRES;
         };
         typedef boost::filtered_graph<SystemGraph, EdgeVisibilityFilter> EmpireViewSystemGraph;
         typedef std::map<int, std::shared_ptr<EmpireViewSystemGraph>> EmpireViewSystemGraphMap;
@@ -559,11 +558,7 @@ namespace {
         }
 
         struct SystemPredicateFilter {
-            SystemPredicateFilter() :
-                m_graph(nullptr),
-                m_empire_id(ALL_EMPIRES),
-                m_pred(nullptr)
-            {}
+            SystemPredicateFilter() {}
 
             SystemPredicateFilter(const SystemGraph* graph, int empire_id,
                                   const Pathfinder::SystemExclusionPredicateType& pred) :
@@ -590,12 +585,12 @@ namespace {
                 int sys_id_2 = sys_id_property_map[sys_graph_index_2];
 
                 // look up objects in system
-                auto system1 = GetEmpireKnownSystem(sys_id_1, m_empire_id);
+                auto system1 = EmpireKnownObjects(m_empire_id).get<System>(sys_id_1);
                 if (!system1) {
                     ErrorLogger() << "Invalid source system " << sys_id_1;
                     return true;
                 }
-                auto system2 = GetEmpireKnownSystem(sys_id_2, m_empire_id);
+                auto system2 = EmpireKnownObjects(m_empire_id).get<System>(sys_id_2);
                 if (!system2) {
                     ErrorLogger() << "Invalid target system " << sys_id_2;
                     return true;
@@ -607,7 +602,7 @@ namespace {
                 }
 
                 // Discard edge if it finds a contained object or matches either system for visitor
-                for (auto object : EmpireKnownObjects(m_empire_id).FindObjects(*m_pred.get())) {
+                for (auto object : EmpireKnownObjects(m_empire_id).find(*m_pred.get())) {
                     if (!object)
                         continue;
                     // object is destination system
@@ -623,8 +618,8 @@ namespace {
             }
 
         private:
-            const SystemGraph* m_graph;
-            int m_empire_id;
+            const SystemGraph* m_graph = nullptr;
+            int m_empire_id = ALL_EMPIRES;
             Pathfinder::SystemExclusionPredicateType m_pred;
         };
         typedef boost::filtered_graph<SystemGraph, SystemPredicateFilter> SystemPredicateGraph;
@@ -730,11 +725,11 @@ Pathfinder::~Pathfinder()
 {}
 
 namespace {
-    std::shared_ptr<const Fleet> FleetFromObject(std::shared_ptr<const UniverseObject> obj) {
+    std::shared_ptr<const Fleet> FleetFromObject(const std::shared_ptr<const UniverseObject>& obj) {
         std::shared_ptr<const Fleet> retval = std::dynamic_pointer_cast<const Fleet>(obj);
         if (!retval) {
             if (auto ship = std::dynamic_pointer_cast<const Ship>(obj))
-                retval = GetFleet(ship->FleetID());
+                retval = Objects().get<Fleet>(ship->FleetID());
         }
         return retval;
     }
@@ -767,12 +762,12 @@ double Pathfinder::LinearDistance(int system1_id, int system2_id) const {
 }
 
 double Pathfinder::PathfinderImpl::LinearDistance(int system1_id, int system2_id) const {
-    std::shared_ptr<const System> system1 = GetSystem(system1_id);
+    const auto system1 = Objects().get<System>(system1_id);
     if (!system1) {
         ErrorLogger() << "Universe::LinearDistance passed invalid system id: " << system1_id;
         throw std::out_of_range("system1_id invalid");
     }
-    std::shared_ptr<const System> system2 = GetSystem(system2_id);
+    const auto system2 = Objects().get<System>(system2_id);
     if (!system2) {
         ErrorLogger() << "Universe::LinearDistance passed invalid system id: " << system2_id;
         throw std::out_of_range("system2_id invalid");
@@ -797,6 +792,12 @@ short Pathfinder::PathfinderImpl::JumpDistanceBetweenSystems(int system1_id, int
         size_t system2_index = m_system_id_to_graph_index.at(system2_id);
         size_t smaller_index = (std::min)(system1_index, system2_index);
         size_t other_index   = (std::max)(system1_index, system2_index);
+
+#if BOOST_VERSION >= 106000
+        using boost::placeholders::_1;
+        using boost::placeholders::_2;
+#endif
+
         // prefer filling the smaller row/column for increased cache locality
         short jumps = cache.get_T(
             smaller_index, other_index,
@@ -826,12 +827,12 @@ namespace {
     typedef boost::variant<std::nullptr_t, int, std::pair<int, int>> GeneralizedLocationType;
 
     /** Return the location of \p obj.*/
-    GeneralizedLocationType GeneralizedLocation(std::shared_ptr<const UniverseObject> obj) {
+    GeneralizedLocationType GeneralizedLocation(const std::shared_ptr<const UniverseObject>& obj) {
         if (!obj)
             return nullptr;
 
         int system_id = obj->SystemID();
-        auto system = GetSystem(system_id);
+        auto system = Objects().get<System>(system_id);
         if (system)
             return system_id;
 
@@ -852,7 +853,7 @@ namespace {
 
     /** Return the location of the object with id \p object_id.*/
     GeneralizedLocationType GeneralizedLocation(int object_id) {
-        auto obj = GetUniverseObject(object_id);
+        auto obj = Objects().get(object_id);
         return GeneralizedLocation(obj);
     }
 
@@ -995,7 +996,7 @@ std::pair<std::list<int>, double> Pathfinder::PathfinderImpl::ShortestPath(int s
     } catch (const std::out_of_range&) {
         ErrorLogger() << "PathfinderImpl::ShortestPath passed invalid system id(s): "
                       << system1_id << " & " << system2_id;
-        throw;
+        return {std::list<int>(), -1.0};
     }
 }
 
@@ -1044,16 +1045,16 @@ double Pathfinder::PathfinderImpl::ShortestPathDistance(int object1_id, int obje
     // If one or both objects are (in) a fleet between systems, use the destination system
     // and add the distance from the fleet to the destination system, essentially calculating
     // the distance travelled until both could be in the same system.
-    std::shared_ptr<const UniverseObject> obj1 = GetUniverseObject(object1_id);
+    const auto obj1 = Objects().get(object1_id);
     if (!obj1)
         return -1;
 
-    std::shared_ptr<const UniverseObject> obj2 = GetUniverseObject(object2_id);
+    const auto obj2 = Objects().get(object2_id);
     if (!obj2)
         return -1;
 
-    std::shared_ptr<const System> system_one = GetSystem(obj1->SystemID());
-    std::shared_ptr<const System> system_two = GetSystem(obj2->SystemID());
+    auto system_one = Objects().get<System>(obj1->SystemID());
+    auto system_two = Objects().get<System>(obj2->SystemID());
     std::pair< std::list< int >, double > path_len_pair;
     double dist1(0.0), dist2(0.0);
     std::shared_ptr<const Fleet> fleet;
@@ -1062,7 +1063,7 @@ double Pathfinder::PathfinderImpl::ShortestPathDistance(int object1_id, int obje
         fleet = FleetFromObject(obj1);
         if (!fleet)
             return -1;
-        if (std::shared_ptr<const System> next_sys = GetSystem(fleet->NextSystemID())) {
+        if (auto next_sys = Objects().get<System>(fleet->NextSystemID())) {
             system_one = next_sys;
             dist1 = std::sqrt(pow((next_sys->X() - fleet->X()), 2) + pow((next_sys->Y() - fleet->Y()), 2));
         }
@@ -1072,7 +1073,7 @@ double Pathfinder::PathfinderImpl::ShortestPathDistance(int object1_id, int obje
         fleet = FleetFromObject(obj2);
         if (!fleet)
             return -1;
-        if (std::shared_ptr<const System> next_sys = GetSystem(fleet->NextSystemID())) {
+        if (auto next_sys = Objects().get<System>(fleet->NextSystemID())) {
             system_two = next_sys;
             dist2 = std::sqrt(pow((next_sys->X() - fleet->X()), 2) + pow((next_sys->Y() - fleet->Y()), 2));
         }
@@ -1139,7 +1140,7 @@ bool Pathfinder::SystemHasVisibleStarlanes(int system_id, int empire_id) const
 { return pimpl->SystemHasVisibleStarlanes(system_id, empire_id); }
 
 bool Pathfinder::PathfinderImpl::SystemHasVisibleStarlanes(int system_id, int empire_id) const {
-    if (auto system = GetEmpireKnownSystem(system_id, empire_id))
+    if (auto system = EmpireKnownObjects(empire_id).get<System>(system_id))
         if (!system->StarlanesWormholes().empty())
             return true;
     return false;
@@ -1198,6 +1199,11 @@ std::unordered_set<int> Pathfinder::PathfinderImpl::WithinJumps(
         if (jumps == 0)
             continue;
 
+#if BOOST_VERSION >= 106000
+        using boost::placeholders::_1;
+        using boost::placeholders::_2;
+#endif
+
         cache.examine_row(system_index,
                           boost::bind(&Pathfinder::PathfinderImpl::HandleCacheMiss, this, _1, _2),
                           boost::bind(&Pathfinder::PathfinderImpl::WithinJumpsCacheHit, this,
@@ -1337,13 +1343,18 @@ bool Pathfinder::PathfinderImpl::WithinJumpsOfOthers(
         return false;
     }
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
     // Examine the cache to see if \p system_id is within \p jumps of \p others
     bool within_jumps(false);
     distance_matrix_cache<distance_matrix_storage<short>> cache(m_system_jumps);
     cache.examine_row(system_index,
                       boost::bind(&Pathfinder::PathfinderImpl::HandleCacheMiss, this, _1, _2),
                       boost::bind(&Pathfinder::PathfinderImpl::WithinJumpsOfOthersCacheHit, this,
-                                  boost::ref(within_jumps), jumps, others, _1, _2));
+                                  std::ref(within_jumps), jumps, others, _1, _2));
     return within_jumps;
 }
 
@@ -1351,10 +1362,10 @@ int Pathfinder::NearestSystemTo(double x, double y) const
 { return pimpl->NearestSystemTo(x, y); }
 
 int Pathfinder::PathfinderImpl::NearestSystemTo(double x, double y) const {
-    double min_dist2 = DBL_MAX;
+    double min_dist2 = std::numeric_limits<double>::max();
     int min_dist2_sys_id = INVALID_OBJECT_ID;
 
-    auto systems = Objects().FindObjects<System>();
+    auto systems = Objects().all<System>();
 
     for (auto const& system : systems) {
         double xs = system->X();
@@ -1414,7 +1425,7 @@ void Pathfinder::PathfinderImpl::InitializeSystemGraph(
     // add edges for all starlanes
     for (size_t system1_index = 0; system1_index < system_ids.size(); ++system1_index) {
         int system1_id = system_ids[system1_index];
-        std::shared_ptr<const System> system1 = GetEmpireKnownSystem(system1_id, for_empire_id);
+        std::shared_ptr<const System> system1 = EmpireKnownObjects(for_empire_id).get<System>(system1_id);
         //std::shared_ptr<const System> & system1 = systems[system1_index];
 
         // add edges and edge weights
