@@ -27,8 +27,7 @@ public:
     bool                    Contains(int object_id) const override;
     bool                    ContainedBy(int object_id) const override;
 
-    float                   CurrentMeterValue(MeterType type) const override;
-    float                   InitialMeterValue(MeterType type) const override;
+    const Meter*            GetMeter(MeterType type) const override;
 
     std::shared_ptr<UniverseObject> Accept(const UniverseObjectVisitor& visitor) const override;
 
@@ -71,6 +70,7 @@ public:
     bool IsAboutToBeBombarded() const           { return m_is_about_to_be_bombarded; }
     int OrderedGivenToEmpire() const            { return m_ordered_given_to_empire_id; }
     int LastTurnAttackedByShip() const          { return m_last_turn_attacked_by_ship; }
+    int LastTurnColonized() const               { return m_turn_last_colonized; }
     int LastTurnConquered() const               { return m_turn_last_conquered; }
 
     const std::string&  SurfaceTexture() const  { return m_surface_texture; }
@@ -85,6 +85,7 @@ public:
 
     void Reset() override;
     void Depopulate() override;
+    void SetSpecies(const std::string& species_name) override;
 
     void SetType(PlanetType type);          ///< sets the type of this Planet to \a type
     void SetOriginalType(PlanetType type);  ///< sets the original type of this Planet to \a type
@@ -128,7 +129,7 @@ public:
     ~Planet() {}
 
 protected:
-    template <class T>
+    template <typename T>
     friend void boost::python::detail::value_destroyer<false>::execute(T const volatile* p);
 
 protected:
@@ -142,8 +143,6 @@ private:
     Visibility GetVisibility(int empire_id) const override
     { return UniverseObject::GetVisibility(empire_id); }
 
-    const Meter* GetMeter(MeterType type) const override;
-
     void AddMeter(MeterType meter_type) override
     { UniverseObject::AddMeter(meter_type); }
 
@@ -161,6 +160,7 @@ private:
 
     std::set<int>   m_buildings;
 
+    int             m_turn_last_colonized = INVALID_GAME_TURN;
     int             m_turn_last_conquered = INVALID_GAME_TURN;
     bool            m_is_about_to_be_colonized = false;
     bool            m_is_about_to_be_invaded = false;
@@ -171,7 +171,7 @@ private:
     std::string     m_surface_texture;  // intentionally not serialized; set by local effects
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
