@@ -3,10 +3,10 @@
 #include "../util/Directories.h"
 #include "../util/Logger.h"
 #include "../util/OptionsDB.h"
+#include "../util/AppInterface.h"
 #include "../Empire/Empire.h"
 #include "Fleet.h"
 #include "Planet.h"
-#include "ShipDesign.h"
 #include "System.h"
 #include "Building.h"
 #include "Enums.h"
@@ -101,7 +101,8 @@ void ResourceCenter::SetFocus(const std::string& focus) {
         return;
     }
     auto avail_foci = AvailableFoci();
-    if (std::count(avail_foci.begin(), avail_foci.end(), focus)) {
+    auto foci_it = std::find(avail_foci.begin(), avail_foci.end(), focus);
+    if (foci_it != avail_foci.end()) {
         m_focus = focus;
         if (m_focus == m_focus_turn_initial)
             m_last_turn_focus_changed = m_last_turn_focus_changed_turn_initial;
@@ -120,7 +121,7 @@ void ResourceCenter::ClearFocus() {
 }
 
 void ResourceCenter::UpdateFocusHistory() {
-    DebugLogger() << "ResourceCenter::UpdateFocusHistory: focus: " << m_focus
+    TraceLogger() << "ResourceCenter::UpdateFocusHistory: focus: " << m_focus
                   << "  initial focus: " << m_focus_turn_initial
                   << "  turns since change initial: " << m_last_turn_focus_changed_turn_initial;
     if (m_focus != m_focus_turn_initial) {
