@@ -8,6 +8,8 @@
 #include "Fleet.h"
 #include "Predicates.h"
 #include "ShipDesign.h"
+#include "ShipPart.h"
+#include "ShipHull.h"
 #include "Species.h"
 #include "Universe.h"
 #include "Enums.h"
@@ -57,8 +59,8 @@ Ship::Ship(int empire_id, int design_id, const std::string& species_name,
 
     const std::vector<std::string>& part_names = Design()->Parts();
     for (const std::string& part_name : part_names) {
-        if (part_name != "") {
-            const PartType* part = GetPartType(part_name);
+        if (!part_name.empty()) {
+            const ShipPart* part = GetShipPart(part_name);
             if (!part) {
                 ErrorLogger() << "Ship::Ship couldn't get part with name " << part_name;
                 continue;
@@ -117,7 +119,7 @@ void Ship::Copy(std::shared_ptr<const UniverseObject> copied_object, int empire_
     if (vis >= VIS_BASIC_VISIBILITY) {
         if (this->m_fleet_id != copied_ship->m_fleet_id) {
             // as with other containers, removal from the old container is triggered by the contained Object; removal from System is handled by UniverseObject::Copy
-            if (auto old_fleet = GetFleet(this->m_fleet_id))
+            if (auto old_fleet = Objects().get<Fleet>(this->m_fleet_id))
                 old_fleet->RemoveShips({this->ID()});
             this->m_fleet_id = copied_ship->m_fleet_id; // as with other containers (Systems), actual insertion into fleet ships set is handled by the fleet
         }
@@ -160,7 +162,7 @@ std::set<std::string> Ship::Tags() const {
     if (!design)
         return retval;
 
-    const HullType* hull = ::GetHullType(design->Hull());
+    const ShipHull* hull = ::GetShipHull(design->Hull());
     if (!hull)
         return retval;
     retval.insert(hull->Tags().begin(), hull->Tags().end());
@@ -170,7 +172,7 @@ std::set<std::string> Ship::Tags() const {
         return retval;
 
     for (const std::string& part_name : parts) {
-        if (const PartType* part = GetPartType(part_name)) {
+        if (const ShipPart* part = GetShipPart(part_name)) {
             retval.insert(part->Tags().begin(), part->Tags().end());
         }
     }
@@ -182,13 +184,13 @@ bool Ship::HasTag(const std::string& name) const {
     const ShipDesign* design = GetShipDesign(m_design_id);
     if (design) {
         // check hull for tag
-        const HullType* hull = ::GetHullType(design->Hull());
+        const ShipHull* hull = ::GetShipHull(design->Hull());
         if (hull && hull->Tags().count(name))
             return true;
 
         // check parts for tag
         for (const std::string& part_name : design->Parts()) {
-            const PartType* part = GetPartType(part_name);
+            const ShipPart* part = GetShipPart(part_name);
             if (part && part->Tags().count(name))
                 return true;
         }
@@ -222,13 +224,11 @@ std::string Ship::Dump(unsigned short ntabs) const {
     if (!m_part_meters.empty()) {
         os << " part meters: ";
         for (const auto& entry : m_part_meters) {
-        const std::string part_name = entry.first.second;
-        MeterType meter_type = entry.first.first;
-        const Meter& meter = entry.second;
-        os << part_name << " "
-           << meter_type
-           << ": " << meter.Current() << "  ";
-    }
+            const std::string part_name = entry.first.second;
+            MeterType meter_type = entry.first.first;
+            const Meter& meter = entry.second;
+            os << part_name << " " << meter_type << ": " << meter.Current() << "  ";
+        }
     }
     return os.str();
 }
@@ -245,19 +245,18 @@ bool Ship::IsMonster() const {
 }
 
 bool Ship::IsArmed() const {
-    const ShipDesign* design = Design();
-    if (design)
-        return design->IsArmed();
-    else
-        return false;
+    if (TotalWeaponsDamage(0.0f, false) > 0.0f)
+        return true;    // has non-fighter weapons
+    if (HasFighters() && (TotalWeaponsDamage(0.0f, true) > 0.0f))
+        return true;    // has no non-fighter weapons but has launchable fighters that do damage
+    return false;
 }
 
 bool Ship::HasFighters() const {
     const ShipDesign* design = Design();
-    if (design)
-        return design->HasFighters();
-    else
+    if (!design || !design->HasFighters())  // ensures ship has ability to launch fighters
         return false;
+    return FighterCount() >= 1.0f;          // ensures ship currently has fighters to launch
 }
 
 bool Ship::CanColonize() const {
@@ -281,7 +280,7 @@ bool Ship::CanBombard() const {
 }
 
 float Ship::Speed() const
-{ return InitialMeterValue(METER_SPEED); }
+{ return GetMeter(METER_SPEED)->Initial(); }
 
 float Ship::ColonyCapacity() const {
     float retval = 0.0f;
@@ -293,10 +292,10 @@ float Ship::ColonyCapacity() const {
     for (const std::string& part_name : design->Parts()) {
         if (part_name.empty())
             continue;
-        const PartType* part_type = GetPartType(part_name);
-        if (!part_type)
+        const ShipPart* part = GetShipPart(part_name);
+        if (!part)
             continue;
-        ShipPartClass part_class = part_type->Class();
+        ShipPartClass part_class = part->Class();
         if (part_class != PC_COLONY)
             continue;
         // add capacity for all instances of colony parts to accumulator
@@ -316,10 +315,10 @@ float Ship::TroopCapacity() const {
     for (const std::string& part_name : design->Parts()) {
         if (part_name.empty())
             continue;
-        const PartType* part_type = GetPartType(part_name);
-        if (!part_type)
+        const ShipPart* part = GetShipPart(part_name);
+        if (!part)
             continue;
-        ShipPartClass part_class = part_type->Class();
+        ShipPartClass part_class = part->Class();
         if (part_class != PC_TROOPS)
             continue;
         // add capacity for all instances of colony parts to accumulator
@@ -401,10 +400,10 @@ float Ship::SumCurrentPartMeterValuesForPartClass(MeterType type, ShipPartClass
         const std::string& part_name = part_meter.first.second;
         if (part_counts[part_name] < 1)
             continue;
-        const PartType* part_type = GetPartType(part_name);
-        if (!part_type)
+        const ShipPart* part = GetShipPart(part_name);
+        if (!part)
             continue;
-        if (part_class == part_type->Class())
+        if (part_class == part->Class())
             retval += part_meter.second.Current() * part_counts[part_name];
     }
 
@@ -416,8 +415,8 @@ float Ship::FighterCount() const {
     for (const auto& entry : m_part_meters) {
         if (entry.first.first != METER_CAPACITY)
             continue;
-        const PartType* part_type = GetPartType(entry.first.second);
-        if (!part_type || part_type->Class() != PC_FIGHTER_HANGAR)
+        const ShipPart* part = GetShipPart(entry.first.second);
+        if (!part || part->Class() != PC_FIGHTER_HANGAR)
             continue;
         retval += entry.second.Current();
     }
@@ -431,8 +430,8 @@ float Ship::FighterMax() const {
         //std::map<std::pair<MeterType, std::string>, Meter>
         if (entry.first.first != METER_MAX_CAPACITY)
             continue;
-        const PartType* part_type = GetPartType(entry.first.second);
-        if (!part_type || part_type->Class() != PC_FIGHTER_HANGAR)
+        const ShipPart* part = GetShipPart(entry.first.second);
+        if (!part || part->Class() != PC_FIGHTER_HANGAR)
             continue;
         retval += entry.second.Current();
     }
@@ -470,7 +469,7 @@ namespace {
 
         // for each weapon part, get its damage meter value
         for (const std::string& part_name : parts) {
-            const PartType* part = GetPartType(part_name);
+            const ShipPart* part = GetShipPart(part_name);
             if (!part)
                 continue;
             ShipPartClass part_class = part->Class();
@@ -576,12 +575,18 @@ void Ship::Resupply() {
     // this "upgrades" any direct-fire weapon parts to their latest-allowed
     // strengths, and replaces any lost fighters
     for (auto& entry : m_part_meters) {
-        auto max_it = m_part_meters.end();
-        if (entry.first.first == METER_CAPACITY) {
-            max_it = m_part_meters.find({METER_MAX_CAPACITY, entry.first.second});
-        } else if (entry.first.first == METER_SECONDARY_STAT) {
-            max_it = m_part_meters.find({METER_MAX_SECONDARY_STAT, entry.first.second});
+        const auto& part_name = entry.first.second;
+        MeterType meter_type = entry.first.first;
+        MeterType paired_meter_type = INVALID_METER_TYPE;
+        switch(meter_type) {
+        case METER_CAPACITY:        paired_meter_type = METER_MAX_CAPACITY;         break;
+        case METER_SECONDARY_STAT:  paired_meter_type = METER_MAX_SECONDARY_STAT;   break;
+        default:
+            break;
         }
+        if (paired_meter_type == INVALID_METER_TYPE)
+            continue;
+        auto max_it = m_part_meters.find({paired_meter_type, part_name});
         if (max_it == m_part_meters.end())
             continue;
 
@@ -645,15 +650,31 @@ void Ship::ResetTargetMaxUnpairedMeters() {
     UniverseObject::GetMeter(METER_SPEED)->ResetCurrent();
     //UniverseObject::GetMeter(METER_STEALTH)->ResetCurrent(); redundant with base class function
 
+    // max meters are always treated as target/max meters.
+    // other meters may be unpaired if there is no associated max or target meter
     for (auto& entry : m_part_meters) {
-        auto max_it = m_part_meters.end();
-        if (entry.first.first == METER_CAPACITY) {
-            max_it = m_part_meters.find({METER_MAX_CAPACITY, entry.first.second});
-        } else if (entry.first.first == METER_SECONDARY_STAT) {
-            max_it = m_part_meters.find({METER_MAX_SECONDARY_STAT, entry.first.second});
-        }
-        if (max_it != m_part_meters.end())
+        const auto& part_name = entry.first.second;
+        MeterType meter_type = entry.first.first;
+        MeterType paired_meter_type = INVALID_METER_TYPE;
+
+        switch(meter_type) {
+        case METER_MAX_CAPACITY:
+        case METER_MAX_SECONDARY_STAT:
+            entry.second.ResetCurrent();
             continue;
+            break;
+        case METER_CAPACITY:        paired_meter_type = METER_MAX_CAPACITY;         break;
+        case METER_SECONDARY_STAT:  paired_meter_type = METER_MAX_SECONDARY_STAT;   break;
+        default:
+            continue;
+            break;
+        }
+
+        auto max_it = m_part_meters.find({paired_meter_type, part_name});
+        if (max_it != m_part_meters.end())
+            continue;   // is a max/target meter associated with the meter, so don't treat this a target/max
+
+        // no associated target/max meter, so treat this meter as unpaired
         entry.second.ResetCurrent();
     }
 }
@@ -661,15 +682,32 @@ void Ship::ResetTargetMaxUnpairedMeters() {
 void Ship::ResetPairedActiveMeters() {
     UniverseObject::ResetPairedActiveMeters();
 
+    // meters are paired only if they are not max/target meters, and there is an
+    // associated max/target meter
     for (auto& entry : m_part_meters) {
-        auto max_it = m_part_meters.end();
-        if (entry.first.first == METER_CAPACITY) {
-            max_it = m_part_meters.find({METER_MAX_CAPACITY, entry.first.second});
-        } else if (entry.first.first == METER_SECONDARY_STAT) {
-            max_it = m_part_meters.find({METER_MAX_SECONDARY_STAT, entry.first.second});
+        const auto& part_name = entry.first.second;
+        MeterType meter_type = entry.first.first;
+        MeterType paired_meter_type = INVALID_METER_TYPE;
+
+        switch(meter_type) {
+        case METER_MAX_CAPACITY:
+        case METER_MAX_SECONDARY_STAT:
+            continue;   // is a max/target meter
+            break;
+        case METER_CAPACITY:        paired_meter_type = METER_MAX_CAPACITY;         break;
+        case METER_SECONDARY_STAT:  paired_meter_type = METER_MAX_SECONDARY_STAT;   break;
+        default:
+            continue;   // no associated max/target meter
+            break;
         }
-        if (max_it != m_part_meters.end())
-            entry.second.SetCurrent(entry.second.Initial());
+
+        auto max_it = m_part_meters.find({paired_meter_type, part_name});
+        if (max_it == m_part_meters.end())
+            continue;   // no associated max/target meter
+
+        // has an associated max/target meter.
+        //std::map<std::pair<MeterType, std::string>, Meter>::iterator
+        entry.second.SetCurrent(entry.second.Initial());
     }
 }
 
@@ -682,18 +720,8 @@ void Ship::SetShipMetersToMax() {
     UniverseObject::GetMeter(METER_STRUCTURE)->SetCurrent(Meter::LARGE_VALUE);
 
     // some part capacity meters may have an associated max capacity...
-    for (auto& entry : m_part_meters) {
-        auto max_it = m_part_meters.end();
-        if (entry.first.first == METER_CAPACITY) {
-            max_it = m_part_meters.find({METER_MAX_CAPACITY, entry.first.second});
-        } else if (entry.first.first == METER_SECONDARY_STAT) {
-            max_it = m_part_meters.find({METER_MAX_SECONDARY_STAT, entry.first.second});
-        }
-        if (max_it == m_part_meters.end())
-            continue;
-        max_it->second.SetCurrent(Meter::LARGE_VALUE);
+    for (auto& entry : m_part_meters)
         entry.second.SetCurrent(Meter::LARGE_VALUE);
-    }
 }
 
 void Ship::ClampMeters() {
@@ -717,25 +745,33 @@ void Ship::ClampMeters() {
 
     // clamp most part meters to basic range limits
     for (auto& entry : m_part_meters) {
-        if (entry.first.first == METER_CAPACITY || entry.first.first == METER_SECONDARY_STAT)
-            continue;
-        entry.second.ClampCurrentToRange();
+        MeterType meter_type = entry.first.first;
+        switch(meter_type) {
+        case METER_MAX_CAPACITY:
+        case METER_MAX_SECONDARY_STAT:
+            entry.second.ClampCurrentToRange();
+        default:
+            break;
+        }
     }
 
-    // special case extra clamping for paired CAPACTY meters dependent on their associated MAX_CAPACITY meter...
+    // special case extra clamping for paired active meters dependent
+    // on their associated max meter...
     for (auto& entry : m_part_meters) {
-        auto max_it = m_part_meters.end();
-        if (entry.first.first == METER_CAPACITY) {
-            max_it = m_part_meters.find({METER_MAX_CAPACITY, entry.first.second});
-        } else if (entry.first.first == METER_SECONDARY_STAT) {
-            max_it = m_part_meters.find({METER_MAX_SECONDARY_STAT, entry.first.second});
+        const auto& part_name = entry.first.second;
+        MeterType meter_type = entry.first.first;
+        MeterType paired_meter_type = INVALID_METER_TYPE;
+        switch(meter_type) {
+        case METER_CAPACITY:        paired_meter_type = METER_MAX_CAPACITY;         break;
+        case METER_SECONDARY_STAT:  paired_meter_type = METER_MAX_SECONDARY_STAT;   break;
+        default:
+            break;
         }
-
-        if (max_it == m_part_meters.end()) {
-            // no found max meter, revert to normal clamping for this meter
-            entry.second.ClampCurrentToRange();
+        if (paired_meter_type == INVALID_METER_TYPE)
+            continue;
+        auto max_it = m_part_meters.find({paired_meter_type, part_name});
+        if (max_it == m_part_meters.end())
             continue;
-        }
 
         const Meter& max_meter = max_it->second;
         entry.second.ClampCurrentToRange(Meter::DEFAULT_VALUE, max_meter.Current());
