@@ -74,7 +74,7 @@ public:
     const PartMeterMap&         PartMeters() const { return m_part_meters; }                                ///< returns this Ship's part meters
     const Meter*                GetPartMeter(MeterType type, const std::string& part_name) const;           ///< returns the requested part Meter, or 0 if no such part Meter of that type is found in this ship for that part name
     float                       CurrentPartMeterValue(MeterType type, const std::string& part_name) const;  ///< returns current value of the specified part meter \a type for the specified part name
-    float                       InitialPartMeterValue(MeterType type, const std::string& part_name) const;  ///< returns this turn's initial value for the speicified part meter \a type for the specified part name
+    float                       InitialPartMeterValue(MeterType type, const std::string& part_name) const;  ///< returns this turn's initial value for the specified part meter \a type for the specified part name
 
     /** Returns sum of current value for part meter @p type of all parts with ShipPartClass @p part_class */
     float                       SumCurrentPartMeterValuesForPartClass(MeterType type, ShipPartClass part_class) const;
@@ -122,7 +122,7 @@ public:
          int produced_by_empire_id = ALL_EMPIRES);
 
 protected:
-    template <class T> friend void boost::python::detail::value_destroyer<false>::execute(T const volatile* p);
+    template <typename T> friend void boost::python::detail::value_destroyer<false>::execute(T const volatile* p);
 
 public:
     ~Ship() {}
@@ -143,7 +143,7 @@ private:
     int             m_last_resupplied_on_turn = BEFORE_FIRST_TURN;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
