@@ -2,8 +2,6 @@
 #define _Special_h_
 
 
-#include "ValueRefFwd.h"
-
 #include <boost/serialization/nvp.hpp>
 #include <boost/optional/optional.hpp>
 
@@ -20,7 +18,11 @@ namespace Effect {
     class EffectsGroup;
 }
 namespace Condition {
-    struct ConditionBase;
+    struct Condition;
+}
+namespace ValueRef {
+    template <typename T>
+    struct ValueRef;
 }
 
 /** A predefined set of EffectsGroups that can be attached to a UniverseObject
@@ -32,33 +34,33 @@ class FO_COMMON_API Special {
 public:
     /** \name Structors */ //@{
     Special(const std::string& name, const std::string& description,
-            std::unique_ptr<ValueRef::ValueRefBase<double>>&& stealth,
+            std::unique_ptr<ValueRef::ValueRef<double>>&& stealth,
             std::vector<std::unique_ptr<Effect::EffectsGroup>>&& effects,
             double spawn_rate = 1.0, int spawn_limit = 99999,
-            std::unique_ptr<ValueRef::ValueRefBase<double>>&& initial_capaicty = nullptr,
-            std::unique_ptr<Condition::ConditionBase>&& location = nullptr,
+            std::unique_ptr<ValueRef::ValueRef<double>>&& initial_capaicty = nullptr,
+            std::unique_ptr<Condition::Condition>&& location = nullptr,
             const std::string& graphic = "");
 
     ~Special();
     //@}
 
     /** \name Accessors */ //@{
-    const std::string&                      Name() const        { return m_name; }          ///< returns the unique name for this type of special
-    std::string                             Description() const;                            ///< returns a text description of this type of special
-    std::string                             Dump(unsigned short ntabs = 0) const;           ///< returns a data file format representation of this object
-    const ValueRef::ValueRefBase<double>*   Stealth() const     { return m_stealth.get(); } ///< returns the stealth of the special, which determines how easily it is seen by empires
+    const std::string&                  Name() const            { return m_name; }          ///< returns the unique name for this type of special
+    std::string                         Description() const;                                ///< returns a text description of this type of special
+    std::string                         Dump(unsigned short ntabs = 0) const;               ///< returns a data file format representation of this object
+    const ValueRef::ValueRef<double>*   Stealth() const         { return m_stealth.get(); } ///< returns the stealth of the special, which determines how easily it is seen by empires
 
     /** Returns the EffectsGroups that encapsulate the effects that specials of
         this type have. */
     const std::vector<std::shared_ptr<Effect::EffectsGroup>>& Effects() const
     { return m_effects; }
 
-    float                                   SpawnRate() const       { return m_spawn_rate; }
-    int                                     SpawnLimit() const      { return m_spawn_limit; }
-    const ValueRef::ValueRefBase<double>*   InitialCapacity() const { return m_initial_capacity.get(); }///< returns the ValueRef to use to set the initial capacity of the special when placed
-    float                                   InitialCapacity(int object_id) const;                       ///< evaluates initial apacity ValueRef using the object with specified \a object_id as the object on which the special will be placed
-    const Condition::ConditionBase*         Location() const        { return m_location.get(); }        ///< returns the condition that determines whether an UniverseObject can have this special applied during universe creation
-    const std::string&                      Graphic() const         { return m_graphic; };              ///< returns the name of the grapic file for this special
+    float                               SpawnRate() const       { return m_spawn_rate; }
+    int                                 SpawnLimit() const      { return m_spawn_limit; }
+    const ValueRef::ValueRef<double>*   InitialCapacity() const { return m_initial_capacity.get(); }///< returns the ValueRef to use to set the initial capacity of the special when placed
+    float                               InitialCapacity(int object_id) const;                       ///< evaluates initial apacity ValueRef using the object with specified \a object_id as the object on which the special will be placed
+    const Condition::Condition*         Location() const        { return m_location.get(); }        ///< returns the condition that determines whether an UniverseObject can have this special applied during universe creation
+    const std::string&                  Graphic() const         { return m_graphic; };              ///< returns the name of the grapic file for this special
 
     /** Returns a number, calculated from the contained data, which should be
       * different for different contained data, and must be the same for
@@ -66,24 +68,24 @@ public:
       * and executions of the program and the function. Useful to verify that
       * the parsed content is consistent without sending it all between
       * clients and server. */
-    unsigned int                            GetCheckSum() const;
+    unsigned int GetCheckSum() const;
     //@}
 
 private:
-    void    Init();
+    void Init();
 
-    std::string                                         m_name = "";
-    std::string                                         m_description = "";
-    std::unique_ptr<ValueRef::ValueRefBase<double>>     m_stealth;
+    std::string                                         m_name;
+    std::string                                         m_description;
+    std::unique_ptr<ValueRef::ValueRef<double>>         m_stealth;
     std::vector<std::shared_ptr<Effect::EffectsGroup>>  m_effects;
     float                                               m_spawn_rate = 0.0f;
     int                                                 m_spawn_limit = 99999;
-    std::unique_ptr<ValueRef::ValueRefBase<double>>     m_initial_capacity;
-    std::unique_ptr<Condition::ConditionBase>           m_location;
-    std::string                                         m_graphic ="";
+    std::unique_ptr<ValueRef::ValueRef<double>>         m_initial_capacity;
+    std::unique_ptr<Condition::Condition>               m_location;
+    std::string                                         m_graphic;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -95,7 +97,7 @@ FO_COMMON_API const Special* GetSpecial(const std::string& name);
 FO_COMMON_API std::vector<std::string> SpecialNames();
 
 // template implementations
-template <class Archive>
+template <typename Archive>
 void Special::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_NVP(m_name)
@@ -120,9 +122,10 @@ public:
     //@}
 
     /** \name Accessors */ //@{
-    std::vector<std::string> SpecialNames() const;
-    const Special* GetSpecial(const std::string& name) const;
-    unsigned int GetCheckSum() const;
+    int                         NumSpecials() const { return m_specials.size(); }
+    std::vector<std::string>    SpecialNames() const;
+    const Special*              GetSpecial(const std::string& name) const;
+    unsigned int                GetCheckSum() const;
     //@}
 
     /** Sets types to the value of \p future. */
