@@ -20,7 +20,7 @@
 
 
 namespace Condition {
-    struct ConditionBase;
+    struct Condition;
 }
 namespace Effect {
     class EffectsGroup;
@@ -45,7 +45,8 @@ public:
     {}
 
     FocusType(const std::string& name, const std::string& description,
-              std::unique_ptr<Condition::ConditionBase>&& location, const std::string& graphic);
+              std::unique_ptr<Condition::Condition>&& location,
+              const std::string& graphic);
 
     ~FocusType();
     //@}
@@ -53,7 +54,7 @@ public:
     /** \name Accessors */ //@{
     const std::string&              Name() const        { return m_name; }          ///< returns the name for this focus type
     const std::string&              Description() const { return m_description; }   ///< returns a text description of this focus type
-    const Condition::ConditionBase* Location() const    { return m_location.get(); }///< returns the condition that determines whether an UniverseObject can use this FocusType
+    const Condition::Condition*     Location() const    { return m_location.get(); }///< returns the condition that determines whether an UniverseObject can use this FocusType
     const std::string&              Graphic() const     { return m_graphic; }       ///< returns the name of the grapic file for this focus type
     std::string                     Dump(unsigned short ntabs = 0) const;       ///< returns a data file format representation of this object
 
@@ -69,17 +70,13 @@ public:
 private:
     std::string                                     m_name;
     std::string                                     m_description;
-    std::shared_ptr<const Condition::ConditionBase> m_location;
+    std::shared_ptr<const Condition::Condition>     m_location;
     std::string                                     m_graphic;
 };
 
 /** Used by parser due to limits on number of sub-items per parsed main item. */
 struct SpeciesParams {
-    SpeciesParams() :
-        playable(false),
-        native(false),
-        can_colonize(false),
-        can_produce_ships(false)
+    SpeciesParams()
     {}
     SpeciesParams(bool playable_, bool native_, bool can_colonize_, bool can_produce_ships_) :
         playable(playable_),
@@ -87,18 +84,15 @@ struct SpeciesParams {
         can_colonize(can_colonize_),
         can_produce_ships(can_produce_ships_)
     {}
-    bool    playable;
-    bool    native;
-    bool    can_colonize;
-    bool    can_produce_ships;
+    bool playable = false;
+    bool native = false;
+    bool can_colonize = false;
+    bool can_produce_ships = false;
 };
 
 /** Used by parser due to limits on number of sub-items per parsed main item. */
 struct SpeciesStrings {
-    SpeciesStrings() :
-        name(),
-        desc(),
-        gameplay_desc()
+    SpeciesStrings()
     {}
     SpeciesStrings(const std::string& name_, const std::string& desc_,
                    const std::string& gameplay_desc_) :
@@ -106,9 +100,9 @@ struct SpeciesStrings {
         desc(desc_),
         gameplay_desc(gameplay_desc_)
     {}
-    std::string             name;
-    std::string             desc;
-    std::string             gameplay_desc;
+    std::string name;
+    std::string desc;
+    std::string gameplay_desc;
 };
 
 /** A predefined type of population that can exist on a PopulationCenter.
@@ -124,6 +118,7 @@ public:
             const std::string& preferred_focus,
             const std::map<PlanetType, PlanetEnvironment>& planet_environments,
             std::vector<std::unique_ptr<Effect::EffectsGroup>>&& effects,
+            std::unique_ptr<Condition::Condition>&& combat_targets,
             const SpeciesParams& params,
             const std::set<std::string>& tags,
             const std::string& graphic);
@@ -141,14 +136,15 @@ public:
     const std::map<int, double>&            EmpireOpinions() const      { return m_empire_opinions; }       ///< returns the positive/negative opinions of this species about empires
     const std::map<std::string, double>&    OtherSpeciesOpinions() const{ return m_other_species_opinions; }///< returns the positive/negative opinions of this species about other species
 
-    const Condition::ConditionBase* Location() const;
+    const Condition::Condition*     Location() const                    { return m_location.get(); }        ///< returns the condition determining what planets on which this species may spawn
+    const Condition::Condition*     CombatTargets() const               { return m_combat_targets.get(); }  ///< returns the condition for possible targets. may be nullptr if no condition was specified.
 
-    std::string                     Dump(unsigned short ntabs = 0) const;                                           ///< returns a data file format representation of this object
-    const std::vector<FocusType>&   Foci() const            { return m_foci; }              ///< returns the focus types this species can use
-    const std::string&              PreferredFocus() const  { return m_preferred_focus; }   ///< returns the name of the planetary focus this species prefers. Default for new colonies and may affect happiness if on a different focus?
+    std::string                     Dump(unsigned short ntabs = 0) const;                                   ///< returns a data file format representation of this object
+    const std::vector<FocusType>&   Foci() const                        { return m_foci; }                  ///< returns the focus types this species can use
+    const std::string&              PreferredFocus() const              { return m_preferred_focus; }       ///< returns the name of the planetary focus this species prefers. Default for new colonies and may affect happiness if on a different focus?
     const std::map<PlanetType, PlanetEnvironment>& PlanetEnvironments() const { return m_planet_environments; } ///< returns a map from PlanetType to the PlanetEnvironment this Species has on that PlanetType
-    PlanetEnvironment               GetPlanetEnvironment(PlanetType planet_type) const;     ///< returns the PlanetEnvironment this species has on PlanetType \a planet_type
-    PlanetType                      NextBetterPlanetType(PlanetType initial_planet_type) const; ///< returns the next better PlanetType for this species from the \a initial_planet_type specified
+    PlanetEnvironment               GetPlanetEnvironment(PlanetType planet_type) const;                     ///< returns the PlanetEnvironment this species has on PlanetType \a planet_type
+    PlanetType                      NextBetterPlanetType(PlanetType initial_planet_type) const;             ///< returns the next better PlanetType for this species from the \a initial_planet_type specified
 
     /** Returns the EffectsGroups that encapsulate the effects that species of
         this type have. */
@@ -172,13 +168,13 @@ public:
     //@}
 
     /** \name Mutators */ //@{
-    void    AddHomeworld(int homeworld_id);
-    void    RemoveHomeworld(int homeworld_id);
-    void    SetHomeworlds(const std::set<int>& homeworld_ids);
-    void    SetEmpireOpinions(const std::map<int, double>& opinions);
-    void    SetEmpireOpinion(int empire_id, double opinion);
-    void    SetOtherSpeciesOpinions(const std::map<std::string, double>& opinions);
-    void    SetOtherSpeciesOpinion(const std::string& species_name, double opinion);
+    void AddHomeworld(int homeworld_id);
+    void RemoveHomeworld(int homeworld_id);
+    void SetHomeworlds(const std::set<int>& homeworld_ids);
+    void SetEmpireOpinions(const std::map<int, double>& opinions);
+    void SetEmpireOpinion(int empire_id, double opinion);
+    void SetOtherSpeciesOpinions(const std::map<std::string, double>& opinions);
+    void SetOtherSpeciesOpinion(const std::string& species_name, double opinion);
     //@}
 
 private:
@@ -196,9 +192,9 @@ private:
     std::string                             m_preferred_focus;
     std::map<PlanetType, PlanetEnvironment> m_planet_environments;
 
-    std::vector<std::shared_ptr<Effect::EffectsGroup>> m_effects;
-
-    mutable std::unique_ptr<Condition::ConditionBase>       m_location;
+    std::vector<std::shared_ptr<Effect::EffectsGroup>>  m_effects;
+    std::unique_ptr<Condition::Condition>               m_location;
+    std::unique_ptr<Condition::Condition>               m_combat_targets;
 
     bool                                    m_playable;
     bool                                    m_native;
@@ -246,7 +242,7 @@ public:
     native_iterator     native_end() const;
 
     /** returns an ordered list of tags that should be considered for census listings. */
-    const CensusOrder& census_order() const;
+    const CensusOrder&  census_order() const;
 
     /** returns true iff this SpeciesManager is empty. */
     bool                empty() const;
@@ -307,29 +303,28 @@ public:
     /** sets all species to have no homeworlds.  this is useful when generating
       * a new game, when any homeworlds species had in the previous game should
       * be removed before the new game's homeworlds are added. */
-    void    ClearSpeciesHomeworlds();
+    void ClearSpeciesHomeworlds();
 
     /** sets the opinions of species (indexed by name string) of empires (indexed
       * by id) as a double-valued number. */
-    void    SetSpeciesEmpireOpinions(const std::map<std::string, std::map<int, float>>& species_empire_opinions);
-    void    SetSpeciesEmpireOpinion(const std::string& species_name, int empire_id, float opinion);
+    void SetSpeciesEmpireOpinions(const std::map<std::string, std::map<int, float>>& species_empire_opinions);
+    void SetSpeciesEmpireOpinion(const std::string& species_name, int empire_id, float opinion);
 
     /** sets the opinions of species (indexed by name string) of other species
       * (indexed by name string) as a double-valued number. */
-    void    SetSpeciesSpeciesOpinions(const std::map<std::string, std::map<std::string, float>>& species_species_opinions);
-    void    SetSpeciesSpeciesOpinion(const std::string& opinionated_species, const std::string& rated_species, float opinion);
+    void SetSpeciesSpeciesOpinions(const std::map<std::string, std::map<std::string, float>>& species_species_opinions);
+    void SetSpeciesSpeciesOpinion(const std::string& opinionated_species, const std::string& rated_species, float opinion);
 
     /** clears all species opinion data */
-    void    ClearSpeciesOpinions();
+    void ClearSpeciesOpinions();
 
-    void    UpdatePopulationCounter();
+    void UpdatePopulationCounter();
 
     std::map<std::string, std::map<int, float>>&        SpeciesObjectPopulations(int encoding_empire = ALL_EMPIRES);
     std::map<std::string, std::map<std::string, int>>&  SpeciesShipsDestroyed(int encoding_empire = ALL_EMPIRES);
 
     /** Sets species types to the value of \p future. */
-    FO_COMMON_API void SetSpeciesTypes(Pending::Pending<std::pair<SpeciesTypeMap, CensusOrder>>&& future);
-
+    void SetSpeciesTypes(Pending::Pending<std::pair<SpeciesTypeMap, CensusOrder>>&& future);
     //@}
 
 private:
@@ -337,7 +332,7 @@ private:
 
     /** sets the homeworld ids of species in this SpeciesManager to those
       * specified in \a species_homeworld_ids */
-    void    SetSpeciesHomeworlds(const std::map<std::string, std::set<int>>& species_homeworld_ids);
+    void SetSpeciesHomeworlds(const std::map<std::string, std::set<int>>& species_homeworld_ids);
 
     /** Assigns any m_pending_types to m_species. */
     void CheckPendingSpeciesTypes() const;
@@ -357,7 +352,7 @@ private:
     static SpeciesManager* s_instance;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
