@@ -2,12 +2,11 @@
 #define _System_h_
 
 #include "UniverseObject.h"
-
-#include "../util/AppInterface.h"
 #include "../util/Export.h"
 
 #include <map>
 
+class Fleet;
 
 FO_COMMON_API extern const int INVALID_OBJECT_ID;
 namespace {
@@ -113,17 +112,17 @@ public:
     void Insert(std::shared_ptr<UniverseObject> obj, int orbit = -1);
 
     /** removes the object with ID number \a id from this system. */
-    void                    Remove(int id);
+    void Remove(int id);
 
-    void                    SetStarType(StarType type);     ///< sets the type of the star in this Systems to \a StarType
-    void                    AddStarlane(int id);            ///< adds a starlane between this system and the system with ID number \a id.  \note Adding a starlane to a system to which there is already a wormhole erases the wormhole; you may want to check for a wormhole before calling this function.
-    void                    AddWormhole(int id);            ///< adds a wormhole between this system and the system with ID number \a id  \note Adding a wormhole to a system to which there is already a starlane erases the starlane; you may want to check for a starlane before calling this function.
-    bool                    RemoveStarlane(int id);         ///< removes a starlane between this system and the system with ID number \a id.  Returns false if there was no starlane from this system to system \a id.
-    bool                    RemoveWormhole(int id);         ///< removes a wormhole between this system and the system with ID number \a id.  Returns false if there was no wormhole from this system to system \a id.
+    void SetStarType(StarType type);     ///< sets the type of the star in this Systems to \a StarType
+    void AddStarlane(int id);            ///< adds a starlane between this system and the system with ID number \a id.  \note Adding a starlane to a system to which there is already a wormhole erases the wormhole; you may want to check for a wormhole before calling this function.
+    void AddWormhole(int id);            ///< adds a wormhole between this system and the system with ID number \a id  \note Adding a wormhole to a system to which there is already a starlane erases the starlane; you may want to check for a starlane before calling this function.
+    bool RemoveStarlane(int id);         ///< removes a starlane between this system and the system with ID number \a id.  Returns false if there was no starlane from this system to system \a id.
+    bool RemoveWormhole(int id);         ///< removes a wormhole between this system and the system with ID number \a id.  Returns false if there was no wormhole from this system to system \a id.
 
-    void                    SetLastTurnBattleHere(int turn);///< Sets the last turn there was a battle at this system
+    void SetLastTurnBattleHere(int turn);///< Sets the last turn there was a battle at this system
 
-    void                    SetOverlayTexture(const std::string& texture, double size);
+    void SetOverlayTexture(const std::string& texture, double size);
     //@}
 
 protected:
@@ -131,24 +130,16 @@ protected:
     friend class ObjectMap;
 
     /** \name Structors */ //@{
-    System();
+    explicit System();
 
 public:
-    /** general ctor.  \throw std::invalid_arugment May throw
-      * std::invalid_arugment if \a star is out of the range of StarType,
-      * \a orbits is negative, or either x or y coordinate is outside the map
-      * area.*/
     System(StarType star, const std::string& name, double x, double y);
 
 protected:
-    /** general ctor.  \throw std::invalid_arugment May throw
-      * std::invalid_arugment if \a star is out of the range of StarType,
-      * \a orbits is negative, or either x or y coordinate is outside the map
-      * area.*/
     System(StarType star, const std::map<int, bool>& lanes_and_holes,
            const std::string& name, double x, double y);
 
-    template <class T> friend void boost::python::detail::value_destroyer<false>::execute(T const volatile* p);
+    template <typename T> friend void boost::python::detail::value_destroyer<false>::execute(T const volatile* p);
 
 public:
     ~System() {}
@@ -174,7 +165,7 @@ private:
     double              m_overlay_size = 1.0;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
