@@ -3,7 +3,6 @@
 
 
 #include "EnumsFwd.h"
-#include "ValueRefFwd.h"
 #include "ObjectMap.h"
 #include "UniverseObject.h"
 #include "../util/Pending.h"
@@ -11,6 +10,7 @@
 #include <boost/signals2/signal.hpp>
 #include <boost/serialization/access.hpp>
 #include <boost/thread/shared_mutex.hpp>
+#include <boost/container/flat_map.hpp>
 
 #include <list>
 #include <map>
@@ -18,6 +18,7 @@
 #include <set>
 #include <string>
 #include <vector>
+#include <unordered_map>
 
 #include "../util/Export.h"
 
@@ -29,29 +30,29 @@ class ShipDesign;
 class System;
 class Pathfinder;
 class IDAllocator;
-struct ItemSpec;
+struct UnlockableItem;
 class FleetPlan;
 class MonsterFleetPlan;
 
 
 namespace Condition {
-    struct ConditionBase;
+    struct Condition;
     typedef std::vector<std::shared_ptr<const UniverseObject>> ObjectSet;
 }
 
 namespace Effect {
     struct AccountingInfo;
-    struct TargetsAndCause;
-    struct SourcedEffectsGroup;
+    struct TargetsAndCause;     // struct TargetsAndCause { TargetSet target_set; EffectCause effect_cause; };
+    struct SourcedEffectsGroup; // struct SourcedEffectsGroup { int source_object_id; const EffectsGroup* effects_group; };
     class EffectsGroup;
     typedef std::vector<std::shared_ptr<UniverseObject>> TargetSet;
-    typedef std::map<int, std::map<MeterType, std::vector<AccountingInfo>>> AccountingMap;
-    typedef std::vector<std::pair<SourcedEffectsGroup, TargetsAndCause>> TargetsCauses;
-    typedef std::map<int, std::map<MeterType, double>> DiscrepancyMap;
+    typedef std::unordered_map<int, boost::container::flat_map<MeterType, std::vector<AccountingInfo>>> AccountingMap;
+    typedef std::vector<std::pair<SourcedEffectsGroup, TargetsAndCause>> SourcesEffectsTargetsAndCausesVec;
 }
 
 namespace ValueRef {
-    template <class T> struct ValueRefBase;
+    template <typename T>
+    struct ValueRef;
 }
 
 #if defined(_MSC_VER)
@@ -82,10 +83,17 @@ private:
 
     typedef std::map<int, std::set<int>>            ObjectKnowledgeMap;             ///< IDs of Empires which know information about an object (or deleted object); keyed by object id
 
-    typedef const ValueRef::ValueRefBase<Visibility>*   VisValRef;
-    typedef std::vector<std::pair<int, VisValRef>>      SrcVisValRefVec;
-    typedef std::map<int, SrcVisValRefVec>              ObjSrcVisValRefVecMap;
-    typedef std::map<int, ObjSrcVisValRefVecMap>        EmpireObjectVisValueRefMap;
+    typedef const ValueRef::ValueRef<Visibility>*   VisValRef;
+    typedef std::vector<std::pair<int, VisValRef>>  SrcVisValRefVec;
+    typedef std::map<int, SrcVisValRefVec>          ObjSrcVisValRefVecMap;
+    typedef std::map<int, ObjSrcVisValRefVecMap>    EmpireObjectVisValueRefMap;
+
+    /** Discrepancy between meter's value at start of turn, and the value that
+      * this client calculate that the meter should have with the knowledge
+      * available -> the unknown factor affecting the meter.  This is used
+      * when generating effect accounting, in the case where the expected
+      * and actual meter values don't match. */
+    typedef std::unordered_map<int, boost::container::flat_map<MeterType, double>> DiscrepancyMap;
 
 public:
     typedef std::map<int, Visibility>               ObjectVisibilityMap;            ///< map from object id to Visibility level for a particular empire
@@ -104,7 +112,6 @@ public:
 
     /** \name Structors */ //@{
     Universe();
-
     virtual ~Universe();
     //@}
 
@@ -127,6 +134,7 @@ public:
 
     /** Returns IDs of objects that have been destroyed. */
     const std::set<int>&    DestroyedObjectIds() const;
+    int                     HighestDestroyedObjectID() const;
 
     /** Returns IDs of objects that the Empire with id \a empire_id knows have
       * been destroyed.  Each empire's latest known objects data contains the
@@ -156,30 +164,29 @@ public:
     /** Returns the Visibility level of empire with id \a empire_id of
       * UniverseObject with id \a object_id as determined by calling
       * UpdateEmpireObjectVisibilities. */
-    Visibility              GetObjectVisibilityByEmpire(int object_id, int empire_id) const;
+    Visibility GetObjectVisibilityByEmpire(int object_id, int empire_id) const;
 
     /** Returns the map from Visibility level to turn number on which the empire
       * with id \a empire_id last had the various Visibility levels of the
       * UniverseObject with id \a object_id .  The returned map may be empty or
       * not have entries for all visibility levels, if the empire has not seen
       * the object at that visibility level yet. */
-    const VisibilityTurnMap&
-                            GetObjectVisibilityTurnMapByEmpire(int object_id, int empire_id) const;
+    const VisibilityTurnMap& GetObjectVisibilityTurnMapByEmpire(int object_id, int empire_id) const;
 
     /** Returns the set of specials attached to the object with id \a object_id
       * that the empire with id \a empire_id can see this turn. */
-    std::set<std::string>   GetObjectVisibleSpecialsByEmpire(int object_id, int empire_id) const;
+    std::set<std::string> GetObjectVisibleSpecialsByEmpire(int object_id, int empire_id) const;
 
     /** Return the Pathfinder */
-    std::shared_ptr<const Pathfinder>   GetPathfinder() const {return m_pathfinder;}
+    std::shared_ptr<const Pathfinder> GetPathfinder() const {return m_pathfinder;}
 
     /** Returns map, indexed by object id, to map, indexed by MeterType,
       * to vector of EffectAccountInfo for the meter, in order effects
       * were applied to the meter. */
-    const Effect::AccountingMap&        GetEffectAccountingMap() const {return m_effect_accounting_map;}
+    const Effect::AccountingMap& GetEffectAccountingMap() const {return m_effect_accounting_map;}
 
     const std::map<std::string, std::map<int, std::map<int, double>>>&
-                                        GetStatRecords() const { return m_stat_records; }
+    GetStatRecords() const { return m_stat_records; }
 
     mutable UniverseObjectDeleteSignalType UniverseObjectDeleteSignal; ///< the state changed signal object for this UniverseObject
     //@}
@@ -255,9 +262,6 @@ public:
     /** Sets all objects' meters' initial values to their current values. */
     void BackPropagateObjectMeters();
 
-    /** Sets indicated objects' meters' initial values to their current values. */
-    void BackPropagateObjectMeters(const std::vector<int>& object_ids);
-
     /** Determines which empires can see which objects at what visibility
       * level, based on  */
     void UpdateEmpireObjectVisibilities();
@@ -265,7 +269,7 @@ public:
     /** Sets a special record of visibility that overrides the standard
       * empire-object visibility after the latter is processed. */
     void SetEffectDerivedVisibility(int empire_id, int object_id, int source_id,
-                                    const ValueRef::ValueRefBase<Visibility>* vis);
+                                    const ValueRef::ValueRef<Visibility>* vis);
 
     /** Applies empire-object visibilities set by effects. */
     void ApplyEffectDerivedVisibilities();
@@ -355,18 +359,18 @@ public:
     //@}
 
     /** Returns true if UniverseOjbectSignals are inhibited, false otherwise. */
-    const bool&     UniverseObjectSignalsInhibited();
+    const bool& UniverseObjectSignalsInhibited();
 
     /** HACK! This must be set to the encoding empire's id when serializing a
       * Universe, so that only the relevant parts of the Universe are
       * serialized.  The use of this global variable is done just so I don't
       * have to rewrite any custom boost::serialization classes that implement
       * empire-dependent visibility. */
-    int&    EncodingEmpire();
+    int& EncodingEmpire();
 
-    double  UniverseWidth() const;
-    void    SetUniverseWidth(double width) { m_universe_width = width; }
-    bool    AllObjectsVisible() const { return m_all_objects_visible; }
+    double UniverseWidth() const;
+    void SetUniverseWidth(double width) { m_universe_width = width; }
+    bool AllObjectsVisible() const { return m_all_objects_visible; }
 
     /** \name Generators */ //@{
     /** InsertNew constructs and inserts a UniverseObject into the object map with a new
@@ -398,15 +402,15 @@ public:
     }
     //@}
 
-    /** Set items unlocked before turn 1 from \p future.*/
-    void SetInitiallyUnlockedItems(Pending::Pending<std::vector<ItemSpec>>&& future);
-    /** Items unlocked before turn 1.*/
-    const std::vector<ItemSpec>& InitiallyUnlockedItems() const;
+    //! Set items unlocked before turn 1 from \p future.
+    void SetInitiallyUnlockedItems(Pending::Pending<std::vector<UnlockableItem>>&& future);
+    //! Items unlocked before turn 1.
+    const std::vector<UnlockableItem>& InitiallyUnlockedItems() const;
 
-    /** Set buildings unlocked before turn 1 from \p future.*/
-    void SetInitiallyUnlockedBuildings(Pending::Pending<std::vector<ItemSpec>>&& future);
-    /** Buildings unlocked before turn 1.*/
-    const std::vector<ItemSpec>& InitiallyUnlockedBuildings() const;
+    //! Set buildings unlocked before turn 1 from \p future.
+    void SetInitiallyUnlockedBuildings(Pending::Pending<std::vector<UnlockableItem>>&& future);
+    //! Buildings unlocked before turn 1.
+    const std::vector<UnlockableItem>& InitiallyUnlockedBuildings() const;
 
     /** Set fleets unlocked before turn 1 from \p future.*/
     void SetInitiallyUnlockedFleetPlans(Pending::Pending<std::vector<std::unique_ptr<FleetPlan>>>&& future);
@@ -419,12 +423,11 @@ public:
     const std::vector<MonsterFleetPlan*> MonsterFleetPlans() const;
 
     /** Set the empire stats from \p future. */
-    using EmpireStatsMap = std::map<std::string, std::unique_ptr<ValueRef::ValueRefBase<double>>>;
+    using EmpireStatsMap = std::map<std::string, std::unique_ptr<ValueRef::ValueRef<double>>>;
     void SetEmpireStats(Pending::Pending<EmpireStatsMap> future);
 private:
     const EmpireStatsMap& EmpireStats() const;
 public:
-
     /** ObfuscateIDGenerator applies randomization to the IDAllocator to prevent clients from
         inferring too much information about other client's id generation activities. */
     void ObfuscateIDGenerator();
@@ -436,11 +439,11 @@ private:
 
     /** Generates an object ID for a future object. Usually used by the server
       * to service new ID requests. */
-    int             GenerateObjectID();
+    int GenerateObjectID();
 
     /** Generates design ID for a new (ship) design. Usually used by the
       * server to service new ID requests. */
-    int             GenerateDesignID();
+    int GenerateDesignID();
 
     /** Verify that an object ID \p id could be generated by \p empire_id. */
     bool VerifyUnusedObjectID(const int empire_id, const int id);
@@ -460,16 +463,18 @@ private:
     /** Inserts object \p obj into the universe with the given \p id. */
     void InsertIDCore(std::shared_ptr<UniverseObject> obj, int id);
 
-    /** Clears \a targets_causes, and then populates with all
+    /** Clears \a source_effects_targets_causes, and then populates with all
       * EffectsGroups and their targets in the known universe. */
-    void GetEffectsAndTargets(Effect::TargetsCauses& targets_causes);
+    void GetEffectsAndTargets(std::map<int, Effect::SourcesEffectsTargetsAndCausesVec>& source_effects_targets_causes,
+                              bool only_meter_effects = false) const;
 
-    /** Removes entries in \a targets_causes about effects groups acting
+    /** Removes entries in \a source_effects_targets_causes about effects groups acting
       * on objects in \a target_objects, and then repopulates for EffectsGroups
-      * that act on at least one of the objects in \a target_objects. If 
+      * that act on at least one of the objects in \a target_objects. If
       * \a target_objects is empty then default target candidates will be used. */
-    void GetEffectsAndTargets(Effect::TargetsCauses& targets_causes,
-                              const std::vector<int>& target_objects);
+    void GetEffectsAndTargets(std::map<int, Effect::SourcesEffectsTargetsAndCausesVec>& source_effects_targets_causes,
+                              const std::vector<int>& target_objects,
+                              bool only_meter_effects = false) const;
 
     void ResetObjectMeters(const std::vector<std::shared_ptr<UniverseObject>>& objects,
                            bool target_max_unpaired = true, bool active = true);
@@ -479,7 +484,7 @@ private:
       * executed.  This is useful on server or clients to update meter
       * values after the rest of effects (including non-meter effects) have
       * been executed. */
-    void ExecuteEffects(const Effect::TargetsCauses& targets_causes,
+    void ExecuteEffects(std::map<int, Effect::SourcesEffectsTargetsAndCausesVec>& source_effects_targets_causes,
                         bool update_effect_accounting,
                         bool only_meter_effects = false,
                         bool only_appearance_effects = false,
@@ -488,9 +493,9 @@ private:
 
     /** Does actual updating of meter estimates after the public function have
       * processed objects_vec or whatever they were passed and cleared the
-      * relevant effect accounting for those objects and meters. If an empty 
+      * relevant effect accounting for those objects and meters. If an empty
       * vector is passed, it will instead update all existing objects. */
-    void    UpdateMeterEstimatesImpl(const std::vector<int>& objects_vec, bool do_accounting);
+    void UpdateMeterEstimatesImpl(const std::vector<int>& objects_vec, bool do_accounting);
 
     ObjectMap                       m_objects;                          ///< map from object id to UniverseObjects in the universe.  for the server: all of them, up to date and true information about object is stored;  for clients, only limited information based on what the client knows about is sent.
     EmpireObjectMap                 m_empire_latest_known_objects;      ///< map from empire id to (map from object id to latest known information about each object by that empire)
@@ -511,7 +516,12 @@ private:
     std::map<int, std::set<int>>    m_empire_known_ship_design_ids;     ///< ship designs known to each empire
 
     Effect::AccountingMap           m_effect_accounting_map;            ///< map from target object id, to map from target meter, to orderered list of structs with details of an effect and what it does to the meter
-    Effect::DiscrepancyMap          m_effect_discrepancy_map;           ///< map from target object id, to map from target meter, to discrepancy between meter's actual initial value, and the initial value that this meter should have as far as the client can tell: the unknown factor affecting the meter
+
+    /// map from target object id, to map from target meter, to discrepancy
+    /// between meter's actual initial value, and the initial value that this
+    /// meter should have as far as the client can tell: the unknown factor
+    /// affecting the meter.
+    DiscrepancyMap                  m_effect_discrepancy_map;
 
     std::map<int, std::set<int>>    m_marked_destroyed;                 ///< used while applying effects to cache objects that have been destroyed.  this allows to-be-destroyed objects to remain undestroyed until all effects have been processed, which ensures that to-be-destroyed objects still exist when other effects need to access them as a source object. key is destroyed object, and value set are the ids of objects that caused the destruction (may be multiples destroying a single target on a given turn)
 
@@ -523,22 +533,22 @@ private:
     std::map<std::string, std::map<int, std::map<int, double>>>
                                     m_stat_records;                     ///< storage for statistics calculated for empires. Indexed by stat name (string), contains a map indexed by empire id, contains a map from turn number (int) to stat value (double).
 
-    /** @name Parsed items
-        Various unlocked items are kept as a Pending::Pending while being parsed and
-        then transfered.  They are mutable to allow processing in const accessors. */
-    ///@{
-    mutable boost::optional<Pending::Pending<std::vector<ItemSpec>>> m_pending_items = boost::none;
-    mutable boost::optional<Pending::Pending<std::vector<ItemSpec>>> m_pending_buildings = boost::none;
-    mutable boost::optional<Pending::Pending<std::vector<std::unique_ptr<FleetPlan>>>> m_pending_fleet_plans = boost::none;
-    mutable boost::optional<Pending::Pending<std::vector<std::unique_ptr<MonsterFleetPlan>>>> m_pending_monster_fleet_plans = boost::none;
-    mutable boost::optional<Pending::Pending<EmpireStatsMap>> m_pending_empire_stats = boost::none;
+    //! @name Parsed items
+    //! Various unlocked items are kept as a Pending::Pending while being parsed and
+    //! then transfered.  They are mutable to allow processing in const accessors.
+    //! @{
+    mutable boost::optional<Pending::Pending<std::vector<UnlockableItem>>>                      m_pending_items = boost::none;
+    mutable boost::optional<Pending::Pending<std::vector<UnlockableItem>>>                      m_pending_buildings = boost::none;
+    mutable boost::optional<Pending::Pending<std::vector<std::unique_ptr<FleetPlan>>>>          m_pending_fleet_plans = boost::none;
+    mutable boost::optional<Pending::Pending<std::vector<std::unique_ptr<MonsterFleetPlan>>>>   m_pending_monster_fleet_plans = boost::none;
+    mutable boost::optional<Pending::Pending<EmpireStatsMap>>                                   m_pending_empire_stats = boost::none;
 
-    mutable std::vector<ItemSpec> m_unlocked_items;
-    mutable std::vector<ItemSpec> m_unlocked_buildings;
-    mutable std::vector<std::unique_ptr<FleetPlan>> m_unlocked_fleet_plans;
-    mutable std::vector<std::unique_ptr<MonsterFleetPlan>> m_monster_fleet_plans;
-    mutable EmpireStatsMap m_empire_stats;
-    ///@}
+    mutable std::vector<UnlockableItem>                     m_unlocked_items;
+    mutable std::vector<UnlockableItem>                     m_unlocked_buildings;
+    mutable std::vector<std::unique_ptr<FleetPlan>>         m_unlocked_fleet_plans;
+    mutable std::vector<std::unique_ptr<MonsterFleetPlan>>  m_monster_fleet_plans;
+    mutable EmpireStatsMap                                  m_empire_stats;
+    //! @}
 
     /** Fills \a designs_to_serialize with ShipDesigns known to the empire with
       * the ID \a encoding empire.  If encoding_empire is ALL_EMPIRES, then all
@@ -582,10 +592,11 @@ private:
     std::unique_ptr<IDAllocator> const m_design_id_allocator;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
+
 /** Compute a checksum for each of the universe's content managers. Each value will be of the form
     ("BuildingManager", <checksum>) */
 FO_COMMON_API std::map<std::string, unsigned int> CheckSumContent();
