@@ -3,6 +3,7 @@
 
 
 #include "EnumsFwd.h"
+#include "Meter.h"
 #include "../util/Export.h"
 #include "../util/blocking_combiner.h"
 
@@ -10,12 +11,14 @@
 #include <boost/python/detail/destroy.hpp>
 #include <boost/signals2/signal.hpp>
 #include <boost/signals2/optional_last_value.hpp>
+#include <boost/container/flat_map.hpp>
 
 #include <set>
 #include <string>
 #include <vector>
 
-class Meter;
+using boost::container::flat_map;
+
 class System;
 class SitRepEntry;
 struct UniverseObjectVisitor;
@@ -46,12 +49,15 @@ FO_COMMON_API extern const int TEMPORARY_OBJECT_ID;
   * that is being displayed has changed.*/
 class FO_COMMON_API UniverseObject : virtual public std::enable_shared_from_this<UniverseObject> {
 public:
+    //typedef flat_map<MeterType, Meter, std::less<MeterType>, std::vector<std::pair<MeterType, Meter>>> MeterMap;
+    typedef flat_map<MeterType, Meter, std::less<MeterType>> MeterMap;
+
     /** \name Signal Types */ //@{
     typedef boost::signals2::signal<void (), blocking_combiner<boost::signals2::optional_last_value<void>>> StateChangedSignalType;
     //@}
 
     /** \name Slot Types */ //@{
-    typedef StateChangedSignalType::slot_type               StateChangedSlotType;
+    typedef StateChangedSignalType::slot_type StateChangedSlotType;
     //@}
 
     /** \name Accessors */ //@{
@@ -102,10 +108,8 @@ public:
 
     std::set<int>               VisibleContainedObjectIDs(int empire_id) const; ///< returns the subset of contained object IDs that is visible to empire with id \a empire_id
 
-    const std::map<MeterType, Meter>&   Meters() const { return m_meters; }     ///< returns this UniverseObject's meters
+    const MeterMap&             Meters() const { return m_meters; }             ///< returns this UniverseObject's meters
     const Meter*                GetMeter(MeterType type) const;                 ///< returns the requested Meter, or 0 if no such Meter of that type is found in this object
-    float                       CurrentMeterValue(MeterType type) const;        ///< returns current value of the specified meter \a type
-    float                       InitialMeterValue(MeterType type) const;        ///< returns this turn's initial value for the speicified meter \a type
 
     Visibility                  GetVisibility(int empire_id) const; ///< returns the visibility status of this universe object relative to the input empire.
 
@@ -125,64 +129,62 @@ public:
     /** copies data from \a copied_object to this object, limited to only copy
       * data about the copied object that is known to the empire with id
       * \a empire_id (or all data if empire_id is ALL_EMPIRES) */
-    virtual void Copy(std::shared_ptr<const UniverseObject> copied_object, int empire_id) = 0;
+    virtual void    Copy(std::shared_ptr<const UniverseObject> copied_object, int empire_id) = 0;
 
-    void                    SetID(int id);                      ///< sets the ID number of the object to \a id
-    void                    Rename(const std::string& name);    ///< renames this object to \a name
+    void            SetID(int id);                      ///< sets the ID number of the object to \a id
+    void            Rename(const std::string& name);    ///< renames this object to \a name
 
     /** moves this object by relative displacements x and y. */
-    void                    Move(double x, double y);
+    void            Move(double x, double y);
 
     /** calls MoveTo(std::shared_ptr<const UniverseObject>) with the object
         pointed to by \a object_id. */
-    void                    MoveTo(int object_id);
+    void            MoveTo(int object_id);
 
     /** moves this object to exact map coordinates of specified \a object. */
-    void MoveTo(std::shared_ptr<UniverseObject> object);
+    void            MoveTo(std::shared_ptr<UniverseObject> object);
 
     /** moves this object to map coordinates (x, y). */
-    void                    MoveTo(double x, double y);
+    void            MoveTo(double x, double y);
 
-
-    std::map<MeterType, Meter>&
-                            Meters() { return m_meters; }           ///< returns this UniverseObject's meters
-    Meter*                  GetMeter(MeterType type);               ///< returns the requested Meter, or 0 if no such Meter of that type is found in this object
+    MeterMap&       Meters() { return m_meters; }           ///< returns this UniverseObject's meters
+    Meter*          GetMeter(MeterType type);               ///< returns the requested Meter, or 0 if no such Meter of that type is found in this object
 
     /** Sets all this UniverseObject's meters' initial values equal to their
         current values. */
-    virtual void BackPropagateMeters();
+    virtual void    BackPropagateMeters();
 
     /** Sets the empire that owns this object. */
-    virtual void SetOwner(int id);
+    virtual void    SetOwner(int id);
 
-    void                    SetSystem(int sys);                     ///< assigns this object to a System.  does not actually move object in universe
-    virtual void            AddSpecial(const std::string& name, float capacity = 0.0f); ///< adds the Special \a name to this object, if it is not already present
-    virtual void            RemoveSpecial(const std::string& name); ///< removes the Special \a name from this object, if it is already present
-    void                    SetSpecialCapacity(const std::string& name, float capacity);
+    void            SetSystem(int sys);                     ///< assigns this object to a System.  does not actually move object in universe
+    virtual void    AddSpecial(const std::string& name, float capacity = 0.0f); ///< adds the Special \a name to this object, if it is not already present
+    virtual void    RemoveSpecial(const std::string& name); ///< removes the Special \a name from this object, if it is already present
+    void            SetSpecialCapacity(const std::string& name, float capacity);
 
     /** Performs the movement that this object is responsible for this object's
       * actions during the movement phase of a turn. */
-    virtual void MovementPhase()
+    virtual void    MovementPhase()
     {};
 
     /** Sets current value of max, target and unpaired meters in in this
       * UniverseObject to Meter::DEFAULT_VALUE.  This should be done before any
       * Effects that alter these meter(s) act on the object. */
-    virtual void ResetTargetMaxUnpairedMeters();
+    virtual void    ResetTargetMaxUnpairedMeters();
 
     /** Sets current value of active paired meters (the non-max non-target
       * meters that have a max or target meter associated with them) back to
       * the initial value the meter had at the start of this turn. */
-    virtual void ResetPairedActiveMeters();
+    virtual void    ResetPairedActiveMeters();
 
     /** calls Clamp(min, max) on meters each meter in this UniverseObject, to
       * ensure that meter current values aren't outside the valid range for
       * each meter. */
-    virtual void ClampMeters();
+    virtual void    ClampMeters();
 
     /** performs the movement that this object is responsible for this object's
         actions during the pop growth/production/research phase of a turn. */
-    virtual void PopGrowthProductionResearchPhase()
+    virtual void    PopGrowthProductionResearchPhase()
     {};
     //@}
 
@@ -198,7 +200,7 @@ protected:
     UniverseObject();
     UniverseObject(const std::string name, double x, double y);
 
-    template <class T> friend void boost::python::detail::value_destroyer<false>::execute(T const volatile* p);
+    template <typename T> friend void boost::python::detail::value_destroyer<false>::execute(T const volatile* p);
 
 public:
     virtual ~UniverseObject();
@@ -222,7 +224,7 @@ protected:
     std::string             m_name;
 
 private:
-    std::map<MeterType, Meter>  CensoredMeters(Visibility vis) const;   ///< returns set of meters of this object that are censored based on the specified Visibility \a vis
+    MeterMap                CensoredMeters(Visibility vis) const;   ///< returns set of meters of this object that are censored based on the specified Visibility \a vis
 
     int                                             m_id = INVALID_OBJECT_ID;
     double                                          m_x;
@@ -230,11 +232,11 @@ private:
     int                                             m_owner_empire_id = ALL_EMPIRES;
     int                                             m_system_id = INVALID_OBJECT_ID;
     std::map<std::string, std::pair<int, float>>    m_specials; // map from special name to pair of (turn added, capacity)
-    std::map<MeterType, Meter>                      m_meters;
+    MeterMap                                        m_meters;
     int                                             m_created_on_turn = INVALID_GAME_TURN;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
