@@ -39,7 +39,11 @@ public:
     /** Returns a IApp pointer to the singleton instance of the app. */
     static IApp* GetApp();
 
-    /** Returns applications copy of Universe. */
+    //! Returns the ::Universe known to this application
+    //!
+    //! @return
+    //! A constant reference to the single ::Universe instance representing the
+    //! known universe of this application.
     virtual Universe& GetUniverse() = 0;
 
     /** Start parsing universe object types on a separate thread. */
@@ -61,7 +65,9 @@ public:
 
     virtual std::string GetVisibleObjectName(std::shared_ptr<const UniverseObject> object) = 0;
 
-    /** Returns the current game turn. */
+    //! Returns the current game turn
+    //!
+    //! @return The number representing the current game turn.
     virtual int CurrentTurn() const = 0;
 
     static int MAX_AI_PLAYERS(); ///<Maximum number of AIs
@@ -106,68 +112,16 @@ inline std::shared_ptr<const Pathfinder> GetPathfinder()
 { return IApp::GetApp()->GetUniverse().GetPathfinder(); }
 
 /** Accessor for all (on server) or all known (on client) objects ObjectMap */
-inline ObjectMap& Objects()
-{ return IApp::GetApp()->GetUniverse().Objects(); }
+inline ObjectMap& Objects() {
+    static ObjectMap empty_objects;
+    auto app = IApp::GetApp();
+    return app ? app->GetUniverse().Objects() : empty_objects;
+}
 
 /** Accessor for known objects of specified empire. */
 inline ObjectMap& EmpireKnownObjects(int empire_id)
 { return IApp::GetApp()->EmpireKnownObjects(empire_id); }
 
-/** Accessor for individual objects. */
-inline std::shared_ptr<UniverseObject> GetUniverseObject(int object_id)
-{ return IApp::GetApp()->GetUniverseObject(object_id); }
-
-inline std::shared_ptr<UniverseObject> GetEmpireKnownObject(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObject(object_id, empire_id); }
-
-inline std::shared_ptr<ResourceCenter> GetResourceCenter(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<ResourceCenter>(object_id); }
-
-inline std::shared_ptr<ResourceCenter> GetEmpireKnownResourceCenter(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<ResourceCenter>(object_id); }
-
-inline std::shared_ptr<PopCenter> GetPopCenter(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<PopCenter>(object_id); }
-
-inline std::shared_ptr<PopCenter> GetEmpireKnownPopCenter(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<PopCenter>(object_id); }
-
-inline std::shared_ptr<Planet> GetPlanet(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<Planet>(object_id); }
-
-inline std::shared_ptr<Planet> GetEmpireKnownPlanet(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<Planet>(object_id); }
-
-inline std::shared_ptr<System> GetSystem(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<System>(object_id); }
-
-inline std::shared_ptr<System> GetEmpireKnownSystem(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<System>(object_id); }
-
-inline std::shared_ptr<Field> GetField(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<Field>(object_id); }
-
-inline std::shared_ptr<Field> GetEmpireKnownField(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<Field>(object_id); }
-
-inline std::shared_ptr<Ship> GetShip(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<Ship>(object_id); }
-
-inline std::shared_ptr<Ship> GetEmpireKnownShip(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<Ship>(object_id); }
-
-inline std::shared_ptr<Fleet> GetFleet(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<Fleet>(object_id); }
-
-inline std::shared_ptr<Fleet> GetEmpireKnownFleet(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<Fleet>(object_id); }
-
-inline std::shared_ptr<Building> GetBuilding(int object_id)
-{ return IApp::GetApp()->GetUniverse().Objects().Object<Building>(object_id); }
-
-inline std::shared_ptr<Building> GetEmpireKnownBuilding(int object_id, int empire_id)
-{ return IApp::GetApp()->EmpireKnownObjects(empire_id).Object<Building>(object_id); }
-
 /** Returns the object name of the universe object. This can be apperant object
  * name, if the application isn't supposed to see the real object name. */
 inline std::string GetVisibleObjectName(std::shared_ptr<const UniverseObject> object)
