@@ -3,6 +3,7 @@
 #include <boost/log/core.hpp>
 #include <boost/log/trivial.hpp>
 #include <boost/log/expressions.hpp>
+#include <boost/log/attributes/current_thread_id.hpp>
 #include <boost/log/attributes/value_extraction.hpp>
 #include <boost/log/expressions/keyword.hpp>
 #include <boost/log/sinks/frontend_requirements.hpp>
@@ -141,19 +142,20 @@ namespace {
         return forced_threshold;
     }
 
-    using TextFileSinkBackend  = sinks::text_file_backend;
-    using TextFileSinkFrontend = sinks::synchronous_sink<TextFileSinkBackend>;
+    using LoggerTextFileSinkFrontend = boost::log::sinks::synchronous_sink<boost::log::sinks::text_file_backend>;
 
-    boost::shared_ptr<TextFileSinkBackend>& FileSinkBackend() {
+    using LoggerFileSinkFrontEndConfigurer = std::function<void(LoggerTextFileSinkFrontend& sink_frontend)>;
+
+    boost::shared_ptr<LoggerTextFileSinkFrontend::sink_backend_type>& FileSinkBackend() {
         // Create the sink backend as a function local static variable to avoid the static
         // initilization fiasco.
-        static boost::shared_ptr<TextFileSinkBackend> m_sink_backend;
+        static boost::shared_ptr<LoggerTextFileSinkFrontend::sink_backend_type> m_sink_backend;
         return m_sink_backend;
     }
 
     /** Create a new file sink front end for \p file_sink_backend for \p channel_name and
         configure it with \p configure_front_end. */
-    void ConfigureToFileSinkFrontEndCore(const boost::shared_ptr<TextFileSinkBackend>& file_sink_backend,
+    void ConfigureToFileSinkFrontEndCore(const boost::shared_ptr<LoggerTextFileSinkFrontend::sink_backend_type>& file_sink_backend,
                                          const std::string& channel_name,
                                          const LoggerFileSinkFrontEndConfigurer& configure_front_end);
 
@@ -167,12 +169,12 @@ namespace {
     class LoggersToSinkFrontEnds {
         /// m_mutex serializes access from different threads
         std::mutex m_mutex = {};
-        std::unordered_map<std::string, boost::shared_ptr<TextFileSinkFrontend>> m_names_to_front_ends = {};
+        std::unordered_map<std::string, boost::shared_ptr<LoggerTextFileSinkFrontend>> m_names_to_front_ends = {};
         std::unordered_map<std::string, LoggerFileSinkFrontEndConfigurer> m_names_to_front_end_configurers = {};
         public:
 
         void AddOrReplaceLoggerName(const std::string& channel_name,
-                                    boost::shared_ptr<TextFileSinkFrontend> front_end = nullptr)
+                                    boost::shared_ptr<LoggerTextFileSinkFrontend> front_end = nullptr)
         {
             std::lock_guard<std::mutex> lock(m_mutex);
 
@@ -210,7 +212,7 @@ namespace {
         }
 
         /** Configure front ends for any logger with stored configuration functions. */
-        void ConfigureFrontEnds(const boost::shared_ptr<TextFileSinkBackend>& file_sink_backend) {
+        void ConfigureFrontEnds(const boost::shared_ptr<LoggerTextFileSinkFrontend::sink_backend_type>& file_sink_backend) {
             for (const auto& name_and_conf: m_names_to_front_end_configurers)
                 ConfigureToFileSinkFrontEndCore(file_sink_backend, name_and_conf.first, name_and_conf.second);
         }
@@ -239,27 +241,12 @@ namespace {
         return loggers_names_to_front_ends;
     }
 
-    void ConfigureFileSinkFrontEnd(TextFileSinkFrontend& sink_frontend, const std::string& channel_name) {
-        // Create the format
-        sink_frontend.set_formatter(
-            expr::stream
-            << expr::format_date_time<boost::posix_time::ptime>("TimeStamp", "%H:%M:%S.%f")
-            << " [" << log_severity << "] "
-            << DisplayName(channel_name)
-            << " : " << log_src_filename << ":" << log_src_linenum << " : "
-            << expr::message
-        );
-
-        // Set a filter to only format this channel
-        sink_frontend.set_filter(log_channel == channel_name);
-    }
-
-    void ConfigureToFileSinkFrontEndCore(const boost::shared_ptr<TextFileSinkBackend>& file_sink_backend,
+    void ConfigureToFileSinkFrontEndCore(const boost::shared_ptr<LoggerTextFileSinkFrontend::sink_backend_type>& file_sink_backend,
                                          const std::string& channel_name,
                                          const LoggerFileSinkFrontEndConfigurer& configure_front_end)
     {
         // Create a sink frontend for formatting.
-        auto sink_frontend = boost::make_shared<TextFileSinkFrontend>(file_sink_backend);
+        auto sink_frontend = boost::make_shared<LoggerTextFileSinkFrontend>(file_sink_backend);
 
         configure_front_end(*sink_frontend);
 
@@ -289,6 +276,12 @@ const std::string& DefaultExecLoggerName()
 std::vector<std::string> CreatedLoggersNames()
 { return GetLoggersToSinkFrontEnds().LoggersNames(); }
 
+BOOST_LOG_ATTRIBUTE_KEYWORD(log_severity, "Severity", LogLevel);
+BOOST_LOG_ATTRIBUTE_KEYWORD(log_channel, "Channel", std::string)
+BOOST_LOG_ATTRIBUTE_KEYWORD(log_src_filename, "SrcFilename", std::string);
+BOOST_LOG_ATTRIBUTE_KEYWORD(log_src_linenum, "SrcLinenum", int);
+BOOST_LOG_ATTRIBUTE_KEYWORD(thread_id, "ThreadID", boost::log::attributes::current_thread_id::value_type);
+
 namespace {
 
     /** LoggerThresholdSetter sets the threshold of a logger */
@@ -306,7 +299,6 @@ namespace {
             std::lock_guard<std::mutex> lock(m_mutex);
 
             auto used_threshold = ForcedThreshold() ? *ForcedThreshold() : threshold;
-            logging::core::get()->reset_filter();
             m_min_channel_severity[source] = used_threshold;
             logging::core::get()->set_filter(m_min_channel_severity);
 
@@ -322,6 +314,22 @@ namespace {
 
         return logger_threshold_setter.SetThreshold(source, threshold);
     }
+
+    void ConfigureFileSinkFrontEnd(LoggerTextFileSinkFrontend& sink_frontend, const std::string& channel_name) {
+        // Create the format
+        sink_frontend.set_formatter(
+            expr::stream
+            << expr::format_date_time<boost::posix_time::ptime>("TimeStamp", "%H:%M:%S.%f")
+            << " {" << thread_id << "}"
+            << " [" << log_severity << "] "
+            << DisplayName(channel_name)
+            << " : " << log_src_filename << ":" << log_src_linenum << " : "
+            << expr::message
+        );
+
+        // Set a filter to only format this channel
+        sink_frontend.set_filter(log_channel == channel_name);
+    }
 }
 
 void SetLoggerThreshold(const std::string& source, LogLevel threshold) {
@@ -343,16 +351,21 @@ void InitLoggingSystem(const std::string& log_file, const std::string& _unnamed_
 
     // Create a sink backend that logs to a file
     auto& file_sink_backend = FileSinkBackend();
-    file_sink_backend = boost::make_shared<TextFileSinkBackend>(
+    file_sink_backend = boost::make_shared<LoggerTextFileSinkFrontend::sink_backend_type>(
         keywords::file_name = log_file.c_str(),
         keywords::auto_flush = true
     );
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+#endif
+
     // Create the frontend for formatting default records.
-    ApplyConfigurationToFileSinkFrontEnd("", std::bind(ConfigureFileSinkFrontEnd, std::placeholders::_1, ""));
+    ApplyConfigurationToFileSinkFrontEnd("", boost::bind(ConfigureFileSinkFrontEnd, _1, ""));
 
     // Add global attributes to all records
     logging::core::get()->add_global_attribute("TimeStamp", attr::local_clock());
+    logging::core::get()->add_global_attribute("ThreadID", attr::current_thread_id());
 
     SetLoggerThresholdCore("", default_log_level_threshold);
 
@@ -418,7 +431,12 @@ void ConfigureLogger(NamedThreadedLogger& logger, const std::string& name) {
     if (name.empty())
         return;
 
-    ApplyConfigurationToFileSinkFrontEnd(name, std::bind(ConfigureFileSinkFrontEnd, std::placeholders::_1, name));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+#endif
+
+    ApplyConfigurationToFileSinkFrontEnd(
+        name, boost::bind(ConfigureFileSinkFrontEnd, _1, name));
 
     // Store as static to initialize once.
     static bool dummy = InitializeLoggerCreatedSignal();
