@@ -1,15 +1,15 @@
 #include "MultiplayerCommon.h"
 
 #include "Directories.h"
+#include "GameRules.h"
 #include "i18n.h"
 #include "LoggerWithOptionsDB.h"
 #include "OptionsDB.h"
 #include "Random.h"
-#include "../universe/Fleet.h"
-#include "../universe/Planet.h"
-#include "../universe/System.h"
+#include "AppInterface.h"
 #include "../universe/Enums.h"
 
+
 #if defined(_MSC_VER) && defined(int64_t)
 #undef int64_t
 #endif
@@ -28,12 +28,30 @@ namespace {
         db.Add<std::string>("log-level",                    UserStringNop("OPTIONS_DB_LOG_LEVEL"),              "",
                             OrValidator<std::string>(LogLevelValidator(), DiscreteValidator<std::string>("")),  false);
         db.Add<std::string>("log-file",                     UserStringNop("OPTIONS_DB_LOG_FILE"),               "",
-                            Validator<std::string>() ,                                                          false);
-        // Default stringtable filename is deferred to i18n.cpp::InitStringtableFileName to determine if user specified
+                            Validator<std::string>(),                                                           false);
+        // Default stringtable filename is deferred to i18n.cpp::InitStringtableFileName
         db.Add<std::string>("resource.stringtable.path",    UserStringNop("OPTIONS_DB_STRINGTABLE_FILENAME"),   "");
         db.Add("save.format.binary.enabled",                UserStringNop("OPTIONS_DB_BINARY_SERIALIZATION"),   false);
         db.Add("save.format.xml.zlib.enabled",              UserStringNop("OPTIONS_DB_XML_ZLIB_SERIALIZATION"), true);
         db.Add("save.auto.hostless.enabled",                UserStringNop("OPTIONS_DB_AUTOSAVE_HOSTLESS"),      true);
+        db.Add<int>("save.auto.interval",                   UserStringNop("OPTIONS_DB_AUTOSAVE_INTERVAL"),      0);
+        db.Add<std::string>("load",                         UserStringNop("OPTIONS_DB_LOAD"),                   "",                     Validator<std::string>(), false);
+        db.Add("save.auto.exit.enabled",                    UserStringNop("OPTIONS_DB_AUTOSAVE_GAME_CLOSE"),    true);
+        db.AddFlag('q', "quickstart",                       UserStringNop("OPTIONS_DB_QUICKSTART"),             false);
+
+        // Common galaxy settings
+        db.Add("setup.seed",                UserStringNop("OPTIONS_DB_GAMESETUP_SEED"),                         std::string("0"),       Validator<std::string>());
+        db.Add("setup.star.count",          UserStringNop("OPTIONS_DB_GAMESETUP_STARS"),                        150,                    RangedValidator<int>(10, 5000));
+        db.Add("setup.galaxy.shape",        UserStringNop("OPTIONS_DB_GAMESETUP_GALAXY_SHAPE"),                 DISC,                   RangedValidator<Shape>(SPIRAL_2, RANDOM));
+        db.Add("setup.galaxy.age",          UserStringNop("OPTIONS_DB_GAMESETUP_GALAXY_AGE"),                   GALAXY_SETUP_MEDIUM,    RangedValidator<GalaxySetupOption>(GALAXY_SETUP_LOW, GALAXY_SETUP_RANDOM));
+        db.Add("setup.planet.density",      UserStringNop("OPTIONS_DB_GAMESETUP_PLANET_DENSITY"),               GALAXY_SETUP_MEDIUM,    RangedValidator<GalaxySetupOption>(GALAXY_SETUP_LOW, GALAXY_SETUP_RANDOM));
+        db.Add("setup.starlane.frequency",  UserStringNop("OPTIONS_DB_GAMESETUP_STARLANE_FREQUENCY"),           GALAXY_SETUP_MEDIUM,    RangedValidator<GalaxySetupOption>(GALAXY_SETUP_LOW, GALAXY_SETUP_RANDOM));
+        db.Add("setup.specials.frequency",  UserStringNop("OPTIONS_DB_GAMESETUP_SPECIALS_FREQUENCY"),           GALAXY_SETUP_MEDIUM,    RangedValidator<GalaxySetupOption>(GALAXY_SETUP_NONE, GALAXY_SETUP_RANDOM));
+        db.Add("setup.monster.frequency",   UserStringNop("OPTIONS_DB_GAMESETUP_MONSTER_FREQUENCY"),            GALAXY_SETUP_MEDIUM,    RangedValidator<GalaxySetupOption>(GALAXY_SETUP_NONE, GALAXY_SETUP_RANDOM));
+        db.Add("setup.native.frequency",    UserStringNop("OPTIONS_DB_GAMESETUP_NATIVE_FREQUENCY"),             GALAXY_SETUP_MEDIUM,    RangedValidator<GalaxySetupOption>(GALAXY_SETUP_NONE, GALAXY_SETUP_RANDOM));
+        db.Add("setup.ai.player.count",     UserStringNop("OPTIONS_DB_GAMESETUP_NUM_AI_PLAYERS"),               6,                      RangedValidator<int>(0, IApp::MAX_AI_PLAYERS()));
+        db.Add("setup.ai.aggression",       UserStringNop("OPTIONS_DB_GAMESETUP_AI_MAX_AGGRESSION"),            MANIACAL,               RangedValidator<Aggression>(BEGINNER, MANIACAL));
+
 
         // AI Testing options-- the following options are to facilitate AI testing and do not currently have an options page widget;
         // they are intended to be changed via the command line and are not currently storable in the configuration file.
@@ -43,6 +61,24 @@ namespace {
                             Validator<std::string>(),                                                           false);
     }
     bool temp_bool = RegisterOptions(&AddOptions);
+
+    void AddRules(GameRules& rules) {
+        rules.Add<int>("RULE_THRESHOLD_HUMAN_PLAYER_WIN", "RULE_THRESHOLD_HUMAN_PLAYER_WIN_DESC",
+                       "MULTIPLAYER", 0, true,  RangedValidator<int>(0, 999));
+
+        rules.Add<bool>("RULE_ONLY_ALLIANCE_WIN", "RULE_ONLY_ALLIANCE_WIN_DESC",
+                       "MULTIPLAYER", true, true);
+
+        rules.Add<bool>("RULE_ALLOW_CONCEDE", "RULE_ALLOW_CONCEDE_DESC",
+                       "MULTIPLAYER", false, true);
+
+        rules.Add<int>("RULE_CONCEDE_COLONIES_THRESHOLD", "RULE_CONCEDE_COLONIES_THRESHOLD_DESC",
+                       "MULTIPLAYER", 1, true,  RangedValidator<int>(0, 9999));
+
+        rules.Add<bool>("RULE_SHOW_DETAILED_EMPIRES_DATA", "RULE_SHOW_DETAILED_EMPIRES_DATA_DESC",
+                       "MULTIPLAYER", true, true);
+    }
+    bool temp_bool2 = RegisterGameRules(&AddRules);
 }
 
 /////////////////////////////////////////////////////
@@ -72,7 +108,6 @@ namespace {
 }
 
 GalaxySetupData::GalaxySetupData() :
-    m_seed(),
     m_size(100),
     m_shape(SPIRAL_2),
     m_age(GALAXY_SETUP_MEDIUM),
@@ -81,7 +116,8 @@ GalaxySetupData::GalaxySetupData() :
     m_specials_freq(GALAXY_SETUP_MEDIUM),
     m_monster_freq(GALAXY_SETUP_MEDIUM),
     m_native_freq(GALAXY_SETUP_MEDIUM),
-    m_ai_aggr(MANIACAL)
+    m_ai_aggr(MANIACAL),
+    m_encoding_empire(ALL_EMPIRES)
 {}
 
 GalaxySetupData::GalaxySetupData(GalaxySetupData&& base) :
@@ -96,7 +132,8 @@ GalaxySetupData::GalaxySetupData(GalaxySetupData&& base) :
     m_native_freq(base.m_native_freq),
     m_ai_aggr(base.m_ai_aggr),
     m_game_rules(std::move(base.m_game_rules)),
-    m_game_uid(std::move(base.m_game_uid))
+    m_game_uid(std::move(base.m_game_uid)),
+    m_encoding_empire(base.m_encoding_empire)
 { SetSeed(m_seed); }
 
 const std::string& GalaxySetupData::GetSeed() const
@@ -151,7 +188,7 @@ GalaxySetupOption GalaxySetupData::GetNativeFreq() const {
 Aggression GalaxySetupData::GetAggression() const
 { return m_ai_aggr; }
 
-const std::vector<std::pair<std::string, std::string>>& GalaxySetupData::GetGameRules() const
+const std::map<std::string, std::string>& GalaxySetupData::GetGameRules() const
 { return m_game_rules; }
 
 const std::string& GalaxySetupData::GetGameUID() const
@@ -166,7 +203,7 @@ void GalaxySetupData::SetSeed(const std::string& seed) {
             new_seed += alphanum[RandSmallInt(0, (sizeof(alphanum) - 2))];
         DebugLogger() << "Set empty or requested random seed to " << new_seed;
     }
-    m_seed = new_seed;
+    m_seed = std::move(new_seed);
 }
 
 void GalaxySetupData::SetGameUID(const std::string& game_uid)
@@ -182,7 +219,8 @@ bool operator==(const PlayerSetupData& lhs, const PlayerSetupData& rhs) {
             lhs.m_player_name == rhs.m_player_name &&
             lhs.m_save_game_empire_id == rhs.m_save_game_empire_id &&
             lhs.m_starting_species_name == rhs.m_starting_species_name &&
-            lhs.m_player_ready == rhs.m_player_ready;
+            lhs.m_player_ready == rhs.m_player_ready &&
+            lhs.m_starting_team == rhs.m_starting_team;
 }
 
 bool operator!=(const PlayerSetupData& lhs, const PlayerSetupData& rhs)
