@@ -9,6 +9,7 @@
 #include <boost/filesystem/fstream.hpp>
 #include <boost/signals2/signal.hpp>
 
+#include <functional>
 #include <map>
 #include <unordered_set>
 
@@ -20,7 +21,9 @@ class XMLElement;
 /////////////////////////////////////////////
 // Free Functions
 /////////////////////////////////////////////
-typedef void (*OptionsDBFn)(OptionsDB&); ///< the function signature for functions that add Options to the OptionsDB (void (OptionsDB&))
+
+//! The function signature for functions that add Options to the OptionsDB (void (OptionsDB&))
+typedef std::function<void (OptionsDB&)> OptionsDBFn;
 
 /** adds \a function to a vector of pointers to functions that add Options to
   * the OptionsDB.  This function returns a boolean so that it can be used to
@@ -112,49 +115,63 @@ public:
 
     /** indicates whether an option with name \a name has been added to this
         OptionsDB. */
-    bool        OptionExists(const std::string& name) const
+    bool OptionExists(const std::string& name) const
     { return m_options.count(name) && m_options.at(name).recognized; }
 
-    /** write back the optionDB's state to the XML config file
-        if it has changed since it was last saved. */
-    void        Commit();
+    /** write the optionDB's non-default state to the XML config file. */
+    bool Commit(bool only_if_dirty = true, bool only_non_default = true);
 
     /** Write any options that are not at default value to persistent config, replacing any existing file
      *
      *  @returns bool If file was successfully written
      */
-    bool        CommitPersistent();
+    bool CommitPersistent();
 
     /** validates a value for an option. throws std::runtime_error if no option
       * \a name exists.  throws bad_lexical_cast if \a value cannot be
       * converted to the type of the option \a name. */
-    void        Validate(const std::string& name, const std::string& value) const;
+    void Validate(const std::string& name, const std::string& value) const;
 
     /** returns the value of option \a name. Note that the exact type of item
       * stored in the option \a name must be known in advance.  This means that
       * Get() must be called as Get<int>("foo"), etc. */
-    template <class T>
-    T           Get(const std::string& name) const
+    template <typename T>
+    T Get(const std::string& name) const
     {
         auto it = m_options.find(name);
         if (!OptionExists(it))
             throw std::runtime_error("OptionsDB::Get<>() : Attempted to get nonexistent option \"" + name + "\".");
-        return boost::any_cast<T>(it->second.value);
+        try {
+            return boost::any_cast<T>(it->second.value);
+        } catch (const boost::bad_any_cast&) {
+            ErrorLogger() << "bad any cast converting value option named: " << name << ". Returning default value instead";
+            try {
+                return boost::any_cast<T>(it->second.default_value);
+            } catch (const boost::bad_any_cast&) {
+                ErrorLogger() << "bad any cast converting default value of option named: " << name << ". Returning data-type default value instead: " << T();
+                return T();
+            }
+        }
     }
 
     /** returns the default value of option \a name. Note that the exact type
       * of item stored in the option \a name must be known in advance.  This
       * means that GetDefault() must be called as Get<int>("foo"), etc. */
-    template <class T>
-    T           GetDefault(const std::string& name) const
+    template <typename T>
+    T GetDefault(const std::string& name) const
     {
         auto it = m_options.find(name);
         if (!OptionExists(it))
             throw std::runtime_error("OptionsDB::GetDefault<>() : Attempted to get nonexistent option \"" + name + "\".");
-        return boost::any_cast<T>(it->second.default_value);
+        try {
+            return boost::any_cast<T>(it->second.default_value);
+        } catch (const boost::bad_any_cast&) {
+            ErrorLogger() << "bad any cast converting default value of option named: " << name << "  returning type default value instead";
+            return T();
+        }
     }
 
-    bool        IsDefaultValue(const std::string& name) const {
+    bool IsDefaultValue(const std::string& name) const {
         auto it = m_options.find(name);
         if (!OptionExists(it))
             throw std::runtime_error("OptionsDB::IsDefaultValue<>() : Attempted to get nonexistent option \"" + name + "\".");
@@ -177,7 +194,7 @@ public:
     std::shared_ptr<const ValidatorBase> GetValidator(const std::string& option_name) const;
 
     /** writes a usage message to \a os */
-    void        GetUsage(std::ostream& os, const std::string& command_line = "", bool allow_unrecognized = false) const;
+    void GetUsage(std::ostream& os, const std::string& command_line = "", bool allow_unrecognized = false) const;
 
     /** @brief  Saves the contents of the options DB to the @p doc XMLDoc.
      *
@@ -186,11 +203,11 @@ public:
      * @param[in] non_default_only Do not include options which are set to their
      *      default value, is unrecognized, or is "version.string"
      */
-    void        GetXML(XMLDoc& doc, bool non_default_only = false) const;
+    void GetXML(XMLDoc& doc, bool non_default_only = false, bool include_version = true) const;
 
     /** find all registered Options that begin with \a prefix and store them in
       * \a ret. If \p allow_unrecognized then include unrecognized options. */
-    void        FindOptions(std::set<std::string>& ret, const std::string& prefix, bool allow_unrecognized = false) const;
+    void FindOptions(std::set<std::string>& ret, const std::string& prefix, bool allow_unrecognized = false) const;
 
     /** the option changed signal object for the given option */
     OptionChangedSignalType&        OptionChangedSignal(const std::string& option);
@@ -199,10 +216,10 @@ public:
     mutable OptionRemovedSignalType OptionRemovedSignal; ///< the change removed signal object for this DB
 
     /** adds an Option, optionally with a custom validator */
-    template <class T>
-    void        Add(const std::string& name, const std::string& description, T default_value,
-                    const ValidatorBase& validator = Validator<T>(), bool storable = true,
-                    const std::string& section = std::string())
+    template <typename T>
+    void Add(const std::string& name, const std::string& description, T default_value,
+             const ValidatorBase& validator = Validator<T>(), bool storable = true,
+             const std::string& section = std::string())
     {
         auto it = m_options.find(name);
         boost::any value = default_value;
@@ -229,10 +246,10 @@ public:
 
     /** adds an Option with an alternative one-character shortened name,
       * optionally with a custom validator */
-    template <class T>
-    void        Add(char short_name, const std::string& name, const std::string& description, T default_value,
-                    const ValidatorBase& validator = Validator<T>(), bool storable = true,
-                    const std::string& section = std::string())
+    template <typename T>
+    void Add(char short_name, const std::string& name, const std::string& description, T default_value,
+             const ValidatorBase& validator = Validator<T>(), bool storable = true,
+             const std::string& section = std::string())
     {
         auto it = m_options.find(name);
         boost::any value = default_value;
@@ -247,7 +264,7 @@ public:
                     // This option was previously specified externally but was not recognized at the time, attempt to parse the value found there
                     value = validator.Validate(it->second.ValueToString());
                 } catch (boost::bad_lexical_cast&) {
-                    ErrorLogger() << "OptionsDB::Add<>() : Option " << name << " was given the value \"" << it->second.ValueToString() << "\" from the command line or a config file but that value couldn't be converted to the correct type, using default value instead.";
+                    ErrorLogger() << "OptionsDB::Add<>() : Option " << name << " was given the value from the command line or a config file that cannot be converted to the correct type. Using default value instead.";
                 }
             }
         }
@@ -260,8 +277,8 @@ public:
     /** adds a flag Option, which is treated as a boolean value with a default
       * of false.  Using the flag on the command line at all indicates that its
       * value it set to true. */
-    void        AddFlag(const std::string& name, const std::string& description,
-                        bool storable = true, const std::string& section = std::string())
+    void AddFlag(const std::string& name, const std::string& description,
+                 bool storable = true, const std::string& section = std::string())
     {
         auto it = m_options.find(name);
         bool value = false;
@@ -283,9 +300,9 @@ public:
     /** adds an Option with an alternative one-character shortened name, which
       * is treated as a boolean value with a default of false.  Using the flag
       * on the command line at all indicates that its value it set to true. */
-    void        AddFlag(char short_name, const std::string& name,
-                        const std::string& description, bool storable = true,
-                        const std::string& section = std::string())
+    void AddFlag(char short_name, const std::string& name,
+                 const std::string& description, bool storable = true,
+                 const std::string& section = std::string())
     {
         auto it = m_options.find(name);
         bool value = false;
@@ -305,15 +322,15 @@ public:
     }
 
     /** removes an Option */
-    void        Remove(const std::string& name);
+    void Remove(const std::string& name);
 
     /** removes all unrecognized Options that begin with \a prefix.  A blank
       * string will remove all unrecognized Options. */
-    void        RemoveUnrecognized(const std::string& prefix = "");
+    void RemoveUnrecognized(const std::string& prefix = "");
 
     /** sets the value of option \a name to \a value */
-    template <class T>
-    void        Set(const std::string& name, const T& value)
+    template <typename T>
+    void Set(const std::string& name, const T& value)
     {
         auto it = m_options.find(name);
         if (!OptionExists(it))
@@ -322,8 +339,8 @@ public:
     }
 
     /** Set the default value of option @p name to @p value */
-    template <class T>
-    void        SetDefault(const std::string& name, const T& value) {
+    template <typename T>
+    void SetDefault(const std::string& name, const T& value) {
         std::map<std::string, Option>::iterator it = m_options.find(name);
         if (!OptionExists(it))
             throw std::runtime_error("Attempted to set default value of nonexistent option \"" + name + "\".");
@@ -335,16 +352,16 @@ public:
     /** if an xml file exists at \a file_path and has the same version tag as \a version, fill the
       * DB options contained in that file (read the file using XMLDoc, then fill the DB using SetFromXML)
       * if the \a version string is empty, bypass that check */
-    void        SetFromFile(const boost::filesystem::path& file_path,
-                            const std::string& version = "");
+    void SetFromFile(const boost::filesystem::path& file_path,
+                     const std::string& version = "");
 
     /** fills some or all of the options of the DB from values passed in from
       * the command line */
-    void        SetFromCommandLine(const std::vector<std::string>& args);
+    void SetFromCommandLine(const std::vector<std::string>& args);
 
     /** fills some or all of the options of the DB from values stored in
       * XMLDoc \a doc */
-    void        SetFromXML(const XMLDoc& doc);
+    void SetFromXML(const XMLDoc& doc);
 
     struct FO_COMMON_API Option {
         Option();
@@ -362,9 +379,10 @@ public:
         bool            SetToDefault();
         std::string     ValueToString() const;
         std::string     DefaultValueToString() const;
+        bool            ValueIsDefault() const;
 
         std::string     name;           ///< the name of the option
-        char            short_name;     ///< the one character abbreviation of the option
+        char            short_name{0};  ///< the one character abbreviation of the option
         boost::any      value;          ///< the value of the option
         boost::any      default_value;  ///< the default value of the option
         std::string     description;    ///< a desription of the option
@@ -374,9 +392,9 @@ public:
             boolean conversions are done for them. */
         std::shared_ptr<const ValidatorBase> validator;
 
-        bool            storable;       ///< whether this option can be stored in an XML config file for use across multiple runs
-        bool            flag;
-        bool            recognized;     ///< whether this option has been registered before being specified via an XML input, unrecognized options can't be parsed (don't know their type) but are stored in case they are later registered with Add()
+        bool            storable = false;   ///< whether this option can be stored in an XML config file for use across multiple runs
+        bool            flag = false;
+        bool            recognized = false; ///< whether this option has been registered before being specified via an XML input, unrecognized options can't be parsed (don't know their type) but are stored in case they are later registered with Add()
 
         mutable std::shared_ptr<boost::signals2::signal<void ()>> option_changed_sig_ptr;
 
@@ -405,17 +423,17 @@ private:
     /** indicates whether the option referenced by \a it has been added to this
         OptionsDB.  Overloaded for convenient use within other OptionsDB
         functions */
-    bool        OptionExists(std::map<std::string, Option>::const_iterator it) const
+    bool OptionExists(std::map<std::string, Option>::const_iterator it) const
     { return it != m_options.end() && it->second.recognized; }
 
     /** indicates whether the current value of the option references by \a is
         the default value for that option */
-    bool        IsDefaultValue(std::map<std::string, Option>::const_iterator it) const
+    bool IsDefaultValue(std::map<std::string, Option>::const_iterator it) const
     { return it != m_options.end() && it->second.ValueToString() == it->second.DefaultValueToString(); }
 
     OptionsDB();
 
-    void        SetFromXMLRecursive(const XMLElement& elem, const std::string& section_name);
+    void SetFromXMLRecursive(const XMLElement& elem, const std::string& section_name);
 
     /** Determine known option sections and which options each contains
      *  A special "root" section is added for determined top-level sections */
@@ -432,15 +450,20 @@ private:
 template <typename T>
 bool OptionsDB::Option::SetFromValue(const T& value_) {
     if (value.type() != typeid(T))
-        throw boost::bad_any_cast();
+        ErrorLogger() << "OptionsDB::Option::SetFromValue expected type " << value.type().name() << " but got value of type " << typeid(T).name();
 
     bool changed = false;
 
-    if (!flag) {
-        changed = validator->String(value) != validator->String(value_);
-    } else {
-        changed = (boost::lexical_cast<std::string>(boost::any_cast<bool>(value))
-                   != boost::lexical_cast<std::string>(boost::any_cast<bool>(value_)));
+    try {
+        if (!flag) {
+            changed = validator->String(value) != validator->String(value_);
+        } else {
+            changed = (boost::lexical_cast<std::string>(boost::any_cast<bool>(value))
+                    != boost::lexical_cast<std::string>(boost::any_cast<bool>(value_)));
+        }
+    } catch (...) {
+        ErrorLogger() << "Exception thrown when setting option value, probably due to the previous value being invalid?";
+        changed = true;
     }
 
     if (changed) {
@@ -450,6 +473,9 @@ bool OptionsDB::Option::SetFromValue(const T& value_) {
     return changed;
 }
 
+// needed because std::vector<std::string> is not streamable
+template <>
+FO_COMMON_API std::vector<std::string> OptionsDB::Get<std::vector<std::string>>(const std::string& name) const;
 
 
 #endif // _OptionsDB_h_
