@@ -9,7 +9,7 @@
 
 #include <map>
 #include <memory>
-
+#include <set>
 
 class Order;
 
@@ -38,43 +38,66 @@ private:
     typedef std::map<int, OrderPtr> OrderMap;
 
 public:
-    typedef OrderMap::const_iterator    const_iterator;    ///< defines a public const_iterator type for OrderSet
+    typedef OrderMap::const_iterator const_iterator;
+    typedef OrderMap::iterator iterator;
+    typedef OrderMap::value_type value_type;
+    typedef OrderMap::size_type size_type;
+    typedef OrderMap::key_type key_type;
+    typedef OrderMap::difference_type difference_type;
+    typedef OrderMap::key_compare key_compare;
 
     /** \name Accessors */ //@{
-    const_iterator begin() const {return m_orders.begin();} ///< returns the begin const_iterator for the OrderSet
-    const_iterator end() const   {return m_orders.end();}   ///< returns the end const_iterator for the OrderSet
+    const_iterator  begin() const           { return m_orders.begin(); }///< returns the begin const_iterator for the OrderSet
+    const_iterator  end() const             { return m_orders.end(); }  ///< returns the end const_iterator for the OrderSet
+    iterator        begin()                 { return m_orders.begin(); }///< returns the begin const_iterator for the OrderSet
+    iterator        end()                   { return m_orders.end(); }  ///< returns the end const_iterator for the OrderSet
+    std::size_t     size() const            { return m_orders.size(); }
+    bool            empty() const           { return m_orders.empty(); }
+    iterator        find(const key_type& k) { return m_orders.find(k); }
+    std::pair<iterator, bool> insert(const value_type& val) { return m_orders.insert(val); } ///< direct insert without saving changes
+    void            erase(const key_type& k){ m_orders.erase(k); } ///< direct erase without saving changes
+    OrderPtr&       operator[](std::size_t i);
+    key_compare     key_comp() const        { return m_orders.key_comp(); }
     //@}
 
     /** \name Mutators */ //@{
     /** Execute the \p order immediately on the client.
         Store the \p order in the OrderSet to be executed later on the server.
         Return an index that can be used to reference the order. */
-    int            IssueOrder(const OrderPtr& order);
-    int            IssueOrder(OrderPtr&& order);
+    int IssueOrder(const OrderPtr& order);
+    int IssueOrder(OrderPtr&& order);
 
     /** Applies all Orders in the OrderSet.  As of this writing, this is needed only after deserializing an OrderSet
         client-side during game loading. */
-    void           ApplyOrders();
+    void ApplyOrders();
 
     /** Try to Undo() \p order and if it succeeds remove the order from the
         set.  Return true if \p order exists and was successfully removed. */
-    bool           RescindOrder(int order);
-    void           Reset(); ///< clears all orders; should be called at the beginning of a new turn
+    bool RescindOrder(int order);
+    void Reset(); ///< clears all orders; should be called at the beginning of a new turn
+
+    std::pair<OrderSet, std::set<int>> ExtractChanges(); ///< extract and clear changed orders
     //@}
 
 private:
-    OrderMap m_orders;
+    OrderMap      m_orders;
+    std::set<int> m_last_added_orders; ///< set of ids added/updated orders
+    std::set<int> m_last_deleted_orders; ///< set of ids deleted orders
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
 // Template Implementations
-template <class Archive>
+template <typename Archive>
 void OrderSet::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_NVP(m_orders);
+    if (Archive::is_loading::value) {
+        m_last_added_orders.clear();
+        m_last_deleted_orders.clear();
+    }
 }
 
 #endif // _OrderSet_h_
