@@ -36,7 +36,7 @@ namespace {
     /// Splits time and date on separate lines for an ISO datetime string
     std::string split_time(const std::string& time) {
         std::string result = time;
-        std::string::size_type pos = result.find("T");
+        std::string::size_type pos = result.find('T');
         if (pos != std::string::npos) {
             result.replace(pos, 1, "\n");
         }
@@ -65,22 +65,21 @@ namespace {
 
         DebugLogger() << "LoadSaveGamePreviewData: Loading preview from: " << path.string();
         try {
-            try {
-                ScopedTimer timer("LoadSaveGamePreviewData (binary): " + path.string(), true);
-
+            // read the first five letters of the stream and check if it is opening an xml file
+            std::string xxx5(5, ' ');
+            ifs.read(&xxx5[0], 5);
+            const std::string xml5{"<?xml"};
+            // reset to start of stream
+            boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+            // binary deserialization iff document is not xml
+            if (xml5 != xxx5) {
                 // first attempt binary deserialziation
                 freeorion_bin_iarchive ia(ifs);
 
                 ia >> BOOST_SERIALIZATION_NVP(save_preview_data);
                 ia >> BOOST_SERIALIZATION_NVP(galaxy_setup_data);
 
-            } catch (...) {
-                // if binary deserialization failed, try more-portable XML deserialization
-
-                // reset to start of stream (attempted binary serialization will have consumed some input...)
-                boost::iostreams::seek(ifs, 0, std::ios_base::beg);
-
-                DebugLogger() << "Deserializing XML data";
+            } else {
                 freeorion_xml_iarchive ia(ifs);
                 ia >> BOOST_SERIALIZATION_NVP(save_preview_data);
 
@@ -126,7 +125,7 @@ bool SaveGamePreviewData::Valid() const
 void SaveGamePreviewData::SetBinary(bool bin)
 { description = bin ? BIN_SAVE_FILE_DESCRIPTION : XML_SAVE_FILE_DESCRIPTION; }
 
-template<class Archive>
+template <typename Archive>
 void SaveGamePreviewData::serialize(Archive& ar, unsigned int version)
 {
     if (version >= 2) {
@@ -160,7 +159,8 @@ template void SaveGamePreviewData::serialize<freeorion_bin_iarchive>(freeorion_b
 template void SaveGamePreviewData::serialize<freeorion_xml_oarchive>(freeorion_xml_oarchive&, unsigned int);
 template void SaveGamePreviewData::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive&, unsigned int);
 
-template<class Archive>
+
+template <typename Archive>
 void FullPreview::serialize(Archive& ar, unsigned int version)
 {
     ar & BOOST_SERIALIZATION_NVP(filename)
@@ -187,6 +187,63 @@ template void PreviewInformation::serialize<freeorion_bin_iarchive>(freeorion_bi
 template void PreviewInformation::serialize<freeorion_xml_oarchive>(freeorion_xml_oarchive&, const unsigned int);
 template void PreviewInformation::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive&, const unsigned int);
 
+
+bool SaveFileWithValidHeader(const boost::filesystem::path& path) {
+    if (!fs::exists(path))
+        return false;
+
+    fs::ifstream ifs(path, std::ios_base::binary);
+    if (!ifs)
+        return false;
+
+    // dummy holders for deserialized data
+    SaveGamePreviewData                 ignored_save_preview_data;
+    GalaxySetupData                     ignored_galaxy_setup_data;
+    ServerSaveGameData                  ignored_server_save_game_data;
+    std::vector<PlayerSaveHeaderData>   ignored_player_save_header_data;
+    std::map<int, SaveGameEmpireData>   ignored_empire_save_game_data;
+
+    DebugLogger() << "SaveFileWithValidHeader: Loading headers from: " << path.string();
+    try {
+        // read the first five letters of the stream and check if it is opening an xml file
+        std::string xxx5(5, ' ');
+        ifs.read(&xxx5[0], 5);
+        const std::string xml5{"<?xml"};
+        // reset to start of stream 
+        boost::iostreams::seek(ifs, 0, std::ios_base::beg);
+        // binary deserialization iff document is not xml
+        if (xml5 != xxx5) {
+            ScopedTimer timer("SaveFileWithValidHeader (binary): " + path.string(), true);
+
+            freeorion_bin_iarchive ia(ifs);
+
+            ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
+            ia >> BOOST_SERIALIZATION_NVP(ignored_galaxy_setup_data);
+            ia >> BOOST_SERIALIZATION_NVP(ignored_server_save_game_data);
+            ia >> BOOST_SERIALIZATION_NVP(ignored_player_save_header_data);
+            ia >> BOOST_SERIALIZATION_NVP(ignored_empire_save_game_data);
+        } else {
+            DebugLogger() << "Deserializing XML data";
+            freeorion_xml_iarchive ia(ifs);
+
+            ia >> BOOST_SERIALIZATION_NVP(ignored_save_preview_data);
+
+            if (BOOST_VERSION >= 106600 && ignored_save_preview_data.save_format_marker == XML_COMPRESSED_MARKER)
+                throw std::invalid_argument("Save Format Not Compatible with Boost Version " BOOST_LIB_VERSION);
+
+            ia >> BOOST_SERIALIZATION_NVP(ignored_galaxy_setup_data);
+            ia >> BOOST_SERIALIZATION_NVP(ignored_server_save_game_data);
+            ia >> BOOST_SERIALIZATION_NVP(ignored_player_save_header_data);
+            ia >> BOOST_SERIALIZATION_NVP(ignored_empire_save_game_data);
+        }
+
+    } catch (const std::exception& e) {
+        ErrorLogger() << "SaveFileWithValidHeader: Failed to read headers of " << path.string() << " because: " << e.what();
+        return false;
+    }
+    return true;
+}
+
 std::string ColumnInPreview(const FullPreview& full, const std::string& name, bool thin) {
     if (name == "player") {
         return full.preview.main_player_name;
@@ -254,7 +311,6 @@ void LoadSaveGamePreviews(const fs::path& orig_path, const std::string& extensio
 
     for (fs::directory_iterator it(path); it != end_it; ++it) {
         try {
-            std::string filename = PathToString(it->path().filename());
             if ((it->path().filename().extension() == extension) && !fs::is_directory(it->path())) {
                 if (LoadSaveGamePreviewData(*it, data)) {
                     // Add preview entry to list
