@@ -43,7 +43,7 @@ struct FO_COMMON_API SaveGamePreviewData {
     unsigned int        uncompressed_text_size = 0;     /// How many bytes capacity does the uncompressed save text take up? (ie. the part that was / will be compressed with zlib for compressed xml format saves)
     unsigned int        compressed_text_size = 0;       /// How many bytes capacity does the compressed save text take up?
 
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, unsigned int version);
 };
 
@@ -61,7 +61,7 @@ struct FO_COMMON_API FullPreview {
     GalaxySetupData     galaxy;
 private:
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -72,10 +72,15 @@ struct FO_COMMON_API PreviewInformation {
     std::vector<FullPreview>    previews;       /// The previews of the saves in this folder
 private:
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
+/// Attempts to load headers of a save file.
+/// Returns true on success, false if header data could not be loaded
+/// @param path Filename to load headers of
+FO_COMMON_API bool SaveFileWithValidHeader(const boost::filesystem::path& path);
+
 /// Get the value of column name in this preview
 /// @param full FullPreview to match for column @p name
 /// \param name The name of the column
