@@ -13,14 +13,19 @@
 #include "../universe/System.h"
 #include "../universe/Field.h"
 #include "../universe/Universe.h"
+#include "ScopedTimer.h"
+#include "AppInterface.h"
+#include "OptionsDB.h"
 
 #include <boost/lexical_cast.hpp>
 #include <boost/uuid/nil_generator.hpp>
 
+BOOST_CLASS_EXPORT(UniverseObject)
+BOOST_CLASS_VERSION(UniverseObject, 2)
 BOOST_CLASS_EXPORT(System)
 BOOST_CLASS_EXPORT(Field)
 BOOST_CLASS_EXPORT(Planet)
-BOOST_CLASS_VERSION(Planet, 1)
+BOOST_CLASS_VERSION(Planet, 2)
 BOOST_CLASS_EXPORT(Building)
 BOOST_CLASS_EXPORT(Fleet)
 BOOST_CLASS_VERSION(Fleet, 3)
@@ -31,18 +36,17 @@ BOOST_CLASS_VERSION(ShipDesign, 2)
 BOOST_CLASS_EXPORT(Universe)
 BOOST_CLASS_VERSION(Universe, 1)
 
-template <class Archive>
+template <typename Archive>
 void ObjectMap::serialize(Archive& ar, const unsigned int version)
 {
     ar & BOOST_SERIALIZATION_NVP(m_objects);
 
     // If loading from the archive, propagate the changes to the specialized maps.
-    if (Archive::is_loading::value) {
+    if (Archive::is_loading::value)
         CopyObjectsToSpecializedMaps();
-    }
 }
 
-template <class Archive>
+template <typename Archive>
 void Universe::serialize(Archive& ar, const unsigned int version)
 {
     ObjectMap                       objects;
@@ -58,26 +62,32 @@ void Universe::serialize(Archive& ar, const unsigned int version)
 
     std::string serializing_label = (Archive::is_loading::value ? "deserializing" : "serializing");
 
+    SectionedScopedTimer timer("Universe " + serializing_label);
+
     if (Archive::is_saving::value) {
         DebugLogger() << "Universe::serialize : Getting gamestate data";
+        timer.EnterSection("collecting data");
         GetObjectsToSerialize(              objects,                            m_encoding_empire);
         GetDestroyedObjectsToSerialize(     destroyed_object_ids,               m_encoding_empire);
         GetEmpireKnownObjectsToSerialize(   empire_latest_known_objects,        m_encoding_empire);
         GetEmpireObjectVisibilityMap(       empire_object_visibility,           m_encoding_empire);
         GetEmpireObjectVisibilityTurnMap(   empire_object_visibility_turns,     m_encoding_empire);
-        //GetEffectSpecifiedVisibilities(     effect_specified_visibilities,      m_encoding_empire);
         GetEmpireKnownDestroyedObjects(     empire_known_destroyed_object_ids,  m_encoding_empire);
         GetEmpireStaleKnowledgeObjects(     empire_stale_knowledge_object_ids,  m_encoding_empire);
         GetShipDesignsToSerialize(          ship_designs,                       m_encoding_empire);
+        timer.EnterSection("");
     }
 
     if (Archive::is_loading::value) {
-        Clear();    // clean up any existing dynamically allocated contents before replacing containers with deserialized data
+        // clean up any existing dynamically allocated contents before replacing
+        // containers with deserialized data.
+        Clear();
     }
 
     ar  & BOOST_SERIALIZATION_NVP(m_universe_width);
     DebugLogger() << "Universe::serialize : " << serializing_label << " universe width: " << m_universe_width;
 
+    timer.EnterSection("designs");
     ar  & BOOST_SERIALIZATION_NVP(ship_designs);
     if (Archive::is_loading::value)
         m_ship_designs.swap(ship_designs);
@@ -85,6 +95,7 @@ void Universe::serialize(Archive& ar, const unsigned int version)
 
     ar  & BOOST_SERIALIZATION_NVP(m_empire_known_ship_design_ids);
 
+    timer.EnterSection("vis / known");
     ar  & BOOST_SERIALIZATION_NVP(empire_object_visibility);
     ar  & BOOST_SERIALIZATION_NVP(empire_object_visibility_turns);
     //ar  & BOOST_SERIALIZATION_NVP(effect_specified_visibilities);
@@ -96,20 +107,25 @@ void Universe::serialize(Archive& ar, const unsigned int version)
                   //<< effect_specified_visibilities.size() << ", "
                   << empire_known_destroyed_object_ids.size() << ", "
                   << empire_stale_knowledge_object_ids.size() <<  " empires";
+    timer.EnterSection("");
     if (Archive::is_loading::value) {
+        timer.EnterSection("load swap");
         m_empire_object_visibility.swap(empire_object_visibility);
         m_empire_object_visibility_turns.swap(empire_object_visibility_turns);
         //m_effect_specified_empire_object_visibilities.swap(effect_specified_visibilities);
         m_empire_known_destroyed_object_ids.swap(empire_known_destroyed_object_ids);
         m_empire_stale_knowledge_object_ids.swap(empire_stale_knowledge_object_ids);
+        timer.EnterSection("");
     }
 
+    timer.EnterSection("objects");
     ar  & BOOST_SERIALIZATION_NVP(objects);
-    DebugLogger() << "Universe::serialize : " << serializing_label << " " << objects.NumObjects() << " objects";
+    DebugLogger() << "Universe::serialize : " << serializing_label << " " << objects.size() << " objects";
     if (Archive::is_loading::value) {
         m_objects.swap(objects);
     }
 
+    timer.EnterSection("destroyed ids");
     ar  & BOOST_SERIALIZATION_NVP(destroyed_object_ids);
     DebugLogger() << "Universe::serialize : " << serializing_label << " " << destroyed_object_ids.size() << " destroyed object ids";
     if (Archive::is_loading::value) {
@@ -117,12 +133,14 @@ void Universe::serialize(Archive& ar, const unsigned int version)
         m_objects.UpdateCurrentDestroyedObjects(m_destroyed_object_ids);
     }
 
+    timer.EnterSection("latest known objects");
     ar  & BOOST_SERIALIZATION_NVP(empire_latest_known_objects);
     DebugLogger() << "Universe::serialize : " << serializing_label << " empire known objects for " << empire_latest_known_objects.size() << " empires";
     if (Archive::is_loading::value) {
         m_empire_latest_known_objects.swap(empire_latest_known_objects);
     }
 
+    timer.EnterSection("id allocator");
     if (version >= 1) {
         DebugLogger() << "Universe::serialize : " << serializing_label << " id allocator version = " << version;
         m_object_id_allocator->SerializeForEmpire(ar, version, m_encoding_empire);
@@ -148,32 +166,38 @@ void Universe::serialize(Archive& ar, const unsigned int version)
         }
     }
 
-    ar  & BOOST_SERIALIZATION_NVP(m_stat_records);
-    DebugLogger() << "Universe::serialize : " << serializing_label << " " << m_stat_records.size() << " types of statistic";
-
-    DebugLogger() << "Universe::serialize : " << serializing_label << " done";
+    timer.EnterSection("stats");
+    if (Archive::is_saving::value && m_encoding_empire != ALL_EMPIRES && (!GetOptionsDB().Get<bool>("network.server.publish-statistics"))) {
+        std::map<std::string, std::map<int, std::map<int, double>>> dummy_stat_records;
+        ar  & boost::serialization::make_nvp("m_stat_records", dummy_stat_records);
+    } else {
+        ar  & BOOST_SERIALIZATION_NVP(m_stat_records);
+        DebugLogger() << "Universe::serialize : " << serializing_label << " " << m_stat_records.size() << " types of statistic";
+    }
+    timer.EnterSection("");
 
     if (Archive::is_saving::value) {
         DebugLogger() << "Universe::serialize : Cleaning up temporary data";
-        // clean up temporary objects in temporary ObjectMaps
-        objects.Clear();
+        // clean up temporary objects in temporary ObjectMaps.
+        objects.clear();
         for (auto& elko : empire_latest_known_objects)
-        { elko.second.Clear(); }
+        { elko.second.clear(); }
     }
 
     if (Archive::is_loading::value) {
         DebugLogger() << "Universe::serialize : updating empires' latest known object destruction states";
-        // update known destroyed objects state in each empire's latest known objects
+        // update known destroyed objects state in each empire's latest known
+        // objects.
         for (auto& elko : m_empire_latest_known_objects) {
             auto destroyed_ids_it = m_empire_known_destroyed_object_ids.find(elko.first);
             if (destroyed_ids_it != m_empire_known_destroyed_object_ids.end())
                 elko.second.UpdateCurrentDestroyedObjects(destroyed_ids_it->second);
         }
     }
-    DebugLogger() << "Universe::serialize done";
+    DebugLogger() << "Universe " << serializing_label << " done";
 }
 
-template <class Archive>
+template <typename Archive>
 void UniverseObject::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_NVP(m_id)
@@ -182,12 +206,24 @@ void UniverseObject::serialize(Archive& ar, const unsigned int version)
         & BOOST_SERIALIZATION_NVP(m_y)
         & BOOST_SERIALIZATION_NVP(m_owner_empire_id)
         & BOOST_SERIALIZATION_NVP(m_system_id)
-        & BOOST_SERIALIZATION_NVP(m_specials)
-        & BOOST_SERIALIZATION_NVP(m_meters)
-        & BOOST_SERIALIZATION_NVP(m_created_on_turn);
+        & BOOST_SERIALIZATION_NVP(m_specials);
+    if (version < 2) {
+        std::map<MeterType, Meter> meter_map;
+        ar  & boost::serialization::make_nvp("m_meters", meter_map);
+        m_meters.reserve(meter_map.size());
+        m_meters.insert(meter_map.begin(), meter_map.end());
+    } else {
+        ar  & BOOST_SERIALIZATION_NVP(m_meters);
+
+        // loading the internal vector, like so, was no faster than loading the map
+        //auto meters{m_meters.extract_sequence()};
+        //ar  & BOOST_SERIALIZATION_NVP(meters);
+        //m_meters.adopt_sequence(std::move(meters));
+    }
+    ar  & BOOST_SERIALIZATION_NVP(m_created_on_turn);
 }
 
-template <class Archive>
+template <typename Archive>
 void System::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_BASE_OBJECT_NVP(UniverseObject)
@@ -203,14 +239,14 @@ void System::serialize(Archive& ar, const unsigned int version)
         & BOOST_SERIALIZATION_NVP(m_last_turn_battle_here);
 }
 
-template <class Archive>
+template <typename Archive>
 void Field::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_BASE_OBJECT_NVP(UniverseObject)
         & BOOST_SERIALIZATION_NVP(m_type_name);
 }
 
-template <class Archive>
+template <typename Archive>
 void Planet::serialize(Archive& ar, const unsigned int version)
 {
    ar   & BOOST_SERIALIZATION_BASE_OBJECT_NVP(UniverseObject)
@@ -224,6 +260,14 @@ void Planet::serialize(Archive& ar, const unsigned int version)
         & BOOST_SERIALIZATION_NVP(m_rotational_period)
         & BOOST_SERIALIZATION_NVP(m_axial_tilt)
         & BOOST_SERIALIZATION_NVP(m_buildings);
+    if (version < 2) {
+        // if deserializing an old save, default to standard default never-colonized turn
+        m_turn_last_colonized = INVALID_GAME_TURN;
+        if (!SpeciesName().empty()) // but if a planet has a species, it must have been colonized, so default to the previous turn
+            m_turn_last_colonized = CurrentTurn() - 1;
+    } else {
+        ar   & BOOST_SERIALIZATION_NVP(m_turn_last_colonized);
+    }
     if (version < 1) {
         bool dummy = false;
         ar   & boost::serialization::make_nvp("m_just_conquered", dummy);
@@ -237,7 +281,7 @@ void Planet::serialize(Archive& ar, const unsigned int version)
         & BOOST_SERIALIZATION_NVP(m_last_turn_attacked_by_ship);
 }
 
-template <class Archive>
+template <typename Archive>
 void Building::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_BASE_OBJECT_NVP(UniverseObject)
@@ -247,7 +291,7 @@ void Building::serialize(Archive& ar, const unsigned int version)
         & BOOST_SERIALIZATION_NVP(m_produced_by_empire_id);
 }
 
-template <class Archive>
+template <typename Archive>
 void Fleet::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_BASE_OBJECT_NVP(UniverseObject)
@@ -265,7 +309,7 @@ void Fleet::serialize(Archive& ar, const unsigned int version)
         & BOOST_SERIALIZATION_NVP(m_arrival_starlane);
 }
 
-template <class Archive>
+template <typename Archive>
 void Ship::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_BASE_OBJECT_NVP(UniverseObject)
@@ -287,7 +331,7 @@ void Ship::serialize(Archive& ar, const unsigned int version)
     }
 }
 
-template <class Archive>
+template <typename Archive>
 void ShipDesign::serialize(Archive& ar, const unsigned int version)
 {
     ar  & BOOST_SERIALIZATION_NVP(m_id)
@@ -296,9 +340,9 @@ void ShipDesign::serialize(Archive& ar, const unsigned int version)
     TraceLogger() << "ship design serialize version: " << version << " : " << (Archive::is_saving::value ? "saving" : "loading");
 
     if (version >= 1) {
-        // UUID serialization as a primitive doesn't work as expected from the documentation
-        // ar & BOOST_SERIALIZATION_NVP(m_uuid);
-        // This workaround instead serializes a string representation.
+        // Serialization of m_uuid as a primitive doesn't work as expected from
+        // the documentation.  This workaround instead serializes a string
+        // representation.
         if (Archive::is_saving::value) {
             auto string_uuid = boost::uuids::to_string(m_uuid);
             ar & BOOST_SERIALIZATION_NVP(string_uuid);
@@ -340,7 +384,7 @@ void SpeciesManager::serialize<freeorion_bin_iarchive>(freeorion_bin_iarchive& a
 template
 void SpeciesManager::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive& ar, const unsigned int version);
 
-template <class Archive>
+template <typename Archive>
 void SpeciesManager::serialize(Archive& ar, const unsigned int version)
 {
     // Don't need to send all the data about species, as this is derived from
@@ -367,15 +411,14 @@ void SpeciesManager::serialize(Archive& ar, const unsigned int version)
         & BOOST_SERIALIZATION_NVP(empire_opinions)
         & BOOST_SERIALIZATION_NVP(other_species_opinions)
         & BOOST_SERIALIZATION_NVP(species_object_populations)
-        & BOOST_SERIALIZATION_NVP(species_ships_destroyed)
-    ;
+        & BOOST_SERIALIZATION_NVP(species_ships_destroyed);
 
     if (Archive::is_loading::value) {
         SetSpeciesHomeworlds(species_homeworlds);
         SetSpeciesEmpireOpinions(empire_opinions);
         SetSpeciesSpeciesOpinions(other_species_opinions);
-        m_species_object_populations = species_object_populations;
-        m_species_species_ships_destroyed = species_ships_destroyed;
+        m_species_object_populations = std::move(species_object_populations);
+        m_species_species_ships_destroyed = std::move(species_ships_destroyed);
     }
 }
 
@@ -391,26 +434,73 @@ void System::serialize<freeorion_bin_iarchive>(freeorion_bin_iarchive& ar, const
 template
 void System::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive& ar, const unsigned int version);
 
-template <class Archive>
+template <typename Archive>
 void Serialize(Archive& oa, const Universe& universe)
 { oa << BOOST_SERIALIZATION_NVP(universe); }
 template FO_COMMON_API void Serialize<freeorion_bin_oarchive>(freeorion_bin_oarchive& oa, const Universe& universe);
 template FO_COMMON_API void Serialize<freeorion_xml_oarchive>(freeorion_xml_oarchive& oa, const Universe& universe);
 
-template <class Archive>
+template <typename Archive>
 void Serialize(Archive& oa, const std::map<int, std::shared_ptr<UniverseObject>>& objects)
 { oa << BOOST_SERIALIZATION_NVP(objects); }
 template void Serialize<freeorion_bin_oarchive>(freeorion_bin_oarchive& oa, const std::map<int, std::shared_ptr<UniverseObject>>& objects);
 template void Serialize<freeorion_xml_oarchive>(freeorion_xml_oarchive& oa, const std::map<int, std::shared_ptr<UniverseObject>>& objects);
 
-template <class Archive>
+template <typename Archive>
 void Deserialize(Archive& ia, Universe& universe)
 { ia >> BOOST_SERIALIZATION_NVP(universe); }
 template FO_COMMON_API void Deserialize<freeorion_bin_iarchive>(freeorion_bin_iarchive& ia, Universe& universe);
 template FO_COMMON_API void Deserialize<freeorion_xml_iarchive>(freeorion_xml_iarchive& ia, Universe& universe);
 
-template <class Archive>
+template <typename Archive>
 void Deserialize(Archive& ia, std::map<int, std::shared_ptr<UniverseObject>>& objects)
 { ia >> BOOST_SERIALIZATION_NVP(objects); }
 template void Deserialize<freeorion_bin_iarchive>(freeorion_bin_iarchive& ia, std::map<int, std::shared_ptr<UniverseObject>>& objects);
 template void Deserialize<freeorion_xml_iarchive>(freeorion_xml_iarchive& ia, std::map<int, std::shared_ptr<UniverseObject>>& objects);
+
+namespace boost {
+namespace serialization {
+    template<class Archive, class Key, class Value>
+    void save(Archive& ar, const flat_map<Key, Value>& m, const unsigned int)
+    { stl::save_collection<Archive, flat_map<Key, Value>>(ar, m); }
+
+    template<class Archive, class Key, class Value>
+    void load(Archive& ar, flat_map<Key, Value>& m, const unsigned int)
+    { load_map_collection(ar, m); }
+
+    template<class Archive, class Key, class Value>
+    void serialize(Archive& ar, flat_map<Key, Value>& m, const unsigned int file_version)
+    { split_free(ar, m, file_version); }
+
+
+    // Note: I tried loading the internal vector of a flat_map instead of
+    //       loading it as a map and constructing elements on the stack.
+    //       The result was similar or slightly slower than the stack loader.
+    //
+    //template<class Archive, class U, class Allocator>
+    //inline void save(Archive& ar, const container::vector<U, Allocator>& t,
+    //                 const unsigned int file_version)
+    //{ stl::save_collection(ar, t); }
+
+    //template<class Archive, class U, class Allocator>
+    //inline void load(Archive& ar, container::vector<U, Allocator>& t,
+    //                 const unsigned int file_version)
+    //{
+    //    item_version_type item_version(0);
+    //    collection_size_type count;
+    //    ar >> BOOST_SERIALIZATION_NVP(count);
+    //    ar >> BOOST_SERIALIZATION_NVP(item_version);
+    //    t.resize(count);
+
+    //    using Container = container::vector<U, Allocator>;
+    //    typedef typename Container::value_type type;
+
+    //    for (auto& s : t)
+    //        ar >> make_nvp("item", s);
+    //}
+
+    //template<class Archive, class U, class Allocator>
+    //inline void serialize(Archive& ar, container::vector<U, Allocator>& t,
+    //                      const unsigned int file_version)
+    //{ split_free(ar, t, file_version); }
+}}
\ No newline at end of file
