@@ -2,6 +2,7 @@
 
 #include "i18n.h"
 #include "Logger.h"
+#include "AppInterface.h"
 #include "../universe/Predicates.h"
 #include "../universe/Building.h"
 #include "../universe/Planet.h"
@@ -10,6 +11,7 @@
 #include "../universe/Fleet.h"
 #include "../universe/Universe.h"
 
+
 SitRepEntry::SitRepEntry() :
     VarText(),
     m_turn(INVALID_GAME_TURN),
@@ -57,7 +59,7 @@ std::string SitRepEntry::Dump() const {
 SitRepEntry CreateTechResearchedSitRep(const std::string& tech_name) {
     SitRepEntry sitrep(
         UserStringNop("SITREP_TECH_RESEARCHED"),
-        CurrentTurn() + 1,
+        CurrentTurn(),
         "icons/sitrep/tech_researched.png",
         UserStringNop("SITREP_TECH_RESEARCHED_LABEL"), true);
     sitrep.AddVariable(VarText::TECH_TAG,          tech_name);
@@ -102,7 +104,7 @@ SitRepEntry CreateBuildingBuiltSitRep(int building_id, int planet_id) {
 SitRepEntry CreateTechUnlockedSitRep(const std::string& tech_name) {
     SitRepEntry sitrep(
         UserStringNop("SITREP_TECH_UNLOCKED"),
-        CurrentTurn() + 1,
+        CurrentTurn(),
         "icons/sitrep/tech_unlocked.png",
         UserStringNop("SITREP_TECH_UNLOCKED_LABEL"), true);
     sitrep.AddVariable(VarText::TECH_TAG,          tech_name);
@@ -112,7 +114,7 @@ SitRepEntry CreateTechUnlockedSitRep(const std::string& tech_name) {
 SitRepEntry CreateBuildingTypeUnlockedSitRep(const std::string& building_type_name) {
     SitRepEntry sitrep(
         UserStringNop("SITREP_BUILDING_TYPE_UNLOCKED"),
-        CurrentTurn() + 1,
+        CurrentTurn(),
         "icons/sitrep/building_type_unlocked.png",
         UserStringNop("SITREP_BUILDING_TYPE_UNLOCKED_LABEL"), true);
     sitrep.AddVariable(VarText::BUILDING_TYPE_TAG,  building_type_name);
@@ -122,7 +124,7 @@ SitRepEntry CreateBuildingTypeUnlockedSitRep(const std::string& building_type_na
 SitRepEntry CreateShipHullUnlockedSitRep(const std::string& ship_hull_name) {
     SitRepEntry sitrep(
         UserStringNop("SITREP_SHIP_HULL_UNLOCKED"),
-        CurrentTurn() + 1,
+        CurrentTurn(),
         "icons/sitrep/ship_hull_unlocked.png",
         UserStringNop("SITREP_SHIP_HULL_UNLOCKED_LABEL"), true);
     sitrep.AddVariable(VarText::SHIP_HULL_TAG,      ship_hull_name);
@@ -132,7 +134,7 @@ SitRepEntry CreateShipHullUnlockedSitRep(const std::string& ship_hull_name) {
 SitRepEntry CreateShipPartUnlockedSitRep(const std::string& ship_part_name) {
     SitRepEntry sitrep(
         UserStringNop("SITREP_SHIP_PART_UNLOCKED"),
-        CurrentTurn() + 1,
+        CurrentTurn(),
         "icons/sitrep/ship_part_unlocked.png",
         UserStringNop("SITREP_SHIP_PART_UNLOCKED_LABEL"), true);
     sitrep.AddVariable(VarText::SHIP_PART_TAG,      ship_part_name);
@@ -204,7 +206,7 @@ namespace {
 }
 
 SitRepEntry CreateCombatDamagedObjectSitRep(int object_id, int combat_system_id, int empire_id) {
-    auto obj = GetUniverseObject(object_id);
+    auto obj = Objects().get(object_id);
     if (!obj)
         return GenericCombatDamagedObjectSitrep(combat_system_id);
 
@@ -252,7 +254,7 @@ SitRepEntry CreateCombatDamagedObjectSitRep(int object_id, int combat_system_id,
 }
 
 SitRepEntry CreateCombatDestroyedObjectSitRep(int object_id, int combat_system_id, int empire_id) {
-    auto obj = GetEmpireKnownObject(object_id, empire_id);
+    auto obj = EmpireKnownObjects(empire_id).get(object_id);
     if (!obj) {
         DebugLogger() << "Object " << object_id << " does not exist!!!";
         return GenericCombatDestroyedObjectSitrep(combat_system_id);
@@ -368,13 +370,34 @@ SitRepEntry CreatePlanetOutpostedSitRep(int planet_id) {
     return sitrep;
 }
 
+SitRepEntry CreatePlanetGiftedSitRep(int planet_id, int empire_id) {
+    SitRepEntry sitrep(
+        UserStringNop("SITREP_PLANET_GIFTED"),
+        CurrentTurn() + 1,
+        "icons/sitrep/gift.png",
+        UserStringNop("SITREP_PLANET_GIFTED_LABEL"), true);
+    sitrep.AddVariable(VarText::PLANET_ID_TAG,  std::to_string(planet_id));
+    sitrep.AddVariable(VarText::EMPIRE_ID_TAG,  std::to_string(empire_id));
+    return sitrep;
+}
+
+SitRepEntry CreateFleetGiftedSitRep(int fleet_id, int empire_id) {
+    SitRepEntry sitrep(
+        UserStringNop("SITREP_FLEET_GIFTED"),
+        CurrentTurn() + 1,
+        "icons/sitrep/gift.png",
+        UserStringNop("SITREP_FLEET_GIFTED_LABEL"), true);
+    sitrep.AddVariable(VarText::FLEET_ID_TAG,   std::to_string(fleet_id));
+    sitrep.AddVariable(VarText::EMPIRE_ID_TAG,  std::to_string(empire_id));
+    return sitrep;
+}
+
 SitRepEntry CreateFleetArrivedAtDestinationSitRep(int system_id, int fleet_id, int recipient_empire_id) {
-    auto fleet = GetFleet(fleet_id);
+    auto fleet = Objects().get<Fleet>(fleet_id);
 
     //bool system_contains_recipient_empire_planets = false;
-    //if (const System* system = GetSystem(system_id)) {
-    //    for (int planet_id : system->FindObjectIDs<Planet>()) {
-    //        const Planet* planet = GetPlanet(planet_id);
+    //if (const System* system = Objects().get<System>(system_id)) {
+    //    for (const auto& planet : system->all<Planet>()) {
     //        if (!planet || planet->Unowned())
     //            continue;
     //        if (planet->OwnedBy(recipient_empire_id)) {
@@ -408,7 +431,7 @@ SitRepEntry CreateFleetArrivedAtDestinationSitRep(int system_id, int fleet_id, i
             sitrep.AddVariable(VarText::FLEET_ID_TAG,      std::to_string(fleet_id));
             int ship_id = *fleet->ShipIDs().begin();
             sitrep.AddVariable(VarText::SHIP_ID_TAG,       std::to_string(ship_id));
-            if (auto ship = GetShip(ship_id))
+            if (auto ship = Objects().get<Ship>(ship_id))
                 sitrep.AddVariable(VarText::DESIGN_ID_TAG, std::to_string(ship->DesignID()));
             return sitrep;
         } else {
@@ -444,7 +467,7 @@ SitRepEntry CreateFleetArrivedAtDestinationSitRep(int system_id, int fleet_id, i
             sitrep.AddVariable(VarText::EMPIRE_ID_TAG,     std::to_string(fleet->Owner()));
             int ship_id = *fleet->ShipIDs().begin();
             sitrep.AddVariable(VarText::SHIP_ID_TAG,       std::to_string(ship_id));
-            if (auto ship = GetShip(ship_id))
+            if (auto ship = Objects().get<Ship>(ship_id))
                 sitrep.AddVariable(VarText::DESIGN_ID_TAG, std::to_string(ship->DesignID()));
             return sitrep;
         } else {
@@ -471,7 +494,7 @@ SitRepEntry CreateFleetArrivedAtDestinationSitRep(int system_id, int fleet_id, i
             sitrep.AddVariable(VarText::EMPIRE_ID_TAG,     std::to_string(fleet->Owner()));
             int ship_id = *fleet->ShipIDs().begin();
             sitrep.AddVariable(VarText::SHIP_ID_TAG,       std::to_string(ship_id));
-            if (auto ship = GetShip(ship_id))
+            if (auto ship = Objects().get<Ship>(ship_id))
                 sitrep.AddVariable(VarText::DESIGN_ID_TAG, std::to_string(ship->DesignID()));
             return sitrep;
         } else {
